/* Generated automatically by the program `genattr-common'
   from the machine description file `md'.  */

#ifndef GCC_INSN_ATTR_COMMON_H
#define GCC_INSN_ATTR_COMMON_H

enum attr_got {GOT_UNSET, GOT_XGOT_HIGH, GOT_LOAD};
enum attr_move_type {MOVE_TYPE_UNKNOWN, MOVE_TYPE_LOAD, MOVE_TYPE_FPLOAD, MOVE_TYPE_STORE, MOVE_TYPE_FPSTORE, MOVE_TYPE_MTC, MOVE_TYPE_MFC, MOVE_TYPE_MOVE, MOVE_TYPE_FMOVE, MOVE_TYPE_CONST, MOVE_TYPE_LOGICAL, MOVE_TYPE_ARITH, MOVE_TYPE_ANDI, MOVE_TYPE_SHIFT_SHIFT, MOVE_TYPE_RDVLENB};
enum attr_mode {MODE_UNKNOWN, MODE_NONE, MODE_QI, MODE_HI, MODE_SI, MODE_DI, MODE_TI, MODE_HF, MODE_SF, MODE_DF, MODE_TF, MODE_VNX1BI, MODE_VNX2BI, MODE_VNX4BI, MODE_VNX8BI, MODE_VNX16BI, MODE_VNX32BI, MODE_VNX64BI, MODE_VNX1QI, MODE_VNX2QI, MODE_VNX4QI, MODE_VNX8QI, MODE_VNX16QI, MODE_VNX32QI, MODE_VNX64QI, MODE_VNX1HI, MODE_VNX2HI, MODE_VNX4HI, MODE_VNX8HI, MODE_VNX16HI, MODE_VNX32HI, MODE_VNX1SI, MODE_VNX2SI, MODE_VNX4SI, MODE_VNX8SI, MODE_VNX16SI, MODE_VNX1DI, MODE_VNX2DI, MODE_VNX4DI, MODE_VNX8DI, MODE_VNX1SF, MODE_VNX2SF, MODE_VNX4SF, MODE_VNX8SF, MODE_VNX16SF, MODE_VNX1DF, MODE_VNX2DF, MODE_VNX4DF, MODE_VNX8DF};
enum attr_dword_mode {DWORD_MODE_NO, DWORD_MODE_YES};
enum attr_ext {EXT_BASE, EXT_F, EXT_D, EXT_VECTOR};
enum attr_ext_enabled {EXT_ENABLED_NO, EXT_ENABLED_YES};
enum attr_enabled {ENABLED_NO, ENABLED_YES};
enum attr_type {TYPE_UNKNOWN, TYPE_BRANCH, TYPE_JUMP, TYPE_CALL, TYPE_LOAD, TYPE_FPLOAD, TYPE_STORE, TYPE_FPSTORE, TYPE_MTC, TYPE_MFC, TYPE_CONST, TYPE_ARITH, TYPE_LOGICAL, TYPE_SHIFT, TYPE_SLT, TYPE_IMUL, TYPE_IDIV, TYPE_MOVE, TYPE_FMOVE, TYPE_FADD, TYPE_FMUL, TYPE_FMADD, TYPE_FDIV, TYPE_FCMP, TYPE_FCVT, TYPE_FSQRT, TYPE_MULTI, TYPE_AUIPC, TYPE_SFB_ALU, TYPE_NOP, TYPE_GHOST, TYPE_BITMANIP, TYPE_ROTATE, TYPE_ATOMIC, TYPE_CONDMOVE, TYPE_CRYPTO, TYPE_RDVLENB, TYPE_RDVL, TYPE_VSETVL, TYPE_VLDE, TYPE_VSTE, TYPE_VLDM, TYPE_VSTM, TYPE_VLDS, TYPE_VSTS, TYPE_VLDUX, TYPE_VLDOX, TYPE_VSTUX, TYPE_VSTOX, TYPE_VLDFF, TYPE_VLDR, TYPE_VSTR, TYPE_VIALU, TYPE_VIWALU, TYPE_VEXT, TYPE_VICALU, TYPE_VSHIFT, TYPE_VNSHIFT, TYPE_VICMP, TYPE_VIMINMAX, TYPE_VIMUL, TYPE_VIDIV, TYPE_VIWMUL, TYPE_VIMULADD, TYPE_VIWMULADD, TYPE_VIMERGE, TYPE_VIMOV, TYPE_VSALU, TYPE_VAALU, TYPE_VSMUL, TYPE_VSSHIFT, TYPE_VNCLIP, TYPE_VFALU, TYPE_VFWALU, TYPE_VFMUL, TYPE_VFDIV, TYPE_VFWMUL, TYPE_VFMULADD, TYPE_VFWMULADD, TYPE_VFSQRT, TYPE_VFRECP, TYPE_VFCMP, TYPE_VFMINMAX, TYPE_VFSGNJ, TYPE_VFCLASS, TYPE_VFMERGE, TYPE_VFMOV, TYPE_VFCVTITOF, TYPE_VFCVTFTOI, TYPE_VFWCVTITOF, TYPE_VFWCVTFTOI, TYPE_VFWCVTFTOF, TYPE_VFNCVTITOF, TYPE_VFNCVTFTOI, TYPE_VFNCVTFTOF, TYPE_VIRED, TYPE_VIWRED, TYPE_VFREDU, TYPE_VFREDO, TYPE_VFWREDU, TYPE_VFWREDO, TYPE_VMALU, TYPE_VMPOP, TYPE_VMFFS, TYPE_VMSFS, TYPE_VMIOTA, TYPE_VMIDX, TYPE_VIMOVVX, TYPE_VIMOVXV, TYPE_VFMOVVF, TYPE_VFMOVFV, TYPE_VSLIDEUP, TYPE_VSLIDEDOWN, TYPE_VISLIDE1UP, TYPE_VISLIDE1DOWN, TYPE_VFSLIDE1UP, TYPE_VFSLIDE1DOWN, TYPE_VGATHER, TYPE_VCOMPRESS, TYPE_VMOV};
enum attr_cannot_copy {CANNOT_COPY_NO, CANNOT_COPY_YES};
enum attr_tune {TUNE_GENERIC, TUNE_SIFIVE_7};
enum attr_has_vtype_op {HAS_VTYPE_OP_FALSE, HAS_VTYPE_OP_TRUE};
enum attr_has_vl_op {HAS_VL_OP_FALSE, HAS_VL_OP_TRUE};
#define INSN_SCHEDULING
#define DELAY_SLOTS 0

#endif /* GCC_INSN_ATTR_COMMON_H */
