/* Generated automatically from machmode.def and config/riscv/riscv-modes.def
   by genmodes.  */

#include "config.h"
#include "system.h"
#include "coretypes.h"
#include "tm.h"
#include "real.h"

const char *const mode_name[NUM_MACHINE_MODES] =
{
  "VOID",
  "BLK",
  "CC",
  "BI",
  "QI",
  "HI",
  "SI",
  "DI",
  "TI",
  "QQ",
  "HQ",
  "SQ",
  "DQ",
  "TQ",
  "UQQ",
  "UHQ",
  "USQ",
  "UDQ",
  "UTQ",
  "HA",
  "SA",
  "DA",
  "TA",
  "UHA",
  "USA",
  "UDA",
  "UTA",
  "HF",
  "SF",
  "DF",
  "TF",
  "SD",
  "DD",
  "TD",
  "CQI",
  "CHI",
  "CSI",
  "CDI",
  "CTI",
  "HC",
  "SC",
  "DC",
  "TC",
  "VNx1BI",
  "VNx2BI",
  "VNx4BI",
  "VNx8BI",
  "VNx16BI",
  "VNx32BI",
  "VNx64BI",
  "VNx1QI",
  "VNx2QI",
  "VNx1HI",
  "VNx4QI",
  "VNx2HI",
  "VNx1SI",
  "VNx8QI",
  "VNx4HI",
  "VNx2SI",
  "VNx1DI",
  "VNx16QI",
  "VNx8HI",
  "VNx4SI",
  "VNx2DI",
  "VNx32QI",
  "VNx16HI",
  "VNx8SI",
  "VNx4DI",
  "VNx2TI",
  "VNx64QI",
  "VNx32HI",
  "VNx16SI",
  "VNx8DI",
  "VNx4TI",
  "VNx1HF",
  "VNx2HF",
  "VNx1SF",
  "VNx4HF",
  "VNx2SF",
  "VNx1DF",
  "VNx8HF",
  "VNx4SF",
  "VNx2DF",
  "VNx16HF",
  "VNx8SF",
  "VNx4DF",
  "VNx2TF",
  "VNx32HF",
  "VNx16SF",
  "VNx8DF",
  "VNx4TF",
};

const unsigned char mode_class[NUM_MACHINE_MODES] =
{
  MODE_RANDOM,             /* VOID */
  MODE_RANDOM,             /* BLK */
  MODE_CC,                 /* CC */
  MODE_INT,                /* BI */
  MODE_INT,                /* QI */
  MODE_INT,                /* HI */
  MODE_INT,                /* SI */
  MODE_INT,                /* DI */
  MODE_INT,                /* TI */
  MODE_FRACT,              /* QQ */
  MODE_FRACT,              /* HQ */
  MODE_FRACT,              /* SQ */
  MODE_FRACT,              /* DQ */
  MODE_FRACT,              /* TQ */
  MODE_UFRACT,             /* UQQ */
  MODE_UFRACT,             /* UHQ */
  MODE_UFRACT,             /* USQ */
  MODE_UFRACT,             /* UDQ */
  MODE_UFRACT,             /* UTQ */
  MODE_ACCUM,              /* HA */
  MODE_ACCUM,              /* SA */
  MODE_ACCUM,              /* DA */
  MODE_ACCUM,              /* TA */
  MODE_UACCUM,             /* UHA */
  MODE_UACCUM,             /* USA */
  MODE_UACCUM,             /* UDA */
  MODE_UACCUM,             /* UTA */
  MODE_FLOAT,              /* HF */
  MODE_FLOAT,              /* SF */
  MODE_FLOAT,              /* DF */
  MODE_FLOAT,              /* TF */
  MODE_DECIMAL_FLOAT,      /* SD */
  MODE_DECIMAL_FLOAT,      /* DD */
  MODE_DECIMAL_FLOAT,      /* TD */
  MODE_COMPLEX_INT,        /* CQI */
  MODE_COMPLEX_INT,        /* CHI */
  MODE_COMPLEX_INT,        /* CSI */
  MODE_COMPLEX_INT,        /* CDI */
  MODE_COMPLEX_INT,        /* CTI */
  MODE_COMPLEX_FLOAT,      /* HC */
  MODE_COMPLEX_FLOAT,      /* SC */
  MODE_COMPLEX_FLOAT,      /* DC */
  MODE_COMPLEX_FLOAT,      /* TC */
  MODE_VECTOR_BOOL,        /* VNx1BI */
  MODE_VECTOR_BOOL,        /* VNx2BI */
  MODE_VECTOR_BOOL,        /* VNx4BI */
  MODE_VECTOR_BOOL,        /* VNx8BI */
  MODE_VECTOR_BOOL,        /* VNx16BI */
  MODE_VECTOR_BOOL,        /* VNx32BI */
  MODE_VECTOR_BOOL,        /* VNx64BI */
  MODE_VECTOR_INT,         /* VNx1QI */
  MODE_VECTOR_INT,         /* VNx2QI */
  MODE_VECTOR_INT,         /* VNx1HI */
  MODE_VECTOR_INT,         /* VNx4QI */
  MODE_VECTOR_INT,         /* VNx2HI */
  MODE_VECTOR_INT,         /* VNx1SI */
  MODE_VECTOR_INT,         /* VNx8QI */
  MODE_VECTOR_INT,         /* VNx4HI */
  MODE_VECTOR_INT,         /* VNx2SI */
  MODE_VECTOR_INT,         /* VNx1DI */
  MODE_VECTOR_INT,         /* VNx16QI */
  MODE_VECTOR_INT,         /* VNx8HI */
  MODE_VECTOR_INT,         /* VNx4SI */
  MODE_VECTOR_INT,         /* VNx2DI */
  MODE_VECTOR_INT,         /* VNx32QI */
  MODE_VECTOR_INT,         /* VNx16HI */
  MODE_VECTOR_INT,         /* VNx8SI */
  MODE_VECTOR_INT,         /* VNx4DI */
  MODE_VECTOR_INT,         /* VNx2TI */
  MODE_VECTOR_INT,         /* VNx64QI */
  MODE_VECTOR_INT,         /* VNx32HI */
  MODE_VECTOR_INT,         /* VNx16SI */
  MODE_VECTOR_INT,         /* VNx8DI */
  MODE_VECTOR_INT,         /* VNx4TI */
  MODE_VECTOR_FLOAT,       /* VNx1HF */
  MODE_VECTOR_FLOAT,       /* VNx2HF */
  MODE_VECTOR_FLOAT,       /* VNx1SF */
  MODE_VECTOR_FLOAT,       /* VNx4HF */
  MODE_VECTOR_FLOAT,       /* VNx2SF */
  MODE_VECTOR_FLOAT,       /* VNx1DF */
  MODE_VECTOR_FLOAT,       /* VNx8HF */
  MODE_VECTOR_FLOAT,       /* VNx4SF */
  MODE_VECTOR_FLOAT,       /* VNx2DF */
  MODE_VECTOR_FLOAT,       /* VNx16HF */
  MODE_VECTOR_FLOAT,       /* VNx8SF */
  MODE_VECTOR_FLOAT,       /* VNx4DF */
  MODE_VECTOR_FLOAT,       /* VNx2TF */
  MODE_VECTOR_FLOAT,       /* VNx32HF */
  MODE_VECTOR_FLOAT,       /* VNx16SF */
  MODE_VECTOR_FLOAT,       /* VNx8DF */
  MODE_VECTOR_FLOAT,       /* VNx4TF */
};

poly_uint16_pod mode_precision[NUM_MACHINE_MODES] = 
{
  { 0, 0 },                /* VOID */
  { 0, 0 },                /* BLK */
  { 4 * BITS_PER_UNIT, 0 },/* CC */
  { 1, 0 },                /* BI */
  { 1 * BITS_PER_UNIT, 0 },/* QI */
  { 2 * BITS_PER_UNIT, 0 },/* HI */
  { 4 * BITS_PER_UNIT, 0 },/* SI */
  { 8 * BITS_PER_UNIT, 0 },/* DI */
  { 16 * BITS_PER_UNIT, 0 }, /* TI */
  { 1 * BITS_PER_UNIT, 0 },/* QQ */
  { 2 * BITS_PER_UNIT, 0 },/* HQ */
  { 4 * BITS_PER_UNIT, 0 },/* SQ */
  { 8 * BITS_PER_UNIT, 0 },/* DQ */
  { 16 * BITS_PER_UNIT, 0 }, /* TQ */
  { 1 * BITS_PER_UNIT, 0 },/* UQQ */
  { 2 * BITS_PER_UNIT, 0 },/* UHQ */
  { 4 * BITS_PER_UNIT, 0 },/* USQ */
  { 8 * BITS_PER_UNIT, 0 },/* UDQ */
  { 16 * BITS_PER_UNIT, 0 }, /* UTQ */
  { 2 * BITS_PER_UNIT, 0 },/* HA */
  { 4 * BITS_PER_UNIT, 0 },/* SA */
  { 8 * BITS_PER_UNIT, 0 },/* DA */
  { 16 * BITS_PER_UNIT, 0 }, /* TA */
  { 2 * BITS_PER_UNIT, 0 },/* UHA */
  { 4 * BITS_PER_UNIT, 0 },/* USA */
  { 8 * BITS_PER_UNIT, 0 },/* UDA */
  { 16 * BITS_PER_UNIT, 0 }, /* UTA */
  { 2 * BITS_PER_UNIT, 0 },/* HF */
  { 4 * BITS_PER_UNIT, 0 },/* SF */
  { 8 * BITS_PER_UNIT, 0 },/* DF */
  { 16 * BITS_PER_UNIT, 0 }, /* TF */
  { 4 * BITS_PER_UNIT, 0 },/* SD */
  { 8 * BITS_PER_UNIT, 0 },/* DD */
  { 16 * BITS_PER_UNIT, 0 }, /* TD */
  { 2 * BITS_PER_UNIT, 0 },/* CQI */
  { 4 * BITS_PER_UNIT, 0 },/* CHI */
  { 8 * BITS_PER_UNIT, 0 },/* CSI */
  { 16 * BITS_PER_UNIT, 0 }, /* CDI */
  { 32 * BITS_PER_UNIT, 0 }, /* CTI */
  { 4 * BITS_PER_UNIT, 0 },/* HC */
  { 8 * BITS_PER_UNIT, 0 },/* SC */
  { 16 * BITS_PER_UNIT, 0 }, /* DC */
  { 32 * BITS_PER_UNIT, 0 }, /* TC */
  { 1 * BITS_PER_UNIT, 0 },/* VNx1BI */
  { 1 * BITS_PER_UNIT, 0 },/* VNx2BI */
  { 1 * BITS_PER_UNIT, 0 },/* VNx4BI */
  { 1 * BITS_PER_UNIT, 0 },/* VNx8BI */
  { 2 * BITS_PER_UNIT, 0 },/* VNx16BI */
  { 4 * BITS_PER_UNIT, 0 },/* VNx32BI */
  { 8 * BITS_PER_UNIT, 0 },/* VNx64BI */
  { 1 * BITS_PER_UNIT, 0 },/* VNx1QI */
  { 2 * BITS_PER_UNIT, 0 },/* VNx2QI */
  { 2 * BITS_PER_UNIT, 0 },/* VNx1HI */
  { 4 * BITS_PER_UNIT, 0 },/* VNx4QI */
  { 4 * BITS_PER_UNIT, 0 },/* VNx2HI */
  { 4 * BITS_PER_UNIT, 0 },/* VNx1SI */
  { 8 * BITS_PER_UNIT, 0 },/* VNx8QI */
  { 8 * BITS_PER_UNIT, 0 },/* VNx4HI */
  { 8 * BITS_PER_UNIT, 0 },/* VNx2SI */
  { 8 * BITS_PER_UNIT, 0 },/* VNx1DI */
  { 16 * BITS_PER_UNIT, 0 }, /* VNx16QI */
  { 16 * BITS_PER_UNIT, 0 }, /* VNx8HI */
  { 16 * BITS_PER_UNIT, 0 }, /* VNx4SI */
  { 16 * BITS_PER_UNIT, 0 }, /* VNx2DI */
  { 32 * BITS_PER_UNIT, 0 }, /* VNx32QI */
  { 32 * BITS_PER_UNIT, 0 }, /* VNx16HI */
  { 32 * BITS_PER_UNIT, 0 }, /* VNx8SI */
  { 32 * BITS_PER_UNIT, 0 }, /* VNx4DI */
  { 32 * BITS_PER_UNIT, 0 }, /* VNx2TI */
  { 64 * BITS_PER_UNIT, 0 }, /* VNx64QI */
  { 64 * BITS_PER_UNIT, 0 }, /* VNx32HI */
  { 64 * BITS_PER_UNIT, 0 }, /* VNx16SI */
  { 64 * BITS_PER_UNIT, 0 }, /* VNx8DI */
  { 64 * BITS_PER_UNIT, 0 }, /* VNx4TI */
  { 2 * BITS_PER_UNIT, 0 },/* VNx1HF */
  { 4 * BITS_PER_UNIT, 0 },/* VNx2HF */
  { 4 * BITS_PER_UNIT, 0 },/* VNx1SF */
  { 8 * BITS_PER_UNIT, 0 },/* VNx4HF */
  { 8 * BITS_PER_UNIT, 0 },/* VNx2SF */
  { 8 * BITS_PER_UNIT, 0 },/* VNx1DF */
  { 16 * BITS_PER_UNIT, 0 }, /* VNx8HF */
  { 16 * BITS_PER_UNIT, 0 }, /* VNx4SF */
  { 16 * BITS_PER_UNIT, 0 }, /* VNx2DF */
  { 32 * BITS_PER_UNIT, 0 }, /* VNx16HF */
  { 32 * BITS_PER_UNIT, 0 }, /* VNx8SF */
  { 32 * BITS_PER_UNIT, 0 }, /* VNx4DF */
  { 32 * BITS_PER_UNIT, 0 }, /* VNx2TF */
  { 64 * BITS_PER_UNIT, 0 }, /* VNx32HF */
  { 64 * BITS_PER_UNIT, 0 }, /* VNx16SF */
  { 64 * BITS_PER_UNIT, 0 }, /* VNx8DF */
  { 64 * BITS_PER_UNIT, 0 }, /* VNx4TF */
};

poly_uint16_pod mode_size[NUM_MACHINE_MODES] = 
{
  { 0, 0 },                /* VOID */
  { 0, 0 },                /* BLK */
  { 4, 0 },                /* CC */
  { 1, 0 },                /* BI */
  { 1, 0 },                /* QI */
  { 2, 0 },                /* HI */
  { 4, 0 },                /* SI */
  { 8, 0 },                /* DI */
  { 16, 0 },               /* TI */
  { 1, 0 },                /* QQ */
  { 2, 0 },                /* HQ */
  { 4, 0 },                /* SQ */
  { 8, 0 },                /* DQ */
  { 16, 0 },               /* TQ */
  { 1, 0 },                /* UQQ */
  { 2, 0 },                /* UHQ */
  { 4, 0 },                /* USQ */
  { 8, 0 },                /* UDQ */
  { 16, 0 },               /* UTQ */
  { 2, 0 },                /* HA */
  { 4, 0 },                /* SA */
  { 8, 0 },                /* DA */
  { 16, 0 },               /* TA */
  { 2, 0 },                /* UHA */
  { 4, 0 },                /* USA */
  { 8, 0 },                /* UDA */
  { 16, 0 },               /* UTA */
  { 2, 0 },                /* HF */
  { 4, 0 },                /* SF */
  { 8, 0 },                /* DF */
  { 16, 0 },               /* TF */
  { 4, 0 },                /* SD */
  { 8, 0 },                /* DD */
  { 16, 0 },               /* TD */
  { 2, 0 },                /* CQI */
  { 4, 0 },                /* CHI */
  { 8, 0 },                /* CSI */
  { 16, 0 },               /* CDI */
  { 32, 0 },               /* CTI */
  { 4, 0 },                /* HC */
  { 8, 0 },                /* SC */
  { 16, 0 },               /* DC */
  { 32, 0 },               /* TC */
  { 1, 0 },                /* VNx1BI */
  { 1, 0 },                /* VNx2BI */
  { 1, 0 },                /* VNx4BI */
  { 1, 0 },                /* VNx8BI */
  { 2, 0 },                /* VNx16BI */
  { 4, 0 },                /* VNx32BI */
  { 8, 0 },                /* VNx64BI */
  { 1, 0 },                /* VNx1QI */
  { 2, 0 },                /* VNx2QI */
  { 2, 0 },                /* VNx1HI */
  { 4, 0 },                /* VNx4QI */
  { 4, 0 },                /* VNx2HI */
  { 4, 0 },                /* VNx1SI */
  { 8, 0 },                /* VNx8QI */
  { 8, 0 },                /* VNx4HI */
  { 8, 0 },                /* VNx2SI */
  { 8, 0 },                /* VNx1DI */
  { 16, 0 },               /* VNx16QI */
  { 16, 0 },               /* VNx8HI */
  { 16, 0 },               /* VNx4SI */
  { 16, 0 },               /* VNx2DI */
  { 32, 0 },               /* VNx32QI */
  { 32, 0 },               /* VNx16HI */
  { 32, 0 },               /* VNx8SI */
  { 32, 0 },               /* VNx4DI */
  { 32, 0 },               /* VNx2TI */
  { 64, 0 },               /* VNx64QI */
  { 64, 0 },               /* VNx32HI */
  { 64, 0 },               /* VNx16SI */
  { 64, 0 },               /* VNx8DI */
  { 64, 0 },               /* VNx4TI */
  { 2, 0 },                /* VNx1HF */
  { 4, 0 },                /* VNx2HF */
  { 4, 0 },                /* VNx1SF */
  { 8, 0 },                /* VNx4HF */
  { 8, 0 },                /* VNx2SF */
  { 8, 0 },                /* VNx1DF */
  { 16, 0 },               /* VNx8HF */
  { 16, 0 },               /* VNx4SF */
  { 16, 0 },               /* VNx2DF */
  { 32, 0 },               /* VNx16HF */
  { 32, 0 },               /* VNx8SF */
  { 32, 0 },               /* VNx4DF */
  { 32, 0 },               /* VNx2TF */
  { 64, 0 },               /* VNx32HF */
  { 64, 0 },               /* VNx16SF */
  { 64, 0 },               /* VNx8DF */
  { 64, 0 },               /* VNx4TF */
};

poly_uint16_pod mode_nunits[NUM_MACHINE_MODES] = 
{
  { 0, 0 },                /* VOID */
  { 0, 0 },                /* BLK */
  { 1, 0 },                /* CC */
  { 1, 0 },                /* BI */
  { 1, 0 },                /* QI */
  { 1, 0 },                /* HI */
  { 1, 0 },                /* SI */
  { 1, 0 },                /* DI */
  { 1, 0 },                /* TI */
  { 1, 0 },                /* QQ */
  { 1, 0 },                /* HQ */
  { 1, 0 },                /* SQ */
  { 1, 0 },                /* DQ */
  { 1, 0 },                /* TQ */
  { 1, 0 },                /* UQQ */
  { 1, 0 },                /* UHQ */
  { 1, 0 },                /* USQ */
  { 1, 0 },                /* UDQ */
  { 1, 0 },                /* UTQ */
  { 1, 0 },                /* HA */
  { 1, 0 },                /* SA */
  { 1, 0 },                /* DA */
  { 1, 0 },                /* TA */
  { 1, 0 },                /* UHA */
  { 1, 0 },                /* USA */
  { 1, 0 },                /* UDA */
  { 1, 0 },                /* UTA */
  { 1, 0 },                /* HF */
  { 1, 0 },                /* SF */
  { 1, 0 },                /* DF */
  { 1, 0 },                /* TF */
  { 1, 0 },                /* SD */
  { 1, 0 },                /* DD */
  { 1, 0 },                /* TD */
  { 2, 0 },                /* CQI */
  { 2, 0 },                /* CHI */
  { 2, 0 },                /* CSI */
  { 2, 0 },                /* CDI */
  { 2, 0 },                /* CTI */
  { 2, 0 },                /* HC */
  { 2, 0 },                /* SC */
  { 2, 0 },                /* DC */
  { 2, 0 },                /* TC */
  { 1, 0 },                /* VNx1BI */
  { 2, 0 },                /* VNx2BI */
  { 4, 0 },                /* VNx4BI */
  { 8, 0 },                /* VNx8BI */
  { 16, 0 },               /* VNx16BI */
  { 32, 0 },               /* VNx32BI */
  { 64, 0 },               /* VNx64BI */
  { 1, 0 },                /* VNx1QI */
  { 2, 0 },                /* VNx2QI */
  { 1, 0 },                /* VNx1HI */
  { 4, 0 },                /* VNx4QI */
  { 2, 0 },                /* VNx2HI */
  { 1, 0 },                /* VNx1SI */
  { 8, 0 },                /* VNx8QI */
  { 4, 0 },                /* VNx4HI */
  { 2, 0 },                /* VNx2SI */
  { 1, 0 },                /* VNx1DI */
  { 16, 0 },               /* VNx16QI */
  { 8, 0 },                /* VNx8HI */
  { 4, 0 },                /* VNx4SI */
  { 2, 0 },                /* VNx2DI */
  { 32, 0 },               /* VNx32QI */
  { 16, 0 },               /* VNx16HI */
  { 8, 0 },                /* VNx8SI */
  { 4, 0 },                /* VNx4DI */
  { 2, 0 },                /* VNx2TI */
  { 64, 0 },               /* VNx64QI */
  { 32, 0 },               /* VNx32HI */
  { 16, 0 },               /* VNx16SI */
  { 8, 0 },                /* VNx8DI */
  { 4, 0 },                /* VNx4TI */
  { 1, 0 },                /* VNx1HF */
  { 2, 0 },                /* VNx2HF */
  { 1, 0 },                /* VNx1SF */
  { 4, 0 },                /* VNx4HF */
  { 2, 0 },                /* VNx2SF */
  { 1, 0 },                /* VNx1DF */
  { 8, 0 },                /* VNx8HF */
  { 4, 0 },                /* VNx4SF */
  { 2, 0 },                /* VNx2DF */
  { 16, 0 },               /* VNx16HF */
  { 8, 0 },                /* VNx8SF */
  { 4, 0 },                /* VNx4DF */
  { 2, 0 },                /* VNx2TF */
  { 32, 0 },               /* VNx32HF */
  { 16, 0 },               /* VNx16SF */
  { 8, 0 },                /* VNx8DF */
  { 4, 0 },                /* VNx4TF */
};

const unsigned char mode_next[NUM_MACHINE_MODES] =
{
  E_VOIDmode,              /* VOID */
  E_VOIDmode,              /* BLK */
  E_VOIDmode,              /* CC */
  E_QImode,                /* BI */
  E_HImode,                /* QI */
  E_SImode,                /* HI */
  E_DImode,                /* SI */
  E_TImode,                /* DI */
  E_VOIDmode,              /* TI */
  E_HQmode,                /* QQ */
  E_SQmode,                /* HQ */
  E_DQmode,                /* SQ */
  E_TQmode,                /* DQ */
  E_VOIDmode,              /* TQ */
  E_UHQmode,               /* UQQ */
  E_USQmode,               /* UHQ */
  E_UDQmode,               /* USQ */
  E_UTQmode,               /* UDQ */
  E_VOIDmode,              /* UTQ */
  E_SAmode,                /* HA */
  E_DAmode,                /* SA */
  E_TAmode,                /* DA */
  E_VOIDmode,              /* TA */
  E_USAmode,               /* UHA */
  E_UDAmode,               /* USA */
  E_UTAmode,               /* UDA */
  E_VOIDmode,              /* UTA */
  E_SFmode,                /* HF */
  E_DFmode,                /* SF */
  E_TFmode,                /* DF */
  E_VOIDmode,              /* TF */
  E_DDmode,                /* SD */
  E_TDmode,                /* DD */
  E_VOIDmode,              /* TD */
  E_CHImode,               /* CQI */
  E_CSImode,               /* CHI */
  E_CDImode,               /* CSI */
  E_CTImode,               /* CDI */
  E_VOIDmode,              /* CTI */
  E_SCmode,                /* HC */
  E_DCmode,                /* SC */
  E_TCmode,                /* DC */
  E_VOIDmode,              /* TC */
  E_VNx2BImode,            /* VNx1BI */
  E_VNx4BImode,            /* VNx2BI */
  E_VNx8BImode,            /* VNx4BI */
  E_VNx16BImode,           /* VNx8BI */
  E_VNx32BImode,           /* VNx16BI */
  E_VNx64BImode,           /* VNx32BI */
  E_VOIDmode,              /* VNx64BI */
  E_VNx2QImode,            /* VNx1QI */
  E_VNx1HImode,            /* VNx2QI */
  E_VNx4QImode,            /* VNx1HI */
  E_VNx2HImode,            /* VNx4QI */
  E_VNx1SImode,            /* VNx2HI */
  E_VNx8QImode,            /* VNx1SI */
  E_VNx4HImode,            /* VNx8QI */
  E_VNx2SImode,            /* VNx4HI */
  E_VNx1DImode,            /* VNx2SI */
  E_VNx16QImode,           /* VNx1DI */
  E_VNx8HImode,            /* VNx16QI */
  E_VNx4SImode,            /* VNx8HI */
  E_VNx2DImode,            /* VNx4SI */
  E_VNx32QImode,           /* VNx2DI */
  E_VNx16HImode,           /* VNx32QI */
  E_VNx8SImode,            /* VNx16HI */
  E_VNx4DImode,            /* VNx8SI */
  E_VNx2TImode,            /* VNx4DI */
  E_VNx64QImode,           /* VNx2TI */
  E_VNx32HImode,           /* VNx64QI */
  E_VNx16SImode,           /* VNx32HI */
  E_VNx8DImode,            /* VNx16SI */
  E_VNx4TImode,            /* VNx8DI */
  E_VOIDmode,              /* VNx4TI */
  E_VNx2HFmode,            /* VNx1HF */
  E_VNx1SFmode,            /* VNx2HF */
  E_VNx4HFmode,            /* VNx1SF */
  E_VNx2SFmode,            /* VNx4HF */
  E_VNx1DFmode,            /* VNx2SF */
  E_VNx8HFmode,            /* VNx1DF */
  E_VNx4SFmode,            /* VNx8HF */
  E_VNx2DFmode,            /* VNx4SF */
  E_VNx16HFmode,           /* VNx2DF */
  E_VNx8SFmode,            /* VNx16HF */
  E_VNx4DFmode,            /* VNx8SF */
  E_VNx2TFmode,            /* VNx4DF */
  E_VNx32HFmode,           /* VNx2TF */
  E_VNx16SFmode,           /* VNx32HF */
  E_VNx8DFmode,            /* VNx16SF */
  E_VNx4TFmode,            /* VNx8DF */
  E_VOIDmode,              /* VNx4TF */
};

const unsigned char mode_wider[NUM_MACHINE_MODES] =
{
  E_VOIDmode,              /* VOID */
  E_VOIDmode,              /* BLK */
  E_VOIDmode,              /* CC */
  E_QImode,                /* BI */
  E_HImode,                /* QI */
  E_SImode,                /* HI */
  E_DImode,                /* SI */
  E_TImode,                /* DI */
  E_VOIDmode,              /* TI */
  E_HQmode,                /* QQ */
  E_SQmode,                /* HQ */
  E_DQmode,                /* SQ */
  E_TQmode,                /* DQ */
  E_VOIDmode,              /* TQ */
  E_UHQmode,               /* UQQ */
  E_USQmode,               /* UHQ */
  E_UDQmode,               /* USQ */
  E_UTQmode,               /* UDQ */
  E_VOIDmode,              /* UTQ */
  E_SAmode,                /* HA */
  E_DAmode,                /* SA */
  E_TAmode,                /* DA */
  E_VOIDmode,              /* TA */
  E_USAmode,               /* UHA */
  E_UDAmode,               /* USA */
  E_UTAmode,               /* UDA */
  E_VOIDmode,              /* UTA */
  E_SFmode,                /* HF */
  E_DFmode,                /* SF */
  E_TFmode,                /* DF */
  E_VOIDmode,              /* TF */
  E_DDmode,                /* SD */
  E_TDmode,                /* DD */
  E_VOIDmode,              /* TD */
  E_VOIDmode,              /* CQI */
  E_VOIDmode,              /* CHI */
  E_VOIDmode,              /* CSI */
  E_VOIDmode,              /* CDI */
  E_VOIDmode,              /* CTI */
  E_SCmode,                /* HC */
  E_DCmode,                /* SC */
  E_TCmode,                /* DC */
  E_VOIDmode,              /* TC */
  E_VOIDmode,              /* VNx1BI */
  E_VOIDmode,              /* VNx2BI */
  E_VOIDmode,              /* VNx4BI */
  E_VOIDmode,              /* VNx8BI */
  E_VOIDmode,              /* VNx16BI */
  E_VOIDmode,              /* VNx32BI */
  E_VOIDmode,              /* VNx64BI */
  E_VOIDmode,              /* VNx1QI */
  E_VOIDmode,              /* VNx2QI */
  E_VOIDmode,              /* VNx1HI */
  E_VOIDmode,              /* VNx4QI */
  E_VOIDmode,              /* VNx2HI */
  E_VOIDmode,              /* VNx1SI */
  E_VOIDmode,              /* VNx8QI */
  E_VOIDmode,              /* VNx4HI */
  E_VOIDmode,              /* VNx2SI */
  E_VOIDmode,              /* VNx1DI */
  E_VOIDmode,              /* VNx16QI */
  E_VOIDmode,              /* VNx8HI */
  E_VOIDmode,              /* VNx4SI */
  E_VOIDmode,              /* VNx2DI */
  E_VOIDmode,              /* VNx32QI */
  E_VOIDmode,              /* VNx16HI */
  E_VOIDmode,              /* VNx8SI */
  E_VOIDmode,              /* VNx4DI */
  E_VOIDmode,              /* VNx2TI */
  E_VOIDmode,              /* VNx64QI */
  E_VOIDmode,              /* VNx32HI */
  E_VOIDmode,              /* VNx16SI */
  E_VOIDmode,              /* VNx8DI */
  E_VOIDmode,              /* VNx4TI */
  E_VOIDmode,              /* VNx1HF */
  E_VOIDmode,              /* VNx2HF */
  E_VOIDmode,              /* VNx1SF */
  E_VOIDmode,              /* VNx4HF */
  E_VOIDmode,              /* VNx2SF */
  E_VOIDmode,              /* VNx1DF */
  E_VOIDmode,              /* VNx8HF */
  E_VOIDmode,              /* VNx4SF */
  E_VOIDmode,              /* VNx2DF */
  E_VOIDmode,              /* VNx16HF */
  E_VOIDmode,              /* VNx8SF */
  E_VOIDmode,              /* VNx4DF */
  E_VOIDmode,              /* VNx2TF */
  E_VOIDmode,              /* VNx32HF */
  E_VOIDmode,              /* VNx16SF */
  E_VOIDmode,              /* VNx8DF */
  E_VOIDmode,              /* VNx4TF */
};

const unsigned char mode_2xwider[NUM_MACHINE_MODES] =
{
  E_VOIDmode,              /* VOID */
  E_BLKmode,               /* BLK */
  E_VOIDmode,              /* CC */
  E_VOIDmode,              /* BI */
  E_HImode,                /* QI */
  E_SImode,                /* HI */
  E_DImode,                /* SI */
  E_TImode,                /* DI */
  E_VOIDmode,              /* TI */
  E_HQmode,                /* QQ */
  E_SQmode,                /* HQ */
  E_DQmode,                /* SQ */
  E_TQmode,                /* DQ */
  E_VOIDmode,              /* TQ */
  E_UHQmode,               /* UQQ */
  E_USQmode,               /* UHQ */
  E_UDQmode,               /* USQ */
  E_UTQmode,               /* UDQ */
  E_VOIDmode,              /* UTQ */
  E_SAmode,                /* HA */
  E_DAmode,                /* SA */
  E_TAmode,                /* DA */
  E_VOIDmode,              /* TA */
  E_USAmode,               /* UHA */
  E_UDAmode,               /* USA */
  E_UTAmode,               /* UDA */
  E_VOIDmode,              /* UTA */
  E_SFmode,                /* HF */
  E_DFmode,                /* SF */
  E_TFmode,                /* DF */
  E_VOIDmode,              /* TF */
  E_DDmode,                /* SD */
  E_TDmode,                /* DD */
  E_VOIDmode,              /* TD */
  E_CHImode,               /* CQI */
  E_CSImode,               /* CHI */
  E_CDImode,               /* CSI */
  E_CTImode,               /* CDI */
  E_VOIDmode,              /* CTI */
  E_SCmode,                /* HC */
  E_DCmode,                /* SC */
  E_TCmode,                /* DC */
  E_VOIDmode,              /* TC */
  E_VOIDmode,              /* VNx1BI */
  E_VOIDmode,              /* VNx2BI */
  E_VOIDmode,              /* VNx4BI */
  E_VNx16BImode,           /* VNx8BI */
  E_VNx32BImode,           /* VNx16BI */
  E_VNx64BImode,           /* VNx32BI */
  E_VOIDmode,              /* VNx64BI */
  E_VNx2QImode,            /* VNx1QI */
  E_VNx4QImode,            /* VNx2QI */
  E_VNx2HImode,            /* VNx1HI */
  E_VNx8QImode,            /* VNx4QI */
  E_VNx4HImode,            /* VNx2HI */
  E_VNx2SImode,            /* VNx1SI */
  E_VNx16QImode,           /* VNx8QI */
  E_VNx8HImode,            /* VNx4HI */
  E_VNx4SImode,            /* VNx2SI */
  E_VNx2DImode,            /* VNx1DI */
  E_VNx32QImode,           /* VNx16QI */
  E_VNx16HImode,           /* VNx8HI */
  E_VNx8SImode,            /* VNx4SI */
  E_VNx4DImode,            /* VNx2DI */
  E_VNx64QImode,           /* VNx32QI */
  E_VNx32HImode,           /* VNx16HI */
  E_VNx16SImode,           /* VNx8SI */
  E_VNx8DImode,            /* VNx4DI */
  E_VNx4TImode,            /* VNx2TI */
  E_VOIDmode,              /* VNx64QI */
  E_VOIDmode,              /* VNx32HI */
  E_VOIDmode,              /* VNx16SI */
  E_VOIDmode,              /* VNx8DI */
  E_VOIDmode,              /* VNx4TI */
  E_VNx2HFmode,            /* VNx1HF */
  E_VNx4HFmode,            /* VNx2HF */
  E_VNx2SFmode,            /* VNx1SF */
  E_VNx8HFmode,            /* VNx4HF */
  E_VNx4SFmode,            /* VNx2SF */
  E_VNx2DFmode,            /* VNx1DF */
  E_VNx16HFmode,           /* VNx8HF */
  E_VNx8SFmode,            /* VNx4SF */
  E_VNx4DFmode,            /* VNx2DF */
  E_VNx32HFmode,           /* VNx16HF */
  E_VNx16SFmode,           /* VNx8SF */
  E_VNx8DFmode,            /* VNx4DF */
  E_VNx4TFmode,            /* VNx2TF */
  E_VOIDmode,              /* VNx32HF */
  E_VOIDmode,              /* VNx16SF */
  E_VOIDmode,              /* VNx8DF */
  E_VOIDmode,              /* VNx4TF */
};

const unsigned char mode_complex[NUM_MACHINE_MODES] =
{
  E_VOIDmode,              /* VOID */
  E_VOIDmode,              /* BLK */
  E_VOIDmode,              /* CC */
  E_VOIDmode,              /* BI */
  E_CQImode,               /* QI */
  E_CHImode,               /* HI */
  E_CSImode,               /* SI */
  E_CDImode,               /* DI */
  E_CTImode,               /* TI */
  E_VOIDmode,              /* QQ */
  E_VOIDmode,              /* HQ */
  E_VOIDmode,              /* SQ */
  E_VOIDmode,              /* DQ */
  E_VOIDmode,              /* TQ */
  E_VOIDmode,              /* UQQ */
  E_VOIDmode,              /* UHQ */
  E_VOIDmode,              /* USQ */
  E_VOIDmode,              /* UDQ */
  E_VOIDmode,              /* UTQ */
  E_VOIDmode,              /* HA */
  E_VOIDmode,              /* SA */
  E_VOIDmode,              /* DA */
  E_VOIDmode,              /* TA */
  E_VOIDmode,              /* UHA */
  E_VOIDmode,              /* USA */
  E_VOIDmode,              /* UDA */
  E_VOIDmode,              /* UTA */
  E_HCmode,                /* HF */
  E_SCmode,                /* SF */
  E_DCmode,                /* DF */
  E_TCmode,                /* TF */
  E_VOIDmode,              /* SD */
  E_VOIDmode,              /* DD */
  E_VOIDmode,              /* TD */
  E_VOIDmode,              /* CQI */
  E_VOIDmode,              /* CHI */
  E_VOIDmode,              /* CSI */
  E_VOIDmode,              /* CDI */
  E_VOIDmode,              /* CTI */
  E_VOIDmode,              /* HC */
  E_VOIDmode,              /* SC */
  E_VOIDmode,              /* DC */
  E_VOIDmode,              /* TC */
  E_VOIDmode,              /* VNx1BI */
  E_VOIDmode,              /* VNx2BI */
  E_VOIDmode,              /* VNx4BI */
  E_VOIDmode,              /* VNx8BI */
  E_VOIDmode,              /* VNx16BI */
  E_VOIDmode,              /* VNx32BI */
  E_VOIDmode,              /* VNx64BI */
  E_VOIDmode,              /* VNx1QI */
  E_VOIDmode,              /* VNx2QI */
  E_VOIDmode,              /* VNx1HI */
  E_VOIDmode,              /* VNx4QI */
  E_VOIDmode,              /* VNx2HI */
  E_VOIDmode,              /* VNx1SI */
  E_VOIDmode,              /* VNx8QI */
  E_VOIDmode,              /* VNx4HI */
  E_VOIDmode,              /* VNx2SI */
  E_VOIDmode,              /* VNx1DI */
  E_VOIDmode,              /* VNx16QI */
  E_VOIDmode,              /* VNx8HI */
  E_VOIDmode,              /* VNx4SI */
  E_VOIDmode,              /* VNx2DI */
  E_VOIDmode,              /* VNx32QI */
  E_VOIDmode,              /* VNx16HI */
  E_VOIDmode,              /* VNx8SI */
  E_VOIDmode,              /* VNx4DI */
  E_VOIDmode,              /* VNx2TI */
  E_VOIDmode,              /* VNx64QI */
  E_VOIDmode,              /* VNx32HI */
  E_VOIDmode,              /* VNx16SI */
  E_VOIDmode,              /* VNx8DI */
  E_VOIDmode,              /* VNx4TI */
  E_VOIDmode,              /* VNx1HF */
  E_VOIDmode,              /* VNx2HF */
  E_VOIDmode,              /* VNx1SF */
  E_VOIDmode,              /* VNx4HF */
  E_VOIDmode,              /* VNx2SF */
  E_VOIDmode,              /* VNx1DF */
  E_VOIDmode,              /* VNx8HF */
  E_VOIDmode,              /* VNx4SF */
  E_VOIDmode,              /* VNx2DF */
  E_VOIDmode,              /* VNx16HF */
  E_VOIDmode,              /* VNx8SF */
  E_VOIDmode,              /* VNx4DF */
  E_VOIDmode,              /* VNx2TF */
  E_VOIDmode,              /* VNx32HF */
  E_VOIDmode,              /* VNx16SF */
  E_VOIDmode,              /* VNx8DF */
  E_VOIDmode,              /* VNx4TF */
};

unsigned HOST_WIDE_INT mode_mask_array[NUM_MACHINE_MODES] = 
{
#define MODE_MASK(m)                          \
  ((m) >= HOST_BITS_PER_WIDE_INT)             \
   ? HOST_WIDE_INT_M1U                        \
   : (HOST_WIDE_INT_1U << (m)) - 1

  MODE_MASK (0),           /* VOID */
  MODE_MASK (0),           /* BLK */
  MODE_MASK (4*BITS_PER_UNIT),   /* CC */
  MODE_MASK (1),           /* BI */
  MODE_MASK (1*BITS_PER_UNIT),   /* QI */
  MODE_MASK (2*BITS_PER_UNIT),   /* HI */
  MODE_MASK (4*BITS_PER_UNIT),   /* SI */
  MODE_MASK (8*BITS_PER_UNIT),   /* DI */
  MODE_MASK (16*BITS_PER_UNIT),    /* TI */
  MODE_MASK (1*BITS_PER_UNIT),   /* QQ */
  MODE_MASK (2*BITS_PER_UNIT),   /* HQ */
  MODE_MASK (4*BITS_PER_UNIT),   /* SQ */
  MODE_MASK (8*BITS_PER_UNIT),   /* DQ */
  MODE_MASK (16*BITS_PER_UNIT),    /* TQ */
  MODE_MASK (1*BITS_PER_UNIT),   /* UQQ */
  MODE_MASK (2*BITS_PER_UNIT),   /* UHQ */
  MODE_MASK (4*BITS_PER_UNIT),   /* USQ */
  MODE_MASK (8*BITS_PER_UNIT),   /* UDQ */
  MODE_MASK (16*BITS_PER_UNIT),    /* UTQ */
  MODE_MASK (2*BITS_PER_UNIT),   /* HA */
  MODE_MASK (4*BITS_PER_UNIT),   /* SA */
  MODE_MASK (8*BITS_PER_UNIT),   /* DA */
  MODE_MASK (16*BITS_PER_UNIT),    /* TA */
  MODE_MASK (2*BITS_PER_UNIT),   /* UHA */
  MODE_MASK (4*BITS_PER_UNIT),   /* USA */
  MODE_MASK (8*BITS_PER_UNIT),   /* UDA */
  MODE_MASK (16*BITS_PER_UNIT),    /* UTA */
  MODE_MASK (2*BITS_PER_UNIT),   /* HF */
  MODE_MASK (4*BITS_PER_UNIT),   /* SF */
  MODE_MASK (8*BITS_PER_UNIT),   /* DF */
  MODE_MASK (16*BITS_PER_UNIT),    /* TF */
  MODE_MASK (4*BITS_PER_UNIT),   /* SD */
  MODE_MASK (8*BITS_PER_UNIT),   /* DD */
  MODE_MASK (16*BITS_PER_UNIT),    /* TD */
  MODE_MASK (2*BITS_PER_UNIT),   /* CQI */
  MODE_MASK (4*BITS_PER_UNIT),   /* CHI */
  MODE_MASK (8*BITS_PER_UNIT),   /* CSI */
  MODE_MASK (16*BITS_PER_UNIT),    /* CDI */
  MODE_MASK (32*BITS_PER_UNIT),    /* CTI */
  MODE_MASK (4*BITS_PER_UNIT),   /* HC */
  MODE_MASK (8*BITS_PER_UNIT),   /* SC */
  MODE_MASK (16*BITS_PER_UNIT),    /* DC */
  MODE_MASK (32*BITS_PER_UNIT),    /* TC */
  MODE_MASK (1*BITS_PER_UNIT),   /* VNx1BI */
  MODE_MASK (1*BITS_PER_UNIT),   /* VNx2BI */
  MODE_MASK (1*BITS_PER_UNIT),   /* VNx4BI */
  MODE_MASK (1*BITS_PER_UNIT),   /* VNx8BI */
  MODE_MASK (2*BITS_PER_UNIT),   /* VNx16BI */
  MODE_MASK (4*BITS_PER_UNIT),   /* VNx32BI */
  MODE_MASK (8*BITS_PER_UNIT),   /* VNx64BI */
  MODE_MASK (1*BITS_PER_UNIT),   /* VNx1QI */
  MODE_MASK (2*BITS_PER_UNIT),   /* VNx2QI */
  MODE_MASK (2*BITS_PER_UNIT),   /* VNx1HI */
  MODE_MASK (4*BITS_PER_UNIT),   /* VNx4QI */
  MODE_MASK (4*BITS_PER_UNIT),   /* VNx2HI */
  MODE_MASK (4*BITS_PER_UNIT),   /* VNx1SI */
  MODE_MASK (8*BITS_PER_UNIT),   /* VNx8QI */
  MODE_MASK (8*BITS_PER_UNIT),   /* VNx4HI */
  MODE_MASK (8*BITS_PER_UNIT),   /* VNx2SI */
  MODE_MASK (8*BITS_PER_UNIT),   /* VNx1DI */
  MODE_MASK (16*BITS_PER_UNIT),    /* VNx16QI */
  MODE_MASK (16*BITS_PER_UNIT),    /* VNx8HI */
  MODE_MASK (16*BITS_PER_UNIT),    /* VNx4SI */
  MODE_MASK (16*BITS_PER_UNIT),    /* VNx2DI */
  MODE_MASK (32*BITS_PER_UNIT),    /* VNx32QI */
  MODE_MASK (32*BITS_PER_UNIT),    /* VNx16HI */
  MODE_MASK (32*BITS_PER_UNIT),    /* VNx8SI */
  MODE_MASK (32*BITS_PER_UNIT),    /* VNx4DI */
  MODE_MASK (32*BITS_PER_UNIT),    /* VNx2TI */
  MODE_MASK (64*BITS_PER_UNIT),    /* VNx64QI */
  MODE_MASK (64*BITS_PER_UNIT),    /* VNx32HI */
  MODE_MASK (64*BITS_PER_UNIT),    /* VNx16SI */
  MODE_MASK (64*BITS_PER_UNIT),    /* VNx8DI */
  MODE_MASK (64*BITS_PER_UNIT),    /* VNx4TI */
  MODE_MASK (2*BITS_PER_UNIT),   /* VNx1HF */
  MODE_MASK (4*BITS_PER_UNIT),   /* VNx2HF */
  MODE_MASK (4*BITS_PER_UNIT),   /* VNx1SF */
  MODE_MASK (8*BITS_PER_UNIT),   /* VNx4HF */
  MODE_MASK (8*BITS_PER_UNIT),   /* VNx2SF */
  MODE_MASK (8*BITS_PER_UNIT),   /* VNx1DF */
  MODE_MASK (16*BITS_PER_UNIT),    /* VNx8HF */
  MODE_MASK (16*BITS_PER_UNIT),    /* VNx4SF */
  MODE_MASK (16*BITS_PER_UNIT),    /* VNx2DF */
  MODE_MASK (32*BITS_PER_UNIT),    /* VNx16HF */
  MODE_MASK (32*BITS_PER_UNIT),    /* VNx8SF */
  MODE_MASK (32*BITS_PER_UNIT),    /* VNx4DF */
  MODE_MASK (32*BITS_PER_UNIT),    /* VNx2TF */
  MODE_MASK (64*BITS_PER_UNIT),    /* VNx32HF */
  MODE_MASK (64*BITS_PER_UNIT),    /* VNx16SF */
  MODE_MASK (64*BITS_PER_UNIT),    /* VNx8DF */
  MODE_MASK (64*BITS_PER_UNIT),    /* VNx4TF */
#undef MODE_MASK
};

const unsigned char mode_inner[NUM_MACHINE_MODES] =
{
  E_VOIDmode,              /* VOID */
  E_BLKmode,               /* BLK */
  E_CCmode,                /* CC */
  E_BImode,                /* BI */
  E_QImode,                /* QI */
  E_HImode,                /* HI */
  E_SImode,                /* SI */
  E_DImode,                /* DI */
  E_TImode,                /* TI */
  E_QQmode,                /* QQ */
  E_HQmode,                /* HQ */
  E_SQmode,                /* SQ */
  E_DQmode,                /* DQ */
  E_TQmode,                /* TQ */
  E_UQQmode,               /* UQQ */
  E_UHQmode,               /* UHQ */
  E_USQmode,               /* USQ */
  E_UDQmode,               /* UDQ */
  E_UTQmode,               /* UTQ */
  E_HAmode,                /* HA */
  E_SAmode,                /* SA */
  E_DAmode,                /* DA */
  E_TAmode,                /* TA */
  E_UHAmode,               /* UHA */
  E_USAmode,               /* USA */
  E_UDAmode,               /* UDA */
  E_UTAmode,               /* UTA */
  E_HFmode,                /* HF */
  E_SFmode,                /* SF */
  E_DFmode,                /* DF */
  E_TFmode,                /* TF */
  E_SDmode,                /* SD */
  E_DDmode,                /* DD */
  E_TDmode,                /* TD */
  E_QImode,                /* CQI */
  E_HImode,                /* CHI */
  E_SImode,                /* CSI */
  E_DImode,                /* CDI */
  E_TImode,                /* CTI */
  E_HFmode,                /* HC */
  E_SFmode,                /* SC */
  E_DFmode,                /* DC */
  E_TFmode,                /* TC */
  E_BImode,                /* VNx1BI */
  E_BImode,                /* VNx2BI */
  E_BImode,                /* VNx4BI */
  E_BImode,                /* VNx8BI */
  E_BImode,                /* VNx16BI */
  E_BImode,                /* VNx32BI */
  E_BImode,                /* VNx64BI */
  E_QImode,                /* VNx1QI */
  E_QImode,                /* VNx2QI */
  E_HImode,                /* VNx1HI */
  E_QImode,                /* VNx4QI */
  E_HImode,                /* VNx2HI */
  E_SImode,                /* VNx1SI */
  E_QImode,                /* VNx8QI */
  E_HImode,                /* VNx4HI */
  E_SImode,                /* VNx2SI */
  E_DImode,                /* VNx1DI */
  E_QImode,                /* VNx16QI */
  E_HImode,                /* VNx8HI */
  E_SImode,                /* VNx4SI */
  E_DImode,                /* VNx2DI */
  E_QImode,                /* VNx32QI */
  E_HImode,                /* VNx16HI */
  E_SImode,                /* VNx8SI */
  E_DImode,                /* VNx4DI */
  E_TImode,                /* VNx2TI */
  E_QImode,                /* VNx64QI */
  E_HImode,                /* VNx32HI */
  E_SImode,                /* VNx16SI */
  E_DImode,                /* VNx8DI */
  E_TImode,                /* VNx4TI */
  E_HFmode,                /* VNx1HF */
  E_HFmode,                /* VNx2HF */
  E_SFmode,                /* VNx1SF */
  E_HFmode,                /* VNx4HF */
  E_SFmode,                /* VNx2SF */
  E_DFmode,                /* VNx1DF */
  E_HFmode,                /* VNx8HF */
  E_SFmode,                /* VNx4SF */
  E_DFmode,                /* VNx2DF */
  E_HFmode,                /* VNx16HF */
  E_SFmode,                /* VNx8SF */
  E_DFmode,                /* VNx4DF */
  E_TFmode,                /* VNx2TF */
  E_HFmode,                /* VNx32HF */
  E_SFmode,                /* VNx16SF */
  E_DFmode,                /* VNx8DF */
  E_TFmode,                /* VNx4TF */
};

unsigned char mode_unit_size[NUM_MACHINE_MODES] = 
{
  0,                       /* VOID */
  0,                       /* BLK */
  4,                       /* CC */
  1,                       /* BI */
  1,                       /* QI */
  2,                       /* HI */
  4,                       /* SI */
  8,                       /* DI */
  16,                      /* TI */
  1,                       /* QQ */
  2,                       /* HQ */
  4,                       /* SQ */
  8,                       /* DQ */
  16,                      /* TQ */
  1,                       /* UQQ */
  2,                       /* UHQ */
  4,                       /* USQ */
  8,                       /* UDQ */
  16,                      /* UTQ */
  2,                       /* HA */
  4,                       /* SA */
  8,                       /* DA */
  16,                      /* TA */
  2,                       /* UHA */
  4,                       /* USA */
  8,                       /* UDA */
  16,                      /* UTA */
  2,                       /* HF */
  4,                       /* SF */
  8,                       /* DF */
  16,                      /* TF */
  4,                       /* SD */
  8,                       /* DD */
  16,                      /* TD */
  1,                       /* CQI */
  2,                       /* CHI */
  4,                       /* CSI */
  8,                       /* CDI */
  16,                      /* CTI */
  2,                       /* HC */
  4,                       /* SC */
  8,                       /* DC */
  16,                      /* TC */
  1,                       /* VNx1BI */
  1,                       /* VNx2BI */
  1,                       /* VNx4BI */
  1,                       /* VNx8BI */
  1,                       /* VNx16BI */
  1,                       /* VNx32BI */
  1,                       /* VNx64BI */
  1,                       /* VNx1QI */
  1,                       /* VNx2QI */
  2,                       /* VNx1HI */
  1,                       /* VNx4QI */
  2,                       /* VNx2HI */
  4,                       /* VNx1SI */
  1,                       /* VNx8QI */
  2,                       /* VNx4HI */
  4,                       /* VNx2SI */
  8,                       /* VNx1DI */
  1,                       /* VNx16QI */
  2,                       /* VNx8HI */
  4,                       /* VNx4SI */
  8,                       /* VNx2DI */
  1,                       /* VNx32QI */
  2,                       /* VNx16HI */
  4,                       /* VNx8SI */
  8,                       /* VNx4DI */
  16,                      /* VNx2TI */
  1,                       /* VNx64QI */
  2,                       /* VNx32HI */
  4,                       /* VNx16SI */
  8,                       /* VNx8DI */
  16,                      /* VNx4TI */
  2,                       /* VNx1HF */
  2,                       /* VNx2HF */
  4,                       /* VNx1SF */
  2,                       /* VNx4HF */
  4,                       /* VNx2SF */
  8,                       /* VNx1DF */
  2,                       /* VNx8HF */
  4,                       /* VNx4SF */
  8,                       /* VNx2DF */
  2,                       /* VNx16HF */
  4,                       /* VNx8SF */
  8,                       /* VNx4DF */
  16,                      /* VNx2TF */
  2,                       /* VNx32HF */
  4,                       /* VNx16SF */
  8,                       /* VNx8DF */
  16,                      /* VNx4TF */
};

const unsigned short mode_unit_precision[NUM_MACHINE_MODES] =
{
  0,                       /* VOID */
  0,                       /* BLK */
  4*BITS_PER_UNIT,         /* CC */
  1,                       /* BI */
  1*BITS_PER_UNIT,         /* QI */
  2*BITS_PER_UNIT,         /* HI */
  4*BITS_PER_UNIT,         /* SI */
  8*BITS_PER_UNIT,         /* DI */
  16*BITS_PER_UNIT,        /* TI */
  1*BITS_PER_UNIT,         /* QQ */
  2*BITS_PER_UNIT,         /* HQ */
  4*BITS_PER_UNIT,         /* SQ */
  8*BITS_PER_UNIT,         /* DQ */
  16*BITS_PER_UNIT,        /* TQ */
  1*BITS_PER_UNIT,         /* UQQ */
  2*BITS_PER_UNIT,         /* UHQ */
  4*BITS_PER_UNIT,         /* USQ */
  8*BITS_PER_UNIT,         /* UDQ */
  16*BITS_PER_UNIT,        /* UTQ */
  2*BITS_PER_UNIT,         /* HA */
  4*BITS_PER_UNIT,         /* SA */
  8*BITS_PER_UNIT,         /* DA */
  16*BITS_PER_UNIT,        /* TA */
  2*BITS_PER_UNIT,         /* UHA */
  4*BITS_PER_UNIT,         /* USA */
  8*BITS_PER_UNIT,         /* UDA */
  16*BITS_PER_UNIT,        /* UTA */
  2*BITS_PER_UNIT,         /* HF */
  4*BITS_PER_UNIT,         /* SF */
  8*BITS_PER_UNIT,         /* DF */
  16*BITS_PER_UNIT,        /* TF */
  4*BITS_PER_UNIT,         /* SD */
  8*BITS_PER_UNIT,         /* DD */
  16*BITS_PER_UNIT,        /* TD */
  1*BITS_PER_UNIT,         /* CQI */
  2*BITS_PER_UNIT,         /* CHI */
  4*BITS_PER_UNIT,         /* CSI */
  8*BITS_PER_UNIT,         /* CDI */
  16*BITS_PER_UNIT,        /* CTI */
  2*BITS_PER_UNIT,         /* HC */
  4*BITS_PER_UNIT,         /* SC */
  8*BITS_PER_UNIT,         /* DC */
  16*BITS_PER_UNIT,        /* TC */
  1,                       /* VNx1BI */
  1,                       /* VNx2BI */
  1,                       /* VNx4BI */
  1,                       /* VNx8BI */
  1,                       /* VNx16BI */
  1,                       /* VNx32BI */
  1,                       /* VNx64BI */
  1*BITS_PER_UNIT,         /* VNx1QI */
  1*BITS_PER_UNIT,         /* VNx2QI */
  2*BITS_PER_UNIT,         /* VNx1HI */
  1*BITS_PER_UNIT,         /* VNx4QI */
  2*BITS_PER_UNIT,         /* VNx2HI */
  4*BITS_PER_UNIT,         /* VNx1SI */
  1*BITS_PER_UNIT,         /* VNx8QI */
  2*BITS_PER_UNIT,         /* VNx4HI */
  4*BITS_PER_UNIT,         /* VNx2SI */
  8*BITS_PER_UNIT,         /* VNx1DI */
  1*BITS_PER_UNIT,         /* VNx16QI */
  2*BITS_PER_UNIT,         /* VNx8HI */
  4*BITS_PER_UNIT,         /* VNx4SI */
  8*BITS_PER_UNIT,         /* VNx2DI */
  1*BITS_PER_UNIT,         /* VNx32QI */
  2*BITS_PER_UNIT,         /* VNx16HI */
  4*BITS_PER_UNIT,         /* VNx8SI */
  8*BITS_PER_UNIT,         /* VNx4DI */
  16*BITS_PER_UNIT,        /* VNx2TI */
  1*BITS_PER_UNIT,         /* VNx64QI */
  2*BITS_PER_UNIT,         /* VNx32HI */
  4*BITS_PER_UNIT,         /* VNx16SI */
  8*BITS_PER_UNIT,         /* VNx8DI */
  16*BITS_PER_UNIT,        /* VNx4TI */
  2*BITS_PER_UNIT,         /* VNx1HF */
  2*BITS_PER_UNIT,         /* VNx2HF */
  4*BITS_PER_UNIT,         /* VNx1SF */
  2*BITS_PER_UNIT,         /* VNx4HF */
  4*BITS_PER_UNIT,         /* VNx2SF */
  8*BITS_PER_UNIT,         /* VNx1DF */
  2*BITS_PER_UNIT,         /* VNx8HF */
  4*BITS_PER_UNIT,         /* VNx4SF */
  8*BITS_PER_UNIT,         /* VNx2DF */
  2*BITS_PER_UNIT,         /* VNx16HF */
  4*BITS_PER_UNIT,         /* VNx8SF */
  8*BITS_PER_UNIT,         /* VNx4DF */
  16*BITS_PER_UNIT,        /* VNx2TF */
  2*BITS_PER_UNIT,         /* VNx32HF */
  4*BITS_PER_UNIT,         /* VNx16SF */
  8*BITS_PER_UNIT,         /* VNx8DF */
  16*BITS_PER_UNIT,        /* VNx4TF */
};

unsigned short mode_base_align[NUM_MACHINE_MODES] = 
{
  0,                       /* VOID */
  0,                       /* BLK */
  4,                       /* CC */
  1,                       /* BI */
  1,                       /* QI */
  2,                       /* HI */
  4,                       /* SI */
  8,                       /* DI */
  16,                      /* TI */
  1,                       /* QQ */
  2,                       /* HQ */
  4,                       /* SQ */
  8,                       /* DQ */
  16,                      /* TQ */
  1,                       /* UQQ */
  2,                       /* UHQ */
  4,                       /* USQ */
  8,                       /* UDQ */
  16,                      /* UTQ */
  2,                       /* HA */
  4,                       /* SA */
  8,                       /* DA */
  16,                      /* TA */
  2,                       /* UHA */
  4,                       /* USA */
  8,                       /* UDA */
  16,                      /* UTA */
  2,                       /* HF */
  4,                       /* SF */
  8,                       /* DF */
  16,                      /* TF */
  4,                       /* SD */
  8,                       /* DD */
  16,                      /* TD */
  1,                       /* CQI */
  2,                       /* CHI */
  4,                       /* CSI */
  8,                       /* CDI */
  16,                      /* CTI */
  2,                       /* HC */
  4,                       /* SC */
  8,                       /* DC */
  16,                      /* TC */
  1,                       /* VNx1BI */
  1,                       /* VNx2BI */
  1,                       /* VNx4BI */
  1,                       /* VNx8BI */
  2,                       /* VNx16BI */
  4,                       /* VNx32BI */
  8,                       /* VNx64BI */
  1,                       /* VNx1QI */
  2,                       /* VNx2QI */
  2,                       /* VNx1HI */
  4,                       /* VNx4QI */
  4,                       /* VNx2HI */
  4,                       /* VNx1SI */
  8,                       /* VNx8QI */
  8,                       /* VNx4HI */
  8,                       /* VNx2SI */
  8,                       /* VNx1DI */
  16,                      /* VNx16QI */
  16,                      /* VNx8HI */
  16,                      /* VNx4SI */
  16,                      /* VNx2DI */
  32,                      /* VNx32QI */
  32,                      /* VNx16HI */
  32,                      /* VNx8SI */
  32,                      /* VNx4DI */
  32,                      /* VNx2TI */
  64,                      /* VNx64QI */
  64,                      /* VNx32HI */
  64,                      /* VNx16SI */
  64,                      /* VNx8DI */
  64,                      /* VNx4TI */
  2,                       /* VNx1HF */
  4,                       /* VNx2HF */
  4,                       /* VNx1SF */
  8,                       /* VNx4HF */
  8,                       /* VNx2SF */
  8,                       /* VNx1DF */
  16,                      /* VNx8HF */
  16,                      /* VNx4SF */
  16,                      /* VNx2DF */
  32,                      /* VNx16HF */
  32,                      /* VNx8SF */
  32,                      /* VNx4DF */
  32,                      /* VNx2TF */
  64,                      /* VNx32HF */
  64,                      /* VNx16SF */
  64,                      /* VNx8DF */
  64,                      /* VNx4TF */
};

const unsigned char class_narrowest_mode[MAX_MODE_CLASS] =
{
  MIN_MODE_RANDOM,         /* VOID */
  MIN_MODE_CC,             /* CC */
  MIN_MODE_INT,            /* QI */
  MIN_MODE_PARTIAL_INT,    /* VOID */
  MIN_MODE_FRACT,          /* QQ */
  MIN_MODE_UFRACT,         /* UQQ */
  MIN_MODE_ACCUM,          /* HA */
  MIN_MODE_UACCUM,         /* UHA */
  MIN_MODE_FLOAT,          /* HF */
  MIN_MODE_DECIMAL_FLOAT,  /* SD */
  MIN_MODE_COMPLEX_INT,    /* CQI */
  MIN_MODE_COMPLEX_FLOAT,  /* HC */
  MIN_MODE_VECTOR_BOOL,    /* VNx1BI */
  MIN_MODE_VECTOR_INT,     /* VNx1QI */
  MIN_MODE_VECTOR_FRACT,   /* VOID */
  MIN_MODE_VECTOR_UFRACT,  /* VOID */
  MIN_MODE_VECTOR_ACCUM,   /* VOID */
  MIN_MODE_VECTOR_UACCUM,  /* VOID */
  MIN_MODE_VECTOR_FLOAT,   /* VNx1HF */
  MIN_MODE_OPAQUE,         /* VOID */
};

const struct real_format *
 real_format_for_mode[MAX_MODE_FLOAT - MIN_MODE_FLOAT + 1 + MAX_MODE_DECIMAL_FLOAT - MIN_MODE_DECIMAL_FLOAT + 1] =
{
  &ieee_half_format,       /* HF */
  &ieee_single_format,     /* SF */
  &ieee_double_format,     /* DF */
  &ieee_quad_format,       /* TF */
  &decimal_single_format,  /* SD */
  &decimal_double_format,  /* DD */
  &decimal_quad_format,    /* TD */
};

void
adjust_mode_mask (machine_mode mode)
{
  unsigned int precision;
  if (GET_MODE_PRECISION (mode).is_constant (&precision)
      && precision < HOST_BITS_PER_WIDE_INT)
    mode_mask_array[mode] = (HOST_WIDE_INT_1U << precision) - 1;
  else
    mode_mask_array[mode] = HOST_WIDE_INT_M1U;
}

void
init_adjust_machine_modes (void)
{
  poly_uint16 ps ATTRIBUTE_UNUSED;
  size_t s ATTRIBUTE_UNUSED;

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx1QImode, 1);
    int old_factor = vector_element_size (mode_precision[E_VNx1QImode], mode_nunits[E_VNx1QImode]);
    mode_precision[E_VNx1QImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx1QImode], BITS_PER_UNIT, &mode_size[E_VNx1QImode]))
      mode_size[E_VNx1QImode] = -1;
    mode_nunits[E_VNx1QImode] = ps;
    adjust_mode_mask (E_VNx1QImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx1HFmode, 1);
    int old_factor = vector_element_size (mode_precision[E_VNx1HFmode], mode_nunits[E_VNx1HFmode]);
    mode_precision[E_VNx1HFmode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx1HFmode], BITS_PER_UNIT, &mode_size[E_VNx1HFmode]))
      mode_size[E_VNx1HFmode] = -1;
    mode_nunits[E_VNx1HFmode] = ps;
    adjust_mode_mask (E_VNx1HFmode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx1HImode, 1);
    int old_factor = vector_element_size (mode_precision[E_VNx1HImode], mode_nunits[E_VNx1HImode]);
    mode_precision[E_VNx1HImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx1HImode], BITS_PER_UNIT, &mode_size[E_VNx1HImode]))
      mode_size[E_VNx1HImode] = -1;
    mode_nunits[E_VNx1HImode] = ps;
    adjust_mode_mask (E_VNx1HImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx2QImode, 2);
    int old_factor = vector_element_size (mode_precision[E_VNx2QImode], mode_nunits[E_VNx2QImode]);
    mode_precision[E_VNx2QImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx2QImode], BITS_PER_UNIT, &mode_size[E_VNx2QImode]))
      mode_size[E_VNx2QImode] = -1;
    mode_nunits[E_VNx2QImode] = ps;
    adjust_mode_mask (E_VNx2QImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx1SFmode, 1);
    int old_factor = vector_element_size (mode_precision[E_VNx1SFmode], mode_nunits[E_VNx1SFmode]);
    mode_precision[E_VNx1SFmode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx1SFmode], BITS_PER_UNIT, &mode_size[E_VNx1SFmode]))
      mode_size[E_VNx1SFmode] = -1;
    mode_nunits[E_VNx1SFmode] = ps;
    adjust_mode_mask (E_VNx1SFmode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx1SImode, 1);
    int old_factor = vector_element_size (mode_precision[E_VNx1SImode], mode_nunits[E_VNx1SImode]);
    mode_precision[E_VNx1SImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx1SImode], BITS_PER_UNIT, &mode_size[E_VNx1SImode]))
      mode_size[E_VNx1SImode] = -1;
    mode_nunits[E_VNx1SImode] = ps;
    adjust_mode_mask (E_VNx1SImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx2HFmode, 2);
    int old_factor = vector_element_size (mode_precision[E_VNx2HFmode], mode_nunits[E_VNx2HFmode]);
    mode_precision[E_VNx2HFmode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx2HFmode], BITS_PER_UNIT, &mode_size[E_VNx2HFmode]))
      mode_size[E_VNx2HFmode] = -1;
    mode_nunits[E_VNx2HFmode] = ps;
    adjust_mode_mask (E_VNx2HFmode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx2HImode, 2);
    int old_factor = vector_element_size (mode_precision[E_VNx2HImode], mode_nunits[E_VNx2HImode]);
    mode_precision[E_VNx2HImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx2HImode], BITS_PER_UNIT, &mode_size[E_VNx2HImode]))
      mode_size[E_VNx2HImode] = -1;
    mode_nunits[E_VNx2HImode] = ps;
    adjust_mode_mask (E_VNx2HImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx4QImode, 4);
    int old_factor = vector_element_size (mode_precision[E_VNx4QImode], mode_nunits[E_VNx4QImode]);
    mode_precision[E_VNx4QImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx4QImode], BITS_PER_UNIT, &mode_size[E_VNx4QImode]))
      mode_size[E_VNx4QImode] = -1;
    mode_nunits[E_VNx4QImode] = ps;
    adjust_mode_mask (E_VNx4QImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx8DFmode, 8);
    int old_factor = vector_element_size (mode_precision[E_VNx8DFmode], mode_nunits[E_VNx8DFmode]);
    mode_precision[E_VNx8DFmode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx8DFmode], BITS_PER_UNIT, &mode_size[E_VNx8DFmode]))
      mode_size[E_VNx8DFmode] = -1;
    mode_nunits[E_VNx8DFmode] = ps;
    adjust_mode_mask (E_VNx8DFmode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx16SFmode, 8 * 2);
    int old_factor = vector_element_size (mode_precision[E_VNx16SFmode], mode_nunits[E_VNx16SFmode]);
    mode_precision[E_VNx16SFmode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx16SFmode], BITS_PER_UNIT, &mode_size[E_VNx16SFmode]))
      mode_size[E_VNx16SFmode] = -1;
    mode_nunits[E_VNx16SFmode] = ps;
    adjust_mode_mask (E_VNx16SFmode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx32HFmode, 8 * 4);
    int old_factor = vector_element_size (mode_precision[E_VNx32HFmode], mode_nunits[E_VNx32HFmode]);
    mode_precision[E_VNx32HFmode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx32HFmode], BITS_PER_UNIT, &mode_size[E_VNx32HFmode]))
      mode_size[E_VNx32HFmode] = -1;
    mode_nunits[E_VNx32HFmode] = ps;
    adjust_mode_mask (E_VNx32HFmode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx8DImode, 8);
    int old_factor = vector_element_size (mode_precision[E_VNx8DImode], mode_nunits[E_VNx8DImode]);
    mode_precision[E_VNx8DImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx8DImode], BITS_PER_UNIT, &mode_size[E_VNx8DImode]))
      mode_size[E_VNx8DImode] = -1;
    mode_nunits[E_VNx8DImode] = ps;
    adjust_mode_mask (E_VNx8DImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx16SImode, 8 * 2);
    int old_factor = vector_element_size (mode_precision[E_VNx16SImode], mode_nunits[E_VNx16SImode]);
    mode_precision[E_VNx16SImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx16SImode], BITS_PER_UNIT, &mode_size[E_VNx16SImode]))
      mode_size[E_VNx16SImode] = -1;
    mode_nunits[E_VNx16SImode] = ps;
    adjust_mode_mask (E_VNx16SImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx32HImode, 8 * 4);
    int old_factor = vector_element_size (mode_precision[E_VNx32HImode], mode_nunits[E_VNx32HImode]);
    mode_precision[E_VNx32HImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx32HImode], BITS_PER_UNIT, &mode_size[E_VNx32HImode]))
      mode_size[E_VNx32HImode] = -1;
    mode_nunits[E_VNx32HImode] = ps;
    adjust_mode_mask (E_VNx32HImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx64QImode, 8 * 8);
    int old_factor = vector_element_size (mode_precision[E_VNx64QImode], mode_nunits[E_VNx64QImode]);
    mode_precision[E_VNx64QImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx64QImode], BITS_PER_UNIT, &mode_size[E_VNx64QImode]))
      mode_size[E_VNx64QImode] = -1;
    mode_nunits[E_VNx64QImode] = ps;
    adjust_mode_mask (E_VNx64QImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx4DFmode, 4);
    int old_factor = vector_element_size (mode_precision[E_VNx4DFmode], mode_nunits[E_VNx4DFmode]);
    mode_precision[E_VNx4DFmode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx4DFmode], BITS_PER_UNIT, &mode_size[E_VNx4DFmode]))
      mode_size[E_VNx4DFmode] = -1;
    mode_nunits[E_VNx4DFmode] = ps;
    adjust_mode_mask (E_VNx4DFmode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx8SFmode, 4 * 2);
    int old_factor = vector_element_size (mode_precision[E_VNx8SFmode], mode_nunits[E_VNx8SFmode]);
    mode_precision[E_VNx8SFmode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx8SFmode], BITS_PER_UNIT, &mode_size[E_VNx8SFmode]))
      mode_size[E_VNx8SFmode] = -1;
    mode_nunits[E_VNx8SFmode] = ps;
    adjust_mode_mask (E_VNx8SFmode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx16HFmode, 4 * 4);
    int old_factor = vector_element_size (mode_precision[E_VNx16HFmode], mode_nunits[E_VNx16HFmode]);
    mode_precision[E_VNx16HFmode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx16HFmode], BITS_PER_UNIT, &mode_size[E_VNx16HFmode]))
      mode_size[E_VNx16HFmode] = -1;
    mode_nunits[E_VNx16HFmode] = ps;
    adjust_mode_mask (E_VNx16HFmode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx4DImode, 4);
    int old_factor = vector_element_size (mode_precision[E_VNx4DImode], mode_nunits[E_VNx4DImode]);
    mode_precision[E_VNx4DImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx4DImode], BITS_PER_UNIT, &mode_size[E_VNx4DImode]))
      mode_size[E_VNx4DImode] = -1;
    mode_nunits[E_VNx4DImode] = ps;
    adjust_mode_mask (E_VNx4DImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx8SImode, 4 * 2);
    int old_factor = vector_element_size (mode_precision[E_VNx8SImode], mode_nunits[E_VNx8SImode]);
    mode_precision[E_VNx8SImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx8SImode], BITS_PER_UNIT, &mode_size[E_VNx8SImode]))
      mode_size[E_VNx8SImode] = -1;
    mode_nunits[E_VNx8SImode] = ps;
    adjust_mode_mask (E_VNx8SImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx16HImode, 4 * 4);
    int old_factor = vector_element_size (mode_precision[E_VNx16HImode], mode_nunits[E_VNx16HImode]);
    mode_precision[E_VNx16HImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx16HImode], BITS_PER_UNIT, &mode_size[E_VNx16HImode]))
      mode_size[E_VNx16HImode] = -1;
    mode_nunits[E_VNx16HImode] = ps;
    adjust_mode_mask (E_VNx16HImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx32QImode, 4 * 8);
    int old_factor = vector_element_size (mode_precision[E_VNx32QImode], mode_nunits[E_VNx32QImode]);
    mode_precision[E_VNx32QImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx32QImode], BITS_PER_UNIT, &mode_size[E_VNx32QImode]))
      mode_size[E_VNx32QImode] = -1;
    mode_nunits[E_VNx32QImode] = ps;
    adjust_mode_mask (E_VNx32QImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx2DFmode, 2);
    int old_factor = vector_element_size (mode_precision[E_VNx2DFmode], mode_nunits[E_VNx2DFmode]);
    mode_precision[E_VNx2DFmode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx2DFmode], BITS_PER_UNIT, &mode_size[E_VNx2DFmode]))
      mode_size[E_VNx2DFmode] = -1;
    mode_nunits[E_VNx2DFmode] = ps;
    adjust_mode_mask (E_VNx2DFmode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx4SFmode, 2 * 2);
    int old_factor = vector_element_size (mode_precision[E_VNx4SFmode], mode_nunits[E_VNx4SFmode]);
    mode_precision[E_VNx4SFmode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx4SFmode], BITS_PER_UNIT, &mode_size[E_VNx4SFmode]))
      mode_size[E_VNx4SFmode] = -1;
    mode_nunits[E_VNx4SFmode] = ps;
    adjust_mode_mask (E_VNx4SFmode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx8HFmode, 2 * 4);
    int old_factor = vector_element_size (mode_precision[E_VNx8HFmode], mode_nunits[E_VNx8HFmode]);
    mode_precision[E_VNx8HFmode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx8HFmode], BITS_PER_UNIT, &mode_size[E_VNx8HFmode]))
      mode_size[E_VNx8HFmode] = -1;
    mode_nunits[E_VNx8HFmode] = ps;
    adjust_mode_mask (E_VNx8HFmode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx2DImode, 2);
    int old_factor = vector_element_size (mode_precision[E_VNx2DImode], mode_nunits[E_VNx2DImode]);
    mode_precision[E_VNx2DImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx2DImode], BITS_PER_UNIT, &mode_size[E_VNx2DImode]))
      mode_size[E_VNx2DImode] = -1;
    mode_nunits[E_VNx2DImode] = ps;
    adjust_mode_mask (E_VNx2DImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx4SImode, 2 * 2);
    int old_factor = vector_element_size (mode_precision[E_VNx4SImode], mode_nunits[E_VNx4SImode]);
    mode_precision[E_VNx4SImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx4SImode], BITS_PER_UNIT, &mode_size[E_VNx4SImode]))
      mode_size[E_VNx4SImode] = -1;
    mode_nunits[E_VNx4SImode] = ps;
    adjust_mode_mask (E_VNx4SImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx8HImode, 2 * 4);
    int old_factor = vector_element_size (mode_precision[E_VNx8HImode], mode_nunits[E_VNx8HImode]);
    mode_precision[E_VNx8HImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx8HImode], BITS_PER_UNIT, &mode_size[E_VNx8HImode]))
      mode_size[E_VNx8HImode] = -1;
    mode_nunits[E_VNx8HImode] = ps;
    adjust_mode_mask (E_VNx8HImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx16QImode, 2 * 8);
    int old_factor = vector_element_size (mode_precision[E_VNx16QImode], mode_nunits[E_VNx16QImode]);
    mode_precision[E_VNx16QImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx16QImode], BITS_PER_UNIT, &mode_size[E_VNx16QImode]))
      mode_size[E_VNx16QImode] = -1;
    mode_nunits[E_VNx16QImode] = ps;
    adjust_mode_mask (E_VNx16QImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx1DFmode, 1);
    int old_factor = vector_element_size (mode_precision[E_VNx1DFmode], mode_nunits[E_VNx1DFmode]);
    mode_precision[E_VNx1DFmode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx1DFmode], BITS_PER_UNIT, &mode_size[E_VNx1DFmode]))
      mode_size[E_VNx1DFmode] = -1;
    mode_nunits[E_VNx1DFmode] = ps;
    adjust_mode_mask (E_VNx1DFmode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx2SFmode, 1 * 2);
    int old_factor = vector_element_size (mode_precision[E_VNx2SFmode], mode_nunits[E_VNx2SFmode]);
    mode_precision[E_VNx2SFmode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx2SFmode], BITS_PER_UNIT, &mode_size[E_VNx2SFmode]))
      mode_size[E_VNx2SFmode] = -1;
    mode_nunits[E_VNx2SFmode] = ps;
    adjust_mode_mask (E_VNx2SFmode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx4HFmode, 1 * 4);
    int old_factor = vector_element_size (mode_precision[E_VNx4HFmode], mode_nunits[E_VNx4HFmode]);
    mode_precision[E_VNx4HFmode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx4HFmode], BITS_PER_UNIT, &mode_size[E_VNx4HFmode]))
      mode_size[E_VNx4HFmode] = -1;
    mode_nunits[E_VNx4HFmode] = ps;
    adjust_mode_mask (E_VNx4HFmode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx1DImode, 1);
    int old_factor = vector_element_size (mode_precision[E_VNx1DImode], mode_nunits[E_VNx1DImode]);
    mode_precision[E_VNx1DImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx1DImode], BITS_PER_UNIT, &mode_size[E_VNx1DImode]))
      mode_size[E_VNx1DImode] = -1;
    mode_nunits[E_VNx1DImode] = ps;
    adjust_mode_mask (E_VNx1DImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx2SImode, 1 * 2);
    int old_factor = vector_element_size (mode_precision[E_VNx2SImode], mode_nunits[E_VNx2SImode]);
    mode_precision[E_VNx2SImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx2SImode], BITS_PER_UNIT, &mode_size[E_VNx2SImode]))
      mode_size[E_VNx2SImode] = -1;
    mode_nunits[E_VNx2SImode] = ps;
    adjust_mode_mask (E_VNx2SImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx4HImode, 1 * 4);
    int old_factor = vector_element_size (mode_precision[E_VNx4HImode], mode_nunits[E_VNx4HImode]);
    mode_precision[E_VNx4HImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx4HImode], BITS_PER_UNIT, &mode_size[E_VNx4HImode]))
      mode_size[E_VNx4HImode] = -1;
    mode_nunits[E_VNx4HImode] = ps;
    adjust_mode_mask (E_VNx4HImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx8QImode, 1 * 8);
    int old_factor = vector_element_size (mode_precision[E_VNx8QImode], mode_nunits[E_VNx8QImode]);
    mode_precision[E_VNx8QImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx8QImode], BITS_PER_UNIT, &mode_size[E_VNx8QImode]))
      mode_size[E_VNx8QImode] = -1;
    mode_nunits[E_VNx8QImode] = ps;
    adjust_mode_mask (E_VNx8QImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx64BImode, 64);
    int old_factor = vector_element_size (mode_precision[E_VNx64BImode], mode_nunits[E_VNx64BImode]);
    mode_precision[E_VNx64BImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx64BImode], BITS_PER_UNIT, &mode_size[E_VNx64BImode]))
      mode_size[E_VNx64BImode] = -1;
    mode_nunits[E_VNx64BImode] = ps;
    adjust_mode_mask (E_VNx64BImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx32BImode, 32);
    int old_factor = vector_element_size (mode_precision[E_VNx32BImode], mode_nunits[E_VNx32BImode]);
    mode_precision[E_VNx32BImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx32BImode], BITS_PER_UNIT, &mode_size[E_VNx32BImode]))
      mode_size[E_VNx32BImode] = -1;
    mode_nunits[E_VNx32BImode] = ps;
    adjust_mode_mask (E_VNx32BImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx16BImode, 16);
    int old_factor = vector_element_size (mode_precision[E_VNx16BImode], mode_nunits[E_VNx16BImode]);
    mode_precision[E_VNx16BImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx16BImode], BITS_PER_UNIT, &mode_size[E_VNx16BImode]))
      mode_size[E_VNx16BImode] = -1;
    mode_nunits[E_VNx16BImode] = ps;
    adjust_mode_mask (E_VNx16BImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx8BImode, 8);
    int old_factor = vector_element_size (mode_precision[E_VNx8BImode], mode_nunits[E_VNx8BImode]);
    mode_precision[E_VNx8BImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx8BImode], BITS_PER_UNIT, &mode_size[E_VNx8BImode]))
      mode_size[E_VNx8BImode] = -1;
    mode_nunits[E_VNx8BImode] = ps;
    adjust_mode_mask (E_VNx8BImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx4BImode, 4);
    int old_factor = vector_element_size (mode_precision[E_VNx4BImode], mode_nunits[E_VNx4BImode]);
    mode_precision[E_VNx4BImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx4BImode], BITS_PER_UNIT, &mode_size[E_VNx4BImode]))
      mode_size[E_VNx4BImode] = -1;
    mode_nunits[E_VNx4BImode] = ps;
    adjust_mode_mask (E_VNx4BImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx2BImode, 2);
    int old_factor = vector_element_size (mode_precision[E_VNx2BImode], mode_nunits[E_VNx2BImode]);
    mode_precision[E_VNx2BImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx2BImode], BITS_PER_UNIT, &mode_size[E_VNx2BImode]))
      mode_size[E_VNx2BImode] = -1;
    mode_nunits[E_VNx2BImode] = ps;
    adjust_mode_mask (E_VNx2BImode);
  }

  {
    /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_nunits (VNx1BImode, 1);
    int old_factor = vector_element_size (mode_precision[E_VNx1BImode], mode_nunits[E_VNx1BImode]);
    mode_precision[E_VNx1BImode] = ps * old_factor;
    if (!multiple_p (mode_precision[E_VNx1BImode], BITS_PER_UNIT, &mode_size[E_VNx1BImode]))
      mode_size[E_VNx1BImode] = -1;
    mode_nunits[E_VNx1BImode] = ps;
    adjust_mode_mask (E_VNx1BImode);
  }

  /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_bytesize (VNx64BImode, 8);
  s = mode_unit_size[E_VNx64BImode];
  mode_size[E_VNx64BImode] = ps;
  mode_base_align[E_VNx64BImode] = known_alignment (ps);

  /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_bytesize (VNx32BImode, 4);
  s = mode_unit_size[E_VNx32BImode];
  mode_size[E_VNx32BImode] = ps;
  mode_base_align[E_VNx32BImode] = known_alignment (ps);

  /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_bytesize (VNx16BImode, 2);
  s = mode_unit_size[E_VNx16BImode];
  mode_size[E_VNx16BImode] = ps;
  mode_base_align[E_VNx16BImode] = known_alignment (ps);

  /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_bytesize (VNx8BImode, 1);
  s = mode_unit_size[E_VNx8BImode];
  mode_size[E_VNx8BImode] = ps;
  mode_base_align[E_VNx8BImode] = known_alignment (ps);

  /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_bytesize (VNx4BImode, 1);
  s = mode_unit_size[E_VNx4BImode];
  mode_size[E_VNx4BImode] = ps;
  mode_base_align[E_VNx4BImode] = known_alignment (ps);

  /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_bytesize (VNx2BImode, 1);
  s = mode_unit_size[E_VNx2BImode];
  mode_size[E_VNx2BImode] = ps;
  mode_base_align[E_VNx2BImode] = known_alignment (ps);

  /* config/riscv/riscv-modes.def:0 */
  ps = riscv_v_adjust_bytesize (VNx1BImode, 1);
  s = mode_unit_size[E_VNx1BImode];
  mode_size[E_VNx1BImode] = ps;
  mode_base_align[E_VNx1BImode] = known_alignment (ps);

  /* config/riscv/riscv-modes.def:0 */
  s = 1;
  mode_base_align[E_VNx1QImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 2;
  mode_base_align[E_VNx1HFmode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 2;
  mode_base_align[E_VNx1HImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 1;
  mode_base_align[E_VNx2QImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 4;
  mode_base_align[E_VNx1SFmode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 4;
  mode_base_align[E_VNx1SImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 2;
  mode_base_align[E_VNx2HFmode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 2;
  mode_base_align[E_VNx2HImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 1;
  mode_base_align[E_VNx4QImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 8;
  mode_base_align[E_VNx8DFmode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 4;
  mode_base_align[E_VNx16SFmode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 2;
  mode_base_align[E_VNx32HFmode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 8;
  mode_base_align[E_VNx8DImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 4;
  mode_base_align[E_VNx16SImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 2;
  mode_base_align[E_VNx32HImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 1;
  mode_base_align[E_VNx64QImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 8;
  mode_base_align[E_VNx4DFmode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 4;
  mode_base_align[E_VNx8SFmode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 2;
  mode_base_align[E_VNx16HFmode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 8;
  mode_base_align[E_VNx4DImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 4;
  mode_base_align[E_VNx8SImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 2;
  mode_base_align[E_VNx16HImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 1;
  mode_base_align[E_VNx32QImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 8;
  mode_base_align[E_VNx2DFmode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 4;
  mode_base_align[E_VNx4SFmode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 2;
  mode_base_align[E_VNx8HFmode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 8;
  mode_base_align[E_VNx2DImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 4;
  mode_base_align[E_VNx4SImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 2;
  mode_base_align[E_VNx8HImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 1;
  mode_base_align[E_VNx16QImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 8;
  mode_base_align[E_VNx1DFmode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 4;
  mode_base_align[E_VNx2SFmode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 2;
  mode_base_align[E_VNx4HFmode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 8;
  mode_base_align[E_VNx1DImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 4;
  mode_base_align[E_VNx2SImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 2;
  mode_base_align[E_VNx4HImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 1;
  mode_base_align[E_VNx8QImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 1;
  mode_base_align[E_VNx64BImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 1;
  mode_base_align[E_VNx32BImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 1;
  mode_base_align[E_VNx16BImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 1;
  mode_base_align[E_VNx8BImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 1;
  mode_base_align[E_VNx4BImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 1;
  mode_base_align[E_VNx2BImode] = s;

  /* config/riscv/riscv-modes.def:0 */
  s = 1;
  mode_base_align[E_VNx1BImode] = s;

  /* config/riscv/riscv-modes.def:0.  */
  ps = riscv_v_adjust_precision (VNx64BImode, 64);
  mode_precision[E_VNx64BImode] = ps;

  /* config/riscv/riscv-modes.def:0.  */
  ps = riscv_v_adjust_precision (VNx32BImode, 32);
  mode_precision[E_VNx32BImode] = ps;

  /* config/riscv/riscv-modes.def:0.  */
  ps = riscv_v_adjust_precision (VNx16BImode, 16);
  mode_precision[E_VNx16BImode] = ps;

  /* config/riscv/riscv-modes.def:0.  */
  ps = riscv_v_adjust_precision (VNx8BImode, 8);
  mode_precision[E_VNx8BImode] = ps;

  /* config/riscv/riscv-modes.def:0.  */
  ps = riscv_v_adjust_precision (VNx4BImode, 4);
  mode_precision[E_VNx4BImode] = ps;

  /* config/riscv/riscv-modes.def:0.  */
  ps = riscv_v_adjust_precision (VNx2BImode, 2);
  mode_precision[E_VNx2BImode] = ps;

  /* config/riscv/riscv-modes.def:0.  */
  ps = riscv_v_adjust_precision (VNx1BImode, 1);
  mode_precision[E_VNx1BImode] = ps;

  gcc_assert (maybe_ne (mode_size[E_VOIDmode], -1));

  gcc_assert (maybe_ne (mode_size[E_BLKmode], -1));

  gcc_assert (maybe_ne (mode_size[E_CCmode], -1));

  gcc_assert (maybe_ne (mode_size[E_BImode], -1));

  gcc_assert (maybe_ne (mode_size[E_QImode], -1));

  gcc_assert (maybe_ne (mode_size[E_HImode], -1));

  gcc_assert (maybe_ne (mode_size[E_SImode], -1));

  gcc_assert (maybe_ne (mode_size[E_DImode], -1));

  gcc_assert (maybe_ne (mode_size[E_TImode], -1));

  gcc_assert (maybe_ne (mode_size[E_QQmode], -1));

  gcc_assert (maybe_ne (mode_size[E_HQmode], -1));

  gcc_assert (maybe_ne (mode_size[E_SQmode], -1));

  gcc_assert (maybe_ne (mode_size[E_DQmode], -1));

  gcc_assert (maybe_ne (mode_size[E_TQmode], -1));

  gcc_assert (maybe_ne (mode_size[E_UQQmode], -1));

  gcc_assert (maybe_ne (mode_size[E_UHQmode], -1));

  gcc_assert (maybe_ne (mode_size[E_USQmode], -1));

  gcc_assert (maybe_ne (mode_size[E_UDQmode], -1));

  gcc_assert (maybe_ne (mode_size[E_UTQmode], -1));

  gcc_assert (maybe_ne (mode_size[E_HAmode], -1));

  gcc_assert (maybe_ne (mode_size[E_SAmode], -1));

  gcc_assert (maybe_ne (mode_size[E_DAmode], -1));

  gcc_assert (maybe_ne (mode_size[E_TAmode], -1));

  gcc_assert (maybe_ne (mode_size[E_UHAmode], -1));

  gcc_assert (maybe_ne (mode_size[E_USAmode], -1));

  gcc_assert (maybe_ne (mode_size[E_UDAmode], -1));

  gcc_assert (maybe_ne (mode_size[E_UTAmode], -1));

  gcc_assert (maybe_ne (mode_size[E_HFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_SFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_DFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_TFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_SDmode], -1));

  gcc_assert (maybe_ne (mode_size[E_DDmode], -1));

  gcc_assert (maybe_ne (mode_size[E_TDmode], -1));

  gcc_assert (maybe_ne (mode_size[E_CQImode], -1));

  gcc_assert (maybe_ne (mode_size[E_CHImode], -1));

  gcc_assert (maybe_ne (mode_size[E_CSImode], -1));

  gcc_assert (maybe_ne (mode_size[E_CDImode], -1));

  gcc_assert (maybe_ne (mode_size[E_CTImode], -1));

  gcc_assert (maybe_ne (mode_size[E_HCmode], -1));

  gcc_assert (maybe_ne (mode_size[E_SCmode], -1));

  gcc_assert (maybe_ne (mode_size[E_DCmode], -1));

  gcc_assert (maybe_ne (mode_size[E_TCmode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx1BImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx2BImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx4BImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx8BImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx16BImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx32BImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx64BImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx1QImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx2QImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx1HImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx4QImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx2HImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx1SImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx8QImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx4HImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx2SImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx1DImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx16QImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx8HImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx4SImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx2DImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx32QImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx16HImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx8SImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx4DImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx2TImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx64QImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx32HImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx16SImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx8DImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx4TImode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx1HFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx2HFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx1SFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx4HFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx2SFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx1DFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx8HFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx4SFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx2DFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx16HFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx8SFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx4DFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx2TFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx32HFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx16SFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx8DFmode], -1));

  gcc_assert (maybe_ne (mode_size[E_VNx4TFmode], -1));
}

const unsigned char mode_ibit[NUM_MACHINE_MODES] = 
{
  0,                       /* VOID */
  0,                       /* BLK */
  0,                       /* CC */
  0,                       /* BI */
  0,                       /* QI */
  0,                       /* HI */
  0,                       /* SI */
  0,                       /* DI */
  0,                       /* TI */
  0,                       /* QQ */
  0,                       /* HQ */
  0,                       /* SQ */
  0,                       /* DQ */
  0,                       /* TQ */
  0,                       /* UQQ */
  0,                       /* UHQ */
  0,                       /* USQ */
  0,                       /* UDQ */
  0,                       /* UTQ */
  8,                       /* HA */
  16,                      /* SA */
  32,                      /* DA */
  64,                      /* TA */
  8,                       /* UHA */
  16,                      /* USA */
  32,                      /* UDA */
  64,                      /* UTA */
  0,                       /* HF */
  0,                       /* SF */
  0,                       /* DF */
  0,                       /* TF */
  0,                       /* SD */
  0,                       /* DD */
  0,                       /* TD */
  0,                       /* CQI */
  0,                       /* CHI */
  0,                       /* CSI */
  0,                       /* CDI */
  0,                       /* CTI */
  0,                       /* HC */
  0,                       /* SC */
  0,                       /* DC */
  0,                       /* TC */
  0,                       /* VNx1BI */
  0,                       /* VNx2BI */
  0,                       /* VNx4BI */
  0,                       /* VNx8BI */
  0,                       /* VNx16BI */
  0,                       /* VNx32BI */
  0,                       /* VNx64BI */
  0,                       /* VNx1QI */
  0,                       /* VNx2QI */
  0,                       /* VNx1HI */
  0,                       /* VNx4QI */
  0,                       /* VNx2HI */
  0,                       /* VNx1SI */
  0,                       /* VNx8QI */
  0,                       /* VNx4HI */
  0,                       /* VNx2SI */
  0,                       /* VNx1DI */
  0,                       /* VNx16QI */
  0,                       /* VNx8HI */
  0,                       /* VNx4SI */
  0,                       /* VNx2DI */
  0,                       /* VNx32QI */
  0,                       /* VNx16HI */
  0,                       /* VNx8SI */
  0,                       /* VNx4DI */
  0,                       /* VNx2TI */
  0,                       /* VNx64QI */
  0,                       /* VNx32HI */
  0,                       /* VNx16SI */
  0,                       /* VNx8DI */
  0,                       /* VNx4TI */
  0,                       /* VNx1HF */
  0,                       /* VNx2HF */
  0,                       /* VNx1SF */
  0,                       /* VNx4HF */
  0,                       /* VNx2SF */
  0,                       /* VNx1DF */
  0,                       /* VNx8HF */
  0,                       /* VNx4SF */
  0,                       /* VNx2DF */
  0,                       /* VNx16HF */
  0,                       /* VNx8SF */
  0,                       /* VNx4DF */
  0,                       /* VNx2TF */
  0,                       /* VNx32HF */
  0,                       /* VNx16SF */
  0,                       /* VNx8DF */
  0,                       /* VNx4TF */
};

const unsigned char mode_fbit[NUM_MACHINE_MODES] = 
{
  0,                       /* VOID */
  0,                       /* BLK */
  0,                       /* CC */
  0,                       /* BI */
  0,                       /* QI */
  0,                       /* HI */
  0,                       /* SI */
  0,                       /* DI */
  0,                       /* TI */
  7,                       /* QQ */
  15,                      /* HQ */
  31,                      /* SQ */
  63,                      /* DQ */
  127,                     /* TQ */
  8,                       /* UQQ */
  16,                      /* UHQ */
  32,                      /* USQ */
  64,                      /* UDQ */
  128,                     /* UTQ */
  7,                       /* HA */
  15,                      /* SA */
  31,                      /* DA */
  63,                      /* TA */
  8,                       /* UHA */
  16,                      /* USA */
  32,                      /* UDA */
  64,                      /* UTA */
  0,                       /* HF */
  0,                       /* SF */
  0,                       /* DF */
  0,                       /* TF */
  0,                       /* SD */
  0,                       /* DD */
  0,                       /* TD */
  0,                       /* CQI */
  0,                       /* CHI */
  0,                       /* CSI */
  0,                       /* CDI */
  0,                       /* CTI */
  0,                       /* HC */
  0,                       /* SC */
  0,                       /* DC */
  0,                       /* TC */
  0,                       /* VNx1BI */
  0,                       /* VNx2BI */
  0,                       /* VNx4BI */
  0,                       /* VNx8BI */
  0,                       /* VNx16BI */
  0,                       /* VNx32BI */
  0,                       /* VNx64BI */
  0,                       /* VNx1QI */
  0,                       /* VNx2QI */
  0,                       /* VNx1HI */
  0,                       /* VNx4QI */
  0,                       /* VNx2HI */
  0,                       /* VNx1SI */
  0,                       /* VNx8QI */
  0,                       /* VNx4HI */
  0,                       /* VNx2SI */
  0,                       /* VNx1DI */
  0,                       /* VNx16QI */
  0,                       /* VNx8HI */
  0,                       /* VNx4SI */
  0,                       /* VNx2DI */
  0,                       /* VNx32QI */
  0,                       /* VNx16HI */
  0,                       /* VNx8SI */
  0,                       /* VNx4DI */
  0,                       /* VNx2TI */
  0,                       /* VNx64QI */
  0,                       /* VNx32HI */
  0,                       /* VNx16SI */
  0,                       /* VNx8DI */
  0,                       /* VNx4TI */
  0,                       /* VNx1HF */
  0,                       /* VNx2HF */
  0,                       /* VNx1SF */
  0,                       /* VNx4HF */
  0,                       /* VNx2SF */
  0,                       /* VNx1DF */
  0,                       /* VNx8HF */
  0,                       /* VNx4SF */
  0,                       /* VNx2DF */
  0,                       /* VNx16HF */
  0,                       /* VNx8SF */
  0,                       /* VNx4DF */
  0,                       /* VNx2TF */
  0,                       /* VNx32HF */
  0,                       /* VNx16SF */
  0,                       /* VNx8DF */
  0,                       /* VNx4TF */
};

const int_n_data_t int_n_data[] =
{
 {
  128,                     /* TI */
{ E_TImode }, },
};
