/* Generated by genrvv-type-indexer */
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vbool64_t,
  /*MASK*/ vbool64_t,
  /*SIGNED*/ INVALID,
  /*UNSIGNED*/ INVALID,
  /*EEW8_INDEX*/ INVALID,
  /*EEW16_INDEX*/ INVALID,
  /*EEW32_INDEX*/ INVALID,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ INVALID,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ INVALID,
  /*WLMUL1*/ INVALID,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_INTERPRET*/ INVALID,
  /*X4_INTERPRET*/ INVALID,
  /*X8_INTERPRET*/ INVALID,
  /*X16_INTERPRET*/ INVALID,
  /*X32_INTERPRET*/ INVALID,
  /*X64_INTERPRET*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vbool32_t,
  /*MASK*/ vbool32_t,
  /*SIGNED*/ INVALID,
  /*UNSIGNED*/ INVALID,
  /*EEW8_INDEX*/ INVALID,
  /*EEW16_INDEX*/ INVALID,
  /*EEW32_INDEX*/ INVALID,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ INVALID,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ INVALID,
  /*WLMUL1*/ INVALID,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_INTERPRET*/ INVALID,
  /*X4_INTERPRET*/ INVALID,
  /*X8_INTERPRET*/ INVALID,
  /*X16_INTERPRET*/ INVALID,
  /*X32_INTERPRET*/ INVALID,
  /*X64_INTERPRET*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vbool16_t,
  /*MASK*/ vbool16_t,
  /*SIGNED*/ INVALID,
  /*UNSIGNED*/ INVALID,
  /*EEW8_INDEX*/ INVALID,
  /*EEW16_INDEX*/ INVALID,
  /*EEW32_INDEX*/ INVALID,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ INVALID,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ INVALID,
  /*WLMUL1*/ INVALID,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_INTERPRET*/ INVALID,
  /*X4_INTERPRET*/ INVALID,
  /*X8_INTERPRET*/ INVALID,
  /*X16_INTERPRET*/ INVALID,
  /*X32_INTERPRET*/ INVALID,
  /*X64_INTERPRET*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vbool8_t,
  /*MASK*/ vbool8_t,
  /*SIGNED*/ INVALID,
  /*UNSIGNED*/ INVALID,
  /*EEW8_INDEX*/ INVALID,
  /*EEW16_INDEX*/ INVALID,
  /*EEW32_INDEX*/ INVALID,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ INVALID,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ INVALID,
  /*WLMUL1*/ INVALID,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_INTERPRET*/ INVALID,
  /*X4_INTERPRET*/ INVALID,
  /*X8_INTERPRET*/ INVALID,
  /*X16_INTERPRET*/ INVALID,
  /*X32_INTERPRET*/ INVALID,
  /*X64_INTERPRET*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vbool4_t,
  /*MASK*/ vbool4_t,
  /*SIGNED*/ INVALID,
  /*UNSIGNED*/ INVALID,
  /*EEW8_INDEX*/ INVALID,
  /*EEW16_INDEX*/ INVALID,
  /*EEW32_INDEX*/ INVALID,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ INVALID,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ INVALID,
  /*WLMUL1*/ INVALID,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_INTERPRET*/ INVALID,
  /*X4_INTERPRET*/ INVALID,
  /*X8_INTERPRET*/ INVALID,
  /*X16_INTERPRET*/ INVALID,
  /*X32_INTERPRET*/ INVALID,
  /*X64_INTERPRET*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vbool2_t,
  /*MASK*/ vbool2_t,
  /*SIGNED*/ INVALID,
  /*UNSIGNED*/ INVALID,
  /*EEW8_INDEX*/ INVALID,
  /*EEW16_INDEX*/ INVALID,
  /*EEW32_INDEX*/ INVALID,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ INVALID,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ INVALID,
  /*WLMUL1*/ INVALID,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_INTERPRET*/ INVALID,
  /*X4_INTERPRET*/ INVALID,
  /*X8_INTERPRET*/ INVALID,
  /*X16_INTERPRET*/ INVALID,
  /*X32_INTERPRET*/ INVALID,
  /*X64_INTERPRET*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vbool1_t,
  /*MASK*/ vbool1_t,
  /*SIGNED*/ INVALID,
  /*UNSIGNED*/ INVALID,
  /*EEW8_INDEX*/ INVALID,
  /*EEW16_INDEX*/ INVALID,
  /*EEW32_INDEX*/ INVALID,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ INVALID,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ INVALID,
  /*WLMUL1*/ INVALID,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_INTERPRET*/ INVALID,
  /*X4_INTERPRET*/ INVALID,
  /*X8_INTERPRET*/ INVALID,
  /*X16_INTERPRET*/ INVALID,
  /*X32_INTERPRET*/ INVALID,
  /*X64_INTERPRET*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint8mf8_t,
  /*MASK*/ vbool64_t,
  /*SIGNED*/ vint8mf8_t,
  /*UNSIGNED*/ vuint8mf8_t,
  /*EEW8_INDEX*/ vuint8mf8_t,
  /*EEW16_INDEX*/ vuint16mf4_t,
  /*EEW32_INDEX*/ vuint32mf2_t,
  /*EEW64_INDEX*/ vuint64m1_t,
  /*SHIFT*/ vuint8mf8_t,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vint8m1_t,
  /*WLMUL1*/ vint16m1_t,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vint8mf4_t,
  /*X4_VLMUL_EXT*/ vint8mf2_t,
  /*X8_VLMUL_EXT*/ vint8m1_t,
  /*X16_VLMUL_EXT*/ vint8m2_t,
  /*X32_VLMUL_EXT*/ vint8m4_t,
  /*X64_VLMUL_EXT*/ vint8m8_t
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint8mf8_t,
  /*MASK*/ vbool64_t,
  /*SIGNED*/ vint8mf8_t,
  /*UNSIGNED*/ vuint8mf8_t,
  /*EEW8_INDEX*/ vuint8mf8_t,
  /*EEW16_INDEX*/ vuint16mf4_t,
  /*EEW32_INDEX*/ vuint32mf2_t,
  /*EEW64_INDEX*/ vuint64m1_t,
  /*SHIFT*/ vuint8mf8_t,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vuint8m1_t,
  /*WLMUL1*/ vuint16m1_t,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vuint8mf4_t,
  /*X4_VLMUL_EXT*/ vuint8mf2_t,
  /*X8_VLMUL_EXT*/ vuint8m1_t,
  /*X16_VLMUL_EXT*/ vuint8m2_t,
  /*X32_VLMUL_EXT*/ vuint8m4_t,
  /*X64_VLMUL_EXT*/ vuint8m8_t
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint8mf4_t,
  /*MASK*/ vbool32_t,
  /*SIGNED*/ vint8mf4_t,
  /*UNSIGNED*/ vuint8mf4_t,
  /*EEW8_INDEX*/ vuint8mf4_t,
  /*EEW16_INDEX*/ vuint16mf2_t,
  /*EEW32_INDEX*/ vuint32m1_t,
  /*EEW64_INDEX*/ vuint64m2_t,
  /*SHIFT*/ vuint8mf4_t,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vint8m1_t,
  /*WLMUL1*/ vint16m1_t,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ vint16mf4_t,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vint8mf2_t,
  /*X4_VLMUL_EXT*/ vint8m1_t,
  /*X8_VLMUL_EXT*/ vint8m2_t,
  /*X16_VLMUL_EXT*/ vint8m4_t,
  /*X32_VLMUL_EXT*/ vint8m8_t,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint8mf4_t,
  /*MASK*/ vbool32_t,
  /*SIGNED*/ vint8mf4_t,
  /*UNSIGNED*/ vuint8mf4_t,
  /*EEW8_INDEX*/ vuint8mf4_t,
  /*EEW16_INDEX*/ vuint16mf2_t,
  /*EEW32_INDEX*/ vuint32m1_t,
  /*EEW64_INDEX*/ vuint64m2_t,
  /*SHIFT*/ vuint8mf4_t,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vuint8m1_t,
  /*WLMUL1*/ vuint16m1_t,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ vuint16mf4_t,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vuint8mf2_t,
  /*X4_VLMUL_EXT*/ vuint8m1_t,
  /*X8_VLMUL_EXT*/ vuint8m2_t,
  /*X16_VLMUL_EXT*/ vuint8m4_t,
  /*X32_VLMUL_EXT*/ vuint8m8_t,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint8mf2_t,
  /*MASK*/ vbool16_t,
  /*SIGNED*/ vint8mf2_t,
  /*UNSIGNED*/ vuint8mf2_t,
  /*EEW8_INDEX*/ vuint8mf2_t,
  /*EEW16_INDEX*/ vuint16m1_t,
  /*EEW32_INDEX*/ vuint32m2_t,
  /*EEW64_INDEX*/ vuint64m4_t,
  /*SHIFT*/ vuint8mf2_t,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vint8m1_t,
  /*WLMUL1*/ vint16m1_t,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ vint16mf2_t,
  /*EEW32_INTERPRET*/ vint32mf2_t,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vint8m1_t,
  /*X4_VLMUL_EXT*/ vint8m2_t,
  /*X8_VLMUL_EXT*/ vint8m4_t,
  /*X16_VLMUL_EXT*/ vint8m8_t,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint8mf2_t,
  /*MASK*/ vbool16_t,
  /*SIGNED*/ vint8mf2_t,
  /*UNSIGNED*/ vuint8mf2_t,
  /*EEW8_INDEX*/ vuint8mf2_t,
  /*EEW16_INDEX*/ vuint16m1_t,
  /*EEW32_INDEX*/ vuint32m2_t,
  /*EEW64_INDEX*/ vuint64m4_t,
  /*SHIFT*/ vuint8mf2_t,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vuint8m1_t,
  /*WLMUL1*/ vuint16m1_t,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ vuint16mf2_t,
  /*EEW32_INTERPRET*/ vuint32mf2_t,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vuint8m1_t,
  /*X4_VLMUL_EXT*/ vuint8m2_t,
  /*X8_VLMUL_EXT*/ vuint8m4_t,
  /*X16_VLMUL_EXT*/ vuint8m8_t,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint8m1_t,
  /*MASK*/ vbool8_t,
  /*SIGNED*/ vint8m1_t,
  /*UNSIGNED*/ vuint8m1_t,
  /*EEW8_INDEX*/ vuint8m1_t,
  /*EEW16_INDEX*/ vuint16m2_t,
  /*EEW32_INDEX*/ vuint32m4_t,
  /*EEW64_INDEX*/ vuint64m8_t,
  /*SHIFT*/ vuint8m1_t,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vint8m1_t,
  /*WLMUL1*/ vint16m1_t,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ vint16m1_t,
  /*EEW32_INTERPRET*/ vint32m1_t,
  /*EEW64_INTERPRET*/ vint64m1_t,
  /*X2_VLMUL_EXT*/ vint8m2_t,
  /*X4_VLMUL_EXT*/ vint8m4_t,
  /*X8_VLMUL_EXT*/ vint8m8_t,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint8m1_t,
  /*MASK*/ vbool8_t,
  /*SIGNED*/ vint8m1_t,
  /*UNSIGNED*/ vuint8m1_t,
  /*EEW8_INDEX*/ vuint8m1_t,
  /*EEW16_INDEX*/ vuint16m2_t,
  /*EEW32_INDEX*/ vuint32m4_t,
  /*EEW64_INDEX*/ vuint64m8_t,
  /*SHIFT*/ vuint8m1_t,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vuint8m1_t,
  /*WLMUL1*/ vuint16m1_t,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ vuint16m1_t,
  /*EEW32_INTERPRET*/ vuint32m1_t,
  /*EEW64_INTERPRET*/ vuint64m1_t,
  /*X2_VLMUL_EXT*/ vuint8m2_t,
  /*X4_VLMUL_EXT*/ vuint8m4_t,
  /*X8_VLMUL_EXT*/ vuint8m8_t,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint8m2_t,
  /*MASK*/ vbool4_t,
  /*SIGNED*/ vint8m2_t,
  /*UNSIGNED*/ vuint8m2_t,
  /*EEW8_INDEX*/ vuint8m2_t,
  /*EEW16_INDEX*/ vuint16m4_t,
  /*EEW32_INDEX*/ vuint32m8_t,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ vuint8m2_t,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vint8m1_t,
  /*WLMUL1*/ vint16m1_t,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ vint16m2_t,
  /*EEW32_INTERPRET*/ vint32m2_t,
  /*EEW64_INTERPRET*/ vint64m2_t,
  /*X2_VLMUL_EXT*/ vint8m4_t,
  /*X4_VLMUL_EXT*/ vint8m8_t,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint8m2_t,
  /*MASK*/ vbool4_t,
  /*SIGNED*/ vint8m2_t,
  /*UNSIGNED*/ vuint8m2_t,
  /*EEW8_INDEX*/ vuint8m2_t,
  /*EEW16_INDEX*/ vuint16m4_t,
  /*EEW32_INDEX*/ vuint32m8_t,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ vuint8m2_t,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vuint8m1_t,
  /*WLMUL1*/ vuint16m1_t,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ vuint16m2_t,
  /*EEW32_INTERPRET*/ vuint32m2_t,
  /*EEW64_INTERPRET*/ vuint64m2_t,
  /*X2_VLMUL_EXT*/ vuint8m4_t,
  /*X4_VLMUL_EXT*/ vuint8m8_t,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint8m4_t,
  /*MASK*/ vbool2_t,
  /*SIGNED*/ vint8m4_t,
  /*UNSIGNED*/ vuint8m4_t,
  /*EEW8_INDEX*/ vuint8m4_t,
  /*EEW16_INDEX*/ vuint16m8_t,
  /*EEW32_INDEX*/ INVALID,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ vuint8m4_t,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vint8m1_t,
  /*WLMUL1*/ vint16m1_t,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ vint16m4_t,
  /*EEW32_INTERPRET*/ vint32m4_t,
  /*EEW64_INTERPRET*/ vint64m4_t,
  /*X2_VLMUL_EXT*/ vint8m8_t,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint8m4_t,
  /*MASK*/ vbool2_t,
  /*SIGNED*/ vint8m4_t,
  /*UNSIGNED*/ vuint8m4_t,
  /*EEW8_INDEX*/ vuint8m4_t,
  /*EEW16_INDEX*/ vuint16m8_t,
  /*EEW32_INDEX*/ INVALID,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ vuint8m4_t,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vuint8m1_t,
  /*WLMUL1*/ vuint16m1_t,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ vuint16m4_t,
  /*EEW32_INTERPRET*/ vuint32m4_t,
  /*EEW64_INTERPRET*/ vuint64m4_t,
  /*X2_VLMUL_EXT*/ vuint8m8_t,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint8m8_t,
  /*MASK*/ vbool1_t,
  /*SIGNED*/ vint8m8_t,
  /*UNSIGNED*/ vuint8m8_t,
  /*EEW8_INDEX*/ vuint8m8_t,
  /*EEW16_INDEX*/ INVALID,
  /*EEW32_INDEX*/ INVALID,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ vuint8m8_t,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vint8m1_t,
  /*WLMUL1*/ vint16m1_t,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ vint16m8_t,
  /*EEW32_INTERPRET*/ vint32m8_t,
  /*EEW64_INTERPRET*/ vint64m8_t,
  /*X2_VLMUL_EXT*/ INVALID,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint8m8_t,
  /*MASK*/ vbool1_t,
  /*SIGNED*/ vint8m8_t,
  /*UNSIGNED*/ vuint8m8_t,
  /*EEW8_INDEX*/ vuint8m8_t,
  /*EEW16_INDEX*/ INVALID,
  /*EEW32_INDEX*/ INVALID,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ vuint8m8_t,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vuint8m1_t,
  /*WLMUL1*/ vuint16m1_t,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ vuint16m8_t,
  /*EEW32_INTERPRET*/ vuint32m8_t,
  /*EEW64_INTERPRET*/ vuint64m8_t,
  /*X2_VLMUL_EXT*/ INVALID,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint16mf4_t,
  /*MASK*/ vbool64_t,
  /*SIGNED*/ vint16mf4_t,
  /*UNSIGNED*/ vuint16mf4_t,
  /*EEW8_INDEX*/ vuint8mf8_t,
  /*EEW16_INDEX*/ vuint16mf4_t,
  /*EEW32_INDEX*/ vuint32mf2_t,
  /*EEW64_INDEX*/ vuint64m1_t,
  /*SHIFT*/ vuint16mf4_t,
  /*DOUBLE_TRUNC*/ vint8mf8_t,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vint8mf8_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint8mf8_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ vuint8mf8_t,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vint16m1_t,
  /*WLMUL1*/ vint32m1_t,
  /*EEW8_INTERPRET*/ vint8mf4_t,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vint16mf2_t,
  /*X4_VLMUL_EXT*/ vint16m1_t,
  /*X8_VLMUL_EXT*/ vint16m2_t,
  /*X16_VLMUL_EXT*/ vint16m4_t,
  /*X32_VLMUL_EXT*/ vint16m8_t,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint16mf4_t,
  /*MASK*/ vbool64_t,
  /*SIGNED*/ vint16mf4_t,
  /*UNSIGNED*/ vuint16mf4_t,
  /*EEW8_INDEX*/ vuint8mf8_t,
  /*EEW16_INDEX*/ vuint16mf4_t,
  /*EEW32_INDEX*/ vuint32mf2_t,
  /*EEW64_INDEX*/ vuint64m1_t,
  /*SHIFT*/ vuint16mf4_t,
  /*DOUBLE_TRUNC*/ vuint8mf8_t,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vuint8mf8_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint8mf8_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vuint16m1_t,
  /*WLMUL1*/ vuint32m1_t,
  /*EEW8_INTERPRET*/ vuint8mf4_t,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vuint16mf2_t,
  /*X4_VLMUL_EXT*/ vuint16m1_t,
  /*X8_VLMUL_EXT*/ vuint16m2_t,
  /*X16_VLMUL_EXT*/ vuint16m4_t,
  /*X32_VLMUL_EXT*/ vuint16m8_t,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint16mf2_t,
  /*MASK*/ vbool32_t,
  /*SIGNED*/ vint16mf2_t,
  /*UNSIGNED*/ vuint16mf2_t,
  /*EEW8_INDEX*/ vuint8mf4_t,
  /*EEW16_INDEX*/ vuint16mf2_t,
  /*EEW32_INDEX*/ vuint32m1_t,
  /*EEW64_INDEX*/ vuint64m2_t,
  /*SHIFT*/ vuint16mf2_t,
  /*DOUBLE_TRUNC*/ vint8mf4_t,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vint8mf4_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint8mf4_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ vuint8mf4_t,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vint16m1_t,
  /*WLMUL1*/ vint32m1_t,
  /*EEW8_INTERPRET*/ vint8mf2_t,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ vint32mf2_t,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vint16m1_t,
  /*X4_VLMUL_EXT*/ vint16m2_t,
  /*X8_VLMUL_EXT*/ vint16m4_t,
  /*X16_VLMUL_EXT*/ vint16m8_t,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint16mf2_t,
  /*MASK*/ vbool32_t,
  /*SIGNED*/ vint16mf2_t,
  /*UNSIGNED*/ vuint16mf2_t,
  /*EEW8_INDEX*/ vuint8mf4_t,
  /*EEW16_INDEX*/ vuint16mf2_t,
  /*EEW32_INDEX*/ vuint32m1_t,
  /*EEW64_INDEX*/ vuint64m2_t,
  /*SHIFT*/ vuint16mf2_t,
  /*DOUBLE_TRUNC*/ vuint8mf4_t,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vuint8mf4_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint8mf4_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vuint16m1_t,
  /*WLMUL1*/ vuint32m1_t,
  /*EEW8_INTERPRET*/ vuint8mf2_t,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ vuint32mf2_t,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vuint16m1_t,
  /*X4_VLMUL_EXT*/ vuint16m2_t,
  /*X8_VLMUL_EXT*/ vuint16m4_t,
  /*X16_VLMUL_EXT*/ vuint16m8_t,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint16m1_t,
  /*MASK*/ vbool16_t,
  /*SIGNED*/ vint16m1_t,
  /*UNSIGNED*/ vuint16m1_t,
  /*EEW8_INDEX*/ vuint8mf2_t,
  /*EEW16_INDEX*/ vuint16m1_t,
  /*EEW32_INDEX*/ vuint32m2_t,
  /*EEW64_INDEX*/ vuint64m4_t,
  /*SHIFT*/ vuint16m1_t,
  /*DOUBLE_TRUNC*/ vint8mf2_t,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vint8mf2_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint8mf2_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ vuint8mf2_t,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vint16m1_t,
  /*WLMUL1*/ vint32m1_t,
  /*EEW8_INTERPRET*/ vint8m1_t,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ vint32m1_t,
  /*EEW64_INTERPRET*/ vint64m1_t,
  /*X2_VLMUL_EXT*/ vint16m2_t,
  /*X4_VLMUL_EXT*/ vint16m4_t,
  /*X8_VLMUL_EXT*/ vint16m8_t,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint16m1_t,
  /*MASK*/ vbool16_t,
  /*SIGNED*/ vint16m1_t,
  /*UNSIGNED*/ vuint16m1_t,
  /*EEW8_INDEX*/ vuint8mf2_t,
  /*EEW16_INDEX*/ vuint16m1_t,
  /*EEW32_INDEX*/ vuint32m2_t,
  /*EEW64_INDEX*/ vuint64m4_t,
  /*SHIFT*/ vuint16m1_t,
  /*DOUBLE_TRUNC*/ vuint8mf2_t,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vuint8mf2_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint8mf2_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vuint16m1_t,
  /*WLMUL1*/ vuint32m1_t,
  /*EEW8_INTERPRET*/ vuint8m1_t,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ vuint32m1_t,
  /*EEW64_INTERPRET*/ vuint64m1_t,
  /*X2_VLMUL_EXT*/ vuint16m2_t,
  /*X4_VLMUL_EXT*/ vuint16m4_t,
  /*X8_VLMUL_EXT*/ vuint16m8_t,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint16m2_t,
  /*MASK*/ vbool8_t,
  /*SIGNED*/ vint16m2_t,
  /*UNSIGNED*/ vuint16m2_t,
  /*EEW8_INDEX*/ vuint8m1_t,
  /*EEW16_INDEX*/ vuint16m2_t,
  /*EEW32_INDEX*/ vuint32m4_t,
  /*EEW64_INDEX*/ vuint64m8_t,
  /*SHIFT*/ vuint16m2_t,
  /*DOUBLE_TRUNC*/ vint8m1_t,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vint8m1_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint8m1_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ vuint8m1_t,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vint16m1_t,
  /*WLMUL1*/ vint32m1_t,
  /*EEW8_INTERPRET*/ vint8m2_t,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ vint32m2_t,
  /*EEW64_INTERPRET*/ vint64m2_t,
  /*X2_VLMUL_EXT*/ vint16m4_t,
  /*X4_VLMUL_EXT*/ vint16m8_t,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint16m2_t,
  /*MASK*/ vbool8_t,
  /*SIGNED*/ vint16m2_t,
  /*UNSIGNED*/ vuint16m2_t,
  /*EEW8_INDEX*/ vuint8m1_t,
  /*EEW16_INDEX*/ vuint16m2_t,
  /*EEW32_INDEX*/ vuint32m4_t,
  /*EEW64_INDEX*/ vuint64m8_t,
  /*SHIFT*/ vuint16m2_t,
  /*DOUBLE_TRUNC*/ vuint8m1_t,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vuint8m1_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint8m1_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vuint16m1_t,
  /*WLMUL1*/ vuint32m1_t,
  /*EEW8_INTERPRET*/ vuint8m2_t,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ vuint32m2_t,
  /*EEW64_INTERPRET*/ vuint64m2_t,
  /*X2_VLMUL_EXT*/ vuint16m4_t,
  /*X4_VLMUL_EXT*/ vuint16m8_t,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint16m4_t,
  /*MASK*/ vbool4_t,
  /*SIGNED*/ vint16m4_t,
  /*UNSIGNED*/ vuint16m4_t,
  /*EEW8_INDEX*/ vuint8m2_t,
  /*EEW16_INDEX*/ vuint16m4_t,
  /*EEW32_INDEX*/ vuint32m8_t,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ vuint16m4_t,
  /*DOUBLE_TRUNC*/ vint8m2_t,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vint8m2_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint8m2_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ vuint8m2_t,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vint16m1_t,
  /*WLMUL1*/ vint32m1_t,
  /*EEW8_INTERPRET*/ vint8m4_t,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ vint32m4_t,
  /*EEW64_INTERPRET*/ vint64m4_t,
  /*X2_VLMUL_EXT*/ vint16m8_t,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint16m4_t,
  /*MASK*/ vbool4_t,
  /*SIGNED*/ vint16m4_t,
  /*UNSIGNED*/ vuint16m4_t,
  /*EEW8_INDEX*/ vuint8m2_t,
  /*EEW16_INDEX*/ vuint16m4_t,
  /*EEW32_INDEX*/ vuint32m8_t,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ vuint16m4_t,
  /*DOUBLE_TRUNC*/ vuint8m2_t,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vuint8m2_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint8m2_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vuint16m1_t,
  /*WLMUL1*/ vuint32m1_t,
  /*EEW8_INTERPRET*/ vuint8m4_t,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ vuint32m4_t,
  /*EEW64_INTERPRET*/ vuint64m4_t,
  /*X2_VLMUL_EXT*/ vuint16m8_t,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint16m8_t,
  /*MASK*/ vbool2_t,
  /*SIGNED*/ vint16m8_t,
  /*UNSIGNED*/ vuint16m8_t,
  /*EEW8_INDEX*/ vuint8m4_t,
  /*EEW16_INDEX*/ vuint16m8_t,
  /*EEW32_INDEX*/ INVALID,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ vuint16m8_t,
  /*DOUBLE_TRUNC*/ vint8m4_t,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vint8m4_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint8m4_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ vuint8m4_t,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vint16m1_t,
  /*WLMUL1*/ vint32m1_t,
  /*EEW8_INTERPRET*/ vint8m8_t,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ vint32m8_t,
  /*EEW64_INTERPRET*/ vint64m8_t,
  /*X2_VLMUL_EXT*/ INVALID,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint16m8_t,
  /*MASK*/ vbool2_t,
  /*SIGNED*/ vint16m8_t,
  /*UNSIGNED*/ vuint16m8_t,
  /*EEW8_INDEX*/ vuint8m4_t,
  /*EEW16_INDEX*/ vuint16m8_t,
  /*EEW32_INDEX*/ INVALID,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ vuint16m8_t,
  /*DOUBLE_TRUNC*/ vuint8m4_t,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vuint8m4_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint8m4_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vuint16m1_t,
  /*WLMUL1*/ vuint32m1_t,
  /*EEW8_INTERPRET*/ vuint8m8_t,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ vuint32m8_t,
  /*EEW64_INTERPRET*/ vuint64m8_t,
  /*X2_VLMUL_EXT*/ INVALID,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint32mf2_t,
  /*MASK*/ vbool64_t,
  /*SIGNED*/ vint32mf2_t,
  /*UNSIGNED*/ vuint32mf2_t,
  /*EEW8_INDEX*/ vuint8mf8_t,
  /*EEW16_INDEX*/ vuint16mf4_t,
  /*EEW32_INDEX*/ vuint32mf2_t,
  /*EEW64_INDEX*/ vuint64m1_t,
  /*SHIFT*/ vuint32mf2_t,
  /*DOUBLE_TRUNC*/ vint16mf4_t,
  /*QUAD_TRUNC*/ vint8mf8_t,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vint16mf4_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint16mf4_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ vuint16mf4_t,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ vfloat32mf2_t,
  /*LMUL1*/ vint32m1_t,
  /*WLMUL1*/ vint64m1_t,
  /*EEW8_INTERPRET*/ vint8mf2_t,
  /*EEW16_INTERPRET*/ vint16mf2_t,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vint32m1_t,
  /*X4_VLMUL_EXT*/ vint32m2_t,
  /*X8_VLMUL_EXT*/ vint32m4_t,
  /*X16_VLMUL_EXT*/ vint32m8_t,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint32mf2_t,
  /*MASK*/ vbool64_t,
  /*SIGNED*/ vint32mf2_t,
  /*UNSIGNED*/ vuint32mf2_t,
  /*EEW8_INDEX*/ vuint8mf8_t,
  /*EEW16_INDEX*/ vuint16mf4_t,
  /*EEW32_INDEX*/ vuint32mf2_t,
  /*EEW64_INDEX*/ vuint64m1_t,
  /*SHIFT*/ vuint32mf2_t,
  /*DOUBLE_TRUNC*/ vuint16mf4_t,
  /*QUAD_TRUNC*/ vuint8mf8_t,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vuint16mf4_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint16mf4_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ vfloat32mf2_t,
  /*LMUL1*/ vuint32m1_t,
  /*WLMUL1*/ vuint64m1_t,
  /*EEW8_INTERPRET*/ vuint8mf2_t,
  /*EEW16_INTERPRET*/ vuint16mf2_t,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vuint32m1_t,
  /*X4_VLMUL_EXT*/ vuint32m2_t,
  /*X8_VLMUL_EXT*/ vuint32m4_t,
  /*X16_VLMUL_EXT*/ vuint32m8_t,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint32m1_t,
  /*MASK*/ vbool32_t,
  /*SIGNED*/ vint32m1_t,
  /*UNSIGNED*/ vuint32m1_t,
  /*EEW8_INDEX*/ vuint8mf4_t,
  /*EEW16_INDEX*/ vuint16mf2_t,
  /*EEW32_INDEX*/ vuint32m1_t,
  /*EEW64_INDEX*/ vuint64m2_t,
  /*SHIFT*/ vuint32m1_t,
  /*DOUBLE_TRUNC*/ vint16mf2_t,
  /*QUAD_TRUNC*/ vint8mf4_t,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vint16mf2_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint16mf2_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ vuint16mf2_t,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ vfloat32m1_t,
  /*LMUL1*/ vint32m1_t,
  /*WLMUL1*/ vint64m1_t,
  /*EEW8_INTERPRET*/ vint8m1_t,
  /*EEW16_INTERPRET*/ vint16m1_t,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ vint64m1_t,
  /*X2_VLMUL_EXT*/ vint32m2_t,
  /*X4_VLMUL_EXT*/ vint32m4_t,
  /*X8_VLMUL_EXT*/ vint32m8_t,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint32m1_t,
  /*MASK*/ vbool32_t,
  /*SIGNED*/ vint32m1_t,
  /*UNSIGNED*/ vuint32m1_t,
  /*EEW8_INDEX*/ vuint8mf4_t,
  /*EEW16_INDEX*/ vuint16mf2_t,
  /*EEW32_INDEX*/ vuint32m1_t,
  /*EEW64_INDEX*/ vuint64m2_t,
  /*SHIFT*/ vuint32m1_t,
  /*DOUBLE_TRUNC*/ vuint16mf2_t,
  /*QUAD_TRUNC*/ vuint8mf4_t,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vuint16mf2_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint16mf2_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ vfloat32m1_t,
  /*LMUL1*/ vuint32m1_t,
  /*WLMUL1*/ vuint64m1_t,
  /*EEW8_INTERPRET*/ vuint8m1_t,
  /*EEW16_INTERPRET*/ vuint16m1_t,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ vuint64m1_t,
  /*X2_VLMUL_EXT*/ vuint32m2_t,
  /*X4_VLMUL_EXT*/ vuint32m4_t,
  /*X8_VLMUL_EXT*/ vuint32m8_t,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint32m2_t,
  /*MASK*/ vbool16_t,
  /*SIGNED*/ vint32m2_t,
  /*UNSIGNED*/ vuint32m2_t,
  /*EEW8_INDEX*/ vuint8mf2_t,
  /*EEW16_INDEX*/ vuint16m1_t,
  /*EEW32_INDEX*/ vuint32m2_t,
  /*EEW64_INDEX*/ vuint64m4_t,
  /*SHIFT*/ vuint32m2_t,
  /*DOUBLE_TRUNC*/ vint16m1_t,
  /*QUAD_TRUNC*/ vint8mf2_t,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vint16m1_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint16m1_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ vuint16m1_t,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ vfloat32m2_t,
  /*LMUL1*/ vint32m1_t,
  /*WLMUL1*/ vint64m1_t,
  /*EEW8_INTERPRET*/ vint8m2_t,
  /*EEW16_INTERPRET*/ vint16m2_t,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ vint64m2_t,
  /*X2_VLMUL_EXT*/ vint32m4_t,
  /*X4_VLMUL_EXT*/ vint32m8_t,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint32m2_t,
  /*MASK*/ vbool16_t,
  /*SIGNED*/ vint32m2_t,
  /*UNSIGNED*/ vuint32m2_t,
  /*EEW8_INDEX*/ vuint8mf2_t,
  /*EEW16_INDEX*/ vuint16m1_t,
  /*EEW32_INDEX*/ vuint32m2_t,
  /*EEW64_INDEX*/ vuint64m4_t,
  /*SHIFT*/ vuint32m2_t,
  /*DOUBLE_TRUNC*/ vuint16m1_t,
  /*QUAD_TRUNC*/ vuint8mf2_t,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vuint16m1_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint16m1_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ vfloat32m2_t,
  /*LMUL1*/ vuint32m1_t,
  /*WLMUL1*/ vuint64m1_t,
  /*EEW8_INTERPRET*/ vuint8m2_t,
  /*EEW16_INTERPRET*/ vuint16m2_t,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ vuint64m2_t,
  /*X2_VLMUL_EXT*/ vuint32m4_t,
  /*X4_VLMUL_EXT*/ vuint32m8_t,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint32m4_t,
  /*MASK*/ vbool8_t,
  /*SIGNED*/ vint32m4_t,
  /*UNSIGNED*/ vuint32m4_t,
  /*EEW8_INDEX*/ vuint8m1_t,
  /*EEW16_INDEX*/ vuint16m2_t,
  /*EEW32_INDEX*/ vuint32m4_t,
  /*EEW64_INDEX*/ vuint64m8_t,
  /*SHIFT*/ vuint32m4_t,
  /*DOUBLE_TRUNC*/ vint16m2_t,
  /*QUAD_TRUNC*/ vint8m1_t,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vint16m2_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint16m2_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ vuint16m2_t,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ vfloat32m4_t,
  /*LMUL1*/ vint32m1_t,
  /*WLMUL1*/ vint64m1_t,
  /*EEW8_INTERPRET*/ vint8m4_t,
  /*EEW16_INTERPRET*/ vint16m4_t,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ vint64m4_t,
  /*X2_VLMUL_EXT*/ vint32m8_t,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint32m4_t,
  /*MASK*/ vbool8_t,
  /*SIGNED*/ vint32m4_t,
  /*UNSIGNED*/ vuint32m4_t,
  /*EEW8_INDEX*/ vuint8m1_t,
  /*EEW16_INDEX*/ vuint16m2_t,
  /*EEW32_INDEX*/ vuint32m4_t,
  /*EEW64_INDEX*/ vuint64m8_t,
  /*SHIFT*/ vuint32m4_t,
  /*DOUBLE_TRUNC*/ vuint16m2_t,
  /*QUAD_TRUNC*/ vuint8m1_t,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vuint16m2_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint16m2_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ vfloat32m4_t,
  /*LMUL1*/ vuint32m1_t,
  /*WLMUL1*/ vuint64m1_t,
  /*EEW8_INTERPRET*/ vuint8m4_t,
  /*EEW16_INTERPRET*/ vuint16m4_t,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ vuint64m4_t,
  /*X2_VLMUL_EXT*/ vuint32m8_t,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint32m8_t,
  /*MASK*/ vbool4_t,
  /*SIGNED*/ vint32m8_t,
  /*UNSIGNED*/ vuint32m8_t,
  /*EEW8_INDEX*/ vuint8m2_t,
  /*EEW16_INDEX*/ vuint16m4_t,
  /*EEW32_INDEX*/ vuint32m8_t,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ vuint32m8_t,
  /*DOUBLE_TRUNC*/ vint16m4_t,
  /*QUAD_TRUNC*/ vint8m2_t,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vint16m4_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint16m4_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ vuint16m4_t,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ vfloat32m8_t,
  /*LMUL1*/ vint32m1_t,
  /*WLMUL1*/ vint64m1_t,
  /*EEW8_INTERPRET*/ vint8m8_t,
  /*EEW16_INTERPRET*/ vint16m8_t,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ vint64m8_t,
  /*X2_VLMUL_EXT*/ INVALID,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint32m8_t,
  /*MASK*/ vbool4_t,
  /*SIGNED*/ vint32m8_t,
  /*UNSIGNED*/ vuint32m8_t,
  /*EEW8_INDEX*/ vuint8m2_t,
  /*EEW16_INDEX*/ vuint16m4_t,
  /*EEW32_INDEX*/ vuint32m8_t,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ vuint32m8_t,
  /*DOUBLE_TRUNC*/ vuint16m4_t,
  /*QUAD_TRUNC*/ vuint8m2_t,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vuint16m4_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint16m4_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ vfloat32m8_t,
  /*LMUL1*/ vuint32m1_t,
  /*WLMUL1*/ vuint64m1_t,
  /*EEW8_INTERPRET*/ vuint8m8_t,
  /*EEW16_INTERPRET*/ vuint16m8_t,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ vuint64m8_t,
  /*X2_VLMUL_EXT*/ INVALID,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint64m1_t,
  /*MASK*/ vbool64_t,
  /*SIGNED*/ vint64m1_t,
  /*UNSIGNED*/ vuint64m1_t,
  /*EEW8_INDEX*/ vuint8mf8_t,
  /*EEW16_INDEX*/ vuint16mf4_t,
  /*EEW32_INDEX*/ vuint32mf2_t,
  /*EEW64_INDEX*/ vuint64m1_t,
  /*SHIFT*/ vuint64m1_t,
  /*DOUBLE_TRUNC*/ vint32mf2_t,
  /*QUAD_TRUNC*/ vint16mf4_t,
  /*OCT_TRUNC*/ vint8mf8_t,
  /*DOUBLE_TRUNC_SCALAR*/ vint32mf2_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint32mf2_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ vuint32mf2_t,
  /*DOUBLE_TRUNC_FLOAT*/ vfloat32mf2_t,
  /*FLOAT*/ vfloat64m1_t,
  /*LMUL1*/ vint64m1_t,
  /*WLMUL1*/ INVALID,
  /*EEW8_INTERPRET*/ vint8m1_t,
  /*EEW16_INTERPRET*/ vint16m1_t,
  /*EEW32_INTERPRET*/ vint32m1_t,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vint64m2_t,
  /*X4_VLMUL_EXT*/ vint64m4_t,
  /*X8_VLMUL_EXT*/ vint64m8_t,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint64m1_t,
  /*MASK*/ vbool64_t,
  /*SIGNED*/ vint64m1_t,
  /*UNSIGNED*/ vuint64m1_t,
  /*EEW8_INDEX*/ vuint8mf8_t,
  /*EEW16_INDEX*/ vuint16mf4_t,
  /*EEW32_INDEX*/ vuint32mf2_t,
  /*EEW64_INDEX*/ vuint64m1_t,
  /*SHIFT*/ vuint64m1_t,
  /*DOUBLE_TRUNC*/ vuint32mf2_t,
  /*QUAD_TRUNC*/ vuint16mf4_t,
  /*OCT_TRUNC*/ vuint8mf8_t,
  /*DOUBLE_TRUNC_SCALAR*/ vuint32mf2_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint32mf2_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ vfloat32mf2_t,
  /*FLOAT*/ vfloat64m1_t,
  /*LMUL1*/ vuint64m1_t,
  /*WLMUL1*/ INVALID,
  /*EEW8_INTERPRET*/ vuint8m1_t,
  /*EEW16_INTERPRET*/ vuint16m1_t,
  /*EEW32_INTERPRET*/ vuint32m1_t,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vuint64m2_t,
  /*X4_VLMUL_EXT*/ vuint64m4_t,
  /*X8_VLMUL_EXT*/ vuint64m8_t,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint64m2_t,
  /*MASK*/ vbool32_t,
  /*SIGNED*/ vint64m2_t,
  /*UNSIGNED*/ vuint64m2_t,
  /*EEW8_INDEX*/ vuint8mf4_t,
  /*EEW16_INDEX*/ vuint16mf2_t,
  /*EEW32_INDEX*/ vuint32m1_t,
  /*EEW64_INDEX*/ vuint64m2_t,
  /*SHIFT*/ vuint64m2_t,
  /*DOUBLE_TRUNC*/ vint32m1_t,
  /*QUAD_TRUNC*/ vint16mf2_t,
  /*OCT_TRUNC*/ vint8mf4_t,
  /*DOUBLE_TRUNC_SCALAR*/ vint32m1_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint32m1_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ vuint32m1_t,
  /*DOUBLE_TRUNC_FLOAT*/ vfloat32m1_t,
  /*FLOAT*/ vfloat64m2_t,
  /*LMUL1*/ vint64m1_t,
  /*WLMUL1*/ INVALID,
  /*EEW8_INTERPRET*/ vint8m2_t,
  /*EEW16_INTERPRET*/ vint16m2_t,
  /*EEW32_INTERPRET*/ vint32m2_t,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vint64m4_t,
  /*X4_VLMUL_EXT*/ vint64m8_t,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint64m2_t,
  /*MASK*/ vbool32_t,
  /*SIGNED*/ vint64m2_t,
  /*UNSIGNED*/ vuint64m2_t,
  /*EEW8_INDEX*/ vuint8mf4_t,
  /*EEW16_INDEX*/ vuint16mf2_t,
  /*EEW32_INDEX*/ vuint32m1_t,
  /*EEW64_INDEX*/ vuint64m2_t,
  /*SHIFT*/ vuint64m2_t,
  /*DOUBLE_TRUNC*/ vuint32m1_t,
  /*QUAD_TRUNC*/ vuint16mf2_t,
  /*OCT_TRUNC*/ vuint8mf4_t,
  /*DOUBLE_TRUNC_SCALAR*/ vuint32m1_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint32m1_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ vfloat32m1_t,
  /*FLOAT*/ vfloat64m2_t,
  /*LMUL1*/ vuint64m1_t,
  /*WLMUL1*/ INVALID,
  /*EEW8_INTERPRET*/ vuint8m2_t,
  /*EEW16_INTERPRET*/ vuint16m2_t,
  /*EEW32_INTERPRET*/ vuint32m2_t,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vuint64m4_t,
  /*X4_VLMUL_EXT*/ vuint64m8_t,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint64m4_t,
  /*MASK*/ vbool16_t,
  /*SIGNED*/ vint64m4_t,
  /*UNSIGNED*/ vuint64m4_t,
  /*EEW8_INDEX*/ vuint8mf2_t,
  /*EEW16_INDEX*/ vuint16m1_t,
  /*EEW32_INDEX*/ vuint32m2_t,
  /*EEW64_INDEX*/ vuint64m4_t,
  /*SHIFT*/ vuint64m4_t,
  /*DOUBLE_TRUNC*/ vint32m2_t,
  /*QUAD_TRUNC*/ vint16m1_t,
  /*OCT_TRUNC*/ vint8mf2_t,
  /*DOUBLE_TRUNC_SCALAR*/ vint32m2_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint32m2_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ vuint32m2_t,
  /*DOUBLE_TRUNC_FLOAT*/ vfloat32m2_t,
  /*FLOAT*/ vfloat64m4_t,
  /*LMUL1*/ vint64m1_t,
  /*WLMUL1*/ INVALID,
  /*EEW8_INTERPRET*/ vint8m4_t,
  /*EEW16_INTERPRET*/ vint16m4_t,
  /*EEW32_INTERPRET*/ vint32m4_t,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vint64m8_t,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint64m4_t,
  /*MASK*/ vbool16_t,
  /*SIGNED*/ vint64m4_t,
  /*UNSIGNED*/ vuint64m4_t,
  /*EEW8_INDEX*/ vuint8mf2_t,
  /*EEW16_INDEX*/ vuint16m1_t,
  /*EEW32_INDEX*/ vuint32m2_t,
  /*EEW64_INDEX*/ vuint64m4_t,
  /*SHIFT*/ vuint64m4_t,
  /*DOUBLE_TRUNC*/ vuint32m2_t,
  /*QUAD_TRUNC*/ vuint16m1_t,
  /*OCT_TRUNC*/ vuint8mf2_t,
  /*DOUBLE_TRUNC_SCALAR*/ vuint32m2_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint32m2_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ vfloat32m2_t,
  /*FLOAT*/ vfloat64m4_t,
  /*LMUL1*/ vuint64m1_t,
  /*WLMUL1*/ INVALID,
  /*EEW8_INTERPRET*/ vuint8m4_t,
  /*EEW16_INTERPRET*/ vuint16m4_t,
  /*EEW32_INTERPRET*/ vuint32m4_t,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vuint64m8_t,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vint64m8_t,
  /*MASK*/ vbool8_t,
  /*SIGNED*/ vint64m8_t,
  /*UNSIGNED*/ vuint64m8_t,
  /*EEW8_INDEX*/ vuint8m1_t,
  /*EEW16_INDEX*/ vuint16m2_t,
  /*EEW32_INDEX*/ vuint32m4_t,
  /*EEW64_INDEX*/ vuint64m8_t,
  /*SHIFT*/ vuint64m8_t,
  /*DOUBLE_TRUNC*/ vint32m4_t,
  /*QUAD_TRUNC*/ vint16m2_t,
  /*OCT_TRUNC*/ vint8m1_t,
  /*DOUBLE_TRUNC_SCALAR*/ vint32m4_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint32m4_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ vuint32m4_t,
  /*DOUBLE_TRUNC_FLOAT*/ vfloat32m4_t,
  /*FLOAT*/ vfloat64m8_t,
  /*LMUL1*/ vint64m1_t,
  /*WLMUL1*/ INVALID,
  /*EEW8_INTERPRET*/ vint8m8_t,
  /*EEW16_INTERPRET*/ vint16m8_t,
  /*EEW32_INTERPRET*/ vint32m8_t,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ INVALID,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vuint64m8_t,
  /*MASK*/ vbool8_t,
  /*SIGNED*/ vint64m8_t,
  /*UNSIGNED*/ vuint64m8_t,
  /*EEW8_INDEX*/ vuint8m1_t,
  /*EEW16_INDEX*/ vuint16m2_t,
  /*EEW32_INDEX*/ vuint32m4_t,
  /*EEW64_INDEX*/ vuint64m8_t,
  /*SHIFT*/ vuint64m8_t,
  /*DOUBLE_TRUNC*/ vuint32m4_t,
  /*QUAD_TRUNC*/ vuint16m2_t,
  /*OCT_TRUNC*/ vuint8m1_t,
  /*DOUBLE_TRUNC_SCALAR*/ vuint32m4_t,
  /*DOUBLE_TRUNC_SIGNED*/ INVALID,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint32m4_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ vfloat32m4_t,
  /*FLOAT*/ vfloat64m8_t,
  /*LMUL1*/ vuint64m1_t,
  /*WLMUL1*/ INVALID,
  /*EEW8_INTERPRET*/ vuint8m8_t,
  /*EEW16_INTERPRET*/ vuint16m8_t,
  /*EEW32_INTERPRET*/ vuint32m8_t,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ INVALID,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vfloat32mf2_t,
  /*MASK*/ vbool64_t,
  /*SIGNED*/ vint32mf2_t,
  /*UNSIGNED*/ vuint32mf2_t,
  /*EEW8_INDEX*/ vuint8mf8_t,
  /*EEW16_INDEX*/ vuint16mf4_t,
  /*EEW32_INDEX*/ vuint32mf2_t,
  /*EEW64_INDEX*/ vuint64m1_t,
  /*SHIFT*/ INVALID,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ vint16mf4_t,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint16mf4_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vfloat32m1_t,
  /*WLMUL1*/ vfloat64m1_t,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vfloat32m1_t,
  /*X4_VLMUL_EXT*/ vfloat32m2_t,
  /*X8_VLMUL_EXT*/ vfloat32m4_t,
  /*X16_VLMUL_EXT*/ vfloat32m8_t,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vfloat32m1_t,
  /*MASK*/ vbool32_t,
  /*SIGNED*/ vint32m1_t,
  /*UNSIGNED*/ vuint32m1_t,
  /*EEW8_INDEX*/ vuint8mf4_t,
  /*EEW16_INDEX*/ vuint16mf2_t,
  /*EEW32_INDEX*/ vuint32m1_t,
  /*EEW64_INDEX*/ vuint64m2_t,
  /*SHIFT*/ INVALID,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ vint16mf2_t,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint16mf2_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vfloat32m1_t,
  /*WLMUL1*/ vfloat64m1_t,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vfloat32m2_t,
  /*X4_VLMUL_EXT*/ vfloat32m4_t,
  /*X8_VLMUL_EXT*/ vfloat32m8_t,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vfloat32m2_t,
  /*MASK*/ vbool16_t,
  /*SIGNED*/ vint32m2_t,
  /*UNSIGNED*/ vuint32m2_t,
  /*EEW8_INDEX*/ vuint8mf2_t,
  /*EEW16_INDEX*/ vuint16m1_t,
  /*EEW32_INDEX*/ vuint32m2_t,
  /*EEW64_INDEX*/ vuint64m4_t,
  /*SHIFT*/ INVALID,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ vint16m1_t,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint16m1_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vfloat32m1_t,
  /*WLMUL1*/ vfloat64m1_t,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vfloat32m4_t,
  /*X4_VLMUL_EXT*/ vfloat32m8_t,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vfloat32m4_t,
  /*MASK*/ vbool8_t,
  /*SIGNED*/ vint32m4_t,
  /*UNSIGNED*/ vuint32m4_t,
  /*EEW8_INDEX*/ vuint8m1_t,
  /*EEW16_INDEX*/ vuint16m2_t,
  /*EEW32_INDEX*/ vuint32m4_t,
  /*EEW64_INDEX*/ vuint64m8_t,
  /*SHIFT*/ INVALID,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ vint16m2_t,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint16m2_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vfloat32m1_t,
  /*WLMUL1*/ vfloat64m1_t,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vfloat32m8_t,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vfloat32m8_t,
  /*MASK*/ vbool4_t,
  /*SIGNED*/ vint32m8_t,
  /*UNSIGNED*/ vuint32m8_t,
  /*EEW8_INDEX*/ vuint8m2_t,
  /*EEW16_INDEX*/ vuint16m4_t,
  /*EEW32_INDEX*/ vuint32m8_t,
  /*EEW64_INDEX*/ INVALID,
  /*SHIFT*/ INVALID,
  /*DOUBLE_TRUNC*/ INVALID,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_SIGNED*/ vint16m4_t,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint16m4_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ INVALID,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vfloat32m1_t,
  /*WLMUL1*/ vfloat64m1_t,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ INVALID,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vfloat64m1_t,
  /*MASK*/ vbool64_t,
  /*SIGNED*/ vint64m1_t,
  /*UNSIGNED*/ vuint64m1_t,
  /*EEW8_INDEX*/ vuint8mf8_t,
  /*EEW16_INDEX*/ vuint16mf4_t,
  /*EEW32_INDEX*/ vuint32mf2_t,
  /*EEW64_INDEX*/ vuint64m1_t,
  /*SHIFT*/ INVALID,
  /*DOUBLE_TRUNC*/ vfloat32mf2_t,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vfloat32mf2_t,
  /*DOUBLE_TRUNC_SIGNED*/ vint32mf2_t,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint32mf2_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ vfloat32mf2_t,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vfloat64m1_t,
  /*WLMUL1*/ INVALID,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vfloat64m2_t,
  /*X4_VLMUL_EXT*/ vfloat64m4_t,
  /*X8_VLMUL_EXT*/ vfloat64m8_t,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vfloat64m2_t,
  /*MASK*/ vbool32_t,
  /*SIGNED*/ vint64m2_t,
  /*UNSIGNED*/ vuint64m2_t,
  /*EEW8_INDEX*/ vuint8mf4_t,
  /*EEW16_INDEX*/ vuint16mf2_t,
  /*EEW32_INDEX*/ vuint32m1_t,
  /*EEW64_INDEX*/ vuint64m2_t,
  /*SHIFT*/ INVALID,
  /*DOUBLE_TRUNC*/ vfloat32m1_t,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vfloat32m1_t,
  /*DOUBLE_TRUNC_SIGNED*/ vint32m1_t,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint32m1_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ vfloat32m1_t,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vfloat64m1_t,
  /*WLMUL1*/ INVALID,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vfloat64m4_t,
  /*X4_VLMUL_EXT*/ vfloat64m8_t,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vfloat64m4_t,
  /*MASK*/ vbool16_t,
  /*SIGNED*/ vint64m4_t,
  /*UNSIGNED*/ vuint64m4_t,
  /*EEW8_INDEX*/ vuint8mf2_t,
  /*EEW16_INDEX*/ vuint16m1_t,
  /*EEW32_INDEX*/ vuint32m2_t,
  /*EEW64_INDEX*/ vuint64m4_t,
  /*SHIFT*/ INVALID,
  /*DOUBLE_TRUNC*/ vfloat32m2_t,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vfloat32m2_t,
  /*DOUBLE_TRUNC_SIGNED*/ vint32m2_t,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint32m2_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ vfloat32m2_t,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vfloat64m1_t,
  /*WLMUL1*/ INVALID,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ vfloat64m8_t,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
DEF_RVV_TYPE_INDEX (
  /*VECTOR*/ vfloat64m8_t,
  /*MASK*/ vbool8_t,
  /*SIGNED*/ vint64m8_t,
  /*UNSIGNED*/ vuint64m8_t,
  /*EEW8_INDEX*/ vuint8m1_t,
  /*EEW16_INDEX*/ vuint16m2_t,
  /*EEW32_INDEX*/ vuint32m4_t,
  /*EEW64_INDEX*/ vuint64m8_t,
  /*SHIFT*/ INVALID,
  /*DOUBLE_TRUNC*/ vfloat32m4_t,
  /*QUAD_TRUNC*/ INVALID,
  /*OCT_TRUNC*/ INVALID,
  /*DOUBLE_TRUNC_SCALAR*/ vfloat32m4_t,
  /*DOUBLE_TRUNC_SIGNED*/ vint32m4_t,
  /*DOUBLE_TRUNC_UNSIGNED*/ vuint32m4_t,
  /*DOUBLE_TRUNC_UNSIGNED_SCALAR*/ INVALID,
  /*DOUBLE_TRUNC_FLOAT*/ vfloat32m4_t,
  /*FLOAT*/ INVALID,
  /*LMUL1*/ vfloat64m1_t,
  /*WLMUL1*/ INVALID,
  /*EEW8_INTERPRET*/ INVALID,
  /*EEW16_INTERPRET*/ INVALID,
  /*EEW32_INTERPRET*/ INVALID,
  /*EEW64_INTERPRET*/ INVALID,
  /*X2_VLMUL_EXT*/ INVALID,
  /*X4_VLMUL_EXT*/ INVALID,
  /*X8_VLMUL_EXT*/ INVALID,
  /*X16_VLMUL_EXT*/ INVALID,
  /*X32_VLMUL_EXT*/ INVALID,
  /*X64_VLMUL_EXT*/ INVALID
)
