/* Generated automatically by the program `genenums'
   from the machine description file.  */

#include "config.h"

#include "system.h"

#include "insn-constants.h"


const char *const unspec_strings[] = {
  "UNSPEC_EH_RETURN",
  "UNSPEC_ADDRESS_FIRST",
  "UNSPEC_PCREL",
  "UNSPEC_LOAD_GOT",
  "UNSPEC_TLS",
  "UNSPEC_TLS_LE",
  "UNSPEC_TLS_IE",
  "UNSPEC_TLS_GD",
  "UNSPEC_AUIPC",
  "UNSPEC_FLT_QUIET",
  "UNSPEC_FLE_QUIET",
  "UNSPEC_COPYSIGN",
  "UNSPEC_LRINT",
  "UNSPEC_LROUND",
  "UNSPEC_FMIN",
  "UNSPEC_FMAX",
  "UNSPEC_TIE",
  "UNSPEC_ORC_B",
  "UNSPEC_BREV8",
  "UNSPEC_ZIP",
  "UNSPEC_UNZIP",
  "UNSPEC_PACK",
  "UNSPEC_PACKH",
  "UNSPEC_PACKW",
  "UNSPEC_CLMUL",
  "UNSPEC_CLMULH",
  "UNSPEC_XPERM8",
  "UNSPEC_XPERM4",
  "UNSPEC_AES_DSI",
  "UNSPEC_AES_DSMI",
  "UNSPEC_AES_DS",
  "UNSPEC_AES_DSM",
  "UNSPEC_AES_IM",
  "UNSPEC_AES_KS1I",
  "UNSPEC_AES_KS2",
  "UNSPEC_AES_ES",
  "UNSPEC_AES_ESM",
  "UNSPEC_AES_ESI",
  "UNSPEC_AES_ESMI",
  "UNSPEC_SHA_256_SIG0",
  "UNSPEC_SHA_256_SIG1",
  "UNSPEC_SHA_256_SUM0",
  "UNSPEC_SHA_256_SUM1",
  "UNSPEC_SHA_512_SIG0",
  "UNSPEC_SHA_512_SIG0H",
  "UNSPEC_SHA_512_SIG0L",
  "UNSPEC_SHA_512_SIG1",
  "UNSPEC_SHA_512_SIG1H",
  "UNSPEC_SHA_512_SIG1L",
  "UNSPEC_SHA_512_SUM0",
  "UNSPEC_SHA_512_SUM0R",
  "UNSPEC_SHA_512_SUM1",
  "UNSPEC_SHA_512_SUM1R",
  "UNSPEC_SM3_P0",
  "UNSPEC_SM3_P1",
  "UNSPEC_SM4_ED",
  "UNSPEC_SM4_KS",
  "UNSPEC_COMPARE_AND_SWAP",
  "UNSPEC_COMPARE_AND_SWAP_SUBWORD",
  "UNSPEC_SYNC_OLD_OP",
  "UNSPEC_SYNC_OLD_OP_SUBWORD",
  "UNSPEC_SYNC_EXCHANGE",
  "UNSPEC_SYNC_EXCHANGE_SUBWORD",
  "UNSPEC_ATOMIC_LOAD",
  "UNSPEC_ATOMIC_STORE",
  "UNSPEC_MEMORY_BARRIER",
  "UNSPEC_VSETVL",
  "UNSPEC_VUNDEF",
  "UNSPEC_VPREDICATE",
  "UNSPEC_VLMAX",
  "UNSPEC_STRIDED",
  "UNSPEC_ORDERED",
  "UNSPEC_UNORDERED",
  "UNSPEC_VMULHS",
  "UNSPEC_VMULHU",
  "UNSPEC_VMULHSU",
  "UNSPEC_VADC",
  "UNSPEC_VSBC",
  "UNSPEC_VMADC",
  "UNSPEC_VMSBC",
  "UNSPEC_OVERFLOW",
  "UNSPEC_VNCLIP",
  "UNSPEC_VNCLIPU",
  "UNSPEC_VSSRL",
  "UNSPEC_VSSRA",
  "UNSPEC_VAADDU",
  "UNSPEC_VAADD",
  "UNSPEC_VASUBU",
  "UNSPEC_VASUB",
  "UNSPEC_VSMUL",
  "UNSPEC_VMSBF",
  "UNSPEC_VMSIF",
  "UNSPEC_VMSOF",
  "UNSPEC_VIOTA",
  "UNSPEC_VFRSQRT7",
  "UNSPEC_VFREC7",
  "UNSPEC_VFCLASS",
  "UNSPEC_VCOPYSIGN",
  "UNSPEC_VNCOPYSIGN",
  "UNSPEC_VXORSIGN",
  "UNSPEC_VFCVT",
  "UNSPEC_UNSIGNED_VFCVT",
  "UNSPEC_ROD",
  "UNSPEC_REDUC",
  "UNSPEC_WREDUC_SUM",
  "UNSPEC_WREDUC_USUM",
  "UNSPEC_VSLIDEUP",
  "UNSPEC_VSLIDEDOWN",
  "UNSPEC_VSLIDE1UP",
  "UNSPEC_VSLIDE1DOWN",
  "UNSPEC_VFSLIDE1UP",
  "UNSPEC_VFSLIDE1DOWN",
  "UNSPEC_VRGATHER",
  "UNSPEC_VRGATHEREI16",
  "UNSPEC_VCOMPRESS",
  "UNSPEC_VLEFF"
};

const char *const unspecv_strings[] = {
  "UNSPECV_GPR_SAVE",
  "UNSPECV_GPR_RESTORE",
  "UNSPECV_FRFLAGS",
  "UNSPECV_FSFLAGS",
  "UNSPECV_FSNVSNAN",
  "UNSPECV_MRET",
  "UNSPECV_SRET",
  "UNSPECV_URET",
  "UNSPECV_BLOCKAGE",
  "UNSPECV_FENCE",
  "UNSPECV_FENCE_I",
  "UNSPEC_SSP_SET",
  "UNSPEC_SSP_TEST",
  "UNSPECV_CLEAN",
  "UNSPECV_FLUSH",
  "UNSPECV_INVAL",
  "UNSPECV_ZERO",
  "UNSPECV_PREI",
  "UNSPECV_PAUSE",
  "UNSPEC_XTHEADFMV",
  "UNSPEC_XTHEADFMV_HW"
};
