/* Generated automatically by the program `genattrtab'
   from the machine description file `md'.  */

#define IN_TARGET_CODE 1
#include "config.h"
#include "system.h"
#include "coretypes.h"
#include "backend.h"
#include "predict.h"
#include "tree.h"
#include "rtl.h"
#include "alias.h"
#include "options.h"
#include "varasm.h"
#include "stor-layout.h"
#include "calls.h"
#include "insn-attr.h"
#include "memmodel.h"
#include "tm_p.h"
#include "insn-config.h"
#include "recog.h"
#include "regs.h"
#include "real.h"
#include "output.h"
#include "toplev.h"
#include "flags.h"
#include "emit-rtl.h"

#define operands recog_data.operand

int
insn_current_length (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;
  enum attr_move_type cached_move_type ATTRIBUTE_UNUSED;
  enum attr_dword_mode cached_dword_mode ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 242:  /* *branchdi */
    case 241:  /* *branchsi */
      extract_insn_cached (insn);
      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[0]) == LABEL_REF ? XEXP (operands[0], 0) : operands[0])) : 0) - (insn_current_reference_address (insn))) <= (4088)) && (((insn_current_reference_address (insn)) - (INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[0]) == LABEL_REF ? XEXP (operands[0], 0) : operands[0])) : 0)) <= (4092)))
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      extract_insn_cached (insn);
      if (get_attr_type (insn) == TYPE_BRANCH)
        {
	  if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[0]) == LABEL_REF ? XEXP (operands[0], 0) : operands[0])) : 0) - (insn_current_reference_address (insn))) <= (4088)) && (((insn_current_reference_address (insn)) - (INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[0]) == LABEL_REF ? XEXP (operands[0], 0) : operands[0])) : 0)) <= (4092)))
	    {
	      return 4;
	    }
	  else
	    {
	      return 8;
	    }
        }
      else
        {
	  return 0;
        }

    default:
      return 0;

    }
}

int
insn_variable_length_p (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;
  enum attr_move_type cached_move_type ATTRIBUTE_UNUSED;
  enum attr_dword_mode cached_dword_mode ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 242:  /* *branchdi */
    case 241:  /* *branchsi */
      return 1;

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (get_attr_type (insn) == TYPE_BRANCH)
        {
	  return 1;
        }
      else
        {
	  return 0;
        }

    default:
      return 0;

    }
}

int
insn_min_length (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;
  enum attr_move_type cached_move_type ATTRIBUTE_UNUSED;
  enum attr_dword_mode cached_dword_mode ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 612:  /* *th_mempair_store_di2 */
    case 611:  /* *th_mempair_store_si2 */
      extract_constrain_insn_cached (insn);
      return 
#line 431 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[0], insn) * 4);

    case 610:  /* *th_mempair_load_di2 */
    case 609:  /* *th_mempair_load_si2 */
      extract_constrain_insn_cached (insn);
      return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);

    case 596:  /* th_fmv_x_hw */
    case 595:  /* th_fmv_x_w */
    case 594:  /* th_fmv_hw_w_x */
      extract_constrain_insn_cached (insn);
      if ((
#line 178 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_64BIT)) == (0))
        {
	  return 8;
        }
      else
        {
	  return 4;
        }

    case 191:  /* *movdf_softfloat */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 0) && ((
#line 178 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_64BIT)) == (0)))
        {
	  return 8;
        }
      else if (which_alternative == 1)
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else if (!((1ULL << which_alternative) & 0x3ULL))
        {
	  return 
#line 431 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[0], insn) * 4);
        }
      else
        {
	  return 4;
        }

    case 190:  /* *movdf_hardfloat_rv64 */
    case 189:  /* *movdf_hardfloat_rv32 */
      extract_constrain_insn_cached (insn);
      if ((((1ULL << which_alternative) & 0xe2ULL)) && ((
#line 178 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_64BIT)) == (0)))
        {
	  return 8;
        }
      else if (((1ULL << which_alternative) & 0x104ULL))
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else if (!((1ULL << which_alternative) & 0x1e7ULL))
        {
	  return 
#line 431 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[0], insn) * 4);
        }
      else
        {
	  return 4;
        }

    case 188:  /* *movsf_softfloat */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 1)
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else if (!((1ULL << which_alternative) & 0x3ULL))
        {
	  return 
#line 431 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[0], insn) * 4);
        }
      else
        {
	  return 4;
        }

    case 180:  /* *movsi_internal */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x24ULL))
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else if (((1ULL << which_alternative) & 0x88ULL))
        {
	  return 
#line 431 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[0], insn) * 4);
        }
      else
        {
	  return 4;
        }

    case 179:  /* *movdi_64bit */
    case 178:  /* *movdi_32bit */
      extract_constrain_insn_cached (insn);
      if ((((1ULL << which_alternative) & 0x51ULL)) && ((
#line 178 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_64BIT)) == (0)))
        {
	  return 8;
        }
      else if ((which_alternative == 1) && ((
#line 178 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_64BIT)) == (0)))
        {
	  return 
#line 424 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_split_const_insns (operands[1]) * 4);
        }
      else if (((1ULL << which_alternative) & 0x24ULL))
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else if (((1ULL << which_alternative) & 0x108ULL))
        {
	  return 
#line 431 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[0], insn) * 4);
        }
      else
        {
	  return 4;
        }

    case 186:  /* *movqi_internal */
    case 181:  /* *movhi_internal */
    case 127:  /* *movhf_softfloat */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 2)
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else if (which_alternative == 3)
        {
	  return 
#line 431 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[0], insn) * 4);
        }
      else
        {
	  return 4;
        }

    case 187:  /* *movsf_hardfloat */
    case 126:  /* *movhf_hardfloat */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x104ULL))
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else if (!((1ULL << which_alternative) & 0x1e7ULL))
        {
	  return 
#line 431 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[0], insn) * 4);
        }
      else
        {
	  return 4;
        }

    case 116:  /* extendsidi2 */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 0) && ((
#line 178 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_64BIT)) == (0)))
        {
	  return 8;
        }
      else if (which_alternative != 0)
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else
        {
	  return 4;
        }

    case 115:  /* zero_extendqidi2 */
    case 114:  /* zero_extendqisi2 */
    case 113:  /* zero_extendqihi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else
        {
	  return 4;
        }

    case 122:  /* *extendhidi2 */
    case 121:  /* *extendhisi2 */
    case 120:  /* *extendhihi2 */
    case 119:  /* *extendqidi2 */
    case 118:  /* *extendqisi2 */
    case 117:  /* *extendqihi2 */
    case 112:  /* *zero_extendhidi2 */
    case 111:  /* *zero_extendhisi2 */
    case 110:  /* *zero_extendsidi2_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 8;
        }
      else
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }

    case 300:  /* call_value_internal */
    case 299:  /* call_internal */
    case 298:  /* sibcall_value_internal */
    case 297:  /* sibcall_internal */
    case 171:  /* got_load_tls_iedi */
    case 170:  /* got_load_tls_iesi */
    case 169:  /* got_load_tls_gddi */
    case 168:  /* got_load_tls_gdsi */
    case 165:  /* got_loaddi */
    case 164:  /* got_loadsi */
    case 614:  /* *th_mempair_load_zero_extendsidi2 */
    case 613:  /* *th_mempair_load_extendsidi2 */
    case 571:  /* *local_pic_store_sfhf */
    case 570:  /* *local_pic_store_sfdf */
    case 569:  /* *local_pic_store_sfsf */
    case 568:  /* *local_pic_store_sfhf */
    case 567:  /* *local_pic_store_sfdf */
    case 566:  /* *local_pic_store_sfsf */
    case 565:  /* *local_pic_store_32dhf */
    case 564:  /* *local_pic_store_32ddf */
    case 563:  /* *local_pic_store_32dsf */
    case 562:  /* *local_pic_store_32dhf */
    case 561:  /* *local_pic_store_32ddf */
    case 560:  /* *local_pic_store_32dsf */
    case 559:  /* *local_pic_storehf */
    case 558:  /* *local_pic_storedf */
    case 557:  /* *local_pic_storesf */
    case 556:  /* *local_pic_storehf */
    case 555:  /* *local_pic_storedf */
    case 554:  /* *local_pic_storesf */
    case 553:  /* *local_pic_storedi */
    case 552:  /* *local_pic_storesi */
    case 551:  /* *local_pic_storehi */
    case 550:  /* *local_pic_storeqi */
    case 549:  /* *local_pic_storedi */
    case 548:  /* *local_pic_storesi */
    case 547:  /* *local_pic_storehi */
    case 546:  /* *local_pic_storeqi */
    case 545:  /* *local_pic_load_sfhf */
    case 544:  /* *local_pic_load_sfdf */
    case 543:  /* *local_pic_load_sfsf */
    case 542:  /* *local_pic_load_32dhf */
    case 541:  /* *local_pic_load_32ddf */
    case 540:  /* *local_pic_load_32dsf */
    case 539:  /* *local_pic_load_32dhf */
    case 538:  /* *local_pic_load_32ddf */
    case 537:  /* *local_pic_load_32dsf */
    case 536:  /* *local_pic_loadhf */
    case 535:  /* *local_pic_loaddf */
    case 534:  /* *local_pic_loadsf */
    case 533:  /* *local_pic_loadhf */
    case 532:  /* *local_pic_loaddf */
    case 531:  /* *local_pic_loadsf */
    case 530:  /* *local_pic_load_usi */
    case 529:  /* *local_pic_load_usi */
    case 528:  /* *local_pic_load_usi */
    case 527:  /* *local_pic_load_uhi */
    case 526:  /* *local_pic_load_uhi */
    case 525:  /* *local_pic_load_uhi */
    case 524:  /* *local_pic_load_uqi */
    case 523:  /* *local_pic_load_uqi */
    case 522:  /* *local_pic_load_uqi */
    case 521:  /* *local_pic_load_ssi */
    case 520:  /* *local_pic_load_ssi */
    case 519:  /* *local_pic_load_ssi */
    case 518:  /* *local_pic_load_shi */
    case 517:  /* *local_pic_load_shi */
    case 516:  /* *local_pic_load_shi */
    case 515:  /* *local_pic_load_sqi */
    case 514:  /* *local_pic_load_sqi */
    case 513:  /* *local_pic_load_sqi */
    case 512:  /* *local_pic_loaddi */
    case 511:  /* *local_pic_loadsi */
    case 510:  /* *local_pic_loadhi */
    case 509:  /* *local_pic_loadqi */
    case 245:  /* *movdidicc */
    case 244:  /* *movsidicc */
    case 243:  /* *movsisicc */
      return 8;

    case 508:  /* subword_atomic_cas_strong */
    case 501:  /* subword_atomic_fetch_strong_and */
    case 500:  /* subword_atomic_fetch_strong_xor */
    case 499:  /* subword_atomic_fetch_strong_or */
    case 498:  /* subword_atomic_fetch_strong_add */
      return 28 /* 0x1c */;

    case 507:  /* atomic_cas_value_strongdi */
    case 506:  /* atomic_cas_value_strongsi */
      return 16 /* 0x10 */;

    case 505:  /* subword_atomic_exchange_strong */
      return 20 /* 0x14 */;

    case 502:  /* subword_atomic_fetch_strong_nand */
      return 32 /* 0x20 */;

    case 481:  /* atomic_storedi */
    case 480:  /* atomic_storesi */
    case 479:  /* atomic_loaddi */
    case 478:  /* atomic_loadsi */
    case 319:  /* stack_protect_test_di */
    case 318:  /* stack_protect_test_si */
    case 317:  /* stack_protect_set_di */
    case 316:  /* stack_protect_set_si */
      return 12 /* 0xc */;

    case 291:  /* blockage */
    case 315:  /* stack_tiedi */
    case 314:  /* stack_tiesi */
      return 0;

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      extract_constrain_insn_cached (insn);
      if ((cached_type = get_attr_type (insn)) == TYPE_BRANCH)
        {
	  return 4;
        }
      else if (cached_type == TYPE_CALL)
        {
	  return 8;
        }
      else if (cached_type == TYPE_GHOST)
        {
	  return 0;
        }
      else if (get_attr_got (insn) == GOT_LOAD)
        {
	  return 8;
        }
      else if ((cached_move_type = get_attr_move_type (insn)) == MOVE_TYPE_SHIFT_SHIFT)
        {
	  return 8;
        }
      else if (((cached_move_type == MOVE_TYPE_MTC) || (cached_move_type == MOVE_TYPE_MFC) || (cached_move_type == MOVE_TYPE_MOVE)) && ((cached_dword_mode = get_attr_dword_mode (insn)) == DWORD_MODE_YES))
        {
	  return 8;
        }
      else if ((cached_move_type == MOVE_TYPE_CONST) && ((cached_dword_mode = get_attr_dword_mode (insn)) == DWORD_MODE_YES))
        {
	  return 
#line 424 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_split_const_insns (operands[1]) * 4);
        }
      else if ((cached_move_type == MOVE_TYPE_LOAD) || (cached_move_type == MOVE_TYPE_FPLOAD))
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else if ((cached_move_type == MOVE_TYPE_STORE) || (cached_move_type == MOVE_TYPE_FPSTORE))
        {
	  return 
#line 431 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[0], insn) * 4);
        }
      else
        {
	  return 4;
        }

    default:
      return 4;

    }
}

int
insn_default_length (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;
  enum attr_move_type cached_move_type ATTRIBUTE_UNUSED;
  enum attr_dword_mode cached_dword_mode ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 612:  /* *th_mempair_store_di2 */
    case 611:  /* *th_mempair_store_si2 */
      extract_constrain_insn_cached (insn);
      return 
#line 431 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[0], insn) * 4);

    case 610:  /* *th_mempair_load_di2 */
    case 609:  /* *th_mempair_load_si2 */
      extract_constrain_insn_cached (insn);
      return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);

    case 596:  /* th_fmv_x_hw */
    case 595:  /* th_fmv_x_w */
    case 594:  /* th_fmv_hw_w_x */
      extract_constrain_insn_cached (insn);
      if ((
#line 178 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_64BIT)) == (0))
        {
	  return 8;
        }
      else
        {
	  return 4;
        }

    case 191:  /* *movdf_softfloat */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 0) && ((
#line 178 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_64BIT)) == (0)))
        {
	  return 8;
        }
      else if (which_alternative == 1)
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else if (!((1ULL << which_alternative) & 0x3ULL))
        {
	  return 
#line 431 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[0], insn) * 4);
        }
      else
        {
	  return 4;
        }

    case 190:  /* *movdf_hardfloat_rv64 */
    case 189:  /* *movdf_hardfloat_rv32 */
      extract_constrain_insn_cached (insn);
      if ((((1ULL << which_alternative) & 0xe2ULL)) && ((
#line 178 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_64BIT)) == (0)))
        {
	  return 8;
        }
      else if (((1ULL << which_alternative) & 0x104ULL))
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else if (!((1ULL << which_alternative) & 0x1e7ULL))
        {
	  return 
#line 431 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[0], insn) * 4);
        }
      else
        {
	  return 4;
        }

    case 188:  /* *movsf_softfloat */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 1)
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else if (!((1ULL << which_alternative) & 0x3ULL))
        {
	  return 
#line 431 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[0], insn) * 4);
        }
      else
        {
	  return 4;
        }

    case 180:  /* *movsi_internal */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x24ULL))
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else if (((1ULL << which_alternative) & 0x88ULL))
        {
	  return 
#line 431 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[0], insn) * 4);
        }
      else
        {
	  return 4;
        }

    case 179:  /* *movdi_64bit */
    case 178:  /* *movdi_32bit */
      extract_constrain_insn_cached (insn);
      if ((((1ULL << which_alternative) & 0x51ULL)) && ((
#line 178 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_64BIT)) == (0)))
        {
	  return 8;
        }
      else if ((which_alternative == 1) && ((
#line 178 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_64BIT)) == (0)))
        {
	  return 
#line 424 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_split_const_insns (operands[1]) * 4);
        }
      else if (((1ULL << which_alternative) & 0x24ULL))
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else if (((1ULL << which_alternative) & 0x108ULL))
        {
	  return 
#line 431 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[0], insn) * 4);
        }
      else
        {
	  return 4;
        }

    case 186:  /* *movqi_internal */
    case 181:  /* *movhi_internal */
    case 127:  /* *movhf_softfloat */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 2)
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else if (which_alternative == 3)
        {
	  return 
#line 431 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[0], insn) * 4);
        }
      else
        {
	  return 4;
        }

    case 187:  /* *movsf_hardfloat */
    case 126:  /* *movhf_hardfloat */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x104ULL))
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else if (!((1ULL << which_alternative) & 0x1e7ULL))
        {
	  return 
#line 431 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[0], insn) * 4);
        }
      else
        {
	  return 4;
        }

    case 116:  /* extendsidi2 */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 0) && ((
#line 178 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_64BIT)) == (0)))
        {
	  return 8;
        }
      else if (which_alternative != 0)
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else
        {
	  return 4;
        }

    case 115:  /* zero_extendqidi2 */
    case 114:  /* zero_extendqisi2 */
    case 113:  /* zero_extendqihi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else
        {
	  return 4;
        }

    case 122:  /* *extendhidi2 */
    case 121:  /* *extendhisi2 */
    case 120:  /* *extendhihi2 */
    case 119:  /* *extendqidi2 */
    case 118:  /* *extendqisi2 */
    case 117:  /* *extendqihi2 */
    case 112:  /* *zero_extendhidi2 */
    case 111:  /* *zero_extendhisi2 */
    case 110:  /* *zero_extendsidi2_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 8;
        }
      else
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }

    case 300:  /* call_value_internal */
    case 299:  /* call_internal */
    case 298:  /* sibcall_value_internal */
    case 297:  /* sibcall_internal */
    case 242:  /* *branchdi */
    case 241:  /* *branchsi */
    case 171:  /* got_load_tls_iedi */
    case 170:  /* got_load_tls_iesi */
    case 169:  /* got_load_tls_gddi */
    case 168:  /* got_load_tls_gdsi */
    case 165:  /* got_loaddi */
    case 164:  /* got_loadsi */
    case 614:  /* *th_mempair_load_zero_extendsidi2 */
    case 613:  /* *th_mempair_load_extendsidi2 */
    case 571:  /* *local_pic_store_sfhf */
    case 570:  /* *local_pic_store_sfdf */
    case 569:  /* *local_pic_store_sfsf */
    case 568:  /* *local_pic_store_sfhf */
    case 567:  /* *local_pic_store_sfdf */
    case 566:  /* *local_pic_store_sfsf */
    case 565:  /* *local_pic_store_32dhf */
    case 564:  /* *local_pic_store_32ddf */
    case 563:  /* *local_pic_store_32dsf */
    case 562:  /* *local_pic_store_32dhf */
    case 561:  /* *local_pic_store_32ddf */
    case 560:  /* *local_pic_store_32dsf */
    case 559:  /* *local_pic_storehf */
    case 558:  /* *local_pic_storedf */
    case 557:  /* *local_pic_storesf */
    case 556:  /* *local_pic_storehf */
    case 555:  /* *local_pic_storedf */
    case 554:  /* *local_pic_storesf */
    case 553:  /* *local_pic_storedi */
    case 552:  /* *local_pic_storesi */
    case 551:  /* *local_pic_storehi */
    case 550:  /* *local_pic_storeqi */
    case 549:  /* *local_pic_storedi */
    case 548:  /* *local_pic_storesi */
    case 547:  /* *local_pic_storehi */
    case 546:  /* *local_pic_storeqi */
    case 545:  /* *local_pic_load_sfhf */
    case 544:  /* *local_pic_load_sfdf */
    case 543:  /* *local_pic_load_sfsf */
    case 542:  /* *local_pic_load_32dhf */
    case 541:  /* *local_pic_load_32ddf */
    case 540:  /* *local_pic_load_32dsf */
    case 539:  /* *local_pic_load_32dhf */
    case 538:  /* *local_pic_load_32ddf */
    case 537:  /* *local_pic_load_32dsf */
    case 536:  /* *local_pic_loadhf */
    case 535:  /* *local_pic_loaddf */
    case 534:  /* *local_pic_loadsf */
    case 533:  /* *local_pic_loadhf */
    case 532:  /* *local_pic_loaddf */
    case 531:  /* *local_pic_loadsf */
    case 530:  /* *local_pic_load_usi */
    case 529:  /* *local_pic_load_usi */
    case 528:  /* *local_pic_load_usi */
    case 527:  /* *local_pic_load_uhi */
    case 526:  /* *local_pic_load_uhi */
    case 525:  /* *local_pic_load_uhi */
    case 524:  /* *local_pic_load_uqi */
    case 523:  /* *local_pic_load_uqi */
    case 522:  /* *local_pic_load_uqi */
    case 521:  /* *local_pic_load_ssi */
    case 520:  /* *local_pic_load_ssi */
    case 519:  /* *local_pic_load_ssi */
    case 518:  /* *local_pic_load_shi */
    case 517:  /* *local_pic_load_shi */
    case 516:  /* *local_pic_load_shi */
    case 515:  /* *local_pic_load_sqi */
    case 514:  /* *local_pic_load_sqi */
    case 513:  /* *local_pic_load_sqi */
    case 512:  /* *local_pic_loaddi */
    case 511:  /* *local_pic_loadsi */
    case 510:  /* *local_pic_loadhi */
    case 509:  /* *local_pic_loadqi */
    case 245:  /* *movdidicc */
    case 244:  /* *movsidicc */
    case 243:  /* *movsisicc */
      return 8;

    case 508:  /* subword_atomic_cas_strong */
    case 501:  /* subword_atomic_fetch_strong_and */
    case 500:  /* subword_atomic_fetch_strong_xor */
    case 499:  /* subword_atomic_fetch_strong_or */
    case 498:  /* subword_atomic_fetch_strong_add */
      return 28 /* 0x1c */;

    case 507:  /* atomic_cas_value_strongdi */
    case 506:  /* atomic_cas_value_strongsi */
      return 16 /* 0x10 */;

    case 505:  /* subword_atomic_exchange_strong */
      return 20 /* 0x14 */;

    case 502:  /* subword_atomic_fetch_strong_nand */
      return 32 /* 0x20 */;

    case 481:  /* atomic_storedi */
    case 480:  /* atomic_storesi */
    case 479:  /* atomic_loaddi */
    case 478:  /* atomic_loadsi */
    case 319:  /* stack_protect_test_di */
    case 318:  /* stack_protect_test_si */
    case 317:  /* stack_protect_set_di */
    case 316:  /* stack_protect_set_si */
      return 12 /* 0xc */;

    case 291:  /* blockage */
    case 315:  /* stack_tiedi */
    case 314:  /* stack_tiesi */
      return 0;

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      extract_constrain_insn_cached (insn);
      if ((cached_type = get_attr_type (insn)) == TYPE_BRANCH)
        {
	  return 8;
        }
      else if (cached_type == TYPE_CALL)
        {
	  return 8;
        }
      else if (cached_type == TYPE_GHOST)
        {
	  return 0;
        }
      else if (get_attr_got (insn) == GOT_LOAD)
        {
	  return 8;
        }
      else if ((cached_move_type = get_attr_move_type (insn)) == MOVE_TYPE_SHIFT_SHIFT)
        {
	  return 8;
        }
      else if (((cached_move_type == MOVE_TYPE_MTC) || (cached_move_type == MOVE_TYPE_MFC) || (cached_move_type == MOVE_TYPE_MOVE)) && ((cached_dword_mode = get_attr_dword_mode (insn)) == DWORD_MODE_YES))
        {
	  return 8;
        }
      else if ((cached_move_type == MOVE_TYPE_CONST) && ((cached_dword_mode = get_attr_dword_mode (insn)) == DWORD_MODE_YES))
        {
	  return 
#line 424 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_split_const_insns (operands[1]) * 4);
        }
      else if ((cached_move_type == MOVE_TYPE_LOAD) || (cached_move_type == MOVE_TYPE_FPLOAD))
        {
	  return 
#line 429 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[1], insn) * 4);
        }
      else if ((cached_move_type == MOVE_TYPE_STORE) || (cached_move_type == MOVE_TYPE_FPSTORE))
        {
	  return 
#line 431 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(riscv_load_store_insns (operands[0], insn) * 4);
        }
      else
        {
	  return 4;
        }

    default:
      return 4;

    }
}

int
bypass_p (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 362:  /* *zero_extendhidi2_zbb */
    case 361:  /* *zero_extendhisi2_zbb */
    case 360:  /* *extendhidi2_zbb */
    case 359:  /* *extendhisi2_zbb */
    case 358:  /* *extendhihi2_zbb */
    case 357:  /* *extendqidi2_zbb */
    case 356:  /* *extendqisi2_zbb */
    case 355:  /* *extendqihi2_zbb */
    case 354:  /* *zero_extendhidi2_bitmanip */
    case 353:  /* *zero_extendhisi2_bitmanip */
    case 331:  /* *zero_extendsidi2_bitmanip */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 1) && (((
#line 441 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(((enum attr_tune) riscv_microarchitecture))) == (
(TUNE_SIFIVE_7)))))
        {
	  return 1;
        }
      else
        {
	  return 0;
        }

    case 191:  /* *movdf_softfloat */
    case 188:  /* *movsf_softfloat */
      extract_constrain_insn_cached (insn);
      if ((((
#line 441 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(((enum attr_tune) riscv_microarchitecture))) == (
(TUNE_SIFIVE_7)))) && (((1ULL << which_alternative) & 0x3ULL)))
        {
	  return 1;
        }
      else
        {
	  return 0;
        }

    case 186:  /* *movqi_internal */
    case 181:  /* *movhi_internal */
      extract_constrain_insn_cached (insn);
      if ((((
#line 441 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(((enum attr_tune) riscv_microarchitecture))) == (
(TUNE_SIFIVE_7)))) && (((1ULL << which_alternative) & 0x35ULL)))
        {
	  return 1;
        }
      else
        {
	  return 0;
        }

    case 180:  /* *movsi_internal */
      extract_constrain_insn_cached (insn);
      if ((((
#line 441 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(((enum attr_tune) riscv_microarchitecture))) == (
(TUNE_SIFIVE_7)))) && (((1ULL << which_alternative) & 0x55ULL)))
        {
	  return 1;
        }
      else
        {
	  return 0;
        }

    case 127:  /* *movhf_softfloat */
      extract_constrain_insn_cached (insn);
      if (((((
#line 441 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(((enum attr_tune) riscv_microarchitecture))) == (
(TUNE_SIFIVE_7)))) && (((1ULL << which_alternative) & 0x17ULL))) || ((which_alternative == 5) && (((
#line 441 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(((enum attr_tune) riscv_microarchitecture))) == (
(TUNE_SIFIVE_7))))))
        {
	  return 1;
        }
      else
        {
	  return 0;
        }

    case 190:  /* *movdf_hardfloat_rv64 */
    case 189:  /* *movdf_hardfloat_rv32 */
    case 187:  /* *movsf_hardfloat */
    case 126:  /* *movhf_hardfloat */
      extract_constrain_insn_cached (insn);
      if ((((
#line 441 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(((enum attr_tune) riscv_microarchitecture))) == (
(TUNE_SIFIVE_7)))) && (((1ULL << which_alternative) & 0x1e3ULL)))
        {
	  return 1;
        }
      else
        {
	  return 0;
        }

    case 122:  /* *extendhidi2 */
    case 121:  /* *extendhisi2 */
    case 120:  /* *extendhihi2 */
    case 119:  /* *extendqidi2 */
    case 118:  /* *extendqisi2 */
    case 117:  /* *extendqihi2 */
    case 116:  /* extendsidi2 */
    case 115:  /* zero_extendqidi2 */
    case 114:  /* zero_extendqisi2 */
    case 113:  /* zero_extendqihi2 */
    case 112:  /* *zero_extendhidi2 */
    case 111:  /* *zero_extendhisi2 */
    case 110:  /* *zero_extendsidi2_internal */
      extract_constrain_insn_cached (insn);
      if (((which_alternative == 1) && (((
#line 441 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(((enum attr_tune) riscv_microarchitecture))) == (
(TUNE_SIFIVE_7))))) || ((((
#line 441 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(((enum attr_tune) riscv_microarchitecture))) == (
(TUNE_SIFIVE_7)))) && (which_alternative == 0)))
        {
	  return 1;
        }
      else
        {
	  return 0;
        }

    case 792:  /* *movvnx64bidi_lra */
    case 791:  /* *movvnx32bidi_lra */
    case 790:  /* *movvnx16bidi_lra */
    case 789:  /* *movvnx8bidi_lra */
    case 788:  /* *movvnx4bidi_lra */
    case 787:  /* *movvnx2bidi_lra */
    case 786:  /* *movvnx1bidi_lra */
    case 785:  /* *movvnx64bisi_lra */
    case 784:  /* *movvnx32bisi_lra */
    case 783:  /* *movvnx16bisi_lra */
    case 782:  /* *movvnx8bisi_lra */
    case 781:  /* *movvnx4bisi_lra */
    case 780:  /* *movvnx2bisi_lra */
    case 779:  /* *movvnx1bisi_lra */
    case 778:  /* *movvnx1sfdi_lra */
    case 777:  /* *movvnx1sfsi_lra */
    case 776:  /* *movvnx1sidi_lra */
    case 775:  /* *movvnx1sisi_lra */
    case 774:  /* *movvnx2hidi_lra */
    case 773:  /* *movvnx2hisi_lra */
    case 772:  /* *movvnx1hidi_lra */
    case 771:  /* *movvnx1hisi_lra */
    case 770:  /* *movvnx4qidi_lra */
    case 769:  /* *movvnx4qisi_lra */
    case 768:  /* *movvnx2qidi_lra */
    case 767:  /* *movvnx2qisi_lra */
    case 766:  /* *movvnx1qidi_lra */
    case 765:  /* *movvnx1qisi_lra */
    case 722:  /* vlmax_avldi */
    case 721:  /* vlmax_avlsi */
    case 720:  /* *vlmul_extx64vnx1qi */
    case 719:  /* *vlmul_extx32vnx1hi */
    case 718:  /* *vlmul_extx32vnx2qi */
    case 717:  /* *vlmul_extx32vnx1qi */
    case 716:  /* *vlmul_extx16vnx1sf */
    case 715:  /* *vlmul_extx16vnx1si */
    case 714:  /* *vlmul_extx16vnx2hi */
    case 713:  /* *vlmul_extx16vnx1hi */
    case 712:  /* *vlmul_extx16vnx4qi */
    case 711:  /* *vlmul_extx16vnx2qi */
    case 710:  /* *vlmul_extx16vnx1qi */
    case 709:  /* *vlmul_extx8vnx1df */
    case 708:  /* *vlmul_extx8vnx2sf */
    case 707:  /* *vlmul_extx8vnx1sf */
    case 706:  /* *vlmul_extx8vnx1di */
    case 705:  /* *vlmul_extx8vnx2si */
    case 704:  /* *vlmul_extx8vnx1si */
    case 703:  /* *vlmul_extx8vnx4hi */
    case 702:  /* *vlmul_extx8vnx2hi */
    case 701:  /* *vlmul_extx8vnx1hi */
    case 700:  /* *vlmul_extx8vnx8qi */
    case 699:  /* *vlmul_extx8vnx4qi */
    case 698:  /* *vlmul_extx8vnx2qi */
    case 697:  /* *vlmul_extx8vnx1qi */
    case 696:  /* *vlmul_extx4vnx2df */
    case 695:  /* *vlmul_extx4vnx1df */
    case 694:  /* *vlmul_extx4vnx4sf */
    case 693:  /* *vlmul_extx4vnx2sf */
    case 692:  /* *vlmul_extx4vnx1sf */
    case 691:  /* *vlmul_extx4vnx2di */
    case 690:  /* *vlmul_extx4vnx1di */
    case 689:  /* *vlmul_extx4vnx4si */
    case 688:  /* *vlmul_extx4vnx2si */
    case 687:  /* *vlmul_extx4vnx1si */
    case 686:  /* *vlmul_extx4vnx8hi */
    case 685:  /* *vlmul_extx4vnx4hi */
    case 684:  /* *vlmul_extx4vnx2hi */
    case 683:  /* *vlmul_extx4vnx1hi */
    case 682:  /* *vlmul_extx4vnx16qi */
    case 681:  /* *vlmul_extx4vnx8qi */
    case 680:  /* *vlmul_extx4vnx4qi */
    case 679:  /* *vlmul_extx4vnx2qi */
    case 678:  /* *vlmul_extx4vnx1qi */
    case 677:  /* *vlmul_extx2vnx4df */
    case 676:  /* *vlmul_extx2vnx2df */
    case 675:  /* *vlmul_extx2vnx1df */
    case 674:  /* *vlmul_extx2vnx8sf */
    case 673:  /* *vlmul_extx2vnx4sf */
    case 672:  /* *vlmul_extx2vnx2sf */
    case 671:  /* *vlmul_extx2vnx1sf */
    case 670:  /* *vlmul_extx2vnx4di */
    case 669:  /* *vlmul_extx2vnx2di */
    case 668:  /* *vlmul_extx2vnx1di */
    case 667:  /* *vlmul_extx2vnx8si */
    case 666:  /* *vlmul_extx2vnx4si */
    case 665:  /* *vlmul_extx2vnx2si */
    case 664:  /* *vlmul_extx2vnx1si */
    case 663:  /* *vlmul_extx2vnx16hi */
    case 662:  /* *vlmul_extx2vnx8hi */
    case 661:  /* *vlmul_extx2vnx4hi */
    case 660:  /* *vlmul_extx2vnx2hi */
    case 659:  /* *vlmul_extx2vnx1hi */
    case 658:  /* *vlmul_extx2vnx32qi */
    case 657:  /* *vlmul_extx2vnx16qi */
    case 656:  /* *vlmul_extx2vnx8qi */
    case 655:  /* *vlmul_extx2vnx4qi */
    case 654:  /* *vlmul_extx2vnx2qi */
    case 653:  /* *vlmul_extx2vnx1qi */
    case 652:  /* vundefinedvnx64bi */
    case 651:  /* vundefinedvnx32bi */
    case 650:  /* vundefinedvnx16bi */
    case 649:  /* vundefinedvnx8bi */
    case 648:  /* vundefinedvnx4bi */
    case 647:  /* vundefinedvnx2bi */
    case 646:  /* vundefinedvnx1bi */
    case 645:  /* vundefinedvnx8df */
    case 644:  /* vundefinedvnx4df */
    case 643:  /* vundefinedvnx2df */
    case 642:  /* vundefinedvnx1df */
    case 641:  /* vundefinedvnx16sf */
    case 640:  /* vundefinedvnx8sf */
    case 639:  /* vundefinedvnx4sf */
    case 638:  /* vundefinedvnx2sf */
    case 637:  /* vundefinedvnx1sf */
    case 636:  /* vundefinedvnx8di */
    case 635:  /* vundefinedvnx4di */
    case 634:  /* vundefinedvnx2di */
    case 633:  /* vundefinedvnx1di */
    case 632:  /* vundefinedvnx16si */
    case 631:  /* vundefinedvnx8si */
    case 630:  /* vundefinedvnx4si */
    case 629:  /* vundefinedvnx2si */
    case 628:  /* vundefinedvnx1si */
    case 627:  /* vundefinedvnx32hi */
    case 626:  /* vundefinedvnx16hi */
    case 625:  /* vundefinedvnx8hi */
    case 624:  /* vundefinedvnx4hi */
    case 623:  /* vundefinedvnx2hi */
    case 622:  /* vundefinedvnx1hi */
    case 621:  /* vundefinedvnx64qi */
    case 620:  /* vundefinedvnx32qi */
    case 619:  /* vundefinedvnx16qi */
    case 618:  /* vundefinedvnx8qi */
    case 617:  /* vundefinedvnx4qi */
    case 616:  /* vundefinedvnx2qi */
    case 615:  /* vundefinedvnx1qi */
    case 614:  /* *th_mempair_load_zero_extendsidi2 */
    case 613:  /* *th_mempair_load_extendsidi2 */
    case 610:  /* *th_mempair_load_di2 */
    case 609:  /* *th_mempair_load_si2 */
    case 608:  /* *th_sextw_msubhisi4 */
    case 607:  /* *th_msubhisi4 */
    case 606:  /* *th_mulswsi2 */
    case 605:  /* *th_mulswsi */
    case 604:  /* *th_mulsdi */
    case 603:  /* *th_mulssi */
    case 602:  /* *th_sextw_maddhisi4 */
    case 601:  /* *th_maddhisi4 */
    case 600:  /* *th_mulawsi2 */
    case 599:  /* *th_mulawsi */
    case 598:  /* *th_muladi */
    case 597:  /* *th_mulasi */
    case 596:  /* th_fmv_x_hw */
    case 595:  /* th_fmv_x_w */
    case 594:  /* th_fmv_hw_w_x */
    case 571:  /* *local_pic_store_sfhf */
    case 570:  /* *local_pic_store_sfdf */
    case 569:  /* *local_pic_store_sfsf */
    case 568:  /* *local_pic_store_sfhf */
    case 567:  /* *local_pic_store_sfdf */
    case 566:  /* *local_pic_store_sfsf */
    case 565:  /* *local_pic_store_32dhf */
    case 564:  /* *local_pic_store_32ddf */
    case 563:  /* *local_pic_store_32dsf */
    case 562:  /* *local_pic_store_32dhf */
    case 561:  /* *local_pic_store_32ddf */
    case 560:  /* *local_pic_store_32dsf */
    case 559:  /* *local_pic_storehf */
    case 558:  /* *local_pic_storedf */
    case 557:  /* *local_pic_storesf */
    case 556:  /* *local_pic_storehf */
    case 555:  /* *local_pic_storedf */
    case 554:  /* *local_pic_storesf */
    case 553:  /* *local_pic_storedi */
    case 552:  /* *local_pic_storesi */
    case 551:  /* *local_pic_storehi */
    case 550:  /* *local_pic_storeqi */
    case 549:  /* *local_pic_storedi */
    case 548:  /* *local_pic_storesi */
    case 547:  /* *local_pic_storehi */
    case 546:  /* *local_pic_storeqi */
    case 545:  /* *local_pic_load_sfhf */
    case 544:  /* *local_pic_load_sfdf */
    case 543:  /* *local_pic_load_sfsf */
    case 542:  /* *local_pic_load_32dhf */
    case 541:  /* *local_pic_load_32ddf */
    case 540:  /* *local_pic_load_32dsf */
    case 539:  /* *local_pic_load_32dhf */
    case 538:  /* *local_pic_load_32ddf */
    case 537:  /* *local_pic_load_32dsf */
    case 536:  /* *local_pic_loadhf */
    case 535:  /* *local_pic_loaddf */
    case 534:  /* *local_pic_loadsf */
    case 533:  /* *local_pic_loadhf */
    case 532:  /* *local_pic_loaddf */
    case 531:  /* *local_pic_loadsf */
    case 530:  /* *local_pic_load_usi */
    case 529:  /* *local_pic_load_usi */
    case 528:  /* *local_pic_load_usi */
    case 527:  /* *local_pic_load_uhi */
    case 526:  /* *local_pic_load_uhi */
    case 525:  /* *local_pic_load_uhi */
    case 524:  /* *local_pic_load_uqi */
    case 523:  /* *local_pic_load_uqi */
    case 522:  /* *local_pic_load_uqi */
    case 521:  /* *local_pic_load_ssi */
    case 520:  /* *local_pic_load_ssi */
    case 519:  /* *local_pic_load_ssi */
    case 518:  /* *local_pic_load_shi */
    case 517:  /* *local_pic_load_shi */
    case 516:  /* *local_pic_load_shi */
    case 515:  /* *local_pic_load_sqi */
    case 514:  /* *local_pic_load_sqi */
    case 513:  /* *local_pic_load_sqi */
    case 512:  /* *local_pic_loaddi */
    case 511:  /* *local_pic_loadsi */
    case 510:  /* *local_pic_loadhi */
    case 509:  /* *local_pic_loadqi */
    case 508:  /* subword_atomic_cas_strong */
    case 505:  /* subword_atomic_exchange_strong */
    case 502:  /* subword_atomic_fetch_strong_nand */
    case 501:  /* subword_atomic_fetch_strong_and */
    case 500:  /* subword_atomic_fetch_strong_xor */
    case 499:  /* subword_atomic_fetch_strong_or */
    case 498:  /* subword_atomic_fetch_strong_add */
    case 477:  /* mem_thread_fence_1 */
    case 420:  /* *branchdi_mask_twobits_equals_singlebit */
    case 419:  /* *branchsi_mask_twobits_equals_singlebit */
    case 418:  /* *andidi_extrabit */
    case 417:  /* *andisi_extrabit */
    case 416:  /* *xoridi_extrabit */
    case 415:  /* *ioridi_extrabit */
    case 414:  /* *xorisi_extrabit */
    case 413:  /* *iorisi_extrabit */
    case 402:  /* *bclridisi_nottwobits */
    case 401:  /* *bclridi_nottwobits */
    case 400:  /* *bclrisi_nottwobits */
    case 384:  /* *minmax */
    case 383:  /* *minmax */
    case 382:  /* *minmax */
    case 381:  /* *minmax */
    case 370:  /* orcbdi2 */
    case 369:  /* orcbsi2 */
    case 334:  /* *andi_add.uw */
    case 330:  /* riscv_prefetchi_di */
    case 329:  /* riscv_prefetchi_si */
    case 328:  /* prefetch */
    case 327:  /* riscv_zero_di */
    case 326:  /* riscv_zero_si */
    case 325:  /* riscv_inval_di */
    case 324:  /* riscv_inval_si */
    case 323:  /* riscv_flush_di */
    case 322:  /* riscv_flush_si */
    case 321:  /* riscv_clean_di */
    case 320:  /* riscv_clean_si */
    case 319:  /* stack_protect_test_di */
    case 318:  /* stack_protect_test_si */
    case 317:  /* stack_protect_set_di */
    case 316:  /* stack_protect_set_si */
    case 315:  /* stack_tiedi */
    case 314:  /* stack_tiesi */
    case 313:  /* riscv_uret */
    case 312:  /* riscv_sret */
    case 311:  /* riscv_mret */
    case 310:  /* *riscv_fsnvsnanhf2 */
    case 309:  /* *riscv_fsnvsnandf2 */
    case 308:  /* *riscv_fsnvsnansf2 */
    case 307:  /* riscv_fsflags */
    case 306:  /* riscv_frflags */
    case 305:  /* gpr_restore_return */
    case 304:  /* gpr_restore */
    case 303:  /* gpr_save */
    case 302:  /* trap */
    case 296:  /* eh_return_internal */
    case 295:  /* eh_set_lr_di */
    case 294:  /* eh_set_lr_si */
    case 285:  /* *sleu_didi */
    case 284:  /* *sle_didi */
    case 283:  /* *sleu_disi */
    case 282:  /* *sle_disi */
    case 281:  /* *sleu_sisi */
    case 280:  /* *sle_sisi */
    case 279:  /* *sltu_didi */
    case 278:  /* *slt_didi */
    case 277:  /* *sltu_disi */
    case 276:  /* *slt_disi */
    case 275:  /* *sltu_sisi */
    case 274:  /* *slt_sisi */
    case 273:  /* *sgeu_didi */
    case 272:  /* *sge_didi */
    case 271:  /* *sgeu_disi */
    case 270:  /* *sge_disi */
    case 269:  /* *sgeu_sisi */
    case 268:  /* *sge_sisi */
    case 267:  /* *sgtu_didi */
    case 266:  /* *sgt_didi */
    case 265:  /* *sgtu_disi */
    case 264:  /* *sgt_disi */
    case 263:  /* *sgtu_sisi */
    case 262:  /* *sgt_sisi */
    case 261:  /* *sne_zero_didi */
    case 260:  /* *sne_zero_disi */
    case 259:  /* *sne_zero_sisi */
    case 258:  /* *seq_zero_didi */
    case 257:  /* *seq_zero_disi */
    case 256:  /* *seq_zero_sisi */
    case 255:  /* *cstorehfdi4 */
    case 254:  /* *cstorehfsi4 */
    case 253:  /* *cstoredfdi4 */
    case 252:  /* *cstoredfsi4 */
    case 251:  /* *cstoresfdi4 */
    case 250:  /* *cstoresfsi4 */
    case 249:  /* *branch_on_bit_rangedi */
    case 248:  /* *branch_on_bit_rangesi */
    case 247:  /* *branch_on_bitdi */
    case 246:  /* *branch_on_bitsi */
    case 245:  /* *movdidicc */
    case 244:  /* *movsidicc */
    case 243:  /* *movsisicc */
    case 240:  /* *branchdi_shiftedmask_equals_zero */
    case 239:  /* *branchsi_shiftedmask_equals_zero */
    case 238:  /* *branchhi_shiftedmask_equals_zero */
    case 237:  /* *branchqi_shiftedmask_equals_zero */
    case 236:  /* *branchdi_shiftedmask_equals_zero */
    case 235:  /* *branchsi_shiftedmask_equals_zero */
    case 234:  /* *branchhi_shiftedmask_equals_zero */
    case 233:  /* *branchqi_shiftedmask_equals_zero */
    case 232:  /* *branchdi_shiftedarith_equals_zero */
    case 231:  /* *branchsi_shiftedarith_equals_zero */
    case 230:  /* *branchhi_shiftedarith_equals_zero */
    case 229:  /* *branchqi_shiftedarith_equals_zero */
    case 228:  /* *branchsi_shiftedarith_equals_zero */
    case 227:  /* *branchhi_shiftedarith_equals_zero */
    case 226:  /* *branchqi_shiftedarith_equals_zero */
    case 225:  /* zero_extendsidi2_shifted */
    case 224:  /* *lshrsi3_zero_extend_3 */
    case 223:  /* *lshrsi3_zero_extend_2 */
    case 222:  /* *lshrsi3_zero_extend_1 */
    case 221:  /* *lshrsi3_extend_mask_1 */
    case 220:  /* *ashrsi3_extend_mask_1 */
    case 219:  /* *ashlsi3_extend_mask_1 */
    case 218:  /* *lshrsi3_extend_mask */
    case 217:  /* *ashrsi3_extend_mask */
    case 216:  /* *ashlsi3_extend_mask */
    case 215:  /* *lshrsi3_extend */
    case 214:  /* *ashrsi3_extend */
    case 213:  /* *ashlsi3_extend */
    case 212:  /* *lshrdi3_mask_1 */
    case 211:  /* *ashrdi3_mask_1 */
    case 210:  /* *ashldi3_mask_1 */
    case 209:  /* *lshrdi3_mask */
    case 208:  /* *ashrdi3_mask */
    case 207:  /* *ashldi3_mask */
    case 206:  /* lshrdi3 */
    case 205:  /* ashrdi3 */
    case 204:  /* ashldi3 */
    case 203:  /* *lshrsi3_mask_1 */
    case 202:  /* *ashrsi3_mask_1 */
    case 201:  /* *ashlsi3_mask_1 */
    case 200:  /* *lshrsi3_mask */
    case 199:  /* *ashrsi3_mask */
    case 198:  /* *ashlsi3_mask */
    case 197:  /* lshrsi3 */
    case 196:  /* ashrsi3 */
    case 195:  /* ashlsi3 */
    case 194:  /* riscv_pause */
    case 193:  /* fence_i */
    case 192:  /* fence */
    case 185:  /* *xorsihi3 */
    case 184:  /* *xorhihi3 */
    case 183:  /* *addsihi3 */
    case 182:  /* *addhihi3 */
    case 177:  /* *mvconst_internal */
    case 176:  /* *mvconst_internal */
    case 175:  /* *lowdi */
    case 174:  /* *lowsi */
    case 171:  /* got_load_tls_iedi */
    case 170:  /* got_load_tls_iesi */
    case 169:  /* got_load_tls_gddi */
    case 168:  /* got_load_tls_gdsi */
    case 167:  /* tls_add_tp_ledi */
    case 166:  /* tls_add_tp_lesi */
    case 165:  /* got_loaddi */
    case 164:  /* got_loadsi */
    case 163:  /* lroundhfdi2 */
    case 162:  /* lrinthfdi2 */
    case 161:  /* lroundhfsi2 */
    case 160:  /* lrinthfsi2 */
    case 159:  /* lrounddfdi2 */
    case 158:  /* lrintdfdi2 */
    case 157:  /* lrounddfsi2 */
    case 156:  /* lrintdfsi2 */
    case 155:  /* lroundsfdi2 */
    case 154:  /* lrintsfdi2 */
    case 153:  /* lroundsfsi2 */
    case 152:  /* lrintsfsi2 */
    case 151:  /* floatunsdihf2 */
    case 150:  /* floatunssihf2 */
    case 149:  /* floatunsdidf2 */
    case 148:  /* floatunssidf2 */
    case 147:  /* floatunsdisf2 */
    case 146:  /* floatunssisf2 */
    case 145:  /* floatdihf2 */
    case 144:  /* floatsihf2 */
    case 143:  /* floatdidf2 */
    case 142:  /* floatsidf2 */
    case 141:  /* floatdisf2 */
    case 140:  /* floatsisf2 */
    case 139:  /* fixuns_trunchfdi2 */
    case 138:  /* fixuns_trunchfsi2 */
    case 137:  /* fixuns_truncdfdi2 */
    case 136:  /* fixuns_truncdfsi2 */
    case 135:  /* fixuns_truncsfdi2 */
    case 134:  /* fixuns_truncsfsi2 */
    case 133:  /* fix_trunchfdi2 */
    case 132:  /* fix_trunchfsi2 */
    case 131:  /* fix_truncdfdi2 */
    case 130:  /* fix_truncdfsi2 */
    case 129:  /* fix_truncsfdi2 */
    case 128:  /* fix_truncsfsi2 */
    case 125:  /* extendhfdf2 */
    case 124:  /* extendsfdf2 */
    case 123:  /* extendhfsf2 */
    case 109:  /* truncdfhf2 */
    case 108:  /* truncsfhf2 */
    case 107:  /* truncdfsf2 */
    case 106:  /* *one_cmplsi2_internal */
    case 105:  /* one_cmpldi2 */
    case 104:  /* one_cmplsi2 */
    case 103:  /* *xorsi3_internal */
    case 102:  /* *iorsi3_internal */
    case 101:  /* *andsi3_internal */
    case 100:  /* xordi3 */
    case 99:  /* iordi3 */
    case 98:  /* anddi3 */
    case 97:  /* xorsi3 */
    case 96:  /* iorsi3 */
    case 95:  /* andsi3 */
    case 94:  /* smaxhf3 */
    case 93:  /* smaxdf3 */
    case 92:  /* smaxsf3 */
    case 91:  /* sminhf3 */
    case 90:  /* smindf3 */
    case 89:  /* sminsf3 */
    case 88:  /* fmaxhf3 */
    case 87:  /* fmaxdf3 */
    case 86:  /* fmaxsf3 */
    case 85:  /* fminhf3 */
    case 84:  /* fmindf3 */
    case 83:  /* fminsf3 */
    case 82:  /* neghf2 */
    case 81:  /* negdf2 */
    case 80:  /* negsf2 */
    case 79:  /* copysignhf3 */
    case 78:  /* copysigndf3 */
    case 77:  /* copysignsf3 */
    case 76:  /* abshf2 */
    case 75:  /* absdf2 */
    case 74:  /* abssf2 */
    case 31:  /* usmulsi3_highpart */
    case 30:  /* umulsi3_highpart */
    case 29:  /* smulsi3_highpart */
    case 28:  /* usmuldi3_highpart */
    case 27:  /* umuldi3_highpart */
    case 26:  /* smuldi3_highpart */
    case 25:  /* *mulsi3_extended2 */
    case 24:  /* *mulsi3_extended */
    case 23:  /* muldi3 */
    case 22:  /* mulsi3 */
    case 18:  /* *negsi2_extended2 */
    case 17:  /* *negsi2_extended */
    case 16:  /* negsi2 */
    case 15:  /* negdi2 */
    case 14:  /* *subsi3_extended2 */
    case 13:  /* *subsi3_extended */
    case 12:  /* subsi3 */
    case 11:  /* subdi3 */
    case 7:  /* *addsi3_extended2 */
    case 6:  /* *addsi3_extended */
    case 5:  /* adddi3 */
    case 4:  /* addsi3 */
      if (((
#line 441 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(((enum attr_tune) riscv_microarchitecture))) == (
(TUNE_SIFIVE_7))))
        {
	  return 1;
        }
      else
        {
	  return 0;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    case 178:  /* *movdi_32bit */
    case 179:  /* *movdi_64bit */
      if ((((
#line 441 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(((enum attr_tune) riscv_microarchitecture))) == (
(TUNE_SIFIVE_7)))) && ((cached_type = get_attr_type (insn)) == TYPE_LOAD))
        {
	  return 1;
        }
      else if ((((
#line 441 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(((enum attr_tune) riscv_microarchitecture))) == (
(TUNE_SIFIVE_7)))) && ((cached_type = get_attr_type (insn)) == TYPE_SFB_ALU))
        {
	  return 1;
        }
      else if ((((
#line 441 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(((enum attr_tune) riscv_microarchitecture))) == (
(TUNE_SIFIVE_7)))) && ((cached_type = get_attr_type (insn)) == TYPE_IMUL))
        {
	  return 1;
        }
      else if ((((
#line 441 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(((enum attr_tune) riscv_microarchitecture))) == (
(TUNE_SIFIVE_7)))) && (((cached_type = get_attr_type (insn)) == TYPE_UNKNOWN) || (cached_type == TYPE_ARITH) || (cached_type == TYPE_SHIFT) || (cached_type == TYPE_SLT) || (cached_type == TYPE_MULTI) || (cached_type == TYPE_LOGICAL) || (cached_type == TYPE_MOVE)))
        {
	  return 1;
        }
      else if ((((
#line 441 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(((enum attr_tune) riscv_microarchitecture))) == (
(TUNE_SIFIVE_7)))) && (((cached_type = get_attr_type (insn)) == TYPE_FCVT) || (cached_type == TYPE_FCMP) || (cached_type == TYPE_FMOVE)))
        {
	  return 1;
        }
      else if ((((
#line 441 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(((enum attr_tune) riscv_microarchitecture))) == (
(TUNE_SIFIVE_7)))) && ((cached_type = get_attr_type (insn)) == TYPE_MTC))
        {
	  return 1;
        }
      else if ((((
#line 441 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(((enum attr_tune) riscv_microarchitecture))) == (
(TUNE_SIFIVE_7)))) && ((cached_type = get_attr_type (insn)) == TYPE_MFC))
        {
	  return 1;
        }
      else
        {
	  return 0;
        }

    default:
      return 0;

    }
}

int
num_delay_slots (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return 0;

    }
}

int
get_attr_avl_type (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 4338:  /* *pred_minus_mulvnx8di_extended_scalar */
    case 4337:  /* *pred_minus_mulvnx4di_extended_scalar */
    case 4336:  /* *pred_minus_mulvnx2di_extended_scalar */
    case 4335:  /* *pred_minus_mulvnx1di_extended_scalar */
    case 4326:  /* *pred_minus_mulvnx8di_scalar */
    case 4325:  /* *pred_minus_mulvnx4di_scalar */
    case 4324:  /* *pred_minus_mulvnx2di_scalar */
    case 4323:  /* *pred_minus_mulvnx1di_scalar */
    case 4322:  /* *pred_minus_mulvnx16si_scalar */
    case 4321:  /* *pred_minus_mulvnx8si_scalar */
    case 4320:  /* *pred_minus_mulvnx4si_scalar */
    case 4319:  /* *pred_minus_mulvnx2si_scalar */
    case 4318:  /* *pred_minus_mulvnx1si_scalar */
    case 4317:  /* *pred_minus_mulvnx32hi_scalar */
    case 4316:  /* *pred_minus_mulvnx16hi_scalar */
    case 4315:  /* *pred_minus_mulvnx8hi_scalar */
    case 4314:  /* *pred_minus_mulvnx4hi_scalar */
    case 4313:  /* *pred_minus_mulvnx2hi_scalar */
    case 4312:  /* *pred_minus_mulvnx1hi_scalar */
    case 4311:  /* *pred_minus_mulvnx64qi_scalar */
    case 4310:  /* *pred_minus_mulvnx32qi_scalar */
    case 4309:  /* *pred_minus_mulvnx16qi_scalar */
    case 4308:  /* *pred_minus_mulvnx8qi_scalar */
    case 4307:  /* *pred_minus_mulvnx4qi_scalar */
    case 4306:  /* *pred_minus_mulvnx2qi_scalar */
    case 4305:  /* *pred_minus_mulvnx1qi_scalar */
    case 4260:  /* *pred_minus_mulvnx8di */
    case 4259:  /* *pred_minus_mulvnx4di */
    case 4258:  /* *pred_minus_mulvnx2di */
    case 4257:  /* *pred_minus_mulvnx1di */
    case 4256:  /* *pred_minus_mulvnx16si */
    case 4255:  /* *pred_minus_mulvnx8si */
    case 4254:  /* *pred_minus_mulvnx4si */
    case 4253:  /* *pred_minus_mulvnx2si */
    case 4252:  /* *pred_minus_mulvnx1si */
    case 4251:  /* *pred_minus_mulvnx32hi */
    case 4250:  /* *pred_minus_mulvnx16hi */
    case 4249:  /* *pred_minus_mulvnx8hi */
    case 4248:  /* *pred_minus_mulvnx4hi */
    case 4247:  /* *pred_minus_mulvnx2hi */
    case 4246:  /* *pred_minus_mulvnx1hi */
    case 4245:  /* *pred_minus_mulvnx64qi */
    case 4244:  /* *pred_minus_mulvnx32qi */
    case 4243:  /* *pred_minus_mulvnx16qi */
    case 4242:  /* *pred_minus_mulvnx8qi */
    case 4241:  /* *pred_minus_mulvnx4qi */
    case 4240:  /* *pred_minus_mulvnx2qi */
    case 4239:  /* *pred_minus_mulvnx1qi */
    case 4194:  /* *pred_mul_plusvnx8di_extended_scalar */
    case 4193:  /* *pred_mul_plusvnx4di_extended_scalar */
    case 4192:  /* *pred_mul_plusvnx2di_extended_scalar */
    case 4191:  /* *pred_mul_plusvnx1di_extended_scalar */
    case 4182:  /* *pred_mul_plusvnx8di_scalar */
    case 4181:  /* *pred_mul_plusvnx4di_scalar */
    case 4180:  /* *pred_mul_plusvnx2di_scalar */
    case 4179:  /* *pred_mul_plusvnx1di_scalar */
    case 4178:  /* *pred_mul_plusvnx16si_scalar */
    case 4177:  /* *pred_mul_plusvnx8si_scalar */
    case 4176:  /* *pred_mul_plusvnx4si_scalar */
    case 4175:  /* *pred_mul_plusvnx2si_scalar */
    case 4174:  /* *pred_mul_plusvnx1si_scalar */
    case 4173:  /* *pred_mul_plusvnx32hi_scalar */
    case 4172:  /* *pred_mul_plusvnx16hi_scalar */
    case 4171:  /* *pred_mul_plusvnx8hi_scalar */
    case 4170:  /* *pred_mul_plusvnx4hi_scalar */
    case 4169:  /* *pred_mul_plusvnx2hi_scalar */
    case 4168:  /* *pred_mul_plusvnx1hi_scalar */
    case 4167:  /* *pred_mul_plusvnx64qi_scalar */
    case 4166:  /* *pred_mul_plusvnx32qi_scalar */
    case 4165:  /* *pred_mul_plusvnx16qi_scalar */
    case 4164:  /* *pred_mul_plusvnx8qi_scalar */
    case 4163:  /* *pred_mul_plusvnx4qi_scalar */
    case 4162:  /* *pred_mul_plusvnx2qi_scalar */
    case 4161:  /* *pred_mul_plusvnx1qi_scalar */
    case 4116:  /* *pred_mul_plusvnx8di */
    case 4115:  /* *pred_mul_plusvnx4di */
    case 4114:  /* *pred_mul_plusvnx2di */
    case 4113:  /* *pred_mul_plusvnx1di */
    case 4112:  /* *pred_mul_plusvnx16si */
    case 4111:  /* *pred_mul_plusvnx8si */
    case 4110:  /* *pred_mul_plusvnx4si */
    case 4109:  /* *pred_mul_plusvnx2si */
    case 4108:  /* *pred_mul_plusvnx1si */
    case 4107:  /* *pred_mul_plusvnx32hi */
    case 4106:  /* *pred_mul_plusvnx16hi */
    case 4105:  /* *pred_mul_plusvnx8hi */
    case 4104:  /* *pred_mul_plusvnx4hi */
    case 4103:  /* *pred_mul_plusvnx2hi */
    case 4102:  /* *pred_mul_plusvnx1hi */
    case 4101:  /* *pred_mul_plusvnx64qi */
    case 4100:  /* *pred_mul_plusvnx32qi */
    case 4099:  /* *pred_mul_plusvnx16qi */
    case 4098:  /* *pred_mul_plusvnx8qi */
    case 4097:  /* *pred_mul_plusvnx4qi */
    case 4096:  /* *pred_mul_plusvnx2qi */
    case 4095:  /* *pred_mul_plusvnx1qi */
      extract_constrain_insn_cached (insn);
      return 
#line 345 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[9]));

    case 998:  /* pred_strided_loadvnx8df */
    case 997:  /* pred_strided_loadvnx4df */
    case 996:  /* pred_strided_loadvnx2df */
    case 995:  /* pred_strided_loadvnx1df */
    case 994:  /* pred_strided_loadvnx16sf */
    case 993:  /* pred_strided_loadvnx8sf */
    case 992:  /* pred_strided_loadvnx4sf */
    case 991:  /* pred_strided_loadvnx2sf */
    case 990:  /* pred_strided_loadvnx1sf */
    case 989:  /* pred_strided_loadvnx8di */
    case 988:  /* pred_strided_loadvnx4di */
    case 987:  /* pred_strided_loadvnx2di */
    case 986:  /* pred_strided_loadvnx1di */
    case 985:  /* pred_strided_loadvnx16si */
    case 984:  /* pred_strided_loadvnx8si */
    case 983:  /* pred_strided_loadvnx4si */
    case 982:  /* pred_strided_loadvnx2si */
    case 981:  /* pred_strided_loadvnx1si */
    case 980:  /* pred_strided_loadvnx32hi */
    case 979:  /* pred_strided_loadvnx16hi */
    case 978:  /* pred_strided_loadvnx8hi */
    case 977:  /* pred_strided_loadvnx4hi */
    case 976:  /* pred_strided_loadvnx2hi */
    case 975:  /* pred_strided_loadvnx1hi */
    case 974:  /* pred_strided_loadvnx64qi */
    case 973:  /* pred_strided_loadvnx32qi */
    case 972:  /* pred_strided_loadvnx16qi */
    case 971:  /* pred_strided_loadvnx8qi */
    case 970:  /* pred_strided_loadvnx4qi */
    case 969:  /* pred_strided_loadvnx2qi */
    case 968:  /* pred_strided_loadvnx1qi */
      extract_constrain_insn_cached (insn);
      if (
#line 239 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(VECTOR_MODE_P (GET_MODE (operands[3]))))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 324 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[7]));
        }

    case 963:  /* *pred_broadcastvnx8df */
    case 962:  /* *pred_broadcastvnx4df */
    case 961:  /* *pred_broadcastvnx2df */
    case 960:  /* *pred_broadcastvnx1df */
    case 959:  /* *pred_broadcastvnx16sf */
    case 958:  /* *pred_broadcastvnx8sf */
    case 957:  /* *pred_broadcastvnx4sf */
    case 956:  /* *pred_broadcastvnx2sf */
    case 955:  /* *pred_broadcastvnx1sf */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 
#line 324 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[7]));
        }
      else
        {
	  if (
#line 239 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(VECTOR_MODE_P (GET_MODE (operands[3]))))
	    {
	      return 255 /* 0xff */;
	    }
	  else
	    {
	      return 
#line 324 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[7]));
	    }
        }

    case 954:  /* *pred_broadcastvnx8di */
    case 953:  /* *pred_broadcastvnx4di */
    case 952:  /* *pred_broadcastvnx2di */
    case 951:  /* *pred_broadcastvnx1di */
    case 950:  /* *pred_broadcastvnx16si */
    case 949:  /* *pred_broadcastvnx8si */
    case 948:  /* *pred_broadcastvnx4si */
    case 947:  /* *pred_broadcastvnx2si */
    case 946:  /* *pred_broadcastvnx1si */
    case 945:  /* *pred_broadcastvnx32hi */
    case 944:  /* *pred_broadcastvnx16hi */
    case 943:  /* *pred_broadcastvnx8hi */
    case 942:  /* *pred_broadcastvnx4hi */
    case 941:  /* *pred_broadcastvnx2hi */
    case 940:  /* *pred_broadcastvnx1hi */
    case 939:  /* *pred_broadcastvnx64qi */
    case 938:  /* *pred_broadcastvnx32qi */
    case 937:  /* *pred_broadcastvnx16qi */
    case 936:  /* *pred_broadcastvnx8qi */
    case 935:  /* *pred_broadcastvnx4qi */
    case 934:  /* *pred_broadcastvnx2qi */
    case 933:  /* *pred_broadcastvnx1qi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 
#line 324 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[7]));
        }
      else
        {
	  if (
#line 239 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(VECTOR_MODE_P (GET_MODE (operands[3]))))
	    {
	      return 255 /* 0xff */;
	    }
	  else
	    {
	      return 
#line 324 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[7]));
	    }
        }

    case 6036:  /* read_vldi_zero_extend */
    case 6035:  /* read_vlsi */
    case 5779:  /* *pred_extract_firstvnx8df */
    case 5778:  /* *pred_extract_firstvnx4df */
    case 5777:  /* *pred_extract_firstvnx2df */
    case 5776:  /* *pred_extract_firstvnx1df */
    case 5775:  /* *pred_extract_firstvnx16sf */
    case 5774:  /* *pred_extract_firstvnx8sf */
    case 5773:  /* *pred_extract_firstvnx4sf */
    case 5772:  /* *pred_extract_firstvnx2sf */
    case 5771:  /* *pred_extract_firstvnx1sf */
    case 5770:  /* pred_extract_first_truncvnx8di */
    case 5769:  /* pred_extract_first_truncvnx4di */
    case 5768:  /* pred_extract_first_truncvnx2di */
    case 5767:  /* pred_extract_first_truncvnx1di */
    case 5766:  /* *pred_extract_firstvnx8di */
    case 5765:  /* *pred_extract_firstvnx4di */
    case 5764:  /* *pred_extract_firstvnx2di */
    case 5763:  /* *pred_extract_firstvnx1di */
    case 5762:  /* *pred_extract_firstvnx16si */
    case 5761:  /* *pred_extract_firstvnx8si */
    case 5760:  /* *pred_extract_firstvnx4si */
    case 5759:  /* *pred_extract_firstvnx2si */
    case 5758:  /* *pred_extract_firstvnx1si */
    case 5757:  /* *pred_extract_firstvnx32hi */
    case 5756:  /* *pred_extract_firstvnx16hi */
    case 5755:  /* *pred_extract_firstvnx8hi */
    case 5754:  /* *pred_extract_firstvnx4hi */
    case 5753:  /* *pred_extract_firstvnx2hi */
    case 5752:  /* *pred_extract_firstvnx1hi */
    case 5751:  /* *pred_extract_firstvnx64qi */
    case 5750:  /* *pred_extract_firstvnx32qi */
    case 5749:  /* *pred_extract_firstvnx16qi */
    case 5748:  /* *pred_extract_firstvnx8qi */
    case 5747:  /* *pred_extract_firstvnx4qi */
    case 5746:  /* *pred_extract_firstvnx2qi */
    case 5745:  /* *pred_extract_firstvnx1qi */
    case 4577:  /* pred_iotavnx8di */
    case 4576:  /* pred_iotavnx4di */
    case 4575:  /* pred_iotavnx2di */
    case 4574:  /* pred_iotavnx1di */
    case 4573:  /* pred_iotavnx16si */
    case 4572:  /* pred_iotavnx8si */
    case 4571:  /* pred_iotavnx4si */
    case 4570:  /* pred_iotavnx2si */
    case 4569:  /* pred_iotavnx1si */
    case 4568:  /* pred_iotavnx32hi */
    case 4567:  /* pred_iotavnx16hi */
    case 4566:  /* pred_iotavnx8hi */
    case 4565:  /* pred_iotavnx4hi */
    case 4564:  /* pred_iotavnx2hi */
    case 4563:  /* pred_iotavnx1hi */
    case 4562:  /* pred_iotavnx64qi */
    case 4561:  /* pred_iotavnx32qi */
    case 4560:  /* pred_iotavnx16qi */
    case 4559:  /* pred_iotavnx8qi */
    case 4558:  /* pred_iotavnx4qi */
    case 4557:  /* pred_iotavnx2qi */
    case 4556:  /* pred_iotavnx1qi */
    case 1029:  /* pred_strided_storevnx8df */
    case 1028:  /* pred_strided_storevnx4df */
    case 1027:  /* pred_strided_storevnx2df */
    case 1026:  /* pred_strided_storevnx1df */
    case 1025:  /* pred_strided_storevnx16sf */
    case 1024:  /* pred_strided_storevnx8sf */
    case 1023:  /* pred_strided_storevnx4sf */
    case 1022:  /* pred_strided_storevnx2sf */
    case 1021:  /* pred_strided_storevnx1sf */
    case 1020:  /* pred_strided_storevnx8di */
    case 1019:  /* pred_strided_storevnx4di */
    case 1018:  /* pred_strided_storevnx2di */
    case 1017:  /* pred_strided_storevnx1di */
    case 1016:  /* pred_strided_storevnx16si */
    case 1015:  /* pred_strided_storevnx8si */
    case 1014:  /* pred_strided_storevnx4si */
    case 1013:  /* pred_strided_storevnx2si */
    case 1012:  /* pred_strided_storevnx1si */
    case 1011:  /* pred_strided_storevnx32hi */
    case 1010:  /* pred_strided_storevnx16hi */
    case 1009:  /* pred_strided_storevnx8hi */
    case 1008:  /* pred_strided_storevnx4hi */
    case 1007:  /* pred_strided_storevnx2hi */
    case 1006:  /* pred_strided_storevnx1hi */
    case 1005:  /* pred_strided_storevnx64qi */
    case 1004:  /* pred_strided_storevnx32qi */
    case 1003:  /* pred_strided_storevnx16qi */
    case 1002:  /* pred_strided_storevnx8qi */
    case 1001:  /* pred_strided_storevnx4qi */
    case 1000:  /* pred_strided_storevnx2qi */
    case 999:  /* pred_strided_storevnx1qi */
    case 799:  /* vsetvldi_no_side_effects */
    case 798:  /* vsetvlsi_no_side_effects */
    case 797:  /* vsetvl_discard_resultdi */
    case 796:  /* vsetvl_discard_resultsi */
    case 795:  /* vsetvl_vtype_change_only */
    case 794:  /* vsetvldi */
    case 793:  /* vsetvlsi */
    case 792:  /* *movvnx64bidi_lra */
    case 791:  /* *movvnx32bidi_lra */
    case 790:  /* *movvnx16bidi_lra */
    case 789:  /* *movvnx8bidi_lra */
    case 788:  /* *movvnx4bidi_lra */
    case 787:  /* *movvnx2bidi_lra */
    case 786:  /* *movvnx1bidi_lra */
    case 785:  /* *movvnx64bisi_lra */
    case 784:  /* *movvnx32bisi_lra */
    case 783:  /* *movvnx16bisi_lra */
    case 782:  /* *movvnx8bisi_lra */
    case 781:  /* *movvnx4bisi_lra */
    case 780:  /* *movvnx2bisi_lra */
    case 779:  /* *movvnx1bisi_lra */
    case 778:  /* *movvnx1sfdi_lra */
    case 777:  /* *movvnx1sfsi_lra */
    case 776:  /* *movvnx1sidi_lra */
    case 775:  /* *movvnx1sisi_lra */
    case 774:  /* *movvnx2hidi_lra */
    case 773:  /* *movvnx2hisi_lra */
    case 772:  /* *movvnx1hidi_lra */
    case 771:  /* *movvnx1hisi_lra */
    case 770:  /* *movvnx4qidi_lra */
    case 769:  /* *movvnx4qisi_lra */
    case 768:  /* *movvnx2qidi_lra */
    case 767:  /* *movvnx2qisi_lra */
    case 766:  /* *movvnx1qidi_lra */
    case 765:  /* *movvnx1qisi_lra */
    case 764:  /* *movvnx64bi */
    case 763:  /* *movvnx32bi */
    case 762:  /* *movvnx16bi */
    case 761:  /* *movvnx8bi */
    case 760:  /* *movvnx4bi */
    case 759:  /* *movvnx2bi */
    case 758:  /* *movvnx1bi */
    case 757:  /* *movvnx1sf_fract */
    case 756:  /* *movvnx1si_fract */
    case 755:  /* *movvnx2hi_fract */
    case 754:  /* *movvnx1hi_fract */
    case 753:  /* *movvnx4qi_fract */
    case 752:  /* *movvnx2qi_fract */
    case 751:  /* *movvnx1qi_fract */
    case 750:  /* *movvnx8df_whole */
    case 749:  /* *movvnx4df_whole */
    case 748:  /* *movvnx2df_whole */
    case 747:  /* *movvnx1df_whole */
    case 746:  /* *movvnx16sf_whole */
    case 745:  /* *movvnx8sf_whole */
    case 744:  /* *movvnx4sf_whole */
    case 743:  /* *movvnx2sf_whole */
    case 742:  /* *movvnx1sf_whole */
    case 741:  /* *movvnx8di_whole */
    case 740:  /* *movvnx4di_whole */
    case 739:  /* *movvnx2di_whole */
    case 738:  /* *movvnx1di_whole */
    case 737:  /* *movvnx16si_whole */
    case 736:  /* *movvnx8si_whole */
    case 735:  /* *movvnx4si_whole */
    case 734:  /* *movvnx2si_whole */
    case 733:  /* *movvnx1si_whole */
    case 732:  /* *movvnx32hi_whole */
    case 731:  /* *movvnx16hi_whole */
    case 730:  /* *movvnx8hi_whole */
    case 729:  /* *movvnx4hi_whole */
    case 728:  /* *movvnx2hi_whole */
    case 727:  /* *movvnx64qi_whole */
    case 726:  /* *movvnx32qi_whole */
    case 725:  /* *movvnx16qi_whole */
    case 724:  /* *movvnx8qi_whole */
    case 723:  /* *movvnx4qi_whole */
    case 722:  /* vlmax_avldi */
    case 721:  /* vlmax_avlsi */
    case 720:  /* *vlmul_extx64vnx1qi */
    case 719:  /* *vlmul_extx32vnx1hi */
    case 718:  /* *vlmul_extx32vnx2qi */
    case 717:  /* *vlmul_extx32vnx1qi */
    case 716:  /* *vlmul_extx16vnx1sf */
    case 715:  /* *vlmul_extx16vnx1si */
    case 714:  /* *vlmul_extx16vnx2hi */
    case 713:  /* *vlmul_extx16vnx1hi */
    case 712:  /* *vlmul_extx16vnx4qi */
    case 711:  /* *vlmul_extx16vnx2qi */
    case 710:  /* *vlmul_extx16vnx1qi */
    case 709:  /* *vlmul_extx8vnx1df */
    case 708:  /* *vlmul_extx8vnx2sf */
    case 707:  /* *vlmul_extx8vnx1sf */
    case 706:  /* *vlmul_extx8vnx1di */
    case 705:  /* *vlmul_extx8vnx2si */
    case 704:  /* *vlmul_extx8vnx1si */
    case 703:  /* *vlmul_extx8vnx4hi */
    case 702:  /* *vlmul_extx8vnx2hi */
    case 701:  /* *vlmul_extx8vnx1hi */
    case 700:  /* *vlmul_extx8vnx8qi */
    case 699:  /* *vlmul_extx8vnx4qi */
    case 698:  /* *vlmul_extx8vnx2qi */
    case 697:  /* *vlmul_extx8vnx1qi */
    case 696:  /* *vlmul_extx4vnx2df */
    case 695:  /* *vlmul_extx4vnx1df */
    case 694:  /* *vlmul_extx4vnx4sf */
    case 693:  /* *vlmul_extx4vnx2sf */
    case 692:  /* *vlmul_extx4vnx1sf */
    case 691:  /* *vlmul_extx4vnx2di */
    case 690:  /* *vlmul_extx4vnx1di */
    case 689:  /* *vlmul_extx4vnx4si */
    case 688:  /* *vlmul_extx4vnx2si */
    case 687:  /* *vlmul_extx4vnx1si */
    case 686:  /* *vlmul_extx4vnx8hi */
    case 685:  /* *vlmul_extx4vnx4hi */
    case 684:  /* *vlmul_extx4vnx2hi */
    case 683:  /* *vlmul_extx4vnx1hi */
    case 682:  /* *vlmul_extx4vnx16qi */
    case 681:  /* *vlmul_extx4vnx8qi */
    case 680:  /* *vlmul_extx4vnx4qi */
    case 679:  /* *vlmul_extx4vnx2qi */
    case 678:  /* *vlmul_extx4vnx1qi */
    case 677:  /* *vlmul_extx2vnx4df */
    case 676:  /* *vlmul_extx2vnx2df */
    case 675:  /* *vlmul_extx2vnx1df */
    case 674:  /* *vlmul_extx2vnx8sf */
    case 673:  /* *vlmul_extx2vnx4sf */
    case 672:  /* *vlmul_extx2vnx2sf */
    case 671:  /* *vlmul_extx2vnx1sf */
    case 670:  /* *vlmul_extx2vnx4di */
    case 669:  /* *vlmul_extx2vnx2di */
    case 668:  /* *vlmul_extx2vnx1di */
    case 667:  /* *vlmul_extx2vnx8si */
    case 666:  /* *vlmul_extx2vnx4si */
    case 665:  /* *vlmul_extx2vnx2si */
    case 664:  /* *vlmul_extx2vnx1si */
    case 663:  /* *vlmul_extx2vnx16hi */
    case 662:  /* *vlmul_extx2vnx8hi */
    case 661:  /* *vlmul_extx2vnx4hi */
    case 660:  /* *vlmul_extx2vnx2hi */
    case 659:  /* *vlmul_extx2vnx1hi */
    case 658:  /* *vlmul_extx2vnx32qi */
    case 657:  /* *vlmul_extx2vnx16qi */
    case 656:  /* *vlmul_extx2vnx8qi */
    case 655:  /* *vlmul_extx2vnx4qi */
    case 654:  /* *vlmul_extx2vnx2qi */
    case 653:  /* *vlmul_extx2vnx1qi */
    case 652:  /* vundefinedvnx64bi */
    case 651:  /* vundefinedvnx32bi */
    case 650:  /* vundefinedvnx16bi */
    case 649:  /* vundefinedvnx8bi */
    case 648:  /* vundefinedvnx4bi */
    case 647:  /* vundefinedvnx2bi */
    case 646:  /* vundefinedvnx1bi */
    case 645:  /* vundefinedvnx8df */
    case 644:  /* vundefinedvnx4df */
    case 643:  /* vundefinedvnx2df */
    case 642:  /* vundefinedvnx1df */
    case 641:  /* vundefinedvnx16sf */
    case 640:  /* vundefinedvnx8sf */
    case 639:  /* vundefinedvnx4sf */
    case 638:  /* vundefinedvnx2sf */
    case 637:  /* vundefinedvnx1sf */
    case 636:  /* vundefinedvnx8di */
    case 635:  /* vundefinedvnx4di */
    case 634:  /* vundefinedvnx2di */
    case 633:  /* vundefinedvnx1di */
    case 632:  /* vundefinedvnx16si */
    case 631:  /* vundefinedvnx8si */
    case 630:  /* vundefinedvnx4si */
    case 629:  /* vundefinedvnx2si */
    case 628:  /* vundefinedvnx1si */
    case 627:  /* vundefinedvnx32hi */
    case 626:  /* vundefinedvnx16hi */
    case 625:  /* vundefinedvnx8hi */
    case 624:  /* vundefinedvnx4hi */
    case 623:  /* vundefinedvnx2hi */
    case 622:  /* vundefinedvnx1hi */
    case 621:  /* vundefinedvnx64qi */
    case 620:  /* vundefinedvnx32qi */
    case 619:  /* vundefinedvnx16qi */
    case 618:  /* vundefinedvnx8qi */
    case 617:  /* vundefinedvnx4qi */
    case 616:  /* vundefinedvnx2qi */
    case 615:  /* vundefinedvnx1qi */
    case 614:  /* *th_mempair_load_zero_extendsidi2 */
    case 613:  /* *th_mempair_load_extendsidi2 */
    case 612:  /* *th_mempair_store_di2 */
    case 611:  /* *th_mempair_store_si2 */
    case 610:  /* *th_mempair_load_di2 */
    case 609:  /* *th_mempair_load_si2 */
    case 608:  /* *th_sextw_msubhisi4 */
    case 607:  /* *th_msubhisi4 */
    case 606:  /* *th_mulswsi2 */
    case 605:  /* *th_mulswsi */
    case 604:  /* *th_mulsdi */
    case 603:  /* *th_mulssi */
    case 602:  /* *th_sextw_maddhisi4 */
    case 601:  /* *th_maddhisi4 */
    case 600:  /* *th_mulawsi2 */
    case 599:  /* *th_mulawsi */
    case 598:  /* *th_muladi */
    case 597:  /* *th_mulasi */
    case 596:  /* th_fmv_x_hw */
    case 595:  /* th_fmv_x_w */
    case 594:  /* th_fmv_hw_w_x */
    case 593:  /* *th_cond_gpr_movdidi */
    case 592:  /* *th_cond_gpr_movsidi */
    case 591:  /* *th_cond_gpr_movdisi */
    case 590:  /* *th_cond_gpr_movsisi */
    case 589:  /* *th_cond_movdidi */
    case 588:  /* *th_cond_movsidi */
    case 587:  /* *th_cond_movdisi */
    case 586:  /* *th_cond_movsisi */
    case 585:  /* *th_tstdi3 */
    case 584:  /* *th_tstsi3 */
    case 583:  /* *th_revdi2 */
    case 582:  /* *th_revsi2 */
    case 581:  /* *th_clzdi2 */
    case 580:  /* *th_clzsi2 */
    case 579:  /* *th_extudi4 */
    case 578:  /* *th_extusi4 */
    case 577:  /* *th_extdi4 */
    case 576:  /* *th_extsi4 */
    case 575:  /* *th_srridi3 */
    case 574:  /* *th_srrisi3 */
    case 573:  /* *th_addsldi4 */
    case 572:  /* *th_addslsi4 */
    case 571:  /* *local_pic_store_sfhf */
    case 570:  /* *local_pic_store_sfdf */
    case 569:  /* *local_pic_store_sfsf */
    case 568:  /* *local_pic_store_sfhf */
    case 567:  /* *local_pic_store_sfdf */
    case 566:  /* *local_pic_store_sfsf */
    case 565:  /* *local_pic_store_32dhf */
    case 564:  /* *local_pic_store_32ddf */
    case 563:  /* *local_pic_store_32dsf */
    case 562:  /* *local_pic_store_32dhf */
    case 561:  /* *local_pic_store_32ddf */
    case 560:  /* *local_pic_store_32dsf */
    case 559:  /* *local_pic_storehf */
    case 558:  /* *local_pic_storedf */
    case 557:  /* *local_pic_storesf */
    case 556:  /* *local_pic_storehf */
    case 555:  /* *local_pic_storedf */
    case 554:  /* *local_pic_storesf */
    case 553:  /* *local_pic_storedi */
    case 552:  /* *local_pic_storesi */
    case 551:  /* *local_pic_storehi */
    case 550:  /* *local_pic_storeqi */
    case 549:  /* *local_pic_storedi */
    case 548:  /* *local_pic_storesi */
    case 547:  /* *local_pic_storehi */
    case 546:  /* *local_pic_storeqi */
    case 545:  /* *local_pic_load_sfhf */
    case 544:  /* *local_pic_load_sfdf */
    case 543:  /* *local_pic_load_sfsf */
    case 542:  /* *local_pic_load_32dhf */
    case 541:  /* *local_pic_load_32ddf */
    case 540:  /* *local_pic_load_32dsf */
    case 539:  /* *local_pic_load_32dhf */
    case 538:  /* *local_pic_load_32ddf */
    case 537:  /* *local_pic_load_32dsf */
    case 536:  /* *local_pic_loadhf */
    case 535:  /* *local_pic_loaddf */
    case 534:  /* *local_pic_loadsf */
    case 533:  /* *local_pic_loadhf */
    case 532:  /* *local_pic_loaddf */
    case 531:  /* *local_pic_loadsf */
    case 530:  /* *local_pic_load_usi */
    case 529:  /* *local_pic_load_usi */
    case 528:  /* *local_pic_load_usi */
    case 527:  /* *local_pic_load_uhi */
    case 526:  /* *local_pic_load_uhi */
    case 525:  /* *local_pic_load_uhi */
    case 524:  /* *local_pic_load_uqi */
    case 523:  /* *local_pic_load_uqi */
    case 522:  /* *local_pic_load_uqi */
    case 521:  /* *local_pic_load_ssi */
    case 520:  /* *local_pic_load_ssi */
    case 519:  /* *local_pic_load_ssi */
    case 518:  /* *local_pic_load_shi */
    case 517:  /* *local_pic_load_shi */
    case 516:  /* *local_pic_load_shi */
    case 515:  /* *local_pic_load_sqi */
    case 514:  /* *local_pic_load_sqi */
    case 513:  /* *local_pic_load_sqi */
    case 512:  /* *local_pic_loaddi */
    case 511:  /* *local_pic_loadsi */
    case 510:  /* *local_pic_loadhi */
    case 509:  /* *local_pic_loadqi */
    case 508:  /* subword_atomic_cas_strong */
    case 507:  /* atomic_cas_value_strongdi */
    case 506:  /* atomic_cas_value_strongsi */
    case 505:  /* subword_atomic_exchange_strong */
    case 504:  /* atomic_exchangedi */
    case 503:  /* atomic_exchangesi */
    case 502:  /* subword_atomic_fetch_strong_nand */
    case 501:  /* subword_atomic_fetch_strong_and */
    case 500:  /* subword_atomic_fetch_strong_xor */
    case 499:  /* subword_atomic_fetch_strong_or */
    case 498:  /* subword_atomic_fetch_strong_add */
    case 497:  /* atomic_fetch_anddi */
    case 496:  /* atomic_fetch_xordi */
    case 495:  /* atomic_fetch_ordi */
    case 494:  /* atomic_fetch_adddi */
    case 493:  /* atomic_fetch_andsi */
    case 492:  /* atomic_fetch_xorsi */
    case 491:  /* atomic_fetch_orsi */
    case 490:  /* atomic_fetch_addsi */
    case 489:  /* atomic_anddi */
    case 488:  /* atomic_xordi */
    case 487:  /* atomic_ordi */
    case 486:  /* atomic_adddi */
    case 485:  /* atomic_andsi */
    case 484:  /* atomic_xorsi */
    case 483:  /* atomic_orsi */
    case 482:  /* atomic_addsi */
    case 481:  /* atomic_storedi */
    case 480:  /* atomic_storesi */
    case 479:  /* atomic_loaddi */
    case 478:  /* atomic_loadsi */
    case 477:  /* mem_thread_fence_1 */
    case 476:  /* riscv_sm4ks_di */
    case 475:  /* riscv_sm4ks_si */
    case 474:  /* riscv_sm4ed_di */
    case 473:  /* riscv_sm4ed_si */
    case 472:  /* riscv_sm3p1_di */
    case 471:  /* riscv_sm3p1_si */
    case 470:  /* riscv_sm3p0_di */
    case 469:  /* riscv_sm3p0_si */
    case 468:  /* riscv_sha512sum1 */
    case 467:  /* riscv_sha512sum0 */
    case 466:  /* riscv_sha512sig1 */
    case 465:  /* riscv_sha512sig0 */
    case 464:  /* riscv_sha512sum1r */
    case 463:  /* riscv_sha512sum0r */
    case 462:  /* riscv_sha512sig1l */
    case 461:  /* riscv_sha512sig1h */
    case 460:  /* riscv_sha512sig0l */
    case 459:  /* riscv_sha512sig0h */
    case 458:  /* riscv_sha256sum1_di */
    case 457:  /* riscv_sha256sum1_si */
    case 456:  /* riscv_sha256sum0_di */
    case 455:  /* riscv_sha256sum0_si */
    case 454:  /* riscv_sha256sig1_di */
    case 453:  /* riscv_sha256sig1_si */
    case 452:  /* riscv_sha256sig0_di */
    case 451:  /* riscv_sha256sig0_si */
    case 450:  /* riscv_aes64esm */
    case 449:  /* riscv_aes64es */
    case 448:  /* riscv_aes32esmi */
    case 447:  /* riscv_aes32esi */
    case 446:  /* riscv_aes64ks2 */
    case 445:  /* riscv_aes64ks1i */
    case 444:  /* riscv_aes64im */
    case 443:  /* riscv_aes64dsm */
    case 442:  /* riscv_aes64ds */
    case 441:  /* riscv_aes32dsmi */
    case 440:  /* riscv_aes32dsi */
    case 439:  /* riscv_xperm8_di */
    case 438:  /* riscv_xperm8_si */
    case 437:  /* riscv_xperm4_di */
    case 436:  /* riscv_xperm4_si */
    case 435:  /* riscv_clmulh_di */
    case 434:  /* riscv_clmulh_si */
    case 433:  /* riscv_clmul_di */
    case 432:  /* riscv_clmul_si */
    case 431:  /* riscv_packw */
    case 430:  /* riscv_packh_di */
    case 429:  /* riscv_packh_si */
    case 428:  /* riscv_pack_disi */
    case 427:  /* riscv_pack_dihi */
    case 426:  /* riscv_pack_sisi */
    case 425:  /* riscv_pack_sihi */
    case 424:  /* riscv_unzip */
    case 423:  /* riscv_zip */
    case 422:  /* riscv_brev8_di */
    case 421:  /* riscv_brev8_si */
    case 420:  /* *branchdi_mask_twobits_equals_singlebit */
    case 419:  /* *branchsi_mask_twobits_equals_singlebit */
    case 418:  /* *andidi_extrabit */
    case 417:  /* *andisi_extrabit */
    case 416:  /* *xoridi_extrabit */
    case 415:  /* *ioridi_extrabit */
    case 414:  /* *xorisi_extrabit */
    case 413:  /* *iorisi_extrabit */
    case 412:  /* *bexti */
    case 411:  /* *bexti */
    case 410:  /* *bextdi */
    case 409:  /* *bextsi */
    case 408:  /* *bextdi */
    case 407:  /* *bextsi */
    case 406:  /* *binvidi */
    case 405:  /* *binvisi */
    case 404:  /* *binvdi */
    case 403:  /* *binvsi */
    case 402:  /* *bclridisi_nottwobits */
    case 401:  /* *bclridi_nottwobits */
    case 400:  /* *bclrisi_nottwobits */
    case 399:  /* *bclridi */
    case 398:  /* *bclrisi */
    case 397:  /* *bclrdi */
    case 396:  /* *bclrsi */
    case 395:  /* *bsetidisi */
    case 394:  /* *bsetidi */
    case 393:  /* *bsetisi */
    case 392:  /* *bsetdi_1_mask */
    case 391:  /* *bsetsi_1_mask */
    case 390:  /* *bsetdi_1 */
    case 389:  /* *bsetsi_1 */
    case 388:  /* *bsetdi_mask */
    case 387:  /* *bsetsi_mask */
    case 386:  /* *bsetdi */
    case 385:  /* *bsetsi */
    case 384:  /* *minmax */
    case 383:  /* *minmax */
    case 382:  /* *minmax */
    case 381:  /* *minmax */
    case 380:  /* umaxdi3 */
    case 379:  /* smaxdi3 */
    case 378:  /* umindi3 */
    case 377:  /* smindi3 */
    case 376:  /* umaxsi3 */
    case 375:  /* smaxsi3 */
    case 374:  /* uminsi3 */
    case 373:  /* sminsi3 */
    case 372:  /* *bswapdi2 */
    case 371:  /* *bswapsi2 */
    case 370:  /* orcbdi2 */
    case 369:  /* orcbsi2 */
    case 368:  /* rotlsi3_sext */
    case 367:  /* rotldi3 */
    case 366:  /* rotlsi3 */
    case 365:  /* *rotrsi3_sext */
    case 364:  /* *rotrdi3 */
    case 363:  /* *rotrsi3 */
    case 362:  /* *zero_extendhidi2_zbb */
    case 361:  /* *zero_extendhisi2_zbb */
    case 360:  /* *extendhidi2_zbb */
    case 359:  /* *extendhisi2_zbb */
    case 358:  /* *extendhihi2_zbb */
    case 357:  /* *extendqidi2_zbb */
    case 356:  /* *extendqisi2_zbb */
    case 355:  /* *extendqihi2_zbb */
    case 354:  /* *zero_extendhidi2_bitmanip */
    case 353:  /* *zero_extendhisi2_bitmanip */
    case 352:  /* *popcountdi2 */
    case 351:  /* *ctzdi2 */
    case 350:  /* *clzdi2 */
    case 349:  /* *popcountdisi2 */
    case 348:  /* *ctzdisi2 */
    case 347:  /* *clzdisi2 */
    case 346:  /* *popcountsi2 */
    case 345:  /* *ctzsi2 */
    case 344:  /* *clzsi2 */
    case 343:  /* *xor_notdi */
    case 342:  /* *xor_notsi */
    case 341:  /* *ior_notdi */
    case 340:  /* *and_notdi */
    case 339:  /* *ior_notsi */
    case 338:  /* *and_notsi */
    case 337:  /* *slliuw */
    case 336:  /* *add.uw */
    case 335:  /* *shNadduw */
    case 334:  /* *andi_add.uw */
    case 333:  /* *shNadd */
    case 332:  /* *shNadd */
    case 331:  /* *zero_extendsidi2_bitmanip */
    case 330:  /* riscv_prefetchi_di */
    case 329:  /* riscv_prefetchi_si */
    case 328:  /* prefetch */
    case 327:  /* riscv_zero_di */
    case 326:  /* riscv_zero_si */
    case 325:  /* riscv_inval_di */
    case 324:  /* riscv_inval_si */
    case 323:  /* riscv_flush_di */
    case 322:  /* riscv_flush_si */
    case 321:  /* riscv_clean_di */
    case 320:  /* riscv_clean_si */
    case 319:  /* stack_protect_test_di */
    case 318:  /* stack_protect_test_si */
    case 317:  /* stack_protect_set_di */
    case 316:  /* stack_protect_set_si */
    case 315:  /* stack_tiedi */
    case 314:  /* stack_tiesi */
    case 313:  /* riscv_uret */
    case 312:  /* riscv_sret */
    case 311:  /* riscv_mret */
    case 310:  /* *riscv_fsnvsnanhf2 */
    case 309:  /* *riscv_fsnvsnandf2 */
    case 308:  /* *riscv_fsnvsnansf2 */
    case 307:  /* riscv_fsflags */
    case 306:  /* riscv_frflags */
    case 305:  /* gpr_restore_return */
    case 304:  /* gpr_restore */
    case 303:  /* gpr_save */
    case 302:  /* trap */
    case 301:  /* nop */
    case 300:  /* call_value_internal */
    case 299:  /* call_internal */
    case 298:  /* sibcall_value_internal */
    case 297:  /* sibcall_internal */
    case 296:  /* eh_return_internal */
    case 295:  /* eh_set_lr_di */
    case 294:  /* eh_set_lr_si */
    case 293:  /* simple_return_internal */
    case 292:  /* simple_return */
    case 291:  /* blockage */
    case 290:  /* tablejumpdi */
    case 289:  /* tablejumpsi */
    case 288:  /* indirect_jumpdi */
    case 287:  /* indirect_jumpsi */
    case 286:  /* jump */
    case 285:  /* *sleu_didi */
    case 284:  /* *sle_didi */
    case 283:  /* *sleu_disi */
    case 282:  /* *sle_disi */
    case 281:  /* *sleu_sisi */
    case 280:  /* *sle_sisi */
    case 279:  /* *sltu_didi */
    case 278:  /* *slt_didi */
    case 277:  /* *sltu_disi */
    case 276:  /* *slt_disi */
    case 275:  /* *sltu_sisi */
    case 274:  /* *slt_sisi */
    case 273:  /* *sgeu_didi */
    case 272:  /* *sge_didi */
    case 271:  /* *sgeu_disi */
    case 270:  /* *sge_disi */
    case 269:  /* *sgeu_sisi */
    case 268:  /* *sge_sisi */
    case 267:  /* *sgtu_didi */
    case 266:  /* *sgt_didi */
    case 265:  /* *sgtu_disi */
    case 264:  /* *sgt_disi */
    case 263:  /* *sgtu_sisi */
    case 262:  /* *sgt_sisi */
    case 261:  /* *sne_zero_didi */
    case 260:  /* *sne_zero_disi */
    case 259:  /* *sne_zero_sisi */
    case 258:  /* *seq_zero_didi */
    case 257:  /* *seq_zero_disi */
    case 256:  /* *seq_zero_sisi */
    case 255:  /* *cstorehfdi4 */
    case 254:  /* *cstorehfsi4 */
    case 253:  /* *cstoredfdi4 */
    case 252:  /* *cstoredfsi4 */
    case 251:  /* *cstoresfdi4 */
    case 250:  /* *cstoresfsi4 */
    case 249:  /* *branch_on_bit_rangedi */
    case 248:  /* *branch_on_bit_rangesi */
    case 247:  /* *branch_on_bitdi */
    case 246:  /* *branch_on_bitsi */
    case 245:  /* *movdidicc */
    case 244:  /* *movsidicc */
    case 243:  /* *movsisicc */
    case 242:  /* *branchdi */
    case 241:  /* *branchsi */
    case 240:  /* *branchdi_shiftedmask_equals_zero */
    case 239:  /* *branchsi_shiftedmask_equals_zero */
    case 238:  /* *branchhi_shiftedmask_equals_zero */
    case 237:  /* *branchqi_shiftedmask_equals_zero */
    case 236:  /* *branchdi_shiftedmask_equals_zero */
    case 235:  /* *branchsi_shiftedmask_equals_zero */
    case 234:  /* *branchhi_shiftedmask_equals_zero */
    case 233:  /* *branchqi_shiftedmask_equals_zero */
    case 232:  /* *branchdi_shiftedarith_equals_zero */
    case 231:  /* *branchsi_shiftedarith_equals_zero */
    case 230:  /* *branchhi_shiftedarith_equals_zero */
    case 229:  /* *branchqi_shiftedarith_equals_zero */
    case 228:  /* *branchsi_shiftedarith_equals_zero */
    case 227:  /* *branchhi_shiftedarith_equals_zero */
    case 226:  /* *branchqi_shiftedarith_equals_zero */
    case 225:  /* zero_extendsidi2_shifted */
    case 224:  /* *lshrsi3_zero_extend_3 */
    case 223:  /* *lshrsi3_zero_extend_2 */
    case 222:  /* *lshrsi3_zero_extend_1 */
    case 221:  /* *lshrsi3_extend_mask_1 */
    case 220:  /* *ashrsi3_extend_mask_1 */
    case 219:  /* *ashlsi3_extend_mask_1 */
    case 218:  /* *lshrsi3_extend_mask */
    case 217:  /* *ashrsi3_extend_mask */
    case 216:  /* *ashlsi3_extend_mask */
    case 215:  /* *lshrsi3_extend */
    case 214:  /* *ashrsi3_extend */
    case 213:  /* *ashlsi3_extend */
    case 212:  /* *lshrdi3_mask_1 */
    case 211:  /* *ashrdi3_mask_1 */
    case 210:  /* *ashldi3_mask_1 */
    case 209:  /* *lshrdi3_mask */
    case 208:  /* *ashrdi3_mask */
    case 207:  /* *ashldi3_mask */
    case 206:  /* lshrdi3 */
    case 205:  /* ashrdi3 */
    case 204:  /* ashldi3 */
    case 203:  /* *lshrsi3_mask_1 */
    case 202:  /* *ashrsi3_mask_1 */
    case 201:  /* *ashlsi3_mask_1 */
    case 200:  /* *lshrsi3_mask */
    case 199:  /* *ashrsi3_mask */
    case 198:  /* *ashlsi3_mask */
    case 197:  /* lshrsi3 */
    case 196:  /* ashrsi3 */
    case 195:  /* ashlsi3 */
    case 194:  /* riscv_pause */
    case 193:  /* fence_i */
    case 192:  /* fence */
    case 191:  /* *movdf_softfloat */
    case 190:  /* *movdf_hardfloat_rv64 */
    case 189:  /* *movdf_hardfloat_rv32 */
    case 188:  /* *movsf_softfloat */
    case 187:  /* *movsf_hardfloat */
    case 186:  /* *movqi_internal */
    case 185:  /* *xorsihi3 */
    case 184:  /* *xorhihi3 */
    case 183:  /* *addsihi3 */
    case 182:  /* *addhihi3 */
    case 181:  /* *movhi_internal */
    case 180:  /* *movsi_internal */
    case 179:  /* *movdi_64bit */
    case 178:  /* *movdi_32bit */
    case 177:  /* *mvconst_internal */
    case 176:  /* *mvconst_internal */
    case 175:  /* *lowdi */
    case 174:  /* *lowsi */
    case 173:  /* auipcdi */
    case 172:  /* auipcsi */
    case 171:  /* got_load_tls_iedi */
    case 170:  /* got_load_tls_iesi */
    case 169:  /* got_load_tls_gddi */
    case 168:  /* got_load_tls_gdsi */
    case 167:  /* tls_add_tp_ledi */
    case 166:  /* tls_add_tp_lesi */
    case 165:  /* got_loaddi */
    case 164:  /* got_loadsi */
    case 163:  /* lroundhfdi2 */
    case 162:  /* lrinthfdi2 */
    case 161:  /* lroundhfsi2 */
    case 160:  /* lrinthfsi2 */
    case 159:  /* lrounddfdi2 */
    case 158:  /* lrintdfdi2 */
    case 157:  /* lrounddfsi2 */
    case 156:  /* lrintdfsi2 */
    case 155:  /* lroundsfdi2 */
    case 154:  /* lrintsfdi2 */
    case 153:  /* lroundsfsi2 */
    case 152:  /* lrintsfsi2 */
    case 151:  /* floatunsdihf2 */
    case 150:  /* floatunssihf2 */
    case 149:  /* floatunsdidf2 */
    case 148:  /* floatunssidf2 */
    case 147:  /* floatunsdisf2 */
    case 146:  /* floatunssisf2 */
    case 145:  /* floatdihf2 */
    case 144:  /* floatsihf2 */
    case 143:  /* floatdidf2 */
    case 142:  /* floatsidf2 */
    case 141:  /* floatdisf2 */
    case 140:  /* floatsisf2 */
    case 139:  /* fixuns_trunchfdi2 */
    case 138:  /* fixuns_trunchfsi2 */
    case 137:  /* fixuns_truncdfdi2 */
    case 136:  /* fixuns_truncdfsi2 */
    case 135:  /* fixuns_truncsfdi2 */
    case 134:  /* fixuns_truncsfsi2 */
    case 133:  /* fix_trunchfdi2 */
    case 132:  /* fix_trunchfsi2 */
    case 131:  /* fix_truncdfdi2 */
    case 130:  /* fix_truncdfsi2 */
    case 129:  /* fix_truncsfdi2 */
    case 128:  /* fix_truncsfsi2 */
    case 127:  /* *movhf_softfloat */
    case 126:  /* *movhf_hardfloat */
    case 125:  /* extendhfdf2 */
    case 124:  /* extendsfdf2 */
    case 123:  /* extendhfsf2 */
    case 122:  /* *extendhidi2 */
    case 121:  /* *extendhisi2 */
    case 120:  /* *extendhihi2 */
    case 119:  /* *extendqidi2 */
    case 118:  /* *extendqisi2 */
    case 117:  /* *extendqihi2 */
    case 116:  /* extendsidi2 */
    case 115:  /* zero_extendqidi2 */
    case 114:  /* zero_extendqisi2 */
    case 113:  /* zero_extendqihi2 */
    case 112:  /* *zero_extendhidi2 */
    case 111:  /* *zero_extendhisi2 */
    case 110:  /* *zero_extendsidi2_internal */
    case 109:  /* truncdfhf2 */
    case 108:  /* truncsfhf2 */
    case 107:  /* truncdfsf2 */
    case 106:  /* *one_cmplsi2_internal */
    case 105:  /* one_cmpldi2 */
    case 104:  /* one_cmplsi2 */
    case 103:  /* *xorsi3_internal */
    case 102:  /* *iorsi3_internal */
    case 101:  /* *andsi3_internal */
    case 100:  /* xordi3 */
    case 99:  /* iordi3 */
    case 98:  /* anddi3 */
    case 97:  /* xorsi3 */
    case 96:  /* iorsi3 */
    case 95:  /* andsi3 */
    case 94:  /* smaxhf3 */
    case 93:  /* smaxdf3 */
    case 92:  /* smaxsf3 */
    case 91:  /* sminhf3 */
    case 90:  /* smindf3 */
    case 89:  /* sminsf3 */
    case 88:  /* fmaxhf3 */
    case 87:  /* fmaxdf3 */
    case 86:  /* fmaxsf3 */
    case 85:  /* fminhf3 */
    case 84:  /* fmindf3 */
    case 83:  /* fminsf3 */
    case 82:  /* neghf2 */
    case 81:  /* negdf2 */
    case 80:  /* negsf2 */
    case 79:  /* copysignhf3 */
    case 78:  /* copysigndf3 */
    case 77:  /* copysignsf3 */
    case 76:  /* abshf2 */
    case 75:  /* absdf2 */
    case 74:  /* abssf2 */
    case 73:  /* *fnmahf4 */
    case 72:  /* *fnmadf4 */
    case 71:  /* *fnmasf4 */
    case 70:  /* *fnmshf4 */
    case 69:  /* *fnmsdf4 */
    case 68:  /* *fnmssf4 */
    case 67:  /* *fmshf4 */
    case 66:  /* *fmsdf4 */
    case 65:  /* *fmssf4 */
    case 64:  /* *fmahf4 */
    case 63:  /* *fmadf4 */
    case 62:  /* *fmasf4 */
    case 61:  /* fnmahf4 */
    case 60:  /* fnmadf4 */
    case 59:  /* fnmasf4 */
    case 58:  /* fnmshf4 */
    case 57:  /* fnmsdf4 */
    case 56:  /* fnmssf4 */
    case 55:  /* fmshf4 */
    case 54:  /* fmsdf4 */
    case 53:  /* fmssf4 */
    case 52:  /* fmahf4 */
    case 51:  /* fmadf4 */
    case 50:  /* fmasf4 */
    case 49:  /* sqrthf2 */
    case 48:  /* sqrtdf2 */
    case 47:  /* sqrtsf2 */
    case 46:  /* divhf3 */
    case 45:  /* divdf3 */
    case 44:  /* divsf3 */
    case 43:  /* *umodsi3_extended */
    case 42:  /* *modsi3_extended */
    case 41:  /* *udivsi3_extended */
    case 40:  /* *divsi3_extended */
    case 39:  /* umoddi3 */
    case 38:  /* moddi3 */
    case 37:  /* udivdi3 */
    case 36:  /* divdi3 */
    case 35:  /* umodsi3 */
    case 34:  /* modsi3 */
    case 33:  /* udivsi3 */
    case 32:  /* divsi3 */
    case 31:  /* usmulsi3_highpart */
    case 30:  /* umulsi3_highpart */
    case 29:  /* smulsi3_highpart */
    case 28:  /* usmuldi3_highpart */
    case 27:  /* umuldi3_highpart */
    case 26:  /* smuldi3_highpart */
    case 25:  /* *mulsi3_extended2 */
    case 24:  /* *mulsi3_extended */
    case 23:  /* muldi3 */
    case 22:  /* mulsi3 */
    case 21:  /* mulhf3 */
    case 20:  /* muldf3 */
    case 19:  /* mulsf3 */
    case 18:  /* *negsi2_extended2 */
    case 17:  /* *negsi2_extended */
    case 16:  /* negsi2 */
    case 15:  /* negdi2 */
    case 14:  /* *subsi3_extended2 */
    case 13:  /* *subsi3_extended */
    case 12:  /* subsi3 */
    case 11:  /* subdi3 */
    case 10:  /* subhf3 */
    case 9:  /* subdf3 */
    case 8:  /* subsf3 */
    case 7:  /* *addsi3_extended2 */
    case 6:  /* *addsi3_extended */
    case 5:  /* adddi3 */
    case 4:  /* addsi3 */
    case 3:  /* addhf3 */
    case 2:  /* adddf3 */
    case 1:  /* addsf3 */
      return 255 /* 0xff */;

    case 831:  /* pred_storevnx1qi */
    case 832:  /* pred_storevnx2qi */
    case 833:  /* pred_storevnx4qi */
    case 834:  /* pred_storevnx8qi */
    case 835:  /* pred_storevnx16qi */
    case 836:  /* pred_storevnx32qi */
    case 837:  /* pred_storevnx64qi */
    case 838:  /* pred_storevnx1hi */
    case 839:  /* pred_storevnx2hi */
    case 840:  /* pred_storevnx4hi */
    case 841:  /* pred_storevnx8hi */
    case 842:  /* pred_storevnx16hi */
    case 843:  /* pred_storevnx32hi */
    case 844:  /* pred_storevnx1si */
    case 845:  /* pred_storevnx2si */
    case 846:  /* pred_storevnx4si */
    case 847:  /* pred_storevnx8si */
    case 848:  /* pred_storevnx16si */
    case 849:  /* pred_storevnx1di */
    case 850:  /* pred_storevnx2di */
    case 851:  /* pred_storevnx4di */
    case 852:  /* pred_storevnx8di */
    case 853:  /* pred_storevnx1sf */
    case 854:  /* pred_storevnx2sf */
    case 855:  /* pred_storevnx4sf */
    case 856:  /* pred_storevnx8sf */
    case 857:  /* pred_storevnx16sf */
    case 858:  /* pred_storevnx1df */
    case 859:  /* pred_storevnx2df */
    case 860:  /* pred_storevnx4df */
    case 861:  /* pred_storevnx8df */
    case 869:  /* pred_storevnx1bi */
    case 870:  /* pred_storevnx2bi */
    case 871:  /* pred_storevnx4bi */
    case 872:  /* pred_storevnx8bi */
    case 873:  /* pred_storevnx16bi */
    case 874:  /* pred_storevnx32bi */
    case 875:  /* pred_storevnx64bi */
      extract_constrain_insn_cached (insn);
      return 
#line 1070 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::NONVLMAX);

    case 4534:  /* pred_ffsvnx64bidi */
    case 4533:  /* pred_ffsvnx32bidi */
    case 4532:  /* pred_ffsvnx16bidi */
    case 4531:  /* pred_ffsvnx8bidi */
    case 4530:  /* pred_ffsvnx4bidi */
    case 4529:  /* pred_ffsvnx2bidi */
    case 4528:  /* pred_ffsvnx1bidi */
    case 4527:  /* pred_ffsvnx64bisi */
    case 4526:  /* pred_ffsvnx32bisi */
    case 4525:  /* pred_ffsvnx16bisi */
    case 4524:  /* pred_ffsvnx8bisi */
    case 4523:  /* pred_ffsvnx4bisi */
    case 4522:  /* pred_ffsvnx2bisi */
    case 4521:  /* pred_ffsvnx1bisi */
    case 4520:  /* pred_popcountvnx64bidi */
    case 4519:  /* pred_popcountvnx32bidi */
    case 4518:  /* pred_popcountvnx16bidi */
    case 4517:  /* pred_popcountvnx8bidi */
    case 4516:  /* pred_popcountvnx4bidi */
    case 4515:  /* pred_popcountvnx2bidi */
    case 4514:  /* pred_popcountvnx1bidi */
    case 4513:  /* pred_popcountvnx64bisi */
    case 4512:  /* pred_popcountvnx32bisi */
    case 4511:  /* pred_popcountvnx16bisi */
    case 4510:  /* pred_popcountvnx8bisi */
    case 4509:  /* pred_popcountvnx4bisi */
    case 4508:  /* pred_popcountvnx2bisi */
    case 4507:  /* pred_popcountvnx1bisi */
    case 2648:  /* pred_madcvnx1qi_overflow */
    case 2649:  /* pred_madcvnx2qi_overflow */
    case 2650:  /* pred_madcvnx4qi_overflow */
    case 2651:  /* pred_madcvnx8qi_overflow */
    case 2652:  /* pred_madcvnx16qi_overflow */
    case 2653:  /* pred_madcvnx32qi_overflow */
    case 2654:  /* pred_madcvnx64qi_overflow */
    case 2655:  /* pred_madcvnx1hi_overflow */
    case 2656:  /* pred_madcvnx2hi_overflow */
    case 2657:  /* pred_madcvnx4hi_overflow */
    case 2658:  /* pred_madcvnx8hi_overflow */
    case 2659:  /* pred_madcvnx16hi_overflow */
    case 2660:  /* pred_madcvnx32hi_overflow */
    case 2661:  /* pred_madcvnx1si_overflow */
    case 2662:  /* pred_madcvnx2si_overflow */
    case 2663:  /* pred_madcvnx4si_overflow */
    case 2664:  /* pred_madcvnx8si_overflow */
    case 2665:  /* pred_madcvnx16si_overflow */
    case 2666:  /* pred_madcvnx1di_overflow */
    case 2667:  /* pred_madcvnx2di_overflow */
    case 2668:  /* pred_madcvnx4di_overflow */
    case 2669:  /* pred_madcvnx8di_overflow */
    case 2670:  /* pred_msbcvnx1qi_overflow */
    case 2671:  /* pred_msbcvnx2qi_overflow */
    case 2672:  /* pred_msbcvnx4qi_overflow */
    case 2673:  /* pred_msbcvnx8qi_overflow */
    case 2674:  /* pred_msbcvnx16qi_overflow */
    case 2675:  /* pred_msbcvnx32qi_overflow */
    case 2676:  /* pred_msbcvnx64qi_overflow */
    case 2677:  /* pred_msbcvnx1hi_overflow */
    case 2678:  /* pred_msbcvnx2hi_overflow */
    case 2679:  /* pred_msbcvnx4hi_overflow */
    case 2680:  /* pred_msbcvnx8hi_overflow */
    case 2681:  /* pred_msbcvnx16hi_overflow */
    case 2682:  /* pred_msbcvnx32hi_overflow */
    case 2683:  /* pred_msbcvnx1si_overflow */
    case 2684:  /* pred_msbcvnx2si_overflow */
    case 2685:  /* pred_msbcvnx4si_overflow */
    case 2686:  /* pred_msbcvnx8si_overflow */
    case 2687:  /* pred_msbcvnx16si_overflow */
    case 2688:  /* pred_msbcvnx1di_overflow */
    case 2689:  /* pred_msbcvnx2di_overflow */
    case 2690:  /* pred_msbcvnx4di_overflow */
    case 2691:  /* pred_msbcvnx8di_overflow */
    case 2692:  /* pred_madcvnx1qi_overflow_scalar */
    case 2693:  /* pred_madcvnx2qi_overflow_scalar */
    case 2694:  /* pred_madcvnx4qi_overflow_scalar */
    case 2695:  /* pred_madcvnx8qi_overflow_scalar */
    case 2696:  /* pred_madcvnx16qi_overflow_scalar */
    case 2697:  /* pred_madcvnx32qi_overflow_scalar */
    case 2698:  /* pred_madcvnx64qi_overflow_scalar */
    case 2699:  /* pred_madcvnx1hi_overflow_scalar */
    case 2700:  /* pred_madcvnx2hi_overflow_scalar */
    case 2701:  /* pred_madcvnx4hi_overflow_scalar */
    case 2702:  /* pred_madcvnx8hi_overflow_scalar */
    case 2703:  /* pred_madcvnx16hi_overflow_scalar */
    case 2704:  /* pred_madcvnx32hi_overflow_scalar */
    case 2705:  /* pred_madcvnx1si_overflow_scalar */
    case 2706:  /* pred_madcvnx2si_overflow_scalar */
    case 2707:  /* pred_madcvnx4si_overflow_scalar */
    case 2708:  /* pred_madcvnx8si_overflow_scalar */
    case 2709:  /* pred_madcvnx16si_overflow_scalar */
    case 2710:  /* pred_msbcvnx1qi_overflow_scalar */
    case 2711:  /* pred_msbcvnx2qi_overflow_scalar */
    case 2712:  /* pred_msbcvnx4qi_overflow_scalar */
    case 2713:  /* pred_msbcvnx8qi_overflow_scalar */
    case 2714:  /* pred_msbcvnx16qi_overflow_scalar */
    case 2715:  /* pred_msbcvnx32qi_overflow_scalar */
    case 2716:  /* pred_msbcvnx64qi_overflow_scalar */
    case 2717:  /* pred_msbcvnx1hi_overflow_scalar */
    case 2718:  /* pred_msbcvnx2hi_overflow_scalar */
    case 2719:  /* pred_msbcvnx4hi_overflow_scalar */
    case 2720:  /* pred_msbcvnx8hi_overflow_scalar */
    case 2721:  /* pred_msbcvnx16hi_overflow_scalar */
    case 2722:  /* pred_msbcvnx32hi_overflow_scalar */
    case 2723:  /* pred_msbcvnx1si_overflow_scalar */
    case 2724:  /* pred_msbcvnx2si_overflow_scalar */
    case 2725:  /* pred_msbcvnx4si_overflow_scalar */
    case 2726:  /* pred_msbcvnx8si_overflow_scalar */
    case 2727:  /* pred_msbcvnx16si_overflow_scalar */
    case 2728:  /* *pred_madcvnx1di_overflow_scalar */
    case 2729:  /* *pred_madcvnx2di_overflow_scalar */
    case 2730:  /* *pred_madcvnx4di_overflow_scalar */
    case 2731:  /* *pred_madcvnx8di_overflow_scalar */
    case 2732:  /* *pred_madcvnx1di_overflow_extended_scalar */
    case 2733:  /* *pred_madcvnx2di_overflow_extended_scalar */
    case 2734:  /* *pred_madcvnx4di_overflow_extended_scalar */
    case 2735:  /* *pred_madcvnx8di_overflow_extended_scalar */
    case 2736:  /* *pred_msbcvnx1di_overflow_scalar */
    case 2737:  /* *pred_msbcvnx2di_overflow_scalar */
    case 2738:  /* *pred_msbcvnx4di_overflow_scalar */
    case 2739:  /* *pred_msbcvnx8di_overflow_scalar */
    case 2740:  /* *pred_msbcvnx1di_overflow_extended_scalar */
    case 2741:  /* *pred_msbcvnx2di_overflow_extended_scalar */
    case 2742:  /* *pred_msbcvnx4di_overflow_extended_scalar */
    case 2743:  /* *pred_msbcvnx8di_overflow_extended_scalar */
      extract_constrain_insn_cached (insn);
      return 
#line 351 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[4]));

    case 6034:  /* pred_compressvnx8df */
    case 6033:  /* pred_compressvnx4df */
    case 6032:  /* pred_compressvnx2df */
    case 6031:  /* pred_compressvnx1df */
    case 6030:  /* pred_compressvnx16sf */
    case 6029:  /* pred_compressvnx8sf */
    case 6028:  /* pred_compressvnx4sf */
    case 6027:  /* pred_compressvnx2sf */
    case 6026:  /* pred_compressvnx1sf */
    case 6025:  /* pred_compressvnx8di */
    case 6024:  /* pred_compressvnx4di */
    case 6023:  /* pred_compressvnx2di */
    case 6022:  /* pred_compressvnx1di */
    case 6021:  /* pred_compressvnx16si */
    case 6020:  /* pred_compressvnx8si */
    case 6019:  /* pred_compressvnx4si */
    case 6018:  /* pred_compressvnx2si */
    case 6017:  /* pred_compressvnx1si */
    case 6016:  /* pred_compressvnx32hi */
    case 6015:  /* pred_compressvnx16hi */
    case 6014:  /* pred_compressvnx8hi */
    case 6013:  /* pred_compressvnx4hi */
    case 6012:  /* pred_compressvnx2hi */
    case 6011:  /* pred_compressvnx1hi */
    case 6010:  /* pred_compressvnx64qi */
    case 6009:  /* pred_compressvnx32qi */
    case 6008:  /* pred_compressvnx16qi */
    case 6007:  /* pred_compressvnx8qi */
    case 6006:  /* pred_compressvnx4qi */
    case 6005:  /* pred_compressvnx2qi */
    case 6004:  /* pred_compressvnx1qi */
    case 4599:  /* pred_seriesvnx8di */
    case 4598:  /* pred_seriesvnx4di */
    case 4597:  /* pred_seriesvnx2di */
    case 4596:  /* pred_seriesvnx1di */
    case 4595:  /* pred_seriesvnx16si */
    case 4594:  /* pred_seriesvnx8si */
    case 4593:  /* pred_seriesvnx4si */
    case 4592:  /* pred_seriesvnx2si */
    case 4591:  /* pred_seriesvnx1si */
    case 4590:  /* pred_seriesvnx32hi */
    case 4589:  /* pred_seriesvnx16hi */
    case 4588:  /* pred_seriesvnx8hi */
    case 4587:  /* pred_seriesvnx4hi */
    case 4586:  /* pred_seriesvnx2hi */
    case 4585:  /* pred_seriesvnx1hi */
    case 4584:  /* pred_seriesvnx64qi */
    case 4583:  /* pred_seriesvnx32qi */
    case 4582:  /* pred_seriesvnx16qi */
    case 4581:  /* pred_seriesvnx8qi */
    case 4580:  /* pred_seriesvnx4qi */
    case 4579:  /* pred_seriesvnx2qi */
    case 4578:  /* pred_seriesvnx1qi */
    case 4555:  /* pred_sofvnx64bi */
    case 4554:  /* pred_sifvnx64bi */
    case 4553:  /* pred_sbfvnx64bi */
    case 4552:  /* pred_sofvnx32bi */
    case 4551:  /* pred_sifvnx32bi */
    case 4550:  /* pred_sbfvnx32bi */
    case 4549:  /* pred_sofvnx16bi */
    case 4548:  /* pred_sifvnx16bi */
    case 4547:  /* pred_sbfvnx16bi */
    case 4546:  /* pred_sofvnx8bi */
    case 4545:  /* pred_sifvnx8bi */
    case 4544:  /* pred_sbfvnx8bi */
    case 4543:  /* pred_sofvnx4bi */
    case 4542:  /* pred_sifvnx4bi */
    case 4541:  /* pred_sbfvnx4bi */
    case 4540:  /* pred_sofvnx2bi */
    case 4539:  /* pred_sifvnx2bi */
    case 4538:  /* pred_sbfvnx2bi */
    case 4537:  /* pred_sofvnx1bi */
    case 4536:  /* pred_sifvnx1bi */
    case 4535:  /* pred_sbfvnx1bi */
    case 4444:  /* pred_andvnx1bi */
    case 4445:  /* pred_iorvnx1bi */
    case 4446:  /* pred_xorvnx1bi */
    case 4447:  /* pred_andvnx2bi */
    case 4448:  /* pred_iorvnx2bi */
    case 4449:  /* pred_xorvnx2bi */
    case 4450:  /* pred_andvnx4bi */
    case 4451:  /* pred_iorvnx4bi */
    case 4452:  /* pred_xorvnx4bi */
    case 4453:  /* pred_andvnx8bi */
    case 4454:  /* pred_iorvnx8bi */
    case 4455:  /* pred_xorvnx8bi */
    case 4456:  /* pred_andvnx16bi */
    case 4457:  /* pred_iorvnx16bi */
    case 4458:  /* pred_xorvnx16bi */
    case 4459:  /* pred_andvnx32bi */
    case 4460:  /* pred_iorvnx32bi */
    case 4461:  /* pred_xorvnx32bi */
    case 4462:  /* pred_andvnx64bi */
    case 4463:  /* pred_iorvnx64bi */
    case 4464:  /* pred_xorvnx64bi */
    case 4465:  /* pred_nandvnx1bi */
    case 4466:  /* pred_niorvnx1bi */
    case 4467:  /* pred_nxorvnx1bi */
    case 4468:  /* pred_nandvnx2bi */
    case 4469:  /* pred_niorvnx2bi */
    case 4470:  /* pred_nxorvnx2bi */
    case 4471:  /* pred_nandvnx4bi */
    case 4472:  /* pred_niorvnx4bi */
    case 4473:  /* pred_nxorvnx4bi */
    case 4474:  /* pred_nandvnx8bi */
    case 4475:  /* pred_niorvnx8bi */
    case 4476:  /* pred_nxorvnx8bi */
    case 4477:  /* pred_nandvnx16bi */
    case 4478:  /* pred_niorvnx16bi */
    case 4479:  /* pred_nxorvnx16bi */
    case 4480:  /* pred_nandvnx32bi */
    case 4481:  /* pred_niorvnx32bi */
    case 4482:  /* pred_nxorvnx32bi */
    case 4483:  /* pred_nandvnx64bi */
    case 4484:  /* pred_niorvnx64bi */
    case 4485:  /* pred_nxorvnx64bi */
    case 4486:  /* pred_andnotvnx1bi */
    case 4487:  /* pred_iornotvnx1bi */
    case 4488:  /* pred_andnotvnx2bi */
    case 4489:  /* pred_iornotvnx2bi */
    case 4490:  /* pred_andnotvnx4bi */
    case 4491:  /* pred_iornotvnx4bi */
    case 4492:  /* pred_andnotvnx8bi */
    case 4493:  /* pred_iornotvnx8bi */
    case 4494:  /* pred_andnotvnx16bi */
    case 4495:  /* pred_iornotvnx16bi */
    case 4496:  /* pred_andnotvnx32bi */
    case 4497:  /* pred_iornotvnx32bi */
    case 4498:  /* pred_andnotvnx64bi */
    case 4499:  /* pred_iornotvnx64bi */
      extract_constrain_insn_cached (insn);
      return 
#line 348 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[6]));

    case 1481:  /* pred_indexed_ustorevnx64qivnx64qi */
    case 1480:  /* pred_indexed_ostorevnx64qivnx64qi */
    case 1479:  /* pred_indexed_ustorevnx32hivnx32hi */
    case 1478:  /* pred_indexed_ostorevnx32hivnx32hi */
    case 1477:  /* pred_indexed_ustorevnx32hivnx32qi */
    case 1476:  /* pred_indexed_ostorevnx32hivnx32qi */
    case 1475:  /* pred_indexed_ustorevnx32qivnx32hi */
    case 1474:  /* pred_indexed_ostorevnx32qivnx32hi */
    case 1473:  /* pred_indexed_ustorevnx32qivnx32qi */
    case 1472:  /* pred_indexed_ostorevnx32qivnx32qi */
    case 1471:  /* pred_indexed_ustorevnx16sfvnx16si */
    case 1470:  /* pred_indexed_ostorevnx16sfvnx16si */
    case 1469:  /* pred_indexed_ustorevnx16sivnx16si */
    case 1468:  /* pred_indexed_ostorevnx16sivnx16si */
    case 1467:  /* pred_indexed_ustorevnx16hivnx16si */
    case 1466:  /* pred_indexed_ostorevnx16hivnx16si */
    case 1465:  /* pred_indexed_ustorevnx16qivnx16si */
    case 1464:  /* pred_indexed_ostorevnx16qivnx16si */
    case 1463:  /* pred_indexed_ustorevnx16sfvnx16hi */
    case 1462:  /* pred_indexed_ostorevnx16sfvnx16hi */
    case 1461:  /* pred_indexed_ustorevnx16sivnx16hi */
    case 1460:  /* pred_indexed_ostorevnx16sivnx16hi */
    case 1459:  /* pred_indexed_ustorevnx16hivnx16hi */
    case 1458:  /* pred_indexed_ostorevnx16hivnx16hi */
    case 1457:  /* pred_indexed_ustorevnx16qivnx16hi */
    case 1456:  /* pred_indexed_ostorevnx16qivnx16hi */
    case 1455:  /* pred_indexed_ustorevnx16sfvnx16qi */
    case 1454:  /* pred_indexed_ostorevnx16sfvnx16qi */
    case 1453:  /* pred_indexed_ustorevnx16sivnx16qi */
    case 1452:  /* pred_indexed_ostorevnx16sivnx16qi */
    case 1451:  /* pred_indexed_ustorevnx16hivnx16qi */
    case 1450:  /* pred_indexed_ostorevnx16hivnx16qi */
    case 1449:  /* pred_indexed_ustorevnx16qivnx16qi */
    case 1448:  /* pred_indexed_ostorevnx16qivnx16qi */
    case 1447:  /* pred_indexed_ustorevnx8dfvnx8di */
    case 1446:  /* pred_indexed_ostorevnx8dfvnx8di */
    case 1445:  /* pred_indexed_ustorevnx8sfvnx8di */
    case 1444:  /* pred_indexed_ostorevnx8sfvnx8di */
    case 1443:  /* pred_indexed_ustorevnx8divnx8di */
    case 1442:  /* pred_indexed_ostorevnx8divnx8di */
    case 1441:  /* pred_indexed_ustorevnx8sivnx8di */
    case 1440:  /* pred_indexed_ostorevnx8sivnx8di */
    case 1439:  /* pred_indexed_ustorevnx8hivnx8di */
    case 1438:  /* pred_indexed_ostorevnx8hivnx8di */
    case 1437:  /* pred_indexed_ustorevnx8qivnx8di */
    case 1436:  /* pred_indexed_ostorevnx8qivnx8di */
    case 1435:  /* pred_indexed_ustorevnx8dfvnx8si */
    case 1434:  /* pred_indexed_ostorevnx8dfvnx8si */
    case 1433:  /* pred_indexed_ustorevnx8sfvnx8si */
    case 1432:  /* pred_indexed_ostorevnx8sfvnx8si */
    case 1431:  /* pred_indexed_ustorevnx8divnx8si */
    case 1430:  /* pred_indexed_ostorevnx8divnx8si */
    case 1429:  /* pred_indexed_ustorevnx8sivnx8si */
    case 1428:  /* pred_indexed_ostorevnx8sivnx8si */
    case 1427:  /* pred_indexed_ustorevnx8hivnx8si */
    case 1426:  /* pred_indexed_ostorevnx8hivnx8si */
    case 1425:  /* pred_indexed_ustorevnx8qivnx8si */
    case 1424:  /* pred_indexed_ostorevnx8qivnx8si */
    case 1423:  /* pred_indexed_ustorevnx8dfvnx8hi */
    case 1422:  /* pred_indexed_ostorevnx8dfvnx8hi */
    case 1421:  /* pred_indexed_ustorevnx8sfvnx8hi */
    case 1420:  /* pred_indexed_ostorevnx8sfvnx8hi */
    case 1419:  /* pred_indexed_ustorevnx8divnx8hi */
    case 1418:  /* pred_indexed_ostorevnx8divnx8hi */
    case 1417:  /* pred_indexed_ustorevnx8sivnx8hi */
    case 1416:  /* pred_indexed_ostorevnx8sivnx8hi */
    case 1415:  /* pred_indexed_ustorevnx8hivnx8hi */
    case 1414:  /* pred_indexed_ostorevnx8hivnx8hi */
    case 1413:  /* pred_indexed_ustorevnx8qivnx8hi */
    case 1412:  /* pred_indexed_ostorevnx8qivnx8hi */
    case 1411:  /* pred_indexed_ustorevnx8dfvnx8qi */
    case 1410:  /* pred_indexed_ostorevnx8dfvnx8qi */
    case 1409:  /* pred_indexed_ustorevnx8sfvnx8qi */
    case 1408:  /* pred_indexed_ostorevnx8sfvnx8qi */
    case 1407:  /* pred_indexed_ustorevnx8divnx8qi */
    case 1406:  /* pred_indexed_ostorevnx8divnx8qi */
    case 1405:  /* pred_indexed_ustorevnx8sivnx8qi */
    case 1404:  /* pred_indexed_ostorevnx8sivnx8qi */
    case 1403:  /* pred_indexed_ustorevnx8hivnx8qi */
    case 1402:  /* pred_indexed_ostorevnx8hivnx8qi */
    case 1401:  /* pred_indexed_ustorevnx8qivnx8qi */
    case 1400:  /* pred_indexed_ostorevnx8qivnx8qi */
    case 1399:  /* pred_indexed_ustorevnx4dfvnx4di */
    case 1398:  /* pred_indexed_ostorevnx4dfvnx4di */
    case 1397:  /* pred_indexed_ustorevnx4sfvnx4di */
    case 1396:  /* pred_indexed_ostorevnx4sfvnx4di */
    case 1395:  /* pred_indexed_ustorevnx4divnx4di */
    case 1394:  /* pred_indexed_ostorevnx4divnx4di */
    case 1393:  /* pred_indexed_ustorevnx4sivnx4di */
    case 1392:  /* pred_indexed_ostorevnx4sivnx4di */
    case 1391:  /* pred_indexed_ustorevnx4hivnx4di */
    case 1390:  /* pred_indexed_ostorevnx4hivnx4di */
    case 1389:  /* pred_indexed_ustorevnx4qivnx4di */
    case 1388:  /* pred_indexed_ostorevnx4qivnx4di */
    case 1387:  /* pred_indexed_ustorevnx4dfvnx4si */
    case 1386:  /* pred_indexed_ostorevnx4dfvnx4si */
    case 1385:  /* pred_indexed_ustorevnx4sfvnx4si */
    case 1384:  /* pred_indexed_ostorevnx4sfvnx4si */
    case 1383:  /* pred_indexed_ustorevnx4divnx4si */
    case 1382:  /* pred_indexed_ostorevnx4divnx4si */
    case 1381:  /* pred_indexed_ustorevnx4sivnx4si */
    case 1380:  /* pred_indexed_ostorevnx4sivnx4si */
    case 1379:  /* pred_indexed_ustorevnx4hivnx4si */
    case 1378:  /* pred_indexed_ostorevnx4hivnx4si */
    case 1377:  /* pred_indexed_ustorevnx4qivnx4si */
    case 1376:  /* pred_indexed_ostorevnx4qivnx4si */
    case 1375:  /* pred_indexed_ustorevnx4dfvnx4hi */
    case 1374:  /* pred_indexed_ostorevnx4dfvnx4hi */
    case 1373:  /* pred_indexed_ustorevnx4sfvnx4hi */
    case 1372:  /* pred_indexed_ostorevnx4sfvnx4hi */
    case 1371:  /* pred_indexed_ustorevnx4divnx4hi */
    case 1370:  /* pred_indexed_ostorevnx4divnx4hi */
    case 1369:  /* pred_indexed_ustorevnx4sivnx4hi */
    case 1368:  /* pred_indexed_ostorevnx4sivnx4hi */
    case 1367:  /* pred_indexed_ustorevnx4hivnx4hi */
    case 1366:  /* pred_indexed_ostorevnx4hivnx4hi */
    case 1365:  /* pred_indexed_ustorevnx4qivnx4hi */
    case 1364:  /* pred_indexed_ostorevnx4qivnx4hi */
    case 1363:  /* pred_indexed_ustorevnx4dfvnx4qi */
    case 1362:  /* pred_indexed_ostorevnx4dfvnx4qi */
    case 1361:  /* pred_indexed_ustorevnx4sfvnx4qi */
    case 1360:  /* pred_indexed_ostorevnx4sfvnx4qi */
    case 1359:  /* pred_indexed_ustorevnx4divnx4qi */
    case 1358:  /* pred_indexed_ostorevnx4divnx4qi */
    case 1357:  /* pred_indexed_ustorevnx4sivnx4qi */
    case 1356:  /* pred_indexed_ostorevnx4sivnx4qi */
    case 1355:  /* pred_indexed_ustorevnx4hivnx4qi */
    case 1354:  /* pred_indexed_ostorevnx4hivnx4qi */
    case 1353:  /* pred_indexed_ustorevnx4qivnx4qi */
    case 1352:  /* pred_indexed_ostorevnx4qivnx4qi */
    case 1351:  /* pred_indexed_ustorevnx2dfvnx2di */
    case 1350:  /* pred_indexed_ostorevnx2dfvnx2di */
    case 1349:  /* pred_indexed_ustorevnx2sfvnx2di */
    case 1348:  /* pred_indexed_ostorevnx2sfvnx2di */
    case 1347:  /* pred_indexed_ustorevnx2divnx2di */
    case 1346:  /* pred_indexed_ostorevnx2divnx2di */
    case 1345:  /* pred_indexed_ustorevnx2sivnx2di */
    case 1344:  /* pred_indexed_ostorevnx2sivnx2di */
    case 1343:  /* pred_indexed_ustorevnx2hivnx2di */
    case 1342:  /* pred_indexed_ostorevnx2hivnx2di */
    case 1341:  /* pred_indexed_ustorevnx2qivnx2di */
    case 1340:  /* pred_indexed_ostorevnx2qivnx2di */
    case 1339:  /* pred_indexed_ustorevnx2dfvnx2si */
    case 1338:  /* pred_indexed_ostorevnx2dfvnx2si */
    case 1337:  /* pred_indexed_ustorevnx2sfvnx2si */
    case 1336:  /* pred_indexed_ostorevnx2sfvnx2si */
    case 1335:  /* pred_indexed_ustorevnx2divnx2si */
    case 1334:  /* pred_indexed_ostorevnx2divnx2si */
    case 1333:  /* pred_indexed_ustorevnx2sivnx2si */
    case 1332:  /* pred_indexed_ostorevnx2sivnx2si */
    case 1331:  /* pred_indexed_ustorevnx2hivnx2si */
    case 1330:  /* pred_indexed_ostorevnx2hivnx2si */
    case 1329:  /* pred_indexed_ustorevnx2qivnx2si */
    case 1328:  /* pred_indexed_ostorevnx2qivnx2si */
    case 1327:  /* pred_indexed_ustorevnx2dfvnx2hi */
    case 1326:  /* pred_indexed_ostorevnx2dfvnx2hi */
    case 1325:  /* pred_indexed_ustorevnx2sfvnx2hi */
    case 1324:  /* pred_indexed_ostorevnx2sfvnx2hi */
    case 1323:  /* pred_indexed_ustorevnx2divnx2hi */
    case 1322:  /* pred_indexed_ostorevnx2divnx2hi */
    case 1321:  /* pred_indexed_ustorevnx2sivnx2hi */
    case 1320:  /* pred_indexed_ostorevnx2sivnx2hi */
    case 1319:  /* pred_indexed_ustorevnx2hivnx2hi */
    case 1318:  /* pred_indexed_ostorevnx2hivnx2hi */
    case 1317:  /* pred_indexed_ustorevnx2qivnx2hi */
    case 1316:  /* pred_indexed_ostorevnx2qivnx2hi */
    case 1315:  /* pred_indexed_ustorevnx2dfvnx2qi */
    case 1314:  /* pred_indexed_ostorevnx2dfvnx2qi */
    case 1313:  /* pred_indexed_ustorevnx2sfvnx2qi */
    case 1312:  /* pred_indexed_ostorevnx2sfvnx2qi */
    case 1311:  /* pred_indexed_ustorevnx2divnx2qi */
    case 1310:  /* pred_indexed_ostorevnx2divnx2qi */
    case 1309:  /* pred_indexed_ustorevnx2sivnx2qi */
    case 1308:  /* pred_indexed_ostorevnx2sivnx2qi */
    case 1307:  /* pred_indexed_ustorevnx2hivnx2qi */
    case 1306:  /* pred_indexed_ostorevnx2hivnx2qi */
    case 1305:  /* pred_indexed_ustorevnx2qivnx2qi */
    case 1304:  /* pred_indexed_ostorevnx2qivnx2qi */
    case 1303:  /* pred_indexed_ustorevnx1dfvnx1di */
    case 1302:  /* pred_indexed_ostorevnx1dfvnx1di */
    case 1301:  /* pred_indexed_ustorevnx1dfvnx1si */
    case 1300:  /* pred_indexed_ostorevnx1dfvnx1si */
    case 1299:  /* pred_indexed_ustorevnx1dfvnx1hi */
    case 1298:  /* pred_indexed_ostorevnx1dfvnx1hi */
    case 1297:  /* pred_indexed_ustorevnx1dfvnx1qi */
    case 1296:  /* pred_indexed_ostorevnx1dfvnx1qi */
    case 1295:  /* pred_indexed_ustorevnx1sfvnx1di */
    case 1294:  /* pred_indexed_ostorevnx1sfvnx1di */
    case 1293:  /* pred_indexed_ustorevnx1sfvnx1si */
    case 1292:  /* pred_indexed_ostorevnx1sfvnx1si */
    case 1291:  /* pred_indexed_ustorevnx1sfvnx1hi */
    case 1290:  /* pred_indexed_ostorevnx1sfvnx1hi */
    case 1289:  /* pred_indexed_ustorevnx1sfvnx1qi */
    case 1288:  /* pred_indexed_ostorevnx1sfvnx1qi */
    case 1287:  /* pred_indexed_ustorevnx1divnx1di */
    case 1286:  /* pred_indexed_ostorevnx1divnx1di */
    case 1285:  /* pred_indexed_ustorevnx1divnx1si */
    case 1284:  /* pred_indexed_ostorevnx1divnx1si */
    case 1283:  /* pred_indexed_ustorevnx1divnx1hi */
    case 1282:  /* pred_indexed_ostorevnx1divnx1hi */
    case 1281:  /* pred_indexed_ustorevnx1divnx1qi */
    case 1280:  /* pred_indexed_ostorevnx1divnx1qi */
    case 1279:  /* pred_indexed_ustorevnx1sivnx1di */
    case 1278:  /* pred_indexed_ostorevnx1sivnx1di */
    case 1277:  /* pred_indexed_ustorevnx1sivnx1si */
    case 1276:  /* pred_indexed_ostorevnx1sivnx1si */
    case 1275:  /* pred_indexed_ustorevnx1sivnx1hi */
    case 1274:  /* pred_indexed_ostorevnx1sivnx1hi */
    case 1273:  /* pred_indexed_ustorevnx1sivnx1qi */
    case 1272:  /* pred_indexed_ostorevnx1sivnx1qi */
    case 1271:  /* pred_indexed_ustorevnx1hivnx1di */
    case 1270:  /* pred_indexed_ostorevnx1hivnx1di */
    case 1269:  /* pred_indexed_ustorevnx1hivnx1si */
    case 1268:  /* pred_indexed_ostorevnx1hivnx1si */
    case 1267:  /* pred_indexed_ustorevnx1hivnx1hi */
    case 1266:  /* pred_indexed_ostorevnx1hivnx1hi */
    case 1265:  /* pred_indexed_ustorevnx1hivnx1qi */
    case 1264:  /* pred_indexed_ostorevnx1hivnx1qi */
    case 1263:  /* pred_indexed_ustorevnx1qivnx1di */
    case 1262:  /* pred_indexed_ostorevnx1qivnx1di */
    case 1261:  /* pred_indexed_ustorevnx1qivnx1si */
    case 1260:  /* pred_indexed_ostorevnx1qivnx1si */
    case 1259:  /* pred_indexed_ustorevnx1qivnx1hi */
    case 1258:  /* pred_indexed_ostorevnx1qivnx1hi */
    case 1257:  /* pred_indexed_ustorevnx1qivnx1qi */
    case 1256:  /* pred_indexed_ostorevnx1qivnx1qi */
    case 868:  /* pred_movvnx64bi */
    case 867:  /* pred_movvnx32bi */
    case 866:  /* pred_movvnx16bi */
    case 865:  /* pred_movvnx8bi */
    case 864:  /* pred_movvnx4bi */
    case 863:  /* pred_movvnx2bi */
    case 862:  /* pred_movvnx1bi */
    case 2552:  /* pred_madcvnx1qi */
    case 2553:  /* pred_madcvnx2qi */
    case 2554:  /* pred_madcvnx4qi */
    case 2555:  /* pred_madcvnx8qi */
    case 2556:  /* pred_madcvnx16qi */
    case 2557:  /* pred_madcvnx32qi */
    case 2558:  /* pred_madcvnx64qi */
    case 2559:  /* pred_madcvnx1hi */
    case 2560:  /* pred_madcvnx2hi */
    case 2561:  /* pred_madcvnx4hi */
    case 2562:  /* pred_madcvnx8hi */
    case 2563:  /* pred_madcvnx16hi */
    case 2564:  /* pred_madcvnx32hi */
    case 2565:  /* pred_madcvnx1si */
    case 2566:  /* pred_madcvnx2si */
    case 2567:  /* pred_madcvnx4si */
    case 2568:  /* pred_madcvnx8si */
    case 2569:  /* pred_madcvnx16si */
    case 2570:  /* pred_madcvnx1di */
    case 2571:  /* pred_madcvnx2di */
    case 2572:  /* pred_madcvnx4di */
    case 2573:  /* pred_madcvnx8di */
    case 2574:  /* pred_msbcvnx1qi */
    case 2575:  /* pred_msbcvnx2qi */
    case 2576:  /* pred_msbcvnx4qi */
    case 2577:  /* pred_msbcvnx8qi */
    case 2578:  /* pred_msbcvnx16qi */
    case 2579:  /* pred_msbcvnx32qi */
    case 2580:  /* pred_msbcvnx64qi */
    case 2581:  /* pred_msbcvnx1hi */
    case 2582:  /* pred_msbcvnx2hi */
    case 2583:  /* pred_msbcvnx4hi */
    case 2584:  /* pred_msbcvnx8hi */
    case 2585:  /* pred_msbcvnx16hi */
    case 2586:  /* pred_msbcvnx32hi */
    case 2587:  /* pred_msbcvnx1si */
    case 2588:  /* pred_msbcvnx2si */
    case 2589:  /* pred_msbcvnx4si */
    case 2590:  /* pred_msbcvnx8si */
    case 2591:  /* pred_msbcvnx16si */
    case 2592:  /* pred_msbcvnx1di */
    case 2593:  /* pred_msbcvnx2di */
    case 2594:  /* pred_msbcvnx4di */
    case 2595:  /* pred_msbcvnx8di */
    case 2596:  /* pred_madcvnx1qi_scalar */
    case 2597:  /* pred_madcvnx2qi_scalar */
    case 2598:  /* pred_madcvnx4qi_scalar */
    case 2599:  /* pred_madcvnx8qi_scalar */
    case 2600:  /* pred_madcvnx16qi_scalar */
    case 2601:  /* pred_madcvnx32qi_scalar */
    case 2602:  /* pred_madcvnx64qi_scalar */
    case 2603:  /* pred_madcvnx1hi_scalar */
    case 2604:  /* pred_madcvnx2hi_scalar */
    case 2605:  /* pred_madcvnx4hi_scalar */
    case 2606:  /* pred_madcvnx8hi_scalar */
    case 2607:  /* pred_madcvnx16hi_scalar */
    case 2608:  /* pred_madcvnx32hi_scalar */
    case 2609:  /* pred_madcvnx1si_scalar */
    case 2610:  /* pred_madcvnx2si_scalar */
    case 2611:  /* pred_madcvnx4si_scalar */
    case 2612:  /* pred_madcvnx8si_scalar */
    case 2613:  /* pred_madcvnx16si_scalar */
    case 2614:  /* pred_msbcvnx1qi_scalar */
    case 2615:  /* pred_msbcvnx2qi_scalar */
    case 2616:  /* pred_msbcvnx4qi_scalar */
    case 2617:  /* pred_msbcvnx8qi_scalar */
    case 2618:  /* pred_msbcvnx16qi_scalar */
    case 2619:  /* pred_msbcvnx32qi_scalar */
    case 2620:  /* pred_msbcvnx64qi_scalar */
    case 2621:  /* pred_msbcvnx1hi_scalar */
    case 2622:  /* pred_msbcvnx2hi_scalar */
    case 2623:  /* pred_msbcvnx4hi_scalar */
    case 2624:  /* pred_msbcvnx8hi_scalar */
    case 2625:  /* pred_msbcvnx16hi_scalar */
    case 2626:  /* pred_msbcvnx32hi_scalar */
    case 2627:  /* pred_msbcvnx1si_scalar */
    case 2628:  /* pred_msbcvnx2si_scalar */
    case 2629:  /* pred_msbcvnx4si_scalar */
    case 2630:  /* pred_msbcvnx8si_scalar */
    case 2631:  /* pred_msbcvnx16si_scalar */
    case 2632:  /* *pred_madcvnx1di_scalar */
    case 2633:  /* *pred_madcvnx2di_scalar */
    case 2634:  /* *pred_madcvnx4di_scalar */
    case 2635:  /* *pred_madcvnx8di_scalar */
    case 2636:  /* *pred_madcvnx1di_extended_scalar */
    case 2637:  /* *pred_madcvnx2di_extended_scalar */
    case 2638:  /* *pred_madcvnx4di_extended_scalar */
    case 2639:  /* *pred_madcvnx8di_extended_scalar */
    case 2640:  /* *pred_msbcvnx1di_scalar */
    case 2641:  /* *pred_msbcvnx2di_scalar */
    case 2642:  /* *pred_msbcvnx4di_scalar */
    case 2643:  /* *pred_msbcvnx8di_scalar */
    case 2644:  /* *pred_msbcvnx1di_extended_scalar */
    case 2645:  /* *pred_msbcvnx2di_extended_scalar */
    case 2646:  /* *pred_msbcvnx4di_extended_scalar */
    case 2647:  /* *pred_msbcvnx8di_extended_scalar */
    case 4500:  /* pred_notvnx1bi */
    case 4501:  /* pred_notvnx2bi */
    case 4502:  /* pred_notvnx4bi */
    case 4503:  /* pred_notvnx8bi */
    case 4504:  /* pred_notvnx16bi */
    case 4505:  /* pred_notvnx32bi */
    case 4506:  /* pred_notvnx64bi */
      extract_constrain_insn_cached (insn);
      return 
#line 326 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[5]));

    case 6067:  /* pred_fault_loadvnx8df */
    case 6066:  /* pred_fault_loadvnx4df */
    case 6065:  /* pred_fault_loadvnx2df */
    case 6064:  /* pred_fault_loadvnx1df */
    case 6063:  /* pred_fault_loadvnx16sf */
    case 6062:  /* pred_fault_loadvnx8sf */
    case 6061:  /* pred_fault_loadvnx4sf */
    case 6060:  /* pred_fault_loadvnx2sf */
    case 6059:  /* pred_fault_loadvnx1sf */
    case 6058:  /* pred_fault_loadvnx8di */
    case 6057:  /* pred_fault_loadvnx4di */
    case 6056:  /* pred_fault_loadvnx2di */
    case 6055:  /* pred_fault_loadvnx1di */
    case 6054:  /* pred_fault_loadvnx16si */
    case 6053:  /* pred_fault_loadvnx8si */
    case 6052:  /* pred_fault_loadvnx4si */
    case 6051:  /* pred_fault_loadvnx2si */
    case 6050:  /* pred_fault_loadvnx1si */
    case 6049:  /* pred_fault_loadvnx32hi */
    case 6048:  /* pred_fault_loadvnx16hi */
    case 6047:  /* pred_fault_loadvnx8hi */
    case 6046:  /* pred_fault_loadvnx4hi */
    case 6045:  /* pred_fault_loadvnx2hi */
    case 6044:  /* pred_fault_loadvnx1hi */
    case 6043:  /* pred_fault_loadvnx64qi */
    case 6042:  /* pred_fault_loadvnx32qi */
    case 6041:  /* pred_fault_loadvnx16qi */
    case 6040:  /* pred_fault_loadvnx8qi */
    case 6039:  /* pred_fault_loadvnx4qi */
    case 6038:  /* pred_fault_loadvnx2qi */
    case 6037:  /* pred_fault_loadvnx1qi */
    case 5744:  /* pred_widen_reduc_plusuvnx16sfvnx1df */
    case 5743:  /* pred_widen_reduc_plusovnx16sfvnx1df */
    case 5742:  /* pred_widen_reduc_plusuvnx8sfvnx1df */
    case 5741:  /* pred_widen_reduc_plusovnx8sfvnx1df */
    case 5740:  /* pred_widen_reduc_plusuvnx4sfvnx1df */
    case 5739:  /* pred_widen_reduc_plusovnx4sfvnx1df */
    case 5738:  /* pred_widen_reduc_plusuvnx2sfvnx1df */
    case 5737:  /* pred_widen_reduc_plusovnx2sfvnx1df */
    case 5736:  /* pred_widen_reduc_plusuvnx1sfvnx1df */
    case 5735:  /* pred_widen_reduc_plusovnx1sfvnx1df */
    case 5734:  /* pred_reduc_plusuvnx8sfvnx1sf */
    case 5733:  /* pred_reduc_plusovnx8sfvnx1sf */
    case 5732:  /* pred_reduc_plusuvnx4sfvnx1sf */
    case 5731:  /* pred_reduc_plusovnx4sfvnx1sf */
    case 5730:  /* pred_reduc_plusuvnx2sfvnx1sf */
    case 5729:  /* pred_reduc_plusovnx2sfvnx1sf */
    case 5728:  /* pred_reduc_plusuvnx1sfvnx1sf */
    case 5727:  /* pred_reduc_plusovnx1sfvnx1sf */
    case 5726:  /* pred_reduc_plusuvnx8dfvnx1df */
    case 5725:  /* pred_reduc_plusovnx8dfvnx1df */
    case 5724:  /* pred_reduc_plusuvnx4dfvnx1df */
    case 5723:  /* pred_reduc_plusovnx4dfvnx1df */
    case 5722:  /* pred_reduc_plusuvnx2dfvnx1df */
    case 5721:  /* pred_reduc_plusovnx2dfvnx1df */
    case 5720:  /* pred_reduc_plusuvnx1dfvnx1df */
    case 5719:  /* pred_reduc_plusovnx1dfvnx1df */
    case 5718:  /* pred_reduc_plusuvnx16sfvnx2sf */
    case 5717:  /* pred_reduc_plusovnx16sfvnx2sf */
    case 5716:  /* pred_reduc_plusuvnx8sfvnx2sf */
    case 5715:  /* pred_reduc_plusovnx8sfvnx2sf */
    case 5714:  /* pred_reduc_plusuvnx4sfvnx2sf */
    case 5713:  /* pred_reduc_plusovnx4sfvnx2sf */
    case 5712:  /* pred_reduc_plusuvnx2sfvnx2sf */
    case 5711:  /* pred_reduc_plusovnx2sfvnx2sf */
    case 5710:  /* pred_reduc_plusuvnx1sfvnx2sf */
    case 5709:  /* pred_reduc_plusovnx1sfvnx2sf */
    case 5708:  /* pred_reduc_minvnx8sfvnx1sf */
    case 5707:  /* pred_reduc_maxvnx8sfvnx1sf */
    case 5706:  /* pred_reduc_minvnx4sfvnx1sf */
    case 5705:  /* pred_reduc_maxvnx4sfvnx1sf */
    case 5704:  /* pred_reduc_minvnx2sfvnx1sf */
    case 5703:  /* pred_reduc_maxvnx2sfvnx1sf */
    case 5702:  /* pred_reduc_minvnx1sfvnx1sf */
    case 5701:  /* pred_reduc_maxvnx1sfvnx1sf */
    case 5700:  /* pred_reduc_minvnx8dfvnx1df */
    case 5699:  /* pred_reduc_maxvnx8dfvnx1df */
    case 5698:  /* pred_reduc_minvnx4dfvnx1df */
    case 5697:  /* pred_reduc_maxvnx4dfvnx1df */
    case 5696:  /* pred_reduc_minvnx2dfvnx1df */
    case 5695:  /* pred_reduc_maxvnx2dfvnx1df */
    case 5694:  /* pred_reduc_minvnx1dfvnx1df */
    case 5693:  /* pred_reduc_maxvnx1dfvnx1df */
    case 5692:  /* pred_reduc_minvnx16sfvnx2sf */
    case 5691:  /* pred_reduc_maxvnx16sfvnx2sf */
    case 5690:  /* pred_reduc_minvnx8sfvnx2sf */
    case 5689:  /* pred_reduc_maxvnx8sfvnx2sf */
    case 5688:  /* pred_reduc_minvnx4sfvnx2sf */
    case 5687:  /* pred_reduc_maxvnx4sfvnx2sf */
    case 5686:  /* pred_reduc_minvnx2sfvnx2sf */
    case 5685:  /* pred_reduc_maxvnx2sfvnx2sf */
    case 5684:  /* pred_reduc_minvnx1sfvnx2sf */
    case 5683:  /* pred_reduc_maxvnx1sfvnx2sf */
    case 5682:  /* pred_widen_reduc_plusuvnx16hivnx1si */
    case 5681:  /* pred_widen_reduc_plusvnx16hivnx1si */
    case 5680:  /* pred_widen_reduc_plusuvnx8hivnx1si */
    case 5679:  /* pred_widen_reduc_plusvnx8hivnx1si */
    case 5678:  /* pred_widen_reduc_plusuvnx4hivnx1si */
    case 5677:  /* pred_widen_reduc_plusvnx4hivnx1si */
    case 5676:  /* pred_widen_reduc_plusuvnx2hivnx1si */
    case 5675:  /* pred_widen_reduc_plusvnx2hivnx1si */
    case 5674:  /* pred_widen_reduc_plusuvnx1hivnx1si */
    case 5673:  /* pred_widen_reduc_plusvnx1hivnx1si */
    case 5672:  /* pred_widen_reduc_plusuvnx32qivnx2hi */
    case 5671:  /* pred_widen_reduc_plusvnx32qivnx2hi */
    case 5670:  /* pred_widen_reduc_plusuvnx16qivnx2hi */
    case 5669:  /* pred_widen_reduc_plusvnx16qivnx2hi */
    case 5668:  /* pred_widen_reduc_plusuvnx8qivnx2hi */
    case 5667:  /* pred_widen_reduc_plusvnx8qivnx2hi */
    case 5666:  /* pred_widen_reduc_plusuvnx4qivnx2hi */
    case 5665:  /* pred_widen_reduc_plusvnx4qivnx2hi */
    case 5664:  /* pred_widen_reduc_plusuvnx2qivnx2hi */
    case 5663:  /* pred_widen_reduc_plusvnx2qivnx2hi */
    case 5662:  /* pred_widen_reduc_plusuvnx1qivnx2hi */
    case 5661:  /* pred_widen_reduc_plusvnx1qivnx2hi */
    case 5660:  /* pred_widen_reduc_plusuvnx16sivnx2di */
    case 5659:  /* pred_widen_reduc_plusvnx16sivnx2di */
    case 5658:  /* pred_widen_reduc_plusuvnx8sivnx2di */
    case 5657:  /* pred_widen_reduc_plusvnx8sivnx2di */
    case 5656:  /* pred_widen_reduc_plusuvnx4sivnx2di */
    case 5655:  /* pred_widen_reduc_plusvnx4sivnx2di */
    case 5654:  /* pred_widen_reduc_plusuvnx2sivnx2di */
    case 5653:  /* pred_widen_reduc_plusvnx2sivnx2di */
    case 5652:  /* pred_widen_reduc_plusuvnx1sivnx2di */
    case 5651:  /* pred_widen_reduc_plusvnx1sivnx2di */
    case 5650:  /* pred_widen_reduc_plusuvnx32hivnx2si */
    case 5649:  /* pred_widen_reduc_plusvnx32hivnx2si */
    case 5648:  /* pred_widen_reduc_plusuvnx16hivnx2si */
    case 5647:  /* pred_widen_reduc_plusvnx16hivnx2si */
    case 5646:  /* pred_widen_reduc_plusuvnx8hivnx2si */
    case 5645:  /* pred_widen_reduc_plusvnx8hivnx2si */
    case 5644:  /* pred_widen_reduc_plusuvnx4hivnx2si */
    case 5643:  /* pred_widen_reduc_plusvnx4hivnx2si */
    case 5642:  /* pred_widen_reduc_plusuvnx2hivnx2si */
    case 5641:  /* pred_widen_reduc_plusvnx2hivnx2si */
    case 5640:  /* pred_widen_reduc_plusuvnx1hivnx2si */
    case 5639:  /* pred_widen_reduc_plusvnx1hivnx2si */
    case 5638:  /* pred_widen_reduc_plusuvnx64qivnx4hi */
    case 5637:  /* pred_widen_reduc_plusvnx64qivnx4hi */
    case 5636:  /* pred_widen_reduc_plusuvnx32qivnx4hi */
    case 5635:  /* pred_widen_reduc_plusvnx32qivnx4hi */
    case 5634:  /* pred_widen_reduc_plusuvnx16qivnx4hi */
    case 5633:  /* pred_widen_reduc_plusvnx16qivnx4hi */
    case 5632:  /* pred_widen_reduc_plusuvnx8qivnx4hi */
    case 5631:  /* pred_widen_reduc_plusvnx8qivnx4hi */
    case 5630:  /* pred_widen_reduc_plusuvnx4qivnx4hi */
    case 5629:  /* pred_widen_reduc_plusvnx4qivnx4hi */
    case 5628:  /* pred_widen_reduc_plusuvnx2qivnx4hi */
    case 5627:  /* pred_widen_reduc_plusvnx2qivnx4hi */
    case 5626:  /* pred_widen_reduc_plusuvnx1qivnx4hi */
    case 5625:  /* pred_widen_reduc_plusvnx1qivnx4hi */
    case 5624:  /* pred_reduc_xorvnx8sivnx1si */
    case 5623:  /* pred_reduc_orvnx8sivnx1si */
    case 5622:  /* pred_reduc_andvnx8sivnx1si */
    case 5621:  /* pred_reduc_minvnx8sivnx1si */
    case 5620:  /* pred_reduc_minuvnx8sivnx1si */
    case 5619:  /* pred_reduc_maxvnx8sivnx1si */
    case 5618:  /* pred_reduc_maxuvnx8sivnx1si */
    case 5617:  /* pred_reduc_sumvnx8sivnx1si */
    case 5616:  /* pred_reduc_xorvnx4sivnx1si */
    case 5615:  /* pred_reduc_orvnx4sivnx1si */
    case 5614:  /* pred_reduc_andvnx4sivnx1si */
    case 5613:  /* pred_reduc_minvnx4sivnx1si */
    case 5612:  /* pred_reduc_minuvnx4sivnx1si */
    case 5611:  /* pred_reduc_maxvnx4sivnx1si */
    case 5610:  /* pred_reduc_maxuvnx4sivnx1si */
    case 5609:  /* pred_reduc_sumvnx4sivnx1si */
    case 5608:  /* pred_reduc_xorvnx2sivnx1si */
    case 5607:  /* pred_reduc_orvnx2sivnx1si */
    case 5606:  /* pred_reduc_andvnx2sivnx1si */
    case 5605:  /* pred_reduc_minvnx2sivnx1si */
    case 5604:  /* pred_reduc_minuvnx2sivnx1si */
    case 5603:  /* pred_reduc_maxvnx2sivnx1si */
    case 5602:  /* pred_reduc_maxuvnx2sivnx1si */
    case 5601:  /* pred_reduc_sumvnx2sivnx1si */
    case 5600:  /* pred_reduc_xorvnx1sivnx1si */
    case 5599:  /* pred_reduc_orvnx1sivnx1si */
    case 5598:  /* pred_reduc_andvnx1sivnx1si */
    case 5597:  /* pred_reduc_minvnx1sivnx1si */
    case 5596:  /* pred_reduc_minuvnx1sivnx1si */
    case 5595:  /* pred_reduc_maxvnx1sivnx1si */
    case 5594:  /* pred_reduc_maxuvnx1sivnx1si */
    case 5593:  /* pred_reduc_sumvnx1sivnx1si */
    case 5592:  /* pred_reduc_xorvnx16hivnx2hi */
    case 5591:  /* pred_reduc_orvnx16hivnx2hi */
    case 5590:  /* pred_reduc_andvnx16hivnx2hi */
    case 5589:  /* pred_reduc_minvnx16hivnx2hi */
    case 5588:  /* pred_reduc_minuvnx16hivnx2hi */
    case 5587:  /* pred_reduc_maxvnx16hivnx2hi */
    case 5586:  /* pred_reduc_maxuvnx16hivnx2hi */
    case 5585:  /* pred_reduc_sumvnx16hivnx2hi */
    case 5584:  /* pred_reduc_xorvnx8hivnx2hi */
    case 5583:  /* pred_reduc_orvnx8hivnx2hi */
    case 5582:  /* pred_reduc_andvnx8hivnx2hi */
    case 5581:  /* pred_reduc_minvnx8hivnx2hi */
    case 5580:  /* pred_reduc_minuvnx8hivnx2hi */
    case 5579:  /* pred_reduc_maxvnx8hivnx2hi */
    case 5578:  /* pred_reduc_maxuvnx8hivnx2hi */
    case 5577:  /* pred_reduc_sumvnx8hivnx2hi */
    case 5576:  /* pred_reduc_xorvnx4hivnx2hi */
    case 5575:  /* pred_reduc_orvnx4hivnx2hi */
    case 5574:  /* pred_reduc_andvnx4hivnx2hi */
    case 5573:  /* pred_reduc_minvnx4hivnx2hi */
    case 5572:  /* pred_reduc_minuvnx4hivnx2hi */
    case 5571:  /* pred_reduc_maxvnx4hivnx2hi */
    case 5570:  /* pred_reduc_maxuvnx4hivnx2hi */
    case 5569:  /* pred_reduc_sumvnx4hivnx2hi */
    case 5568:  /* pred_reduc_xorvnx2hivnx2hi */
    case 5567:  /* pred_reduc_orvnx2hivnx2hi */
    case 5566:  /* pred_reduc_andvnx2hivnx2hi */
    case 5565:  /* pred_reduc_minvnx2hivnx2hi */
    case 5564:  /* pred_reduc_minuvnx2hivnx2hi */
    case 5563:  /* pred_reduc_maxvnx2hivnx2hi */
    case 5562:  /* pred_reduc_maxuvnx2hivnx2hi */
    case 5561:  /* pred_reduc_sumvnx2hivnx2hi */
    case 5560:  /* pred_reduc_xorvnx1hivnx2hi */
    case 5559:  /* pred_reduc_orvnx1hivnx2hi */
    case 5558:  /* pred_reduc_andvnx1hivnx2hi */
    case 5557:  /* pred_reduc_minvnx1hivnx2hi */
    case 5556:  /* pred_reduc_minuvnx1hivnx2hi */
    case 5555:  /* pred_reduc_maxvnx1hivnx2hi */
    case 5554:  /* pred_reduc_maxuvnx1hivnx2hi */
    case 5553:  /* pred_reduc_sumvnx1hivnx2hi */
    case 5552:  /* pred_reduc_xorvnx32qivnx4qi */
    case 5551:  /* pred_reduc_orvnx32qivnx4qi */
    case 5550:  /* pred_reduc_andvnx32qivnx4qi */
    case 5549:  /* pred_reduc_minvnx32qivnx4qi */
    case 5548:  /* pred_reduc_minuvnx32qivnx4qi */
    case 5547:  /* pred_reduc_maxvnx32qivnx4qi */
    case 5546:  /* pred_reduc_maxuvnx32qivnx4qi */
    case 5545:  /* pred_reduc_sumvnx32qivnx4qi */
    case 5544:  /* pred_reduc_xorvnx16qivnx4qi */
    case 5543:  /* pred_reduc_orvnx16qivnx4qi */
    case 5542:  /* pred_reduc_andvnx16qivnx4qi */
    case 5541:  /* pred_reduc_minvnx16qivnx4qi */
    case 5540:  /* pred_reduc_minuvnx16qivnx4qi */
    case 5539:  /* pred_reduc_maxvnx16qivnx4qi */
    case 5538:  /* pred_reduc_maxuvnx16qivnx4qi */
    case 5537:  /* pred_reduc_sumvnx16qivnx4qi */
    case 5536:  /* pred_reduc_xorvnx8qivnx4qi */
    case 5535:  /* pred_reduc_orvnx8qivnx4qi */
    case 5534:  /* pred_reduc_andvnx8qivnx4qi */
    case 5533:  /* pred_reduc_minvnx8qivnx4qi */
    case 5532:  /* pred_reduc_minuvnx8qivnx4qi */
    case 5531:  /* pred_reduc_maxvnx8qivnx4qi */
    case 5530:  /* pred_reduc_maxuvnx8qivnx4qi */
    case 5529:  /* pred_reduc_sumvnx8qivnx4qi */
    case 5528:  /* pred_reduc_xorvnx4qivnx4qi */
    case 5527:  /* pred_reduc_orvnx4qivnx4qi */
    case 5526:  /* pred_reduc_andvnx4qivnx4qi */
    case 5525:  /* pred_reduc_minvnx4qivnx4qi */
    case 5524:  /* pred_reduc_minuvnx4qivnx4qi */
    case 5523:  /* pred_reduc_maxvnx4qivnx4qi */
    case 5522:  /* pred_reduc_maxuvnx4qivnx4qi */
    case 5521:  /* pred_reduc_sumvnx4qivnx4qi */
    case 5520:  /* pred_reduc_xorvnx2qivnx4qi */
    case 5519:  /* pred_reduc_orvnx2qivnx4qi */
    case 5518:  /* pred_reduc_andvnx2qivnx4qi */
    case 5517:  /* pred_reduc_minvnx2qivnx4qi */
    case 5516:  /* pred_reduc_minuvnx2qivnx4qi */
    case 5515:  /* pred_reduc_maxvnx2qivnx4qi */
    case 5514:  /* pred_reduc_maxuvnx2qivnx4qi */
    case 5513:  /* pred_reduc_sumvnx2qivnx4qi */
    case 5512:  /* pred_reduc_xorvnx1qivnx4qi */
    case 5511:  /* pred_reduc_orvnx1qivnx4qi */
    case 5510:  /* pred_reduc_andvnx1qivnx4qi */
    case 5509:  /* pred_reduc_minvnx1qivnx4qi */
    case 5508:  /* pred_reduc_minuvnx1qivnx4qi */
    case 5507:  /* pred_reduc_maxvnx1qivnx4qi */
    case 5506:  /* pred_reduc_maxuvnx1qivnx4qi */
    case 5505:  /* pred_reduc_sumvnx1qivnx4qi */
    case 5504:  /* pred_reduc_xorvnx8divnx1DI */
    case 5503:  /* pred_reduc_orvnx8divnx1DI */
    case 5502:  /* pred_reduc_andvnx8divnx1DI */
    case 5501:  /* pred_reduc_minvnx8divnx1DI */
    case 5500:  /* pred_reduc_minuvnx8divnx1DI */
    case 5499:  /* pred_reduc_maxvnx8divnx1DI */
    case 5498:  /* pred_reduc_maxuvnx8divnx1DI */
    case 5497:  /* pred_reduc_sumvnx8divnx1DI */
    case 5496:  /* pred_reduc_xorvnx4divnx1DI */
    case 5495:  /* pred_reduc_orvnx4divnx1DI */
    case 5494:  /* pred_reduc_andvnx4divnx1DI */
    case 5493:  /* pred_reduc_minvnx4divnx1DI */
    case 5492:  /* pred_reduc_minuvnx4divnx1DI */
    case 5491:  /* pred_reduc_maxvnx4divnx1DI */
    case 5490:  /* pred_reduc_maxuvnx4divnx1DI */
    case 5489:  /* pred_reduc_sumvnx4divnx1DI */
    case 5488:  /* pred_reduc_xorvnx2divnx1DI */
    case 5487:  /* pred_reduc_orvnx2divnx1DI */
    case 5486:  /* pred_reduc_andvnx2divnx1DI */
    case 5485:  /* pred_reduc_minvnx2divnx1DI */
    case 5484:  /* pred_reduc_minuvnx2divnx1DI */
    case 5483:  /* pred_reduc_maxvnx2divnx1DI */
    case 5482:  /* pred_reduc_maxuvnx2divnx1DI */
    case 5481:  /* pred_reduc_sumvnx2divnx1DI */
    case 5480:  /* pred_reduc_xorvnx1divnx1DI */
    case 5479:  /* pred_reduc_orvnx1divnx1DI */
    case 5478:  /* pred_reduc_andvnx1divnx1DI */
    case 5477:  /* pred_reduc_minvnx1divnx1DI */
    case 5476:  /* pred_reduc_minuvnx1divnx1DI */
    case 5475:  /* pred_reduc_maxvnx1divnx1DI */
    case 5474:  /* pred_reduc_maxuvnx1divnx1DI */
    case 5473:  /* pred_reduc_sumvnx1divnx1DI */
    case 5472:  /* pred_reduc_xorvnx16sivnx2si */
    case 5471:  /* pred_reduc_orvnx16sivnx2si */
    case 5470:  /* pred_reduc_andvnx16sivnx2si */
    case 5469:  /* pred_reduc_minvnx16sivnx2si */
    case 5468:  /* pred_reduc_minuvnx16sivnx2si */
    case 5467:  /* pred_reduc_maxvnx16sivnx2si */
    case 5466:  /* pred_reduc_maxuvnx16sivnx2si */
    case 5465:  /* pred_reduc_sumvnx16sivnx2si */
    case 5464:  /* pred_reduc_xorvnx8sivnx2si */
    case 5463:  /* pred_reduc_orvnx8sivnx2si */
    case 5462:  /* pred_reduc_andvnx8sivnx2si */
    case 5461:  /* pred_reduc_minvnx8sivnx2si */
    case 5460:  /* pred_reduc_minuvnx8sivnx2si */
    case 5459:  /* pred_reduc_maxvnx8sivnx2si */
    case 5458:  /* pred_reduc_maxuvnx8sivnx2si */
    case 5457:  /* pred_reduc_sumvnx8sivnx2si */
    case 5456:  /* pred_reduc_xorvnx4sivnx2si */
    case 5455:  /* pred_reduc_orvnx4sivnx2si */
    case 5454:  /* pred_reduc_andvnx4sivnx2si */
    case 5453:  /* pred_reduc_minvnx4sivnx2si */
    case 5452:  /* pred_reduc_minuvnx4sivnx2si */
    case 5451:  /* pred_reduc_maxvnx4sivnx2si */
    case 5450:  /* pred_reduc_maxuvnx4sivnx2si */
    case 5449:  /* pred_reduc_sumvnx4sivnx2si */
    case 5448:  /* pred_reduc_xorvnx2sivnx2si */
    case 5447:  /* pred_reduc_orvnx2sivnx2si */
    case 5446:  /* pred_reduc_andvnx2sivnx2si */
    case 5445:  /* pred_reduc_minvnx2sivnx2si */
    case 5444:  /* pred_reduc_minuvnx2sivnx2si */
    case 5443:  /* pred_reduc_maxvnx2sivnx2si */
    case 5442:  /* pred_reduc_maxuvnx2sivnx2si */
    case 5441:  /* pred_reduc_sumvnx2sivnx2si */
    case 5440:  /* pred_reduc_xorvnx1sivnx2si */
    case 5439:  /* pred_reduc_orvnx1sivnx2si */
    case 5438:  /* pred_reduc_andvnx1sivnx2si */
    case 5437:  /* pred_reduc_minvnx1sivnx2si */
    case 5436:  /* pred_reduc_minuvnx1sivnx2si */
    case 5435:  /* pred_reduc_maxvnx1sivnx2si */
    case 5434:  /* pred_reduc_maxuvnx1sivnx2si */
    case 5433:  /* pred_reduc_sumvnx1sivnx2si */
    case 5432:  /* pred_reduc_xorvnx32hivnx4hi */
    case 5431:  /* pred_reduc_orvnx32hivnx4hi */
    case 5430:  /* pred_reduc_andvnx32hivnx4hi */
    case 5429:  /* pred_reduc_minvnx32hivnx4hi */
    case 5428:  /* pred_reduc_minuvnx32hivnx4hi */
    case 5427:  /* pred_reduc_maxvnx32hivnx4hi */
    case 5426:  /* pred_reduc_maxuvnx32hivnx4hi */
    case 5425:  /* pred_reduc_sumvnx32hivnx4hi */
    case 5424:  /* pred_reduc_xorvnx16hivnx4hi */
    case 5423:  /* pred_reduc_orvnx16hivnx4hi */
    case 5422:  /* pred_reduc_andvnx16hivnx4hi */
    case 5421:  /* pred_reduc_minvnx16hivnx4hi */
    case 5420:  /* pred_reduc_minuvnx16hivnx4hi */
    case 5419:  /* pred_reduc_maxvnx16hivnx4hi */
    case 5418:  /* pred_reduc_maxuvnx16hivnx4hi */
    case 5417:  /* pred_reduc_sumvnx16hivnx4hi */
    case 5416:  /* pred_reduc_xorvnx8hivnx4hi */
    case 5415:  /* pred_reduc_orvnx8hivnx4hi */
    case 5414:  /* pred_reduc_andvnx8hivnx4hi */
    case 5413:  /* pred_reduc_minvnx8hivnx4hi */
    case 5412:  /* pred_reduc_minuvnx8hivnx4hi */
    case 5411:  /* pred_reduc_maxvnx8hivnx4hi */
    case 5410:  /* pred_reduc_maxuvnx8hivnx4hi */
    case 5409:  /* pred_reduc_sumvnx8hivnx4hi */
    case 5408:  /* pred_reduc_xorvnx4hivnx4hi */
    case 5407:  /* pred_reduc_orvnx4hivnx4hi */
    case 5406:  /* pred_reduc_andvnx4hivnx4hi */
    case 5405:  /* pred_reduc_minvnx4hivnx4hi */
    case 5404:  /* pred_reduc_minuvnx4hivnx4hi */
    case 5403:  /* pred_reduc_maxvnx4hivnx4hi */
    case 5402:  /* pred_reduc_maxuvnx4hivnx4hi */
    case 5401:  /* pred_reduc_sumvnx4hivnx4hi */
    case 5400:  /* pred_reduc_xorvnx2hivnx4hi */
    case 5399:  /* pred_reduc_orvnx2hivnx4hi */
    case 5398:  /* pred_reduc_andvnx2hivnx4hi */
    case 5397:  /* pred_reduc_minvnx2hivnx4hi */
    case 5396:  /* pred_reduc_minuvnx2hivnx4hi */
    case 5395:  /* pred_reduc_maxvnx2hivnx4hi */
    case 5394:  /* pred_reduc_maxuvnx2hivnx4hi */
    case 5393:  /* pred_reduc_sumvnx2hivnx4hi */
    case 5392:  /* pred_reduc_xorvnx1hivnx4hi */
    case 5391:  /* pred_reduc_orvnx1hivnx4hi */
    case 5390:  /* pred_reduc_andvnx1hivnx4hi */
    case 5389:  /* pred_reduc_minvnx1hivnx4hi */
    case 5388:  /* pred_reduc_minuvnx1hivnx4hi */
    case 5387:  /* pred_reduc_maxvnx1hivnx4hi */
    case 5386:  /* pred_reduc_maxuvnx1hivnx4hi */
    case 5385:  /* pred_reduc_sumvnx1hivnx4hi */
    case 5384:  /* pred_reduc_xorvnx64qivnx8qi */
    case 5383:  /* pred_reduc_orvnx64qivnx8qi */
    case 5382:  /* pred_reduc_andvnx64qivnx8qi */
    case 5381:  /* pred_reduc_minvnx64qivnx8qi */
    case 5380:  /* pred_reduc_minuvnx64qivnx8qi */
    case 5379:  /* pred_reduc_maxvnx64qivnx8qi */
    case 5378:  /* pred_reduc_maxuvnx64qivnx8qi */
    case 5377:  /* pred_reduc_sumvnx64qivnx8qi */
    case 5376:  /* pred_reduc_xorvnx32qivnx8qi */
    case 5375:  /* pred_reduc_orvnx32qivnx8qi */
    case 5374:  /* pred_reduc_andvnx32qivnx8qi */
    case 5373:  /* pred_reduc_minvnx32qivnx8qi */
    case 5372:  /* pred_reduc_minuvnx32qivnx8qi */
    case 5371:  /* pred_reduc_maxvnx32qivnx8qi */
    case 5370:  /* pred_reduc_maxuvnx32qivnx8qi */
    case 5369:  /* pred_reduc_sumvnx32qivnx8qi */
    case 5368:  /* pred_reduc_xorvnx16qivnx8qi */
    case 5367:  /* pred_reduc_orvnx16qivnx8qi */
    case 5366:  /* pred_reduc_andvnx16qivnx8qi */
    case 5365:  /* pred_reduc_minvnx16qivnx8qi */
    case 5364:  /* pred_reduc_minuvnx16qivnx8qi */
    case 5363:  /* pred_reduc_maxvnx16qivnx8qi */
    case 5362:  /* pred_reduc_maxuvnx16qivnx8qi */
    case 5361:  /* pred_reduc_sumvnx16qivnx8qi */
    case 5360:  /* pred_reduc_xorvnx8qivnx8qi */
    case 5359:  /* pred_reduc_orvnx8qivnx8qi */
    case 5358:  /* pred_reduc_andvnx8qivnx8qi */
    case 5357:  /* pred_reduc_minvnx8qivnx8qi */
    case 5356:  /* pred_reduc_minuvnx8qivnx8qi */
    case 5355:  /* pred_reduc_maxvnx8qivnx8qi */
    case 5354:  /* pred_reduc_maxuvnx8qivnx8qi */
    case 5353:  /* pred_reduc_sumvnx8qivnx8qi */
    case 5352:  /* pred_reduc_xorvnx4qivnx8qi */
    case 5351:  /* pred_reduc_orvnx4qivnx8qi */
    case 5350:  /* pred_reduc_andvnx4qivnx8qi */
    case 5349:  /* pred_reduc_minvnx4qivnx8qi */
    case 5348:  /* pred_reduc_minuvnx4qivnx8qi */
    case 5347:  /* pred_reduc_maxvnx4qivnx8qi */
    case 5346:  /* pred_reduc_maxuvnx4qivnx8qi */
    case 5345:  /* pred_reduc_sumvnx4qivnx8qi */
    case 5344:  /* pred_reduc_xorvnx2qivnx8qi */
    case 5343:  /* pred_reduc_orvnx2qivnx8qi */
    case 5342:  /* pred_reduc_andvnx2qivnx8qi */
    case 5341:  /* pred_reduc_minvnx2qivnx8qi */
    case 5340:  /* pred_reduc_minuvnx2qivnx8qi */
    case 5339:  /* pred_reduc_maxvnx2qivnx8qi */
    case 5338:  /* pred_reduc_maxuvnx2qivnx8qi */
    case 5337:  /* pred_reduc_sumvnx2qivnx8qi */
    case 5336:  /* pred_reduc_xorvnx1qivnx8qi */
    case 5335:  /* pred_reduc_orvnx1qivnx8qi */
    case 5334:  /* pred_reduc_andvnx1qivnx8qi */
    case 5333:  /* pred_reduc_minvnx1qivnx8qi */
    case 5332:  /* pred_reduc_minuvnx1qivnx8qi */
    case 5331:  /* pred_reduc_maxvnx1qivnx8qi */
    case 5330:  /* pred_reduc_maxuvnx1qivnx8qi */
    case 5329:  /* pred_reduc_sumvnx1qivnx8qi */
    case 5328:  /* pred_rod_truncvnx8df */
    case 5327:  /* pred_rod_truncvnx4df */
    case 5326:  /* pred_rod_truncvnx2df */
    case 5325:  /* pred_rod_truncvnx1df */
    case 5324:  /* pred_truncvnx8df */
    case 5323:  /* pred_truncvnx4df */
    case 5322:  /* pred_truncvnx2df */
    case 5321:  /* pred_truncvnx1df */
    case 5320:  /* pred_narrow_floatunsvnx8di */
    case 5319:  /* pred_narrow_floatvnx8di */
    case 5318:  /* pred_narrow_floatunsvnx4di */
    case 5317:  /* pred_narrow_floatvnx4di */
    case 5316:  /* pred_narrow_floatunsvnx2di */
    case 5315:  /* pred_narrow_floatvnx2di */
    case 5314:  /* pred_narrow_floatunsvnx1di */
    case 5313:  /* pred_narrow_floatvnx1di */
    case 5312:  /* pred_narrow_fixuns_truncvnx8df */
    case 5311:  /* pred_narrow_fix_truncvnx8df */
    case 5310:  /* pred_narrow_fixuns_truncvnx4df */
    case 5309:  /* pred_narrow_fix_truncvnx4df */
    case 5308:  /* pred_narrow_fixuns_truncvnx2df */
    case 5307:  /* pred_narrow_fix_truncvnx2df */
    case 5306:  /* pred_narrow_fixuns_truncvnx1df */
    case 5305:  /* pred_narrow_fix_truncvnx1df */
    case 5304:  /* pred_narrow_fixuns_truncvnx16sf */
    case 5303:  /* pred_narrow_fix_truncvnx16sf */
    case 5302:  /* pred_narrow_fixuns_truncvnx8sf */
    case 5301:  /* pred_narrow_fix_truncvnx8sf */
    case 5300:  /* pred_narrow_fixuns_truncvnx4sf */
    case 5299:  /* pred_narrow_fix_truncvnx4sf */
    case 5298:  /* pred_narrow_fixuns_truncvnx2sf */
    case 5297:  /* pred_narrow_fix_truncvnx2sf */
    case 5296:  /* pred_narrow_fixuns_truncvnx1sf */
    case 5295:  /* pred_narrow_fix_truncvnx1sf */
    case 5294:  /* pred_narrow_fcvt_xu_fvnx8df */
    case 5293:  /* pred_narrow_fcvt_x_fvnx8df */
    case 5292:  /* pred_narrow_fcvt_xu_fvnx4df */
    case 5291:  /* pred_narrow_fcvt_x_fvnx4df */
    case 5290:  /* pred_narrow_fcvt_xu_fvnx2df */
    case 5289:  /* pred_narrow_fcvt_x_fvnx2df */
    case 5288:  /* pred_narrow_fcvt_xu_fvnx1df */
    case 5287:  /* pred_narrow_fcvt_x_fvnx1df */
    case 5286:  /* pred_narrow_fcvt_xu_fvnx16sf */
    case 5285:  /* pred_narrow_fcvt_x_fvnx16sf */
    case 5284:  /* pred_narrow_fcvt_xu_fvnx8sf */
    case 5283:  /* pred_narrow_fcvt_x_fvnx8sf */
    case 5282:  /* pred_narrow_fcvt_xu_fvnx4sf */
    case 5281:  /* pred_narrow_fcvt_x_fvnx4sf */
    case 5280:  /* pred_narrow_fcvt_xu_fvnx2sf */
    case 5279:  /* pred_narrow_fcvt_x_fvnx2sf */
    case 5278:  /* pred_narrow_fcvt_xu_fvnx1sf */
    case 5277:  /* pred_narrow_fcvt_x_fvnx1sf */
    case 5276:  /* pred_extendvnx8df */
    case 5275:  /* pred_extendvnx4df */
    case 5274:  /* pred_extendvnx2df */
    case 5273:  /* pred_extendvnx1df */
    case 5272:  /* pred_widen_floatunsvnx8df */
    case 5271:  /* pred_widen_floatvnx8df */
    case 5270:  /* pred_widen_floatunsvnx4df */
    case 5269:  /* pred_widen_floatvnx4df */
    case 5268:  /* pred_widen_floatunsvnx2df */
    case 5267:  /* pred_widen_floatvnx2df */
    case 5266:  /* pred_widen_floatunsvnx1df */
    case 5265:  /* pred_widen_floatvnx1df */
    case 5264:  /* pred_widen_floatunsvnx16sf */
    case 5263:  /* pred_widen_floatvnx16sf */
    case 5262:  /* pred_widen_floatunsvnx8sf */
    case 5261:  /* pred_widen_floatvnx8sf */
    case 5260:  /* pred_widen_floatunsvnx4sf */
    case 5259:  /* pred_widen_floatvnx4sf */
    case 5258:  /* pred_widen_floatunsvnx2sf */
    case 5257:  /* pred_widen_floatvnx2sf */
    case 5256:  /* pred_widen_floatunsvnx1sf */
    case 5255:  /* pred_widen_floatvnx1sf */
    case 5254:  /* pred_widen_fixuns_truncvnx8di */
    case 5253:  /* pred_widen_fix_truncvnx8di */
    case 5252:  /* pred_widen_fixuns_truncvnx4di */
    case 5251:  /* pred_widen_fix_truncvnx4di */
    case 5250:  /* pred_widen_fixuns_truncvnx2di */
    case 5249:  /* pred_widen_fix_truncvnx2di */
    case 5248:  /* pred_widen_fixuns_truncvnx1di */
    case 5247:  /* pred_widen_fix_truncvnx1di */
    case 5246:  /* pred_widen_fcvt_xu_fvnx8di */
    case 5245:  /* pred_widen_fcvt_x_fvnx8di */
    case 5244:  /* pred_widen_fcvt_xu_fvnx4di */
    case 5243:  /* pred_widen_fcvt_x_fvnx4di */
    case 5242:  /* pred_widen_fcvt_xu_fvnx2di */
    case 5241:  /* pred_widen_fcvt_x_fvnx2di */
    case 5240:  /* pred_widen_fcvt_xu_fvnx1di */
    case 5239:  /* pred_widen_fcvt_x_fvnx1di */
    case 5238:  /* pred_floatunsvnx8df */
    case 5237:  /* pred_floatvnx8df */
    case 5236:  /* pred_floatunsvnx4df */
    case 5235:  /* pred_floatvnx4df */
    case 5234:  /* pred_floatunsvnx2df */
    case 5233:  /* pred_floatvnx2df */
    case 5232:  /* pred_floatunsvnx1df */
    case 5231:  /* pred_floatvnx1df */
    case 5230:  /* pred_floatunsvnx16sf */
    case 5229:  /* pred_floatvnx16sf */
    case 5228:  /* pred_floatunsvnx8sf */
    case 5227:  /* pred_floatvnx8sf */
    case 5226:  /* pred_floatunsvnx4sf */
    case 5225:  /* pred_floatvnx4sf */
    case 5224:  /* pred_floatunsvnx2sf */
    case 5223:  /* pred_floatvnx2sf */
    case 5222:  /* pred_floatunsvnx1sf */
    case 5221:  /* pred_floatvnx1sf */
    case 5220:  /* pred_fixuns_truncvnx8df */
    case 5219:  /* pred_fix_truncvnx8df */
    case 5218:  /* pred_fixuns_truncvnx4df */
    case 5217:  /* pred_fix_truncvnx4df */
    case 5216:  /* pred_fixuns_truncvnx2df */
    case 5215:  /* pred_fix_truncvnx2df */
    case 5214:  /* pred_fixuns_truncvnx1df */
    case 5213:  /* pred_fix_truncvnx1df */
    case 5212:  /* pred_fixuns_truncvnx16sf */
    case 5211:  /* pred_fix_truncvnx16sf */
    case 5210:  /* pred_fixuns_truncvnx8sf */
    case 5209:  /* pred_fix_truncvnx8sf */
    case 5208:  /* pred_fixuns_truncvnx4sf */
    case 5207:  /* pred_fix_truncvnx4sf */
    case 5206:  /* pred_fixuns_truncvnx2sf */
    case 5205:  /* pred_fix_truncvnx2sf */
    case 5204:  /* pred_fixuns_truncvnx1sf */
    case 5203:  /* pred_fix_truncvnx1sf */
    case 5202:  /* pred_fcvt_xu_fvnx8df */
    case 5201:  /* pred_fcvt_x_fvnx8df */
    case 5200:  /* pred_fcvt_xu_fvnx4df */
    case 5199:  /* pred_fcvt_x_fvnx4df */
    case 5198:  /* pred_fcvt_xu_fvnx2df */
    case 5197:  /* pred_fcvt_x_fvnx2df */
    case 5196:  /* pred_fcvt_xu_fvnx1df */
    case 5195:  /* pred_fcvt_x_fvnx1df */
    case 5194:  /* pred_fcvt_xu_fvnx16sf */
    case 5193:  /* pred_fcvt_x_fvnx16sf */
    case 5192:  /* pred_fcvt_xu_fvnx8sf */
    case 5191:  /* pred_fcvt_x_fvnx8sf */
    case 5190:  /* pred_fcvt_xu_fvnx4sf */
    case 5189:  /* pred_fcvt_x_fvnx4sf */
    case 5188:  /* pred_fcvt_xu_fvnx2sf */
    case 5187:  /* pred_fcvt_x_fvnx2sf */
    case 5186:  /* pred_fcvt_xu_fvnx1sf */
    case 5185:  /* pred_fcvt_x_fvnx1sf */
    case 5184:  /* pred_mergevnx8df_scalar */
    case 5183:  /* pred_mergevnx4df_scalar */
    case 5182:  /* pred_mergevnx2df_scalar */
    case 5181:  /* pred_mergevnx1df_scalar */
    case 5180:  /* pred_mergevnx16sf_scalar */
    case 5179:  /* pred_mergevnx8sf_scalar */
    case 5178:  /* pred_mergevnx4sf_scalar */
    case 5177:  /* pred_mergevnx2sf_scalar */
    case 5176:  /* pred_mergevnx1sf_scalar */
    case 5049:  /* pred_classvnx8df */
    case 5048:  /* pred_classvnx4df */
    case 5047:  /* pred_classvnx2df */
    case 5046:  /* pred_classvnx1df */
    case 5045:  /* pred_classvnx16sf */
    case 5044:  /* pred_classvnx8sf */
    case 5043:  /* pred_classvnx4sf */
    case 5042:  /* pred_classvnx2sf */
    case 5041:  /* pred_classvnx1sf */
    case 5040:  /* pred_rec7vnx8df */
    case 5039:  /* pred_rsqrt7vnx8df */
    case 5038:  /* pred_rec7vnx4df */
    case 5037:  /* pred_rsqrt7vnx4df */
    case 5036:  /* pred_rec7vnx2df */
    case 5035:  /* pred_rsqrt7vnx2df */
    case 5034:  /* pred_rec7vnx1df */
    case 5033:  /* pred_rsqrt7vnx1df */
    case 5032:  /* pred_rec7vnx16sf */
    case 5031:  /* pred_rsqrt7vnx16sf */
    case 5030:  /* pred_rec7vnx8sf */
    case 5029:  /* pred_rsqrt7vnx8sf */
    case 5028:  /* pred_rec7vnx4sf */
    case 5027:  /* pred_rsqrt7vnx4sf */
    case 5026:  /* pred_rec7vnx2sf */
    case 5025:  /* pred_rsqrt7vnx2sf */
    case 5024:  /* pred_rec7vnx1sf */
    case 5023:  /* pred_rsqrt7vnx1sf */
    case 2843:  /* pred_zero_extendvnx8di_vf8 */
    case 2842:  /* pred_extendvnx8di_vf8 */
    case 2841:  /* pred_zero_extendvnx4di_vf8 */
    case 2840:  /* pred_extendvnx4di_vf8 */
    case 2839:  /* pred_zero_extendvnx2di_vf8 */
    case 2838:  /* pred_extendvnx2di_vf8 */
    case 2837:  /* pred_zero_extendvnx1di_vf8 */
    case 2836:  /* pred_extendvnx1di_vf8 */
    case 2835:  /* pred_zero_extendvnx8di_vf4 */
    case 2834:  /* pred_extendvnx8di_vf4 */
    case 2833:  /* pred_zero_extendvnx4di_vf4 */
    case 2832:  /* pred_extendvnx4di_vf4 */
    case 2831:  /* pred_zero_extendvnx2di_vf4 */
    case 2830:  /* pred_extendvnx2di_vf4 */
    case 2829:  /* pred_zero_extendvnx1di_vf4 */
    case 2828:  /* pred_extendvnx1di_vf4 */
    case 2827:  /* pred_zero_extendvnx16si_vf4 */
    case 2826:  /* pred_extendvnx16si_vf4 */
    case 2825:  /* pred_zero_extendvnx8si_vf4 */
    case 2824:  /* pred_extendvnx8si_vf4 */
    case 2823:  /* pred_zero_extendvnx4si_vf4 */
    case 2822:  /* pred_extendvnx4si_vf4 */
    case 2821:  /* pred_zero_extendvnx2si_vf4 */
    case 2820:  /* pred_extendvnx2si_vf4 */
    case 2819:  /* pred_zero_extendvnx1si_vf4 */
    case 2818:  /* pred_extendvnx1si_vf4 */
    case 2817:  /* pred_zero_extendvnx8di_vf2 */
    case 2816:  /* pred_extendvnx8di_vf2 */
    case 2815:  /* pred_zero_extendvnx4di_vf2 */
    case 2814:  /* pred_extendvnx4di_vf2 */
    case 2813:  /* pred_zero_extendvnx2di_vf2 */
    case 2812:  /* pred_extendvnx2di_vf2 */
    case 2811:  /* pred_zero_extendvnx1di_vf2 */
    case 2810:  /* pred_extendvnx1di_vf2 */
    case 2809:  /* pred_zero_extendvnx16si_vf2 */
    case 2808:  /* pred_extendvnx16si_vf2 */
    case 2807:  /* pred_zero_extendvnx8si_vf2 */
    case 2806:  /* pred_extendvnx8si_vf2 */
    case 2805:  /* pred_zero_extendvnx4si_vf2 */
    case 2804:  /* pred_extendvnx4si_vf2 */
    case 2803:  /* pred_zero_extendvnx2si_vf2 */
    case 2802:  /* pred_extendvnx2si_vf2 */
    case 2801:  /* pred_zero_extendvnx1si_vf2 */
    case 2800:  /* pred_extendvnx1si_vf2 */
    case 2799:  /* pred_zero_extendvnx32hi_vf2 */
    case 2798:  /* pred_extendvnx32hi_vf2 */
    case 2797:  /* pred_zero_extendvnx16hi_vf2 */
    case 2796:  /* pred_extendvnx16hi_vf2 */
    case 2795:  /* pred_zero_extendvnx8hi_vf2 */
    case 2794:  /* pred_extendvnx8hi_vf2 */
    case 2793:  /* pred_zero_extendvnx4hi_vf2 */
    case 2792:  /* pred_extendvnx4hi_vf2 */
    case 2791:  /* pred_zero_extendvnx2hi_vf2 */
    case 2790:  /* pred_extendvnx2hi_vf2 */
    case 2789:  /* pred_zero_extendvnx1hi_vf2 */
    case 2788:  /* pred_extendvnx1hi_vf2 */
    case 967:  /* *pred_broadcastvnx8di_extended_scalar */
    case 966:  /* *pred_broadcastvnx4di_extended_scalar */
    case 965:  /* *pred_broadcastvnx2di_extended_scalar */
    case 964:  /* *pred_broadcastvnx1di_extended_scalar */
    case 932:  /* *pred_mergevnx8di_extended_scalar */
    case 931:  /* *pred_mergevnx4di_extended_scalar */
    case 930:  /* *pred_mergevnx2di_extended_scalar */
    case 929:  /* *pred_mergevnx1di_extended_scalar */
    case 928:  /* *pred_mergevnx8di_scalar */
    case 927:  /* *pred_mergevnx4di_scalar */
    case 926:  /* *pred_mergevnx2di_scalar */
    case 925:  /* *pred_mergevnx1di_scalar */
    case 924:  /* pred_mergevnx16si_scalar */
    case 923:  /* pred_mergevnx8si_scalar */
    case 922:  /* pred_mergevnx4si_scalar */
    case 921:  /* pred_mergevnx2si_scalar */
    case 920:  /* pred_mergevnx1si_scalar */
    case 919:  /* pred_mergevnx32hi_scalar */
    case 918:  /* pred_mergevnx16hi_scalar */
    case 917:  /* pred_mergevnx8hi_scalar */
    case 916:  /* pred_mergevnx4hi_scalar */
    case 915:  /* pred_mergevnx2hi_scalar */
    case 914:  /* pred_mergevnx1hi_scalar */
    case 913:  /* pred_mergevnx64qi_scalar */
    case 912:  /* pred_mergevnx32qi_scalar */
    case 911:  /* pred_mergevnx16qi_scalar */
    case 910:  /* pred_mergevnx8qi_scalar */
    case 909:  /* pred_mergevnx4qi_scalar */
    case 908:  /* pred_mergevnx2qi_scalar */
    case 907:  /* pred_mergevnx1qi_scalar */
    case 906:  /* pred_mergevnx8df */
    case 905:  /* pred_mergevnx4df */
    case 904:  /* pred_mergevnx2df */
    case 903:  /* pred_mergevnx1df */
    case 902:  /* pred_mergevnx16sf */
    case 901:  /* pred_mergevnx8sf */
    case 900:  /* pred_mergevnx4sf */
    case 899:  /* pred_mergevnx2sf */
    case 898:  /* pred_mergevnx1sf */
    case 897:  /* pred_mergevnx8di */
    case 896:  /* pred_mergevnx4di */
    case 895:  /* pred_mergevnx2di */
    case 894:  /* pred_mergevnx1di */
    case 893:  /* pred_mergevnx16si */
    case 892:  /* pred_mergevnx8si */
    case 891:  /* pred_mergevnx4si */
    case 890:  /* pred_mergevnx2si */
    case 889:  /* pred_mergevnx1si */
    case 888:  /* pred_mergevnx32hi */
    case 887:  /* pred_mergevnx16hi */
    case 886:  /* pred_mergevnx8hi */
    case 885:  /* pred_mergevnx4hi */
    case 884:  /* pred_mergevnx2hi */
    case 883:  /* pred_mergevnx1hi */
    case 882:  /* pred_mergevnx64qi */
    case 881:  /* pred_mergevnx32qi */
    case 880:  /* pred_mergevnx16qi */
    case 879:  /* pred_mergevnx8qi */
    case 878:  /* pred_mergevnx4qi */
    case 877:  /* pred_mergevnx2qi */
    case 876:  /* pred_mergevnx1qi */
    case 830:  /* pred_movvnx8df */
    case 829:  /* pred_movvnx4df */
    case 828:  /* pred_movvnx2df */
    case 827:  /* pred_movvnx1df */
    case 826:  /* pred_movvnx16sf */
    case 825:  /* pred_movvnx8sf */
    case 824:  /* pred_movvnx4sf */
    case 823:  /* pred_movvnx2sf */
    case 822:  /* pred_movvnx1sf */
    case 821:  /* pred_movvnx8di */
    case 820:  /* pred_movvnx4di */
    case 819:  /* pred_movvnx2di */
    case 818:  /* pred_movvnx1di */
    case 817:  /* pred_movvnx16si */
    case 816:  /* pred_movvnx8si */
    case 815:  /* pred_movvnx4si */
    case 814:  /* pred_movvnx2si */
    case 813:  /* pred_movvnx1si */
    case 812:  /* pred_movvnx32hi */
    case 811:  /* pred_movvnx16hi */
    case 810:  /* pred_movvnx8hi */
    case 809:  /* pred_movvnx4hi */
    case 808:  /* pred_movvnx2hi */
    case 807:  /* pred_movvnx1hi */
    case 806:  /* pred_movvnx64qi */
    case 805:  /* pred_movvnx32qi */
    case 804:  /* pred_movvnx16qi */
    case 803:  /* pred_movvnx8qi */
    case 802:  /* pred_movvnx4qi */
    case 801:  /* pred_movvnx2qi */
    case 800:  /* pred_movvnx1qi */
    case 2456:  /* pred_adcvnx1qi */
    case 2457:  /* pred_adcvnx2qi */
    case 2458:  /* pred_adcvnx4qi */
    case 2459:  /* pred_adcvnx8qi */
    case 2460:  /* pred_adcvnx16qi */
    case 2461:  /* pred_adcvnx32qi */
    case 2462:  /* pred_adcvnx64qi */
    case 2463:  /* pred_adcvnx1hi */
    case 2464:  /* pred_adcvnx2hi */
    case 2465:  /* pred_adcvnx4hi */
    case 2466:  /* pred_adcvnx8hi */
    case 2467:  /* pred_adcvnx16hi */
    case 2468:  /* pred_adcvnx32hi */
    case 2469:  /* pred_adcvnx1si */
    case 2470:  /* pred_adcvnx2si */
    case 2471:  /* pred_adcvnx4si */
    case 2472:  /* pred_adcvnx8si */
    case 2473:  /* pred_adcvnx16si */
    case 2474:  /* pred_adcvnx1di */
    case 2475:  /* pred_adcvnx2di */
    case 2476:  /* pred_adcvnx4di */
    case 2477:  /* pred_adcvnx8di */
    case 2478:  /* pred_sbcvnx1qi */
    case 2479:  /* pred_sbcvnx2qi */
    case 2480:  /* pred_sbcvnx4qi */
    case 2481:  /* pred_sbcvnx8qi */
    case 2482:  /* pred_sbcvnx16qi */
    case 2483:  /* pred_sbcvnx32qi */
    case 2484:  /* pred_sbcvnx64qi */
    case 2485:  /* pred_sbcvnx1hi */
    case 2486:  /* pred_sbcvnx2hi */
    case 2487:  /* pred_sbcvnx4hi */
    case 2488:  /* pred_sbcvnx8hi */
    case 2489:  /* pred_sbcvnx16hi */
    case 2490:  /* pred_sbcvnx32hi */
    case 2491:  /* pred_sbcvnx1si */
    case 2492:  /* pred_sbcvnx2si */
    case 2493:  /* pred_sbcvnx4si */
    case 2494:  /* pred_sbcvnx8si */
    case 2495:  /* pred_sbcvnx16si */
    case 2496:  /* pred_sbcvnx1di */
    case 2497:  /* pred_sbcvnx2di */
    case 2498:  /* pred_sbcvnx4di */
    case 2499:  /* pred_sbcvnx8di */
    case 2500:  /* pred_adcvnx1qi_scalar */
    case 2501:  /* pred_adcvnx2qi_scalar */
    case 2502:  /* pred_adcvnx4qi_scalar */
    case 2503:  /* pred_adcvnx8qi_scalar */
    case 2504:  /* pred_adcvnx16qi_scalar */
    case 2505:  /* pred_adcvnx32qi_scalar */
    case 2506:  /* pred_adcvnx64qi_scalar */
    case 2507:  /* pred_adcvnx1hi_scalar */
    case 2508:  /* pred_adcvnx2hi_scalar */
    case 2509:  /* pred_adcvnx4hi_scalar */
    case 2510:  /* pred_adcvnx8hi_scalar */
    case 2511:  /* pred_adcvnx16hi_scalar */
    case 2512:  /* pred_adcvnx32hi_scalar */
    case 2513:  /* pred_adcvnx1si_scalar */
    case 2514:  /* pred_adcvnx2si_scalar */
    case 2515:  /* pred_adcvnx4si_scalar */
    case 2516:  /* pred_adcvnx8si_scalar */
    case 2517:  /* pred_adcvnx16si_scalar */
    case 2518:  /* pred_sbcvnx1qi_scalar */
    case 2519:  /* pred_sbcvnx2qi_scalar */
    case 2520:  /* pred_sbcvnx4qi_scalar */
    case 2521:  /* pred_sbcvnx8qi_scalar */
    case 2522:  /* pred_sbcvnx16qi_scalar */
    case 2523:  /* pred_sbcvnx32qi_scalar */
    case 2524:  /* pred_sbcvnx64qi_scalar */
    case 2525:  /* pred_sbcvnx1hi_scalar */
    case 2526:  /* pred_sbcvnx2hi_scalar */
    case 2527:  /* pred_sbcvnx4hi_scalar */
    case 2528:  /* pred_sbcvnx8hi_scalar */
    case 2529:  /* pred_sbcvnx16hi_scalar */
    case 2530:  /* pred_sbcvnx32hi_scalar */
    case 2531:  /* pred_sbcvnx1si_scalar */
    case 2532:  /* pred_sbcvnx2si_scalar */
    case 2533:  /* pred_sbcvnx4si_scalar */
    case 2534:  /* pred_sbcvnx8si_scalar */
    case 2535:  /* pred_sbcvnx16si_scalar */
    case 2536:  /* *pred_adcvnx1di_scalar */
    case 2537:  /* *pred_adcvnx2di_scalar */
    case 2538:  /* *pred_adcvnx4di_scalar */
    case 2539:  /* *pred_adcvnx8di_scalar */
    case 2540:  /* *pred_adcvnx1di_extended_scalar */
    case 2541:  /* *pred_adcvnx2di_extended_scalar */
    case 2542:  /* *pred_adcvnx4di_extended_scalar */
    case 2543:  /* *pred_adcvnx8di_extended_scalar */
    case 2544:  /* *pred_sbcvnx1di_scalar */
    case 2545:  /* *pred_sbcvnx2di_scalar */
    case 2546:  /* *pred_sbcvnx4di_scalar */
    case 2547:  /* *pred_sbcvnx8di_scalar */
    case 2548:  /* *pred_sbcvnx1di_extended_scalar */
    case 2549:  /* *pred_sbcvnx2di_extended_scalar */
    case 2550:  /* *pred_sbcvnx4di_extended_scalar */
    case 2551:  /* *pred_sbcvnx8di_extended_scalar */
    case 2744:  /* pred_negvnx1qi */
    case 2745:  /* pred_one_cmplvnx1qi */
    case 2746:  /* pred_negvnx2qi */
    case 2747:  /* pred_one_cmplvnx2qi */
    case 2748:  /* pred_negvnx4qi */
    case 2749:  /* pred_one_cmplvnx4qi */
    case 2750:  /* pred_negvnx8qi */
    case 2751:  /* pred_one_cmplvnx8qi */
    case 2752:  /* pred_negvnx16qi */
    case 2753:  /* pred_one_cmplvnx16qi */
    case 2754:  /* pred_negvnx32qi */
    case 2755:  /* pred_one_cmplvnx32qi */
    case 2756:  /* pred_negvnx64qi */
    case 2757:  /* pred_one_cmplvnx64qi */
    case 2758:  /* pred_negvnx1hi */
    case 2759:  /* pred_one_cmplvnx1hi */
    case 2760:  /* pred_negvnx2hi */
    case 2761:  /* pred_one_cmplvnx2hi */
    case 2762:  /* pred_negvnx4hi */
    case 2763:  /* pred_one_cmplvnx4hi */
    case 2764:  /* pred_negvnx8hi */
    case 2765:  /* pred_one_cmplvnx8hi */
    case 2766:  /* pred_negvnx16hi */
    case 2767:  /* pred_one_cmplvnx16hi */
    case 2768:  /* pred_negvnx32hi */
    case 2769:  /* pred_one_cmplvnx32hi */
    case 2770:  /* pred_negvnx1si */
    case 2771:  /* pred_one_cmplvnx1si */
    case 2772:  /* pred_negvnx2si */
    case 2773:  /* pred_one_cmplvnx2si */
    case 2774:  /* pred_negvnx4si */
    case 2775:  /* pred_one_cmplvnx4si */
    case 2776:  /* pred_negvnx8si */
    case 2777:  /* pred_one_cmplvnx8si */
    case 2778:  /* pred_negvnx16si */
    case 2779:  /* pred_one_cmplvnx16si */
    case 2780:  /* pred_negvnx1di */
    case 2781:  /* pred_one_cmplvnx1di */
    case 2782:  /* pred_negvnx2di */
    case 2783:  /* pred_one_cmplvnx2di */
    case 2784:  /* pred_negvnx4di */
    case 2785:  /* pred_one_cmplvnx4di */
    case 2786:  /* pred_negvnx8di */
    case 2787:  /* pred_one_cmplvnx8di */
    case 3174:  /* pred_extendvnx1hi */
    case 3175:  /* pred_zero_extendvnx1hi */
    case 3176:  /* pred_extendvnx2hi */
    case 3177:  /* pred_zero_extendvnx2hi */
    case 3178:  /* pred_extendvnx4hi */
    case 3179:  /* pred_zero_extendvnx4hi */
    case 3180:  /* pred_extendvnx8hi */
    case 3181:  /* pred_zero_extendvnx8hi */
    case 3182:  /* pred_extendvnx16hi */
    case 3183:  /* pred_zero_extendvnx16hi */
    case 3184:  /* pred_extendvnx32hi */
    case 3185:  /* pred_zero_extendvnx32hi */
    case 3186:  /* pred_extendvnx1si */
    case 3187:  /* pred_zero_extendvnx1si */
    case 3188:  /* pred_extendvnx2si */
    case 3189:  /* pred_zero_extendvnx2si */
    case 3190:  /* pred_extendvnx4si */
    case 3191:  /* pred_zero_extendvnx4si */
    case 3192:  /* pred_extendvnx8si */
    case 3193:  /* pred_zero_extendvnx8si */
    case 3194:  /* pred_extendvnx16si */
    case 3195:  /* pred_zero_extendvnx16si */
    case 3196:  /* pred_extendvnx1di */
    case 3197:  /* pred_zero_extendvnx1di */
    case 3198:  /* pred_extendvnx2di */
    case 3199:  /* pred_zero_extendvnx2di */
    case 3200:  /* pred_extendvnx4di */
    case 3201:  /* pred_zero_extendvnx4di */
    case 3202:  /* pred_extendvnx8di */
    case 3203:  /* pred_zero_extendvnx8di */
    case 3264:  /* pred_truncvnx1hi */
    case 3265:  /* pred_truncvnx2hi */
    case 3266:  /* pred_truncvnx4hi */
    case 3267:  /* pred_truncvnx8hi */
    case 3268:  /* pred_truncvnx16hi */
    case 3269:  /* pred_truncvnx32hi */
    case 3270:  /* pred_truncvnx1si */
    case 3271:  /* pred_truncvnx2si */
    case 3272:  /* pred_truncvnx4si */
    case 3273:  /* pred_truncvnx8si */
    case 3274:  /* pred_truncvnx16si */
    case 3275:  /* pred_truncvnx1di */
    case 3276:  /* pred_truncvnx2di */
    case 3277:  /* pred_truncvnx4di */
    case 3278:  /* pred_truncvnx8di */
    case 4996:  /* pred_negvnx1sf */
    case 4997:  /* pred_absvnx1sf */
    case 4998:  /* pred_sqrtvnx1sf */
    case 4999:  /* pred_negvnx2sf */
    case 5000:  /* pred_absvnx2sf */
    case 5001:  /* pred_sqrtvnx2sf */
    case 5002:  /* pred_negvnx4sf */
    case 5003:  /* pred_absvnx4sf */
    case 5004:  /* pred_sqrtvnx4sf */
    case 5005:  /* pred_negvnx8sf */
    case 5006:  /* pred_absvnx8sf */
    case 5007:  /* pred_sqrtvnx8sf */
    case 5008:  /* pred_negvnx16sf */
    case 5009:  /* pred_absvnx16sf */
    case 5010:  /* pred_sqrtvnx16sf */
    case 5011:  /* pred_negvnx1df */
    case 5012:  /* pred_absvnx1df */
    case 5013:  /* pred_sqrtvnx1df */
    case 5014:  /* pred_negvnx2df */
    case 5015:  /* pred_absvnx2df */
    case 5016:  /* pred_sqrtvnx2df */
    case 5017:  /* pred_negvnx4df */
    case 5018:  /* pred_absvnx4df */
    case 5019:  /* pred_sqrtvnx4df */
    case 5020:  /* pred_negvnx8df */
    case 5021:  /* pred_absvnx8df */
    case 5022:  /* pred_sqrtvnx8df */
      extract_constrain_insn_cached (insn);
      return 
#line 324 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[7]));

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      extract_constrain_insn_cached (insn);
      if (((cached_type = get_attr_type (insn)) == TYPE_VLDE) || (cached_type == TYPE_VLDFF) || (cached_type == TYPE_VSTE) || (cached_type == TYPE_VIMOV) || (cached_type == TYPE_VFMOV) || (cached_type == TYPE_VEXT) || (cached_type == TYPE_VIMERGE) || (cached_type == TYPE_VFSQRT) || (cached_type == TYPE_VFRECP) || (cached_type == TYPE_VFMERGE) || (cached_type == TYPE_VFCVTITOF) || (cached_type == TYPE_VFCVTFTOI) || (cached_type == TYPE_VFWCVTITOF) || (cached_type == TYPE_VFWCVTFTOI) || (cached_type == TYPE_VFWCVTFTOF) || (cached_type == TYPE_VFNCVTITOF) || (cached_type == TYPE_VFNCVTFTOI) || (cached_type == TYPE_VFNCVTFTOF) || (cached_type == TYPE_VFCLASS) || (cached_type == TYPE_VIRED) || (cached_type == TYPE_VIWRED) || (cached_type == TYPE_VFREDU) || (cached_type == TYPE_VFREDO) || (cached_type == TYPE_VFWREDU) || (cached_type == TYPE_VFWREDO) || (cached_type == TYPE_VIMOVXV) || (cached_type == TYPE_VFMOVFV))
        {
	  return 
#line 324 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[7]));
        }
      else if ((cached_type == TYPE_VLDM) || (cached_type == TYPE_VSTM) || (cached_type == TYPE_VMALU))
        {
	  return 
#line 326 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[5]));
        }
      else if (cached_type == TYPE_VLDS)
        {
	  if (
#line 239 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(VECTOR_MODE_P (GET_MODE (operands[3]))))
	    {
	      return 255 /* 0xff */;
	    }
	  else
	    {
	      return 
#line 324 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[7]));
	    }
        }
      else if ((cached_type == TYPE_VLDUX) || (cached_type == TYPE_VLDOX) || (cached_type == TYPE_VIALU) || (cached_type == TYPE_VSHIFT) || (cached_type == TYPE_VIMINMAX) || (cached_type == TYPE_VIMUL) || (cached_type == TYPE_VIDIV) || (cached_type == TYPE_VSALU) || (cached_type == TYPE_VIWALU) || (cached_type == TYPE_VIWMUL) || (cached_type == TYPE_VNSHIFT) || (cached_type == TYPE_VAALU) || (cached_type == TYPE_VSMUL) || (cached_type == TYPE_VSSHIFT) || (cached_type == TYPE_VNCLIP) || (cached_type == TYPE_VICMP) || (cached_type == TYPE_VFALU) || (cached_type == TYPE_VFMUL) || (cached_type == TYPE_VFMINMAX) || (cached_type == TYPE_VFDIV) || (cached_type == TYPE_VFWALU) || (cached_type == TYPE_VFWMUL) || (cached_type == TYPE_VFSGNJ) || (cached_type == TYPE_VFCMP) || (cached_type == TYPE_VFMULADD) || (cached_type == TYPE_VSLIDEUP) || (cached_type == TYPE_VSLIDEDOWN) || (cached_type == TYPE_VISLIDE1UP) || (cached_type == TYPE_VISLIDE1DOWN) || (cached_type == TYPE_VFSLIDE1UP) || (cached_type == TYPE_VFSLIDE1DOWN) || (cached_type == TYPE_VGATHER) || (cached_type == TYPE_VIWMULADD) || (cached_type == TYPE_VFWMULADD))
        {
	  return 
#line 340 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[8]));
        }
      else if ((cached_type == TYPE_VSTUX) || (cached_type == TYPE_VSTOX))
        {
	  return 
#line 326 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[5]));
        }
      else if (cached_type == TYPE_VIMULADD)
        {
	  return 
#line 345 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[9]));
        }
      else if ((cached_type == TYPE_VMSFS) || (cached_type == TYPE_VMIDX) || (cached_type == TYPE_VCOMPRESS))
        {
	  return 
#line 348 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[6]));
        }
      else if ((cached_type == TYPE_VMPOP) || (cached_type == TYPE_VMFFS))
        {
	  return 
#line 351 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[4]));
        }
      else
        {
	  return 255 /* 0xff */;
        }

    default:
      extract_constrain_insn_cached (insn);
      return 
#line 340 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[8]));

    }
}

enum attr_cannot_copy
get_attr_cannot_copy (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 172:  /* auipcsi */
    case 173:  /* auipcdi */
      return CANNOT_COPY_YES;

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return CANNOT_COPY_NO;

    }
}

enum attr_dword_mode
get_attr_dword_mode (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_mode cached_mode ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 6036:  /* read_vldi_zero_extend */
    case 797:  /* vsetvl_discard_resultdi */
    case 794:  /* vsetvldi */
    case 614:  /* *th_mempair_load_zero_extendsidi2 */
    case 613:  /* *th_mempair_load_extendsidi2 */
    case 612:  /* *th_mempair_store_di2 */
    case 610:  /* *th_mempair_load_di2 */
    case 604:  /* *th_mulsdi */
    case 598:  /* *th_muladi */
    case 596:  /* th_fmv_x_hw */
    case 595:  /* th_fmv_x_w */
    case 594:  /* th_fmv_hw_w_x */
    case 593:  /* *th_cond_gpr_movdidi */
    case 591:  /* *th_cond_gpr_movdisi */
    case 589:  /* *th_cond_movdidi */
    case 587:  /* *th_cond_movdisi */
    case 583:  /* *th_revdi2 */
    case 581:  /* *th_clzdi2 */
    case 579:  /* *th_extudi4 */
    case 577:  /* *th_extdi4 */
    case 575:  /* *th_srridi3 */
    case 573:  /* *th_addsldi4 */
    case 360:  /* *extendhidi2_zbb */
    case 357:  /* *extendqidi2_zbb */
    case 354:  /* *zero_extendhidi2_bitmanip */
    case 352:  /* *popcountdi2 */
    case 351:  /* *ctzdi2 */
    case 350:  /* *clzdi2 */
    case 343:  /* *xor_notdi */
    case 341:  /* *ior_notdi */
    case 340:  /* *and_notdi */
    case 337:  /* *slliuw */
    case 336:  /* *add.uw */
    case 335:  /* *shNadduw */
    case 333:  /* *shNadd */
    case 331:  /* *zero_extendsidi2_bitmanip */
    case 309:  /* *riscv_fsnvsnandf2 */
    case 285:  /* *sleu_didi */
    case 284:  /* *sle_didi */
    case 283:  /* *sleu_disi */
    case 282:  /* *sle_disi */
    case 279:  /* *sltu_didi */
    case 278:  /* *slt_didi */
    case 277:  /* *sltu_disi */
    case 276:  /* *slt_disi */
    case 273:  /* *sgeu_didi */
    case 272:  /* *sge_didi */
    case 271:  /* *sgeu_disi */
    case 270:  /* *sge_disi */
    case 267:  /* *sgtu_didi */
    case 266:  /* *sgt_didi */
    case 265:  /* *sgtu_disi */
    case 264:  /* *sgt_disi */
    case 261:  /* *sne_zero_didi */
    case 260:  /* *sne_zero_disi */
    case 258:  /* *seq_zero_didi */
    case 257:  /* *seq_zero_disi */
    case 253:  /* *cstoredfdi4 */
    case 252:  /* *cstoredfsi4 */
    case 245:  /* *movdidicc */
    case 225:  /* zero_extendsidi2_shifted */
    case 212:  /* *lshrdi3_mask_1 */
    case 211:  /* *ashrdi3_mask_1 */
    case 210:  /* *ashldi3_mask_1 */
    case 209:  /* *lshrdi3_mask */
    case 208:  /* *ashrdi3_mask */
    case 207:  /* *ashldi3_mask */
    case 206:  /* lshrdi3 */
    case 205:  /* ashrdi3 */
    case 204:  /* ashldi3 */
    case 191:  /* *movdf_softfloat */
    case 190:  /* *movdf_hardfloat_rv64 */
    case 189:  /* *movdf_hardfloat_rv32 */
    case 179:  /* *movdi_64bit */
    case 178:  /* *movdi_32bit */
    case 175:  /* *lowdi */
    case 171:  /* got_load_tls_iedi */
    case 169:  /* got_load_tls_gddi */
    case 167:  /* tls_add_tp_ledi */
    case 165:  /* got_loaddi */
    case 159:  /* lrounddfdi2 */
    case 158:  /* lrintdfdi2 */
    case 157:  /* lrounddfsi2 */
    case 156:  /* lrintdfsi2 */
    case 149:  /* floatunsdidf2 */
    case 148:  /* floatunssidf2 */
    case 143:  /* floatdidf2 */
    case 142:  /* floatsidf2 */
    case 137:  /* fixuns_truncdfdi2 */
    case 136:  /* fixuns_truncdfsi2 */
    case 131:  /* fix_truncdfdi2 */
    case 130:  /* fix_truncdfsi2 */
    case 125:  /* extendhfdf2 */
    case 124:  /* extendsfdf2 */
    case 116:  /* extendsidi2 */
    case 115:  /* zero_extendqidi2 */
    case 112:  /* *zero_extendhidi2 */
    case 110:  /* *zero_extendsidi2_internal */
    case 105:  /* one_cmpldi2 */
    case 100:  /* xordi3 */
    case 99:  /* iordi3 */
    case 98:  /* anddi3 */
    case 93:  /* smaxdf3 */
    case 90:  /* smindf3 */
    case 87:  /* fmaxdf3 */
    case 84:  /* fmindf3 */
    case 81:  /* negdf2 */
    case 78:  /* copysigndf3 */
    case 75:  /* absdf2 */
    case 72:  /* *fnmadf4 */
    case 69:  /* *fnmsdf4 */
    case 66:  /* *fmsdf4 */
    case 63:  /* *fmadf4 */
    case 60:  /* fnmadf4 */
    case 57:  /* fnmsdf4 */
    case 54:  /* fmsdf4 */
    case 51:  /* fmadf4 */
    case 48:  /* sqrtdf2 */
    case 45:  /* divdf3 */
    case 43:  /* *umodsi3_extended */
    case 42:  /* *modsi3_extended */
    case 41:  /* *udivsi3_extended */
    case 40:  /* *divsi3_extended */
    case 39:  /* umoddi3 */
    case 38:  /* moddi3 */
    case 37:  /* udivdi3 */
    case 36:  /* divdi3 */
    case 28:  /* usmuldi3_highpart */
    case 27:  /* umuldi3_highpart */
    case 26:  /* smuldi3_highpart */
    case 23:  /* muldi3 */
    case 20:  /* muldf3 */
    case 15:  /* negdi2 */
    case 11:  /* subdi3 */
    case 9:  /* subdf3 */
    case 5:  /* adddi3 */
    case 2:  /* adddf3 */
      extract_constrain_insn_cached (insn);
      if ((
#line 178 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_64BIT)) == (0))
        {
	  return DWORD_MODE_YES;
        }
      else
        {
	  return DWORD_MODE_NO;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      extract_constrain_insn_cached (insn);
      if ((((cached_mode = get_attr_mode (insn)) == MODE_DI) || (cached_mode == MODE_DF)) && ((
#line 178 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_64BIT)) == (0)))
        {
	  return DWORD_MODE_YES;
        }
      else if (((cached_mode == MODE_TI) || (cached_mode == MODE_TF)) && ((
#line 182 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_64BIT)) != (0)))
        {
	  return DWORD_MODE_YES;
        }
      else
        {
	  return DWORD_MODE_NO;
        }

    default:
      return DWORD_MODE_NO;

    }
}

enum attr_enabled
get_attr_enabled (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    case 178:  /* *movdi_32bit */
    case 179:  /* *movdi_64bit */
    case 180:  /* *movsi_internal */
    case 181:  /* *movhi_internal */
    case 186:  /* *movqi_internal */
      if (get_attr_ext_enabled (insn) == EXT_ENABLED_NO)
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    default:
      return ENABLED_YES;

    }
}

enum attr_ext_enabled
get_attr_ext_enabled (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_ext cached_ext ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 186:  /* *movqi_internal */
    case 181:  /* *movhi_internal */
      extract_constrain_insn_cached (insn);
      if ((((1ULL << which_alternative) & 0xfULL)) || ((((1ULL << which_alternative) & 0x30ULL)) && (
#line 196 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_HARD_FLOAT))) || ((which_alternative == 6) && (
#line 204 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_VECTOR))))
        {
	  return EXT_ENABLED_YES;
        }
      else
        {
	  return EXT_ENABLED_NO;
        }

    case 180:  /* *movsi_internal */
      extract_constrain_insn_cached (insn);
      if ((((1ULL << which_alternative) & 0xfULL)) || ((((1ULL << which_alternative) & 0xf0ULL)) && (
#line 196 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_HARD_FLOAT))) || ((which_alternative == 8) && (
#line 204 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_VECTOR))))
        {
	  return EXT_ENABLED_YES;
        }
      else
        {
	  return EXT_ENABLED_NO;
        }

    case 179:  /* *movdi_64bit */
    case 178:  /* *movdi_32bit */
      extract_constrain_insn_cached (insn);
      if ((((1ULL << which_alternative) & 0xfULL)) || ((((1ULL << which_alternative) & 0x1f0ULL)) && (
#line 200 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_DOUBLE_FLOAT))) || ((which_alternative == 9) && (
#line 204 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_VECTOR))))
        {
	  return EXT_ENABLED_YES;
        }
      else
        {
	  return EXT_ENABLED_NO;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      extract_constrain_insn_cached (insn);
      if ((cached_ext = get_attr_ext (insn)) == EXT_BASE)
        {
	  return EXT_ENABLED_YES;
        }
      else if ((cached_ext == EXT_F) && (
#line 196 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_HARD_FLOAT)))
        {
	  return EXT_ENABLED_YES;
        }
      else if ((cached_ext == EXT_D) && (
#line 200 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_DOUBLE_FLOAT)))
        {
	  return EXT_ENABLED_YES;
        }
      else if ((cached_ext == EXT_VECTOR) && (
#line 204 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_VECTOR)))
        {
	  return EXT_ENABLED_YES;
        }
      else
        {
	  return EXT_ENABLED_NO;
        }

    default:
      return EXT_ENABLED_YES;

    }
}

enum attr_ext
get_attr_ext (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 186:  /* *movqi_internal */
    case 181:  /* *movhi_internal */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return EXT_BASE;
        }
      else if (((1ULL << which_alternative) & 0x30ULL))
        {
	  return EXT_F;
        }
      else
        {
	  return EXT_VECTOR;
        }

    case 180:  /* *movsi_internal */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return EXT_BASE;
        }
      else if (((1ULL << which_alternative) & 0xf0ULL))
        {
	  return EXT_F;
        }
      else
        {
	  return EXT_VECTOR;
        }

    case 179:  /* *movdi_64bit */
    case 178:  /* *movdi_32bit */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return EXT_BASE;
        }
      else if (((1ULL << which_alternative) & 0x1f0ULL))
        {
	  return EXT_D;
        }
      else
        {
	  return EXT_VECTOR;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return EXT_BASE;

    }
}

enum attr_got
get_attr_got (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 164:  /* got_loadsi */
    case 165:  /* got_loaddi */
    case 168:  /* got_load_tls_gdsi */
    case 169:  /* got_load_tls_gddi */
    case 170:  /* got_load_tls_iesi */
    case 171:  /* got_load_tls_iedi */
      return GOT_LOAD;

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return GOT_UNSET;

    }
}

enum attr_has_vl_op
get_attr_has_vl_op (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_VLDE) || (cached_type == TYPE_VSTE) || (cached_type == TYPE_VLDM) || (cached_type == TYPE_VSTM) || (cached_type == TYPE_VLDS) || (cached_type == TYPE_VSTS) || (cached_type == TYPE_VLDUX) || (cached_type == TYPE_VLDOX) || (cached_type == TYPE_VSTUX) || (cached_type == TYPE_VSTOX) || (cached_type == TYPE_VLDFF) || (cached_type == TYPE_VIALU) || (cached_type == TYPE_VIWALU) || (cached_type == TYPE_VEXT) || (cached_type == TYPE_VICALU) || (cached_type == TYPE_VSHIFT) || (cached_type == TYPE_VNSHIFT) || (cached_type == TYPE_VICMP) || (cached_type == TYPE_VIMINMAX) || (cached_type == TYPE_VIMUL) || (cached_type == TYPE_VIDIV) || (cached_type == TYPE_VIWMUL) || (cached_type == TYPE_VIMULADD) || (cached_type == TYPE_VIWMULADD) || (cached_type == TYPE_VIMERGE) || (cached_type == TYPE_VIMOV) || (cached_type == TYPE_VSALU) || (cached_type == TYPE_VAALU) || (cached_type == TYPE_VSMUL) || (cached_type == TYPE_VSSHIFT) || (cached_type == TYPE_VNCLIP) || (cached_type == TYPE_VFALU) || (cached_type == TYPE_VFWALU) || (cached_type == TYPE_VFMUL) || (cached_type == TYPE_VFDIV) || (cached_type == TYPE_VFWMUL) || (cached_type == TYPE_VFMULADD) || (cached_type == TYPE_VFWMULADD) || (cached_type == TYPE_VFSQRT) || (cached_type == TYPE_VFRECP) || (cached_type == TYPE_VFCMP) || (cached_type == TYPE_VFMINMAX) || (cached_type == TYPE_VFSGNJ) || (cached_type == TYPE_VFCLASS) || (cached_type == TYPE_VFMERGE) || (cached_type == TYPE_VFMOV) || (cached_type == TYPE_VFCVTITOF) || (cached_type == TYPE_VFCVTFTOI) || (cached_type == TYPE_VFWCVTITOF) || (cached_type == TYPE_VFWCVTFTOI) || (cached_type == TYPE_VFWCVTFTOF) || (cached_type == TYPE_VFNCVTITOF) || (cached_type == TYPE_VFNCVTFTOI) || (cached_type == TYPE_VFNCVTFTOF) || (cached_type == TYPE_VIRED) || (cached_type == TYPE_VIWRED) || (cached_type == TYPE_VFREDU) || (cached_type == TYPE_VFREDO) || (cached_type == TYPE_VFWREDU) || (cached_type == TYPE_VFWREDO) || (cached_type == TYPE_VMALU) || (cached_type == TYPE_VMPOP) || (cached_type == TYPE_VMFFS) || (cached_type == TYPE_VMSFS) || (cached_type == TYPE_VMIOTA) || (cached_type == TYPE_VMIDX) || (cached_type == TYPE_VIMOVXV) || (cached_type == TYPE_VFMOVFV) || (cached_type == TYPE_VSLIDEUP) || (cached_type == TYPE_VSLIDEDOWN) || (cached_type == TYPE_VISLIDE1UP) || (cached_type == TYPE_VISLIDE1DOWN) || (cached_type == TYPE_VFSLIDE1UP) || (cached_type == TYPE_VFSLIDE1DOWN) || (cached_type == TYPE_VGATHER) || (cached_type == TYPE_VCOMPRESS))
        {
	  return HAS_VL_OP_TRUE;
        }
      else
        {
	  return HAS_VL_OP_FALSE;
        }

    case 6036:  /* read_vldi_zero_extend */
    case 6035:  /* read_vlsi */
    case 5779:  /* *pred_extract_firstvnx8df */
    case 5778:  /* *pred_extract_firstvnx4df */
    case 5777:  /* *pred_extract_firstvnx2df */
    case 5776:  /* *pred_extract_firstvnx1df */
    case 5775:  /* *pred_extract_firstvnx16sf */
    case 5774:  /* *pred_extract_firstvnx8sf */
    case 5773:  /* *pred_extract_firstvnx4sf */
    case 5772:  /* *pred_extract_firstvnx2sf */
    case 5771:  /* *pred_extract_firstvnx1sf */
    case 5770:  /* pred_extract_first_truncvnx8di */
    case 5769:  /* pred_extract_first_truncvnx4di */
    case 5768:  /* pred_extract_first_truncvnx2di */
    case 5767:  /* pred_extract_first_truncvnx1di */
    case 5766:  /* *pred_extract_firstvnx8di */
    case 5765:  /* *pred_extract_firstvnx4di */
    case 5764:  /* *pred_extract_firstvnx2di */
    case 5763:  /* *pred_extract_firstvnx1di */
    case 5762:  /* *pred_extract_firstvnx16si */
    case 5761:  /* *pred_extract_firstvnx8si */
    case 5760:  /* *pred_extract_firstvnx4si */
    case 5759:  /* *pred_extract_firstvnx2si */
    case 5758:  /* *pred_extract_firstvnx1si */
    case 5757:  /* *pred_extract_firstvnx32hi */
    case 5756:  /* *pred_extract_firstvnx16hi */
    case 5755:  /* *pred_extract_firstvnx8hi */
    case 5754:  /* *pred_extract_firstvnx4hi */
    case 5753:  /* *pred_extract_firstvnx2hi */
    case 5752:  /* *pred_extract_firstvnx1hi */
    case 5751:  /* *pred_extract_firstvnx64qi */
    case 5750:  /* *pred_extract_firstvnx32qi */
    case 5749:  /* *pred_extract_firstvnx16qi */
    case 5748:  /* *pred_extract_firstvnx8qi */
    case 5747:  /* *pred_extract_firstvnx4qi */
    case 5746:  /* *pred_extract_firstvnx2qi */
    case 5745:  /* *pred_extract_firstvnx1qi */
    case 799:  /* vsetvldi_no_side_effects */
    case 798:  /* vsetvlsi_no_side_effects */
    case 797:  /* vsetvl_discard_resultdi */
    case 796:  /* vsetvl_discard_resultsi */
    case 795:  /* vsetvl_vtype_change_only */
    case 794:  /* vsetvldi */
    case 793:  /* vsetvlsi */
    case 792:  /* *movvnx64bidi_lra */
    case 791:  /* *movvnx32bidi_lra */
    case 790:  /* *movvnx16bidi_lra */
    case 789:  /* *movvnx8bidi_lra */
    case 788:  /* *movvnx4bidi_lra */
    case 787:  /* *movvnx2bidi_lra */
    case 786:  /* *movvnx1bidi_lra */
    case 785:  /* *movvnx64bisi_lra */
    case 784:  /* *movvnx32bisi_lra */
    case 783:  /* *movvnx16bisi_lra */
    case 782:  /* *movvnx8bisi_lra */
    case 781:  /* *movvnx4bisi_lra */
    case 780:  /* *movvnx2bisi_lra */
    case 779:  /* *movvnx1bisi_lra */
    case 778:  /* *movvnx1sfdi_lra */
    case 777:  /* *movvnx1sfsi_lra */
    case 776:  /* *movvnx1sidi_lra */
    case 775:  /* *movvnx1sisi_lra */
    case 774:  /* *movvnx2hidi_lra */
    case 773:  /* *movvnx2hisi_lra */
    case 772:  /* *movvnx1hidi_lra */
    case 771:  /* *movvnx1hisi_lra */
    case 770:  /* *movvnx4qidi_lra */
    case 769:  /* *movvnx4qisi_lra */
    case 768:  /* *movvnx2qidi_lra */
    case 767:  /* *movvnx2qisi_lra */
    case 766:  /* *movvnx1qidi_lra */
    case 765:  /* *movvnx1qisi_lra */
    case 764:  /* *movvnx64bi */
    case 763:  /* *movvnx32bi */
    case 762:  /* *movvnx16bi */
    case 761:  /* *movvnx8bi */
    case 760:  /* *movvnx4bi */
    case 759:  /* *movvnx2bi */
    case 758:  /* *movvnx1bi */
    case 757:  /* *movvnx1sf_fract */
    case 756:  /* *movvnx1si_fract */
    case 755:  /* *movvnx2hi_fract */
    case 754:  /* *movvnx1hi_fract */
    case 753:  /* *movvnx4qi_fract */
    case 752:  /* *movvnx2qi_fract */
    case 751:  /* *movvnx1qi_fract */
    case 750:  /* *movvnx8df_whole */
    case 749:  /* *movvnx4df_whole */
    case 748:  /* *movvnx2df_whole */
    case 747:  /* *movvnx1df_whole */
    case 746:  /* *movvnx16sf_whole */
    case 745:  /* *movvnx8sf_whole */
    case 744:  /* *movvnx4sf_whole */
    case 743:  /* *movvnx2sf_whole */
    case 742:  /* *movvnx1sf_whole */
    case 741:  /* *movvnx8di_whole */
    case 740:  /* *movvnx4di_whole */
    case 739:  /* *movvnx2di_whole */
    case 738:  /* *movvnx1di_whole */
    case 737:  /* *movvnx16si_whole */
    case 736:  /* *movvnx8si_whole */
    case 735:  /* *movvnx4si_whole */
    case 734:  /* *movvnx2si_whole */
    case 733:  /* *movvnx1si_whole */
    case 732:  /* *movvnx32hi_whole */
    case 731:  /* *movvnx16hi_whole */
    case 730:  /* *movvnx8hi_whole */
    case 729:  /* *movvnx4hi_whole */
    case 728:  /* *movvnx2hi_whole */
    case 727:  /* *movvnx64qi_whole */
    case 726:  /* *movvnx32qi_whole */
    case 725:  /* *movvnx16qi_whole */
    case 724:  /* *movvnx8qi_whole */
    case 723:  /* *movvnx4qi_whole */
    case 722:  /* vlmax_avldi */
    case 721:  /* vlmax_avlsi */
    case 720:  /* *vlmul_extx64vnx1qi */
    case 719:  /* *vlmul_extx32vnx1hi */
    case 718:  /* *vlmul_extx32vnx2qi */
    case 717:  /* *vlmul_extx32vnx1qi */
    case 716:  /* *vlmul_extx16vnx1sf */
    case 715:  /* *vlmul_extx16vnx1si */
    case 714:  /* *vlmul_extx16vnx2hi */
    case 713:  /* *vlmul_extx16vnx1hi */
    case 712:  /* *vlmul_extx16vnx4qi */
    case 711:  /* *vlmul_extx16vnx2qi */
    case 710:  /* *vlmul_extx16vnx1qi */
    case 709:  /* *vlmul_extx8vnx1df */
    case 708:  /* *vlmul_extx8vnx2sf */
    case 707:  /* *vlmul_extx8vnx1sf */
    case 706:  /* *vlmul_extx8vnx1di */
    case 705:  /* *vlmul_extx8vnx2si */
    case 704:  /* *vlmul_extx8vnx1si */
    case 703:  /* *vlmul_extx8vnx4hi */
    case 702:  /* *vlmul_extx8vnx2hi */
    case 701:  /* *vlmul_extx8vnx1hi */
    case 700:  /* *vlmul_extx8vnx8qi */
    case 699:  /* *vlmul_extx8vnx4qi */
    case 698:  /* *vlmul_extx8vnx2qi */
    case 697:  /* *vlmul_extx8vnx1qi */
    case 696:  /* *vlmul_extx4vnx2df */
    case 695:  /* *vlmul_extx4vnx1df */
    case 694:  /* *vlmul_extx4vnx4sf */
    case 693:  /* *vlmul_extx4vnx2sf */
    case 692:  /* *vlmul_extx4vnx1sf */
    case 691:  /* *vlmul_extx4vnx2di */
    case 690:  /* *vlmul_extx4vnx1di */
    case 689:  /* *vlmul_extx4vnx4si */
    case 688:  /* *vlmul_extx4vnx2si */
    case 687:  /* *vlmul_extx4vnx1si */
    case 686:  /* *vlmul_extx4vnx8hi */
    case 685:  /* *vlmul_extx4vnx4hi */
    case 684:  /* *vlmul_extx4vnx2hi */
    case 683:  /* *vlmul_extx4vnx1hi */
    case 682:  /* *vlmul_extx4vnx16qi */
    case 681:  /* *vlmul_extx4vnx8qi */
    case 680:  /* *vlmul_extx4vnx4qi */
    case 679:  /* *vlmul_extx4vnx2qi */
    case 678:  /* *vlmul_extx4vnx1qi */
    case 677:  /* *vlmul_extx2vnx4df */
    case 676:  /* *vlmul_extx2vnx2df */
    case 675:  /* *vlmul_extx2vnx1df */
    case 674:  /* *vlmul_extx2vnx8sf */
    case 673:  /* *vlmul_extx2vnx4sf */
    case 672:  /* *vlmul_extx2vnx2sf */
    case 671:  /* *vlmul_extx2vnx1sf */
    case 670:  /* *vlmul_extx2vnx4di */
    case 669:  /* *vlmul_extx2vnx2di */
    case 668:  /* *vlmul_extx2vnx1di */
    case 667:  /* *vlmul_extx2vnx8si */
    case 666:  /* *vlmul_extx2vnx4si */
    case 665:  /* *vlmul_extx2vnx2si */
    case 664:  /* *vlmul_extx2vnx1si */
    case 663:  /* *vlmul_extx2vnx16hi */
    case 662:  /* *vlmul_extx2vnx8hi */
    case 661:  /* *vlmul_extx2vnx4hi */
    case 660:  /* *vlmul_extx2vnx2hi */
    case 659:  /* *vlmul_extx2vnx1hi */
    case 658:  /* *vlmul_extx2vnx32qi */
    case 657:  /* *vlmul_extx2vnx16qi */
    case 656:  /* *vlmul_extx2vnx8qi */
    case 655:  /* *vlmul_extx2vnx4qi */
    case 654:  /* *vlmul_extx2vnx2qi */
    case 653:  /* *vlmul_extx2vnx1qi */
    case 652:  /* vundefinedvnx64bi */
    case 651:  /* vundefinedvnx32bi */
    case 650:  /* vundefinedvnx16bi */
    case 649:  /* vundefinedvnx8bi */
    case 648:  /* vundefinedvnx4bi */
    case 647:  /* vundefinedvnx2bi */
    case 646:  /* vundefinedvnx1bi */
    case 645:  /* vundefinedvnx8df */
    case 644:  /* vundefinedvnx4df */
    case 643:  /* vundefinedvnx2df */
    case 642:  /* vundefinedvnx1df */
    case 641:  /* vundefinedvnx16sf */
    case 640:  /* vundefinedvnx8sf */
    case 639:  /* vundefinedvnx4sf */
    case 638:  /* vundefinedvnx2sf */
    case 637:  /* vundefinedvnx1sf */
    case 636:  /* vundefinedvnx8di */
    case 635:  /* vundefinedvnx4di */
    case 634:  /* vundefinedvnx2di */
    case 633:  /* vundefinedvnx1di */
    case 632:  /* vundefinedvnx16si */
    case 631:  /* vundefinedvnx8si */
    case 630:  /* vundefinedvnx4si */
    case 629:  /* vundefinedvnx2si */
    case 628:  /* vundefinedvnx1si */
    case 627:  /* vundefinedvnx32hi */
    case 626:  /* vundefinedvnx16hi */
    case 625:  /* vundefinedvnx8hi */
    case 624:  /* vundefinedvnx4hi */
    case 623:  /* vundefinedvnx2hi */
    case 622:  /* vundefinedvnx1hi */
    case 621:  /* vundefinedvnx64qi */
    case 620:  /* vundefinedvnx32qi */
    case 619:  /* vundefinedvnx16qi */
    case 618:  /* vundefinedvnx8qi */
    case 617:  /* vundefinedvnx4qi */
    case 616:  /* vundefinedvnx2qi */
    case 615:  /* vundefinedvnx1qi */
    case 614:  /* *th_mempair_load_zero_extendsidi2 */
    case 613:  /* *th_mempair_load_extendsidi2 */
    case 612:  /* *th_mempair_store_di2 */
    case 611:  /* *th_mempair_store_si2 */
    case 610:  /* *th_mempair_load_di2 */
    case 609:  /* *th_mempair_load_si2 */
    case 608:  /* *th_sextw_msubhisi4 */
    case 607:  /* *th_msubhisi4 */
    case 606:  /* *th_mulswsi2 */
    case 605:  /* *th_mulswsi */
    case 604:  /* *th_mulsdi */
    case 603:  /* *th_mulssi */
    case 602:  /* *th_sextw_maddhisi4 */
    case 601:  /* *th_maddhisi4 */
    case 600:  /* *th_mulawsi2 */
    case 599:  /* *th_mulawsi */
    case 598:  /* *th_muladi */
    case 597:  /* *th_mulasi */
    case 596:  /* th_fmv_x_hw */
    case 595:  /* th_fmv_x_w */
    case 594:  /* th_fmv_hw_w_x */
    case 593:  /* *th_cond_gpr_movdidi */
    case 592:  /* *th_cond_gpr_movsidi */
    case 591:  /* *th_cond_gpr_movdisi */
    case 590:  /* *th_cond_gpr_movsisi */
    case 589:  /* *th_cond_movdidi */
    case 588:  /* *th_cond_movsidi */
    case 587:  /* *th_cond_movdisi */
    case 586:  /* *th_cond_movsisi */
    case 585:  /* *th_tstdi3 */
    case 584:  /* *th_tstsi3 */
    case 583:  /* *th_revdi2 */
    case 582:  /* *th_revsi2 */
    case 581:  /* *th_clzdi2 */
    case 580:  /* *th_clzsi2 */
    case 579:  /* *th_extudi4 */
    case 578:  /* *th_extusi4 */
    case 577:  /* *th_extdi4 */
    case 576:  /* *th_extsi4 */
    case 575:  /* *th_srridi3 */
    case 574:  /* *th_srrisi3 */
    case 573:  /* *th_addsldi4 */
    case 572:  /* *th_addslsi4 */
    case 571:  /* *local_pic_store_sfhf */
    case 570:  /* *local_pic_store_sfdf */
    case 569:  /* *local_pic_store_sfsf */
    case 568:  /* *local_pic_store_sfhf */
    case 567:  /* *local_pic_store_sfdf */
    case 566:  /* *local_pic_store_sfsf */
    case 565:  /* *local_pic_store_32dhf */
    case 564:  /* *local_pic_store_32ddf */
    case 563:  /* *local_pic_store_32dsf */
    case 562:  /* *local_pic_store_32dhf */
    case 561:  /* *local_pic_store_32ddf */
    case 560:  /* *local_pic_store_32dsf */
    case 559:  /* *local_pic_storehf */
    case 558:  /* *local_pic_storedf */
    case 557:  /* *local_pic_storesf */
    case 556:  /* *local_pic_storehf */
    case 555:  /* *local_pic_storedf */
    case 554:  /* *local_pic_storesf */
    case 553:  /* *local_pic_storedi */
    case 552:  /* *local_pic_storesi */
    case 551:  /* *local_pic_storehi */
    case 550:  /* *local_pic_storeqi */
    case 549:  /* *local_pic_storedi */
    case 548:  /* *local_pic_storesi */
    case 547:  /* *local_pic_storehi */
    case 546:  /* *local_pic_storeqi */
    case 545:  /* *local_pic_load_sfhf */
    case 544:  /* *local_pic_load_sfdf */
    case 543:  /* *local_pic_load_sfsf */
    case 542:  /* *local_pic_load_32dhf */
    case 541:  /* *local_pic_load_32ddf */
    case 540:  /* *local_pic_load_32dsf */
    case 539:  /* *local_pic_load_32dhf */
    case 538:  /* *local_pic_load_32ddf */
    case 537:  /* *local_pic_load_32dsf */
    case 536:  /* *local_pic_loadhf */
    case 535:  /* *local_pic_loaddf */
    case 534:  /* *local_pic_loadsf */
    case 533:  /* *local_pic_loadhf */
    case 532:  /* *local_pic_loaddf */
    case 531:  /* *local_pic_loadsf */
    case 530:  /* *local_pic_load_usi */
    case 529:  /* *local_pic_load_usi */
    case 528:  /* *local_pic_load_usi */
    case 527:  /* *local_pic_load_uhi */
    case 526:  /* *local_pic_load_uhi */
    case 525:  /* *local_pic_load_uhi */
    case 524:  /* *local_pic_load_uqi */
    case 523:  /* *local_pic_load_uqi */
    case 522:  /* *local_pic_load_uqi */
    case 521:  /* *local_pic_load_ssi */
    case 520:  /* *local_pic_load_ssi */
    case 519:  /* *local_pic_load_ssi */
    case 518:  /* *local_pic_load_shi */
    case 517:  /* *local_pic_load_shi */
    case 516:  /* *local_pic_load_shi */
    case 515:  /* *local_pic_load_sqi */
    case 514:  /* *local_pic_load_sqi */
    case 513:  /* *local_pic_load_sqi */
    case 512:  /* *local_pic_loaddi */
    case 511:  /* *local_pic_loadsi */
    case 510:  /* *local_pic_loadhi */
    case 509:  /* *local_pic_loadqi */
    case 508:  /* subword_atomic_cas_strong */
    case 507:  /* atomic_cas_value_strongdi */
    case 506:  /* atomic_cas_value_strongsi */
    case 505:  /* subword_atomic_exchange_strong */
    case 504:  /* atomic_exchangedi */
    case 503:  /* atomic_exchangesi */
    case 502:  /* subword_atomic_fetch_strong_nand */
    case 501:  /* subword_atomic_fetch_strong_and */
    case 500:  /* subword_atomic_fetch_strong_xor */
    case 499:  /* subword_atomic_fetch_strong_or */
    case 498:  /* subword_atomic_fetch_strong_add */
    case 497:  /* atomic_fetch_anddi */
    case 496:  /* atomic_fetch_xordi */
    case 495:  /* atomic_fetch_ordi */
    case 494:  /* atomic_fetch_adddi */
    case 493:  /* atomic_fetch_andsi */
    case 492:  /* atomic_fetch_xorsi */
    case 491:  /* atomic_fetch_orsi */
    case 490:  /* atomic_fetch_addsi */
    case 489:  /* atomic_anddi */
    case 488:  /* atomic_xordi */
    case 487:  /* atomic_ordi */
    case 486:  /* atomic_adddi */
    case 485:  /* atomic_andsi */
    case 484:  /* atomic_xorsi */
    case 483:  /* atomic_orsi */
    case 482:  /* atomic_addsi */
    case 481:  /* atomic_storedi */
    case 480:  /* atomic_storesi */
    case 479:  /* atomic_loaddi */
    case 478:  /* atomic_loadsi */
    case 477:  /* mem_thread_fence_1 */
    case 476:  /* riscv_sm4ks_di */
    case 475:  /* riscv_sm4ks_si */
    case 474:  /* riscv_sm4ed_di */
    case 473:  /* riscv_sm4ed_si */
    case 472:  /* riscv_sm3p1_di */
    case 471:  /* riscv_sm3p1_si */
    case 470:  /* riscv_sm3p0_di */
    case 469:  /* riscv_sm3p0_si */
    case 468:  /* riscv_sha512sum1 */
    case 467:  /* riscv_sha512sum0 */
    case 466:  /* riscv_sha512sig1 */
    case 465:  /* riscv_sha512sig0 */
    case 464:  /* riscv_sha512sum1r */
    case 463:  /* riscv_sha512sum0r */
    case 462:  /* riscv_sha512sig1l */
    case 461:  /* riscv_sha512sig1h */
    case 460:  /* riscv_sha512sig0l */
    case 459:  /* riscv_sha512sig0h */
    case 458:  /* riscv_sha256sum1_di */
    case 457:  /* riscv_sha256sum1_si */
    case 456:  /* riscv_sha256sum0_di */
    case 455:  /* riscv_sha256sum0_si */
    case 454:  /* riscv_sha256sig1_di */
    case 453:  /* riscv_sha256sig1_si */
    case 452:  /* riscv_sha256sig0_di */
    case 451:  /* riscv_sha256sig0_si */
    case 450:  /* riscv_aes64esm */
    case 449:  /* riscv_aes64es */
    case 448:  /* riscv_aes32esmi */
    case 447:  /* riscv_aes32esi */
    case 446:  /* riscv_aes64ks2 */
    case 445:  /* riscv_aes64ks1i */
    case 444:  /* riscv_aes64im */
    case 443:  /* riscv_aes64dsm */
    case 442:  /* riscv_aes64ds */
    case 441:  /* riscv_aes32dsmi */
    case 440:  /* riscv_aes32dsi */
    case 439:  /* riscv_xperm8_di */
    case 438:  /* riscv_xperm8_si */
    case 437:  /* riscv_xperm4_di */
    case 436:  /* riscv_xperm4_si */
    case 435:  /* riscv_clmulh_di */
    case 434:  /* riscv_clmulh_si */
    case 433:  /* riscv_clmul_di */
    case 432:  /* riscv_clmul_si */
    case 431:  /* riscv_packw */
    case 430:  /* riscv_packh_di */
    case 429:  /* riscv_packh_si */
    case 428:  /* riscv_pack_disi */
    case 427:  /* riscv_pack_dihi */
    case 426:  /* riscv_pack_sisi */
    case 425:  /* riscv_pack_sihi */
    case 424:  /* riscv_unzip */
    case 423:  /* riscv_zip */
    case 422:  /* riscv_brev8_di */
    case 421:  /* riscv_brev8_si */
    case 420:  /* *branchdi_mask_twobits_equals_singlebit */
    case 419:  /* *branchsi_mask_twobits_equals_singlebit */
    case 418:  /* *andidi_extrabit */
    case 417:  /* *andisi_extrabit */
    case 416:  /* *xoridi_extrabit */
    case 415:  /* *ioridi_extrabit */
    case 414:  /* *xorisi_extrabit */
    case 413:  /* *iorisi_extrabit */
    case 412:  /* *bexti */
    case 411:  /* *bexti */
    case 410:  /* *bextdi */
    case 409:  /* *bextsi */
    case 408:  /* *bextdi */
    case 407:  /* *bextsi */
    case 406:  /* *binvidi */
    case 405:  /* *binvisi */
    case 404:  /* *binvdi */
    case 403:  /* *binvsi */
    case 402:  /* *bclridisi_nottwobits */
    case 401:  /* *bclridi_nottwobits */
    case 400:  /* *bclrisi_nottwobits */
    case 399:  /* *bclridi */
    case 398:  /* *bclrisi */
    case 397:  /* *bclrdi */
    case 396:  /* *bclrsi */
    case 395:  /* *bsetidisi */
    case 394:  /* *bsetidi */
    case 393:  /* *bsetisi */
    case 392:  /* *bsetdi_1_mask */
    case 391:  /* *bsetsi_1_mask */
    case 390:  /* *bsetdi_1 */
    case 389:  /* *bsetsi_1 */
    case 388:  /* *bsetdi_mask */
    case 387:  /* *bsetsi_mask */
    case 386:  /* *bsetdi */
    case 385:  /* *bsetsi */
    case 384:  /* *minmax */
    case 383:  /* *minmax */
    case 382:  /* *minmax */
    case 381:  /* *minmax */
    case 380:  /* umaxdi3 */
    case 379:  /* smaxdi3 */
    case 378:  /* umindi3 */
    case 377:  /* smindi3 */
    case 376:  /* umaxsi3 */
    case 375:  /* smaxsi3 */
    case 374:  /* uminsi3 */
    case 373:  /* sminsi3 */
    case 372:  /* *bswapdi2 */
    case 371:  /* *bswapsi2 */
    case 370:  /* orcbdi2 */
    case 369:  /* orcbsi2 */
    case 368:  /* rotlsi3_sext */
    case 367:  /* rotldi3 */
    case 366:  /* rotlsi3 */
    case 365:  /* *rotrsi3_sext */
    case 364:  /* *rotrdi3 */
    case 363:  /* *rotrsi3 */
    case 362:  /* *zero_extendhidi2_zbb */
    case 361:  /* *zero_extendhisi2_zbb */
    case 360:  /* *extendhidi2_zbb */
    case 359:  /* *extendhisi2_zbb */
    case 358:  /* *extendhihi2_zbb */
    case 357:  /* *extendqidi2_zbb */
    case 356:  /* *extendqisi2_zbb */
    case 355:  /* *extendqihi2_zbb */
    case 354:  /* *zero_extendhidi2_bitmanip */
    case 353:  /* *zero_extendhisi2_bitmanip */
    case 352:  /* *popcountdi2 */
    case 351:  /* *ctzdi2 */
    case 350:  /* *clzdi2 */
    case 349:  /* *popcountdisi2 */
    case 348:  /* *ctzdisi2 */
    case 347:  /* *clzdisi2 */
    case 346:  /* *popcountsi2 */
    case 345:  /* *ctzsi2 */
    case 344:  /* *clzsi2 */
    case 343:  /* *xor_notdi */
    case 342:  /* *xor_notsi */
    case 341:  /* *ior_notdi */
    case 340:  /* *and_notdi */
    case 339:  /* *ior_notsi */
    case 338:  /* *and_notsi */
    case 337:  /* *slliuw */
    case 336:  /* *add.uw */
    case 335:  /* *shNadduw */
    case 334:  /* *andi_add.uw */
    case 333:  /* *shNadd */
    case 332:  /* *shNadd */
    case 331:  /* *zero_extendsidi2_bitmanip */
    case 330:  /* riscv_prefetchi_di */
    case 329:  /* riscv_prefetchi_si */
    case 328:  /* prefetch */
    case 327:  /* riscv_zero_di */
    case 326:  /* riscv_zero_si */
    case 325:  /* riscv_inval_di */
    case 324:  /* riscv_inval_si */
    case 323:  /* riscv_flush_di */
    case 322:  /* riscv_flush_si */
    case 321:  /* riscv_clean_di */
    case 320:  /* riscv_clean_si */
    case 319:  /* stack_protect_test_di */
    case 318:  /* stack_protect_test_si */
    case 317:  /* stack_protect_set_di */
    case 316:  /* stack_protect_set_si */
    case 315:  /* stack_tiedi */
    case 314:  /* stack_tiesi */
    case 313:  /* riscv_uret */
    case 312:  /* riscv_sret */
    case 311:  /* riscv_mret */
    case 310:  /* *riscv_fsnvsnanhf2 */
    case 309:  /* *riscv_fsnvsnandf2 */
    case 308:  /* *riscv_fsnvsnansf2 */
    case 307:  /* riscv_fsflags */
    case 306:  /* riscv_frflags */
    case 305:  /* gpr_restore_return */
    case 304:  /* gpr_restore */
    case 303:  /* gpr_save */
    case 302:  /* trap */
    case 301:  /* nop */
    case 300:  /* call_value_internal */
    case 299:  /* call_internal */
    case 298:  /* sibcall_value_internal */
    case 297:  /* sibcall_internal */
    case 296:  /* eh_return_internal */
    case 295:  /* eh_set_lr_di */
    case 294:  /* eh_set_lr_si */
    case 293:  /* simple_return_internal */
    case 292:  /* simple_return */
    case 291:  /* blockage */
    case 290:  /* tablejumpdi */
    case 289:  /* tablejumpsi */
    case 288:  /* indirect_jumpdi */
    case 287:  /* indirect_jumpsi */
    case 286:  /* jump */
    case 285:  /* *sleu_didi */
    case 284:  /* *sle_didi */
    case 283:  /* *sleu_disi */
    case 282:  /* *sle_disi */
    case 281:  /* *sleu_sisi */
    case 280:  /* *sle_sisi */
    case 279:  /* *sltu_didi */
    case 278:  /* *slt_didi */
    case 277:  /* *sltu_disi */
    case 276:  /* *slt_disi */
    case 275:  /* *sltu_sisi */
    case 274:  /* *slt_sisi */
    case 273:  /* *sgeu_didi */
    case 272:  /* *sge_didi */
    case 271:  /* *sgeu_disi */
    case 270:  /* *sge_disi */
    case 269:  /* *sgeu_sisi */
    case 268:  /* *sge_sisi */
    case 267:  /* *sgtu_didi */
    case 266:  /* *sgt_didi */
    case 265:  /* *sgtu_disi */
    case 264:  /* *sgt_disi */
    case 263:  /* *sgtu_sisi */
    case 262:  /* *sgt_sisi */
    case 261:  /* *sne_zero_didi */
    case 260:  /* *sne_zero_disi */
    case 259:  /* *sne_zero_sisi */
    case 258:  /* *seq_zero_didi */
    case 257:  /* *seq_zero_disi */
    case 256:  /* *seq_zero_sisi */
    case 255:  /* *cstorehfdi4 */
    case 254:  /* *cstorehfsi4 */
    case 253:  /* *cstoredfdi4 */
    case 252:  /* *cstoredfsi4 */
    case 251:  /* *cstoresfdi4 */
    case 250:  /* *cstoresfsi4 */
    case 249:  /* *branch_on_bit_rangedi */
    case 248:  /* *branch_on_bit_rangesi */
    case 247:  /* *branch_on_bitdi */
    case 246:  /* *branch_on_bitsi */
    case 245:  /* *movdidicc */
    case 244:  /* *movsidicc */
    case 243:  /* *movsisicc */
    case 242:  /* *branchdi */
    case 241:  /* *branchsi */
    case 240:  /* *branchdi_shiftedmask_equals_zero */
    case 239:  /* *branchsi_shiftedmask_equals_zero */
    case 238:  /* *branchhi_shiftedmask_equals_zero */
    case 237:  /* *branchqi_shiftedmask_equals_zero */
    case 236:  /* *branchdi_shiftedmask_equals_zero */
    case 235:  /* *branchsi_shiftedmask_equals_zero */
    case 234:  /* *branchhi_shiftedmask_equals_zero */
    case 233:  /* *branchqi_shiftedmask_equals_zero */
    case 232:  /* *branchdi_shiftedarith_equals_zero */
    case 231:  /* *branchsi_shiftedarith_equals_zero */
    case 230:  /* *branchhi_shiftedarith_equals_zero */
    case 229:  /* *branchqi_shiftedarith_equals_zero */
    case 228:  /* *branchsi_shiftedarith_equals_zero */
    case 227:  /* *branchhi_shiftedarith_equals_zero */
    case 226:  /* *branchqi_shiftedarith_equals_zero */
    case 225:  /* zero_extendsidi2_shifted */
    case 224:  /* *lshrsi3_zero_extend_3 */
    case 223:  /* *lshrsi3_zero_extend_2 */
    case 222:  /* *lshrsi3_zero_extend_1 */
    case 221:  /* *lshrsi3_extend_mask_1 */
    case 220:  /* *ashrsi3_extend_mask_1 */
    case 219:  /* *ashlsi3_extend_mask_1 */
    case 218:  /* *lshrsi3_extend_mask */
    case 217:  /* *ashrsi3_extend_mask */
    case 216:  /* *ashlsi3_extend_mask */
    case 215:  /* *lshrsi3_extend */
    case 214:  /* *ashrsi3_extend */
    case 213:  /* *ashlsi3_extend */
    case 212:  /* *lshrdi3_mask_1 */
    case 211:  /* *ashrdi3_mask_1 */
    case 210:  /* *ashldi3_mask_1 */
    case 209:  /* *lshrdi3_mask */
    case 208:  /* *ashrdi3_mask */
    case 207:  /* *ashldi3_mask */
    case 206:  /* lshrdi3 */
    case 205:  /* ashrdi3 */
    case 204:  /* ashldi3 */
    case 203:  /* *lshrsi3_mask_1 */
    case 202:  /* *ashrsi3_mask_1 */
    case 201:  /* *ashlsi3_mask_1 */
    case 200:  /* *lshrsi3_mask */
    case 199:  /* *ashrsi3_mask */
    case 198:  /* *ashlsi3_mask */
    case 197:  /* lshrsi3 */
    case 196:  /* ashrsi3 */
    case 195:  /* ashlsi3 */
    case 194:  /* riscv_pause */
    case 193:  /* fence_i */
    case 192:  /* fence */
    case 191:  /* *movdf_softfloat */
    case 190:  /* *movdf_hardfloat_rv64 */
    case 189:  /* *movdf_hardfloat_rv32 */
    case 188:  /* *movsf_softfloat */
    case 187:  /* *movsf_hardfloat */
    case 186:  /* *movqi_internal */
    case 185:  /* *xorsihi3 */
    case 184:  /* *xorhihi3 */
    case 183:  /* *addsihi3 */
    case 182:  /* *addhihi3 */
    case 181:  /* *movhi_internal */
    case 180:  /* *movsi_internal */
    case 179:  /* *movdi_64bit */
    case 178:  /* *movdi_32bit */
    case 177:  /* *mvconst_internal */
    case 176:  /* *mvconst_internal */
    case 175:  /* *lowdi */
    case 174:  /* *lowsi */
    case 173:  /* auipcdi */
    case 172:  /* auipcsi */
    case 171:  /* got_load_tls_iedi */
    case 170:  /* got_load_tls_iesi */
    case 169:  /* got_load_tls_gddi */
    case 168:  /* got_load_tls_gdsi */
    case 167:  /* tls_add_tp_ledi */
    case 166:  /* tls_add_tp_lesi */
    case 165:  /* got_loaddi */
    case 164:  /* got_loadsi */
    case 163:  /* lroundhfdi2 */
    case 162:  /* lrinthfdi2 */
    case 161:  /* lroundhfsi2 */
    case 160:  /* lrinthfsi2 */
    case 159:  /* lrounddfdi2 */
    case 158:  /* lrintdfdi2 */
    case 157:  /* lrounddfsi2 */
    case 156:  /* lrintdfsi2 */
    case 155:  /* lroundsfdi2 */
    case 154:  /* lrintsfdi2 */
    case 153:  /* lroundsfsi2 */
    case 152:  /* lrintsfsi2 */
    case 151:  /* floatunsdihf2 */
    case 150:  /* floatunssihf2 */
    case 149:  /* floatunsdidf2 */
    case 148:  /* floatunssidf2 */
    case 147:  /* floatunsdisf2 */
    case 146:  /* floatunssisf2 */
    case 145:  /* floatdihf2 */
    case 144:  /* floatsihf2 */
    case 143:  /* floatdidf2 */
    case 142:  /* floatsidf2 */
    case 141:  /* floatdisf2 */
    case 140:  /* floatsisf2 */
    case 139:  /* fixuns_trunchfdi2 */
    case 138:  /* fixuns_trunchfsi2 */
    case 137:  /* fixuns_truncdfdi2 */
    case 136:  /* fixuns_truncdfsi2 */
    case 135:  /* fixuns_truncsfdi2 */
    case 134:  /* fixuns_truncsfsi2 */
    case 133:  /* fix_trunchfdi2 */
    case 132:  /* fix_trunchfsi2 */
    case 131:  /* fix_truncdfdi2 */
    case 130:  /* fix_truncdfsi2 */
    case 129:  /* fix_truncsfdi2 */
    case 128:  /* fix_truncsfsi2 */
    case 127:  /* *movhf_softfloat */
    case 126:  /* *movhf_hardfloat */
    case 125:  /* extendhfdf2 */
    case 124:  /* extendsfdf2 */
    case 123:  /* extendhfsf2 */
    case 122:  /* *extendhidi2 */
    case 121:  /* *extendhisi2 */
    case 120:  /* *extendhihi2 */
    case 119:  /* *extendqidi2 */
    case 118:  /* *extendqisi2 */
    case 117:  /* *extendqihi2 */
    case 116:  /* extendsidi2 */
    case 115:  /* zero_extendqidi2 */
    case 114:  /* zero_extendqisi2 */
    case 113:  /* zero_extendqihi2 */
    case 112:  /* *zero_extendhidi2 */
    case 111:  /* *zero_extendhisi2 */
    case 110:  /* *zero_extendsidi2_internal */
    case 109:  /* truncdfhf2 */
    case 108:  /* truncsfhf2 */
    case 107:  /* truncdfsf2 */
    case 106:  /* *one_cmplsi2_internal */
    case 105:  /* one_cmpldi2 */
    case 104:  /* one_cmplsi2 */
    case 103:  /* *xorsi3_internal */
    case 102:  /* *iorsi3_internal */
    case 101:  /* *andsi3_internal */
    case 100:  /* xordi3 */
    case 99:  /* iordi3 */
    case 98:  /* anddi3 */
    case 97:  /* xorsi3 */
    case 96:  /* iorsi3 */
    case 95:  /* andsi3 */
    case 94:  /* smaxhf3 */
    case 93:  /* smaxdf3 */
    case 92:  /* smaxsf3 */
    case 91:  /* sminhf3 */
    case 90:  /* smindf3 */
    case 89:  /* sminsf3 */
    case 88:  /* fmaxhf3 */
    case 87:  /* fmaxdf3 */
    case 86:  /* fmaxsf3 */
    case 85:  /* fminhf3 */
    case 84:  /* fmindf3 */
    case 83:  /* fminsf3 */
    case 82:  /* neghf2 */
    case 81:  /* negdf2 */
    case 80:  /* negsf2 */
    case 79:  /* copysignhf3 */
    case 78:  /* copysigndf3 */
    case 77:  /* copysignsf3 */
    case 76:  /* abshf2 */
    case 75:  /* absdf2 */
    case 74:  /* abssf2 */
    case 73:  /* *fnmahf4 */
    case 72:  /* *fnmadf4 */
    case 71:  /* *fnmasf4 */
    case 70:  /* *fnmshf4 */
    case 69:  /* *fnmsdf4 */
    case 68:  /* *fnmssf4 */
    case 67:  /* *fmshf4 */
    case 66:  /* *fmsdf4 */
    case 65:  /* *fmssf4 */
    case 64:  /* *fmahf4 */
    case 63:  /* *fmadf4 */
    case 62:  /* *fmasf4 */
    case 61:  /* fnmahf4 */
    case 60:  /* fnmadf4 */
    case 59:  /* fnmasf4 */
    case 58:  /* fnmshf4 */
    case 57:  /* fnmsdf4 */
    case 56:  /* fnmssf4 */
    case 55:  /* fmshf4 */
    case 54:  /* fmsdf4 */
    case 53:  /* fmssf4 */
    case 52:  /* fmahf4 */
    case 51:  /* fmadf4 */
    case 50:  /* fmasf4 */
    case 49:  /* sqrthf2 */
    case 48:  /* sqrtdf2 */
    case 47:  /* sqrtsf2 */
    case 46:  /* divhf3 */
    case 45:  /* divdf3 */
    case 44:  /* divsf3 */
    case 43:  /* *umodsi3_extended */
    case 42:  /* *modsi3_extended */
    case 41:  /* *udivsi3_extended */
    case 40:  /* *divsi3_extended */
    case 39:  /* umoddi3 */
    case 38:  /* moddi3 */
    case 37:  /* udivdi3 */
    case 36:  /* divdi3 */
    case 35:  /* umodsi3 */
    case 34:  /* modsi3 */
    case 33:  /* udivsi3 */
    case 32:  /* divsi3 */
    case 31:  /* usmulsi3_highpart */
    case 30:  /* umulsi3_highpart */
    case 29:  /* smulsi3_highpart */
    case 28:  /* usmuldi3_highpart */
    case 27:  /* umuldi3_highpart */
    case 26:  /* smuldi3_highpart */
    case 25:  /* *mulsi3_extended2 */
    case 24:  /* *mulsi3_extended */
    case 23:  /* muldi3 */
    case 22:  /* mulsi3 */
    case 21:  /* mulhf3 */
    case 20:  /* muldf3 */
    case 19:  /* mulsf3 */
    case 18:  /* *negsi2_extended2 */
    case 17:  /* *negsi2_extended */
    case 16:  /* negsi2 */
    case 15:  /* negdi2 */
    case 14:  /* *subsi3_extended2 */
    case 13:  /* *subsi3_extended */
    case 12:  /* subsi3 */
    case 11:  /* subdi3 */
    case 10:  /* subhf3 */
    case 9:  /* subdf3 */
    case 8:  /* subsf3 */
    case 7:  /* *addsi3_extended2 */
    case 6:  /* *addsi3_extended */
    case 5:  /* adddi3 */
    case 4:  /* addsi3 */
    case 3:  /* addhf3 */
    case 2:  /* adddf3 */
    case 1:  /* addsf3 */
      return HAS_VL_OP_FALSE;

    default:
      return HAS_VL_OP_TRUE;

    }
}

enum attr_has_vtype_op
get_attr_has_vtype_op (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_VLDE) || (cached_type == TYPE_VSTE) || (cached_type == TYPE_VLDM) || (cached_type == TYPE_VSTM) || (cached_type == TYPE_VLDS) || (cached_type == TYPE_VSTS) || (cached_type == TYPE_VLDUX) || (cached_type == TYPE_VLDOX) || (cached_type == TYPE_VSTUX) || (cached_type == TYPE_VSTOX) || (cached_type == TYPE_VLDFF) || (cached_type == TYPE_VIALU) || (cached_type == TYPE_VIWALU) || (cached_type == TYPE_VEXT) || (cached_type == TYPE_VICALU) || (cached_type == TYPE_VSHIFT) || (cached_type == TYPE_VNSHIFT) || (cached_type == TYPE_VICMP) || (cached_type == TYPE_VIMINMAX) || (cached_type == TYPE_VIMUL) || (cached_type == TYPE_VIDIV) || (cached_type == TYPE_VIWMUL) || (cached_type == TYPE_VIMULADD) || (cached_type == TYPE_VIWMULADD) || (cached_type == TYPE_VIMERGE) || (cached_type == TYPE_VIMOV) || (cached_type == TYPE_VSALU) || (cached_type == TYPE_VAALU) || (cached_type == TYPE_VSMUL) || (cached_type == TYPE_VSSHIFT) || (cached_type == TYPE_VNCLIP) || (cached_type == TYPE_VFALU) || (cached_type == TYPE_VFWALU) || (cached_type == TYPE_VFMUL) || (cached_type == TYPE_VFDIV) || (cached_type == TYPE_VFWMUL) || (cached_type == TYPE_VFMULADD) || (cached_type == TYPE_VFWMULADD) || (cached_type == TYPE_VFSQRT) || (cached_type == TYPE_VFRECP) || (cached_type == TYPE_VFCMP) || (cached_type == TYPE_VFMINMAX) || (cached_type == TYPE_VFSGNJ) || (cached_type == TYPE_VFCLASS) || (cached_type == TYPE_VFMERGE) || (cached_type == TYPE_VFMOV) || (cached_type == TYPE_VFCVTITOF) || (cached_type == TYPE_VFCVTFTOI) || (cached_type == TYPE_VFWCVTITOF) || (cached_type == TYPE_VFWCVTFTOI) || (cached_type == TYPE_VFWCVTFTOF) || (cached_type == TYPE_VFNCVTITOF) || (cached_type == TYPE_VFNCVTFTOI) || (cached_type == TYPE_VFNCVTFTOF) || (cached_type == TYPE_VIRED) || (cached_type == TYPE_VIWRED) || (cached_type == TYPE_VFREDU) || (cached_type == TYPE_VFREDO) || (cached_type == TYPE_VFWREDU) || (cached_type == TYPE_VFWREDO) || (cached_type == TYPE_VMALU) || (cached_type == TYPE_VMPOP) || (cached_type == TYPE_VMFFS) || (cached_type == TYPE_VMSFS) || (cached_type == TYPE_VMIOTA) || (cached_type == TYPE_VMIDX) || (cached_type == TYPE_VIMOVVX) || (cached_type == TYPE_VIMOVXV) || (cached_type == TYPE_VFMOVVF) || (cached_type == TYPE_VFMOVFV) || (cached_type == TYPE_VSLIDEUP) || (cached_type == TYPE_VSLIDEDOWN) || (cached_type == TYPE_VISLIDE1UP) || (cached_type == TYPE_VISLIDE1DOWN) || (cached_type == TYPE_VFSLIDE1UP) || (cached_type == TYPE_VFSLIDE1DOWN) || (cached_type == TYPE_VGATHER) || (cached_type == TYPE_VCOMPRESS))
        {
	  return HAS_VTYPE_OP_TRUE;
        }
      else
        {
	  return HAS_VTYPE_OP_FALSE;
        }

    case 6036:  /* read_vldi_zero_extend */
    case 6035:  /* read_vlsi */
    case 799:  /* vsetvldi_no_side_effects */
    case 798:  /* vsetvlsi_no_side_effects */
    case 797:  /* vsetvl_discard_resultdi */
    case 796:  /* vsetvl_discard_resultsi */
    case 795:  /* vsetvl_vtype_change_only */
    case 794:  /* vsetvldi */
    case 793:  /* vsetvlsi */
    case 792:  /* *movvnx64bidi_lra */
    case 791:  /* *movvnx32bidi_lra */
    case 790:  /* *movvnx16bidi_lra */
    case 789:  /* *movvnx8bidi_lra */
    case 788:  /* *movvnx4bidi_lra */
    case 787:  /* *movvnx2bidi_lra */
    case 786:  /* *movvnx1bidi_lra */
    case 785:  /* *movvnx64bisi_lra */
    case 784:  /* *movvnx32bisi_lra */
    case 783:  /* *movvnx16bisi_lra */
    case 782:  /* *movvnx8bisi_lra */
    case 781:  /* *movvnx4bisi_lra */
    case 780:  /* *movvnx2bisi_lra */
    case 779:  /* *movvnx1bisi_lra */
    case 778:  /* *movvnx1sfdi_lra */
    case 777:  /* *movvnx1sfsi_lra */
    case 776:  /* *movvnx1sidi_lra */
    case 775:  /* *movvnx1sisi_lra */
    case 774:  /* *movvnx2hidi_lra */
    case 773:  /* *movvnx2hisi_lra */
    case 772:  /* *movvnx1hidi_lra */
    case 771:  /* *movvnx1hisi_lra */
    case 770:  /* *movvnx4qidi_lra */
    case 769:  /* *movvnx4qisi_lra */
    case 768:  /* *movvnx2qidi_lra */
    case 767:  /* *movvnx2qisi_lra */
    case 766:  /* *movvnx1qidi_lra */
    case 765:  /* *movvnx1qisi_lra */
    case 764:  /* *movvnx64bi */
    case 763:  /* *movvnx32bi */
    case 762:  /* *movvnx16bi */
    case 761:  /* *movvnx8bi */
    case 760:  /* *movvnx4bi */
    case 759:  /* *movvnx2bi */
    case 758:  /* *movvnx1bi */
    case 757:  /* *movvnx1sf_fract */
    case 756:  /* *movvnx1si_fract */
    case 755:  /* *movvnx2hi_fract */
    case 754:  /* *movvnx1hi_fract */
    case 753:  /* *movvnx4qi_fract */
    case 752:  /* *movvnx2qi_fract */
    case 751:  /* *movvnx1qi_fract */
    case 750:  /* *movvnx8df_whole */
    case 749:  /* *movvnx4df_whole */
    case 748:  /* *movvnx2df_whole */
    case 747:  /* *movvnx1df_whole */
    case 746:  /* *movvnx16sf_whole */
    case 745:  /* *movvnx8sf_whole */
    case 744:  /* *movvnx4sf_whole */
    case 743:  /* *movvnx2sf_whole */
    case 742:  /* *movvnx1sf_whole */
    case 741:  /* *movvnx8di_whole */
    case 740:  /* *movvnx4di_whole */
    case 739:  /* *movvnx2di_whole */
    case 738:  /* *movvnx1di_whole */
    case 737:  /* *movvnx16si_whole */
    case 736:  /* *movvnx8si_whole */
    case 735:  /* *movvnx4si_whole */
    case 734:  /* *movvnx2si_whole */
    case 733:  /* *movvnx1si_whole */
    case 732:  /* *movvnx32hi_whole */
    case 731:  /* *movvnx16hi_whole */
    case 730:  /* *movvnx8hi_whole */
    case 729:  /* *movvnx4hi_whole */
    case 728:  /* *movvnx2hi_whole */
    case 727:  /* *movvnx64qi_whole */
    case 726:  /* *movvnx32qi_whole */
    case 725:  /* *movvnx16qi_whole */
    case 724:  /* *movvnx8qi_whole */
    case 723:  /* *movvnx4qi_whole */
    case 722:  /* vlmax_avldi */
    case 721:  /* vlmax_avlsi */
    case 720:  /* *vlmul_extx64vnx1qi */
    case 719:  /* *vlmul_extx32vnx1hi */
    case 718:  /* *vlmul_extx32vnx2qi */
    case 717:  /* *vlmul_extx32vnx1qi */
    case 716:  /* *vlmul_extx16vnx1sf */
    case 715:  /* *vlmul_extx16vnx1si */
    case 714:  /* *vlmul_extx16vnx2hi */
    case 713:  /* *vlmul_extx16vnx1hi */
    case 712:  /* *vlmul_extx16vnx4qi */
    case 711:  /* *vlmul_extx16vnx2qi */
    case 710:  /* *vlmul_extx16vnx1qi */
    case 709:  /* *vlmul_extx8vnx1df */
    case 708:  /* *vlmul_extx8vnx2sf */
    case 707:  /* *vlmul_extx8vnx1sf */
    case 706:  /* *vlmul_extx8vnx1di */
    case 705:  /* *vlmul_extx8vnx2si */
    case 704:  /* *vlmul_extx8vnx1si */
    case 703:  /* *vlmul_extx8vnx4hi */
    case 702:  /* *vlmul_extx8vnx2hi */
    case 701:  /* *vlmul_extx8vnx1hi */
    case 700:  /* *vlmul_extx8vnx8qi */
    case 699:  /* *vlmul_extx8vnx4qi */
    case 698:  /* *vlmul_extx8vnx2qi */
    case 697:  /* *vlmul_extx8vnx1qi */
    case 696:  /* *vlmul_extx4vnx2df */
    case 695:  /* *vlmul_extx4vnx1df */
    case 694:  /* *vlmul_extx4vnx4sf */
    case 693:  /* *vlmul_extx4vnx2sf */
    case 692:  /* *vlmul_extx4vnx1sf */
    case 691:  /* *vlmul_extx4vnx2di */
    case 690:  /* *vlmul_extx4vnx1di */
    case 689:  /* *vlmul_extx4vnx4si */
    case 688:  /* *vlmul_extx4vnx2si */
    case 687:  /* *vlmul_extx4vnx1si */
    case 686:  /* *vlmul_extx4vnx8hi */
    case 685:  /* *vlmul_extx4vnx4hi */
    case 684:  /* *vlmul_extx4vnx2hi */
    case 683:  /* *vlmul_extx4vnx1hi */
    case 682:  /* *vlmul_extx4vnx16qi */
    case 681:  /* *vlmul_extx4vnx8qi */
    case 680:  /* *vlmul_extx4vnx4qi */
    case 679:  /* *vlmul_extx4vnx2qi */
    case 678:  /* *vlmul_extx4vnx1qi */
    case 677:  /* *vlmul_extx2vnx4df */
    case 676:  /* *vlmul_extx2vnx2df */
    case 675:  /* *vlmul_extx2vnx1df */
    case 674:  /* *vlmul_extx2vnx8sf */
    case 673:  /* *vlmul_extx2vnx4sf */
    case 672:  /* *vlmul_extx2vnx2sf */
    case 671:  /* *vlmul_extx2vnx1sf */
    case 670:  /* *vlmul_extx2vnx4di */
    case 669:  /* *vlmul_extx2vnx2di */
    case 668:  /* *vlmul_extx2vnx1di */
    case 667:  /* *vlmul_extx2vnx8si */
    case 666:  /* *vlmul_extx2vnx4si */
    case 665:  /* *vlmul_extx2vnx2si */
    case 664:  /* *vlmul_extx2vnx1si */
    case 663:  /* *vlmul_extx2vnx16hi */
    case 662:  /* *vlmul_extx2vnx8hi */
    case 661:  /* *vlmul_extx2vnx4hi */
    case 660:  /* *vlmul_extx2vnx2hi */
    case 659:  /* *vlmul_extx2vnx1hi */
    case 658:  /* *vlmul_extx2vnx32qi */
    case 657:  /* *vlmul_extx2vnx16qi */
    case 656:  /* *vlmul_extx2vnx8qi */
    case 655:  /* *vlmul_extx2vnx4qi */
    case 654:  /* *vlmul_extx2vnx2qi */
    case 653:  /* *vlmul_extx2vnx1qi */
    case 652:  /* vundefinedvnx64bi */
    case 651:  /* vundefinedvnx32bi */
    case 650:  /* vundefinedvnx16bi */
    case 649:  /* vundefinedvnx8bi */
    case 648:  /* vundefinedvnx4bi */
    case 647:  /* vundefinedvnx2bi */
    case 646:  /* vundefinedvnx1bi */
    case 645:  /* vundefinedvnx8df */
    case 644:  /* vundefinedvnx4df */
    case 643:  /* vundefinedvnx2df */
    case 642:  /* vundefinedvnx1df */
    case 641:  /* vundefinedvnx16sf */
    case 640:  /* vundefinedvnx8sf */
    case 639:  /* vundefinedvnx4sf */
    case 638:  /* vundefinedvnx2sf */
    case 637:  /* vundefinedvnx1sf */
    case 636:  /* vundefinedvnx8di */
    case 635:  /* vundefinedvnx4di */
    case 634:  /* vundefinedvnx2di */
    case 633:  /* vundefinedvnx1di */
    case 632:  /* vundefinedvnx16si */
    case 631:  /* vundefinedvnx8si */
    case 630:  /* vundefinedvnx4si */
    case 629:  /* vundefinedvnx2si */
    case 628:  /* vundefinedvnx1si */
    case 627:  /* vundefinedvnx32hi */
    case 626:  /* vundefinedvnx16hi */
    case 625:  /* vundefinedvnx8hi */
    case 624:  /* vundefinedvnx4hi */
    case 623:  /* vundefinedvnx2hi */
    case 622:  /* vundefinedvnx1hi */
    case 621:  /* vundefinedvnx64qi */
    case 620:  /* vundefinedvnx32qi */
    case 619:  /* vundefinedvnx16qi */
    case 618:  /* vundefinedvnx8qi */
    case 617:  /* vundefinedvnx4qi */
    case 616:  /* vundefinedvnx2qi */
    case 615:  /* vundefinedvnx1qi */
    case 614:  /* *th_mempair_load_zero_extendsidi2 */
    case 613:  /* *th_mempair_load_extendsidi2 */
    case 612:  /* *th_mempair_store_di2 */
    case 611:  /* *th_mempair_store_si2 */
    case 610:  /* *th_mempair_load_di2 */
    case 609:  /* *th_mempair_load_si2 */
    case 608:  /* *th_sextw_msubhisi4 */
    case 607:  /* *th_msubhisi4 */
    case 606:  /* *th_mulswsi2 */
    case 605:  /* *th_mulswsi */
    case 604:  /* *th_mulsdi */
    case 603:  /* *th_mulssi */
    case 602:  /* *th_sextw_maddhisi4 */
    case 601:  /* *th_maddhisi4 */
    case 600:  /* *th_mulawsi2 */
    case 599:  /* *th_mulawsi */
    case 598:  /* *th_muladi */
    case 597:  /* *th_mulasi */
    case 596:  /* th_fmv_x_hw */
    case 595:  /* th_fmv_x_w */
    case 594:  /* th_fmv_hw_w_x */
    case 593:  /* *th_cond_gpr_movdidi */
    case 592:  /* *th_cond_gpr_movsidi */
    case 591:  /* *th_cond_gpr_movdisi */
    case 590:  /* *th_cond_gpr_movsisi */
    case 589:  /* *th_cond_movdidi */
    case 588:  /* *th_cond_movsidi */
    case 587:  /* *th_cond_movdisi */
    case 586:  /* *th_cond_movsisi */
    case 585:  /* *th_tstdi3 */
    case 584:  /* *th_tstsi3 */
    case 583:  /* *th_revdi2 */
    case 582:  /* *th_revsi2 */
    case 581:  /* *th_clzdi2 */
    case 580:  /* *th_clzsi2 */
    case 579:  /* *th_extudi4 */
    case 578:  /* *th_extusi4 */
    case 577:  /* *th_extdi4 */
    case 576:  /* *th_extsi4 */
    case 575:  /* *th_srridi3 */
    case 574:  /* *th_srrisi3 */
    case 573:  /* *th_addsldi4 */
    case 572:  /* *th_addslsi4 */
    case 571:  /* *local_pic_store_sfhf */
    case 570:  /* *local_pic_store_sfdf */
    case 569:  /* *local_pic_store_sfsf */
    case 568:  /* *local_pic_store_sfhf */
    case 567:  /* *local_pic_store_sfdf */
    case 566:  /* *local_pic_store_sfsf */
    case 565:  /* *local_pic_store_32dhf */
    case 564:  /* *local_pic_store_32ddf */
    case 563:  /* *local_pic_store_32dsf */
    case 562:  /* *local_pic_store_32dhf */
    case 561:  /* *local_pic_store_32ddf */
    case 560:  /* *local_pic_store_32dsf */
    case 559:  /* *local_pic_storehf */
    case 558:  /* *local_pic_storedf */
    case 557:  /* *local_pic_storesf */
    case 556:  /* *local_pic_storehf */
    case 555:  /* *local_pic_storedf */
    case 554:  /* *local_pic_storesf */
    case 553:  /* *local_pic_storedi */
    case 552:  /* *local_pic_storesi */
    case 551:  /* *local_pic_storehi */
    case 550:  /* *local_pic_storeqi */
    case 549:  /* *local_pic_storedi */
    case 548:  /* *local_pic_storesi */
    case 547:  /* *local_pic_storehi */
    case 546:  /* *local_pic_storeqi */
    case 545:  /* *local_pic_load_sfhf */
    case 544:  /* *local_pic_load_sfdf */
    case 543:  /* *local_pic_load_sfsf */
    case 542:  /* *local_pic_load_32dhf */
    case 541:  /* *local_pic_load_32ddf */
    case 540:  /* *local_pic_load_32dsf */
    case 539:  /* *local_pic_load_32dhf */
    case 538:  /* *local_pic_load_32ddf */
    case 537:  /* *local_pic_load_32dsf */
    case 536:  /* *local_pic_loadhf */
    case 535:  /* *local_pic_loaddf */
    case 534:  /* *local_pic_loadsf */
    case 533:  /* *local_pic_loadhf */
    case 532:  /* *local_pic_loaddf */
    case 531:  /* *local_pic_loadsf */
    case 530:  /* *local_pic_load_usi */
    case 529:  /* *local_pic_load_usi */
    case 528:  /* *local_pic_load_usi */
    case 527:  /* *local_pic_load_uhi */
    case 526:  /* *local_pic_load_uhi */
    case 525:  /* *local_pic_load_uhi */
    case 524:  /* *local_pic_load_uqi */
    case 523:  /* *local_pic_load_uqi */
    case 522:  /* *local_pic_load_uqi */
    case 521:  /* *local_pic_load_ssi */
    case 520:  /* *local_pic_load_ssi */
    case 519:  /* *local_pic_load_ssi */
    case 518:  /* *local_pic_load_shi */
    case 517:  /* *local_pic_load_shi */
    case 516:  /* *local_pic_load_shi */
    case 515:  /* *local_pic_load_sqi */
    case 514:  /* *local_pic_load_sqi */
    case 513:  /* *local_pic_load_sqi */
    case 512:  /* *local_pic_loaddi */
    case 511:  /* *local_pic_loadsi */
    case 510:  /* *local_pic_loadhi */
    case 509:  /* *local_pic_loadqi */
    case 508:  /* subword_atomic_cas_strong */
    case 507:  /* atomic_cas_value_strongdi */
    case 506:  /* atomic_cas_value_strongsi */
    case 505:  /* subword_atomic_exchange_strong */
    case 504:  /* atomic_exchangedi */
    case 503:  /* atomic_exchangesi */
    case 502:  /* subword_atomic_fetch_strong_nand */
    case 501:  /* subword_atomic_fetch_strong_and */
    case 500:  /* subword_atomic_fetch_strong_xor */
    case 499:  /* subword_atomic_fetch_strong_or */
    case 498:  /* subword_atomic_fetch_strong_add */
    case 497:  /* atomic_fetch_anddi */
    case 496:  /* atomic_fetch_xordi */
    case 495:  /* atomic_fetch_ordi */
    case 494:  /* atomic_fetch_adddi */
    case 493:  /* atomic_fetch_andsi */
    case 492:  /* atomic_fetch_xorsi */
    case 491:  /* atomic_fetch_orsi */
    case 490:  /* atomic_fetch_addsi */
    case 489:  /* atomic_anddi */
    case 488:  /* atomic_xordi */
    case 487:  /* atomic_ordi */
    case 486:  /* atomic_adddi */
    case 485:  /* atomic_andsi */
    case 484:  /* atomic_xorsi */
    case 483:  /* atomic_orsi */
    case 482:  /* atomic_addsi */
    case 481:  /* atomic_storedi */
    case 480:  /* atomic_storesi */
    case 479:  /* atomic_loaddi */
    case 478:  /* atomic_loadsi */
    case 477:  /* mem_thread_fence_1 */
    case 476:  /* riscv_sm4ks_di */
    case 475:  /* riscv_sm4ks_si */
    case 474:  /* riscv_sm4ed_di */
    case 473:  /* riscv_sm4ed_si */
    case 472:  /* riscv_sm3p1_di */
    case 471:  /* riscv_sm3p1_si */
    case 470:  /* riscv_sm3p0_di */
    case 469:  /* riscv_sm3p0_si */
    case 468:  /* riscv_sha512sum1 */
    case 467:  /* riscv_sha512sum0 */
    case 466:  /* riscv_sha512sig1 */
    case 465:  /* riscv_sha512sig0 */
    case 464:  /* riscv_sha512sum1r */
    case 463:  /* riscv_sha512sum0r */
    case 462:  /* riscv_sha512sig1l */
    case 461:  /* riscv_sha512sig1h */
    case 460:  /* riscv_sha512sig0l */
    case 459:  /* riscv_sha512sig0h */
    case 458:  /* riscv_sha256sum1_di */
    case 457:  /* riscv_sha256sum1_si */
    case 456:  /* riscv_sha256sum0_di */
    case 455:  /* riscv_sha256sum0_si */
    case 454:  /* riscv_sha256sig1_di */
    case 453:  /* riscv_sha256sig1_si */
    case 452:  /* riscv_sha256sig0_di */
    case 451:  /* riscv_sha256sig0_si */
    case 450:  /* riscv_aes64esm */
    case 449:  /* riscv_aes64es */
    case 448:  /* riscv_aes32esmi */
    case 447:  /* riscv_aes32esi */
    case 446:  /* riscv_aes64ks2 */
    case 445:  /* riscv_aes64ks1i */
    case 444:  /* riscv_aes64im */
    case 443:  /* riscv_aes64dsm */
    case 442:  /* riscv_aes64ds */
    case 441:  /* riscv_aes32dsmi */
    case 440:  /* riscv_aes32dsi */
    case 439:  /* riscv_xperm8_di */
    case 438:  /* riscv_xperm8_si */
    case 437:  /* riscv_xperm4_di */
    case 436:  /* riscv_xperm4_si */
    case 435:  /* riscv_clmulh_di */
    case 434:  /* riscv_clmulh_si */
    case 433:  /* riscv_clmul_di */
    case 432:  /* riscv_clmul_si */
    case 431:  /* riscv_packw */
    case 430:  /* riscv_packh_di */
    case 429:  /* riscv_packh_si */
    case 428:  /* riscv_pack_disi */
    case 427:  /* riscv_pack_dihi */
    case 426:  /* riscv_pack_sisi */
    case 425:  /* riscv_pack_sihi */
    case 424:  /* riscv_unzip */
    case 423:  /* riscv_zip */
    case 422:  /* riscv_brev8_di */
    case 421:  /* riscv_brev8_si */
    case 420:  /* *branchdi_mask_twobits_equals_singlebit */
    case 419:  /* *branchsi_mask_twobits_equals_singlebit */
    case 418:  /* *andidi_extrabit */
    case 417:  /* *andisi_extrabit */
    case 416:  /* *xoridi_extrabit */
    case 415:  /* *ioridi_extrabit */
    case 414:  /* *xorisi_extrabit */
    case 413:  /* *iorisi_extrabit */
    case 412:  /* *bexti */
    case 411:  /* *bexti */
    case 410:  /* *bextdi */
    case 409:  /* *bextsi */
    case 408:  /* *bextdi */
    case 407:  /* *bextsi */
    case 406:  /* *binvidi */
    case 405:  /* *binvisi */
    case 404:  /* *binvdi */
    case 403:  /* *binvsi */
    case 402:  /* *bclridisi_nottwobits */
    case 401:  /* *bclridi_nottwobits */
    case 400:  /* *bclrisi_nottwobits */
    case 399:  /* *bclridi */
    case 398:  /* *bclrisi */
    case 397:  /* *bclrdi */
    case 396:  /* *bclrsi */
    case 395:  /* *bsetidisi */
    case 394:  /* *bsetidi */
    case 393:  /* *bsetisi */
    case 392:  /* *bsetdi_1_mask */
    case 391:  /* *bsetsi_1_mask */
    case 390:  /* *bsetdi_1 */
    case 389:  /* *bsetsi_1 */
    case 388:  /* *bsetdi_mask */
    case 387:  /* *bsetsi_mask */
    case 386:  /* *bsetdi */
    case 385:  /* *bsetsi */
    case 384:  /* *minmax */
    case 383:  /* *minmax */
    case 382:  /* *minmax */
    case 381:  /* *minmax */
    case 380:  /* umaxdi3 */
    case 379:  /* smaxdi3 */
    case 378:  /* umindi3 */
    case 377:  /* smindi3 */
    case 376:  /* umaxsi3 */
    case 375:  /* smaxsi3 */
    case 374:  /* uminsi3 */
    case 373:  /* sminsi3 */
    case 372:  /* *bswapdi2 */
    case 371:  /* *bswapsi2 */
    case 370:  /* orcbdi2 */
    case 369:  /* orcbsi2 */
    case 368:  /* rotlsi3_sext */
    case 367:  /* rotldi3 */
    case 366:  /* rotlsi3 */
    case 365:  /* *rotrsi3_sext */
    case 364:  /* *rotrdi3 */
    case 363:  /* *rotrsi3 */
    case 362:  /* *zero_extendhidi2_zbb */
    case 361:  /* *zero_extendhisi2_zbb */
    case 360:  /* *extendhidi2_zbb */
    case 359:  /* *extendhisi2_zbb */
    case 358:  /* *extendhihi2_zbb */
    case 357:  /* *extendqidi2_zbb */
    case 356:  /* *extendqisi2_zbb */
    case 355:  /* *extendqihi2_zbb */
    case 354:  /* *zero_extendhidi2_bitmanip */
    case 353:  /* *zero_extendhisi2_bitmanip */
    case 352:  /* *popcountdi2 */
    case 351:  /* *ctzdi2 */
    case 350:  /* *clzdi2 */
    case 349:  /* *popcountdisi2 */
    case 348:  /* *ctzdisi2 */
    case 347:  /* *clzdisi2 */
    case 346:  /* *popcountsi2 */
    case 345:  /* *ctzsi2 */
    case 344:  /* *clzsi2 */
    case 343:  /* *xor_notdi */
    case 342:  /* *xor_notsi */
    case 341:  /* *ior_notdi */
    case 340:  /* *and_notdi */
    case 339:  /* *ior_notsi */
    case 338:  /* *and_notsi */
    case 337:  /* *slliuw */
    case 336:  /* *add.uw */
    case 335:  /* *shNadduw */
    case 334:  /* *andi_add.uw */
    case 333:  /* *shNadd */
    case 332:  /* *shNadd */
    case 331:  /* *zero_extendsidi2_bitmanip */
    case 330:  /* riscv_prefetchi_di */
    case 329:  /* riscv_prefetchi_si */
    case 328:  /* prefetch */
    case 327:  /* riscv_zero_di */
    case 326:  /* riscv_zero_si */
    case 325:  /* riscv_inval_di */
    case 324:  /* riscv_inval_si */
    case 323:  /* riscv_flush_di */
    case 322:  /* riscv_flush_si */
    case 321:  /* riscv_clean_di */
    case 320:  /* riscv_clean_si */
    case 319:  /* stack_protect_test_di */
    case 318:  /* stack_protect_test_si */
    case 317:  /* stack_protect_set_di */
    case 316:  /* stack_protect_set_si */
    case 315:  /* stack_tiedi */
    case 314:  /* stack_tiesi */
    case 313:  /* riscv_uret */
    case 312:  /* riscv_sret */
    case 311:  /* riscv_mret */
    case 310:  /* *riscv_fsnvsnanhf2 */
    case 309:  /* *riscv_fsnvsnandf2 */
    case 308:  /* *riscv_fsnvsnansf2 */
    case 307:  /* riscv_fsflags */
    case 306:  /* riscv_frflags */
    case 305:  /* gpr_restore_return */
    case 304:  /* gpr_restore */
    case 303:  /* gpr_save */
    case 302:  /* trap */
    case 301:  /* nop */
    case 300:  /* call_value_internal */
    case 299:  /* call_internal */
    case 298:  /* sibcall_value_internal */
    case 297:  /* sibcall_internal */
    case 296:  /* eh_return_internal */
    case 295:  /* eh_set_lr_di */
    case 294:  /* eh_set_lr_si */
    case 293:  /* simple_return_internal */
    case 292:  /* simple_return */
    case 291:  /* blockage */
    case 290:  /* tablejumpdi */
    case 289:  /* tablejumpsi */
    case 288:  /* indirect_jumpdi */
    case 287:  /* indirect_jumpsi */
    case 286:  /* jump */
    case 285:  /* *sleu_didi */
    case 284:  /* *sle_didi */
    case 283:  /* *sleu_disi */
    case 282:  /* *sle_disi */
    case 281:  /* *sleu_sisi */
    case 280:  /* *sle_sisi */
    case 279:  /* *sltu_didi */
    case 278:  /* *slt_didi */
    case 277:  /* *sltu_disi */
    case 276:  /* *slt_disi */
    case 275:  /* *sltu_sisi */
    case 274:  /* *slt_sisi */
    case 273:  /* *sgeu_didi */
    case 272:  /* *sge_didi */
    case 271:  /* *sgeu_disi */
    case 270:  /* *sge_disi */
    case 269:  /* *sgeu_sisi */
    case 268:  /* *sge_sisi */
    case 267:  /* *sgtu_didi */
    case 266:  /* *sgt_didi */
    case 265:  /* *sgtu_disi */
    case 264:  /* *sgt_disi */
    case 263:  /* *sgtu_sisi */
    case 262:  /* *sgt_sisi */
    case 261:  /* *sne_zero_didi */
    case 260:  /* *sne_zero_disi */
    case 259:  /* *sne_zero_sisi */
    case 258:  /* *seq_zero_didi */
    case 257:  /* *seq_zero_disi */
    case 256:  /* *seq_zero_sisi */
    case 255:  /* *cstorehfdi4 */
    case 254:  /* *cstorehfsi4 */
    case 253:  /* *cstoredfdi4 */
    case 252:  /* *cstoredfsi4 */
    case 251:  /* *cstoresfdi4 */
    case 250:  /* *cstoresfsi4 */
    case 249:  /* *branch_on_bit_rangedi */
    case 248:  /* *branch_on_bit_rangesi */
    case 247:  /* *branch_on_bitdi */
    case 246:  /* *branch_on_bitsi */
    case 245:  /* *movdidicc */
    case 244:  /* *movsidicc */
    case 243:  /* *movsisicc */
    case 242:  /* *branchdi */
    case 241:  /* *branchsi */
    case 240:  /* *branchdi_shiftedmask_equals_zero */
    case 239:  /* *branchsi_shiftedmask_equals_zero */
    case 238:  /* *branchhi_shiftedmask_equals_zero */
    case 237:  /* *branchqi_shiftedmask_equals_zero */
    case 236:  /* *branchdi_shiftedmask_equals_zero */
    case 235:  /* *branchsi_shiftedmask_equals_zero */
    case 234:  /* *branchhi_shiftedmask_equals_zero */
    case 233:  /* *branchqi_shiftedmask_equals_zero */
    case 232:  /* *branchdi_shiftedarith_equals_zero */
    case 231:  /* *branchsi_shiftedarith_equals_zero */
    case 230:  /* *branchhi_shiftedarith_equals_zero */
    case 229:  /* *branchqi_shiftedarith_equals_zero */
    case 228:  /* *branchsi_shiftedarith_equals_zero */
    case 227:  /* *branchhi_shiftedarith_equals_zero */
    case 226:  /* *branchqi_shiftedarith_equals_zero */
    case 225:  /* zero_extendsidi2_shifted */
    case 224:  /* *lshrsi3_zero_extend_3 */
    case 223:  /* *lshrsi3_zero_extend_2 */
    case 222:  /* *lshrsi3_zero_extend_1 */
    case 221:  /* *lshrsi3_extend_mask_1 */
    case 220:  /* *ashrsi3_extend_mask_1 */
    case 219:  /* *ashlsi3_extend_mask_1 */
    case 218:  /* *lshrsi3_extend_mask */
    case 217:  /* *ashrsi3_extend_mask */
    case 216:  /* *ashlsi3_extend_mask */
    case 215:  /* *lshrsi3_extend */
    case 214:  /* *ashrsi3_extend */
    case 213:  /* *ashlsi3_extend */
    case 212:  /* *lshrdi3_mask_1 */
    case 211:  /* *ashrdi3_mask_1 */
    case 210:  /* *ashldi3_mask_1 */
    case 209:  /* *lshrdi3_mask */
    case 208:  /* *ashrdi3_mask */
    case 207:  /* *ashldi3_mask */
    case 206:  /* lshrdi3 */
    case 205:  /* ashrdi3 */
    case 204:  /* ashldi3 */
    case 203:  /* *lshrsi3_mask_1 */
    case 202:  /* *ashrsi3_mask_1 */
    case 201:  /* *ashlsi3_mask_1 */
    case 200:  /* *lshrsi3_mask */
    case 199:  /* *ashrsi3_mask */
    case 198:  /* *ashlsi3_mask */
    case 197:  /* lshrsi3 */
    case 196:  /* ashrsi3 */
    case 195:  /* ashlsi3 */
    case 194:  /* riscv_pause */
    case 193:  /* fence_i */
    case 192:  /* fence */
    case 191:  /* *movdf_softfloat */
    case 190:  /* *movdf_hardfloat_rv64 */
    case 189:  /* *movdf_hardfloat_rv32 */
    case 188:  /* *movsf_softfloat */
    case 187:  /* *movsf_hardfloat */
    case 186:  /* *movqi_internal */
    case 185:  /* *xorsihi3 */
    case 184:  /* *xorhihi3 */
    case 183:  /* *addsihi3 */
    case 182:  /* *addhihi3 */
    case 181:  /* *movhi_internal */
    case 180:  /* *movsi_internal */
    case 179:  /* *movdi_64bit */
    case 178:  /* *movdi_32bit */
    case 177:  /* *mvconst_internal */
    case 176:  /* *mvconst_internal */
    case 175:  /* *lowdi */
    case 174:  /* *lowsi */
    case 173:  /* auipcdi */
    case 172:  /* auipcsi */
    case 171:  /* got_load_tls_iedi */
    case 170:  /* got_load_tls_iesi */
    case 169:  /* got_load_tls_gddi */
    case 168:  /* got_load_tls_gdsi */
    case 167:  /* tls_add_tp_ledi */
    case 166:  /* tls_add_tp_lesi */
    case 165:  /* got_loaddi */
    case 164:  /* got_loadsi */
    case 163:  /* lroundhfdi2 */
    case 162:  /* lrinthfdi2 */
    case 161:  /* lroundhfsi2 */
    case 160:  /* lrinthfsi2 */
    case 159:  /* lrounddfdi2 */
    case 158:  /* lrintdfdi2 */
    case 157:  /* lrounddfsi2 */
    case 156:  /* lrintdfsi2 */
    case 155:  /* lroundsfdi2 */
    case 154:  /* lrintsfdi2 */
    case 153:  /* lroundsfsi2 */
    case 152:  /* lrintsfsi2 */
    case 151:  /* floatunsdihf2 */
    case 150:  /* floatunssihf2 */
    case 149:  /* floatunsdidf2 */
    case 148:  /* floatunssidf2 */
    case 147:  /* floatunsdisf2 */
    case 146:  /* floatunssisf2 */
    case 145:  /* floatdihf2 */
    case 144:  /* floatsihf2 */
    case 143:  /* floatdidf2 */
    case 142:  /* floatsidf2 */
    case 141:  /* floatdisf2 */
    case 140:  /* floatsisf2 */
    case 139:  /* fixuns_trunchfdi2 */
    case 138:  /* fixuns_trunchfsi2 */
    case 137:  /* fixuns_truncdfdi2 */
    case 136:  /* fixuns_truncdfsi2 */
    case 135:  /* fixuns_truncsfdi2 */
    case 134:  /* fixuns_truncsfsi2 */
    case 133:  /* fix_trunchfdi2 */
    case 132:  /* fix_trunchfsi2 */
    case 131:  /* fix_truncdfdi2 */
    case 130:  /* fix_truncdfsi2 */
    case 129:  /* fix_truncsfdi2 */
    case 128:  /* fix_truncsfsi2 */
    case 127:  /* *movhf_softfloat */
    case 126:  /* *movhf_hardfloat */
    case 125:  /* extendhfdf2 */
    case 124:  /* extendsfdf2 */
    case 123:  /* extendhfsf2 */
    case 122:  /* *extendhidi2 */
    case 121:  /* *extendhisi2 */
    case 120:  /* *extendhihi2 */
    case 119:  /* *extendqidi2 */
    case 118:  /* *extendqisi2 */
    case 117:  /* *extendqihi2 */
    case 116:  /* extendsidi2 */
    case 115:  /* zero_extendqidi2 */
    case 114:  /* zero_extendqisi2 */
    case 113:  /* zero_extendqihi2 */
    case 112:  /* *zero_extendhidi2 */
    case 111:  /* *zero_extendhisi2 */
    case 110:  /* *zero_extendsidi2_internal */
    case 109:  /* truncdfhf2 */
    case 108:  /* truncsfhf2 */
    case 107:  /* truncdfsf2 */
    case 106:  /* *one_cmplsi2_internal */
    case 105:  /* one_cmpldi2 */
    case 104:  /* one_cmplsi2 */
    case 103:  /* *xorsi3_internal */
    case 102:  /* *iorsi3_internal */
    case 101:  /* *andsi3_internal */
    case 100:  /* xordi3 */
    case 99:  /* iordi3 */
    case 98:  /* anddi3 */
    case 97:  /* xorsi3 */
    case 96:  /* iorsi3 */
    case 95:  /* andsi3 */
    case 94:  /* smaxhf3 */
    case 93:  /* smaxdf3 */
    case 92:  /* smaxsf3 */
    case 91:  /* sminhf3 */
    case 90:  /* smindf3 */
    case 89:  /* sminsf3 */
    case 88:  /* fmaxhf3 */
    case 87:  /* fmaxdf3 */
    case 86:  /* fmaxsf3 */
    case 85:  /* fminhf3 */
    case 84:  /* fmindf3 */
    case 83:  /* fminsf3 */
    case 82:  /* neghf2 */
    case 81:  /* negdf2 */
    case 80:  /* negsf2 */
    case 79:  /* copysignhf3 */
    case 78:  /* copysigndf3 */
    case 77:  /* copysignsf3 */
    case 76:  /* abshf2 */
    case 75:  /* absdf2 */
    case 74:  /* abssf2 */
    case 73:  /* *fnmahf4 */
    case 72:  /* *fnmadf4 */
    case 71:  /* *fnmasf4 */
    case 70:  /* *fnmshf4 */
    case 69:  /* *fnmsdf4 */
    case 68:  /* *fnmssf4 */
    case 67:  /* *fmshf4 */
    case 66:  /* *fmsdf4 */
    case 65:  /* *fmssf4 */
    case 64:  /* *fmahf4 */
    case 63:  /* *fmadf4 */
    case 62:  /* *fmasf4 */
    case 61:  /* fnmahf4 */
    case 60:  /* fnmadf4 */
    case 59:  /* fnmasf4 */
    case 58:  /* fnmshf4 */
    case 57:  /* fnmsdf4 */
    case 56:  /* fnmssf4 */
    case 55:  /* fmshf4 */
    case 54:  /* fmsdf4 */
    case 53:  /* fmssf4 */
    case 52:  /* fmahf4 */
    case 51:  /* fmadf4 */
    case 50:  /* fmasf4 */
    case 49:  /* sqrthf2 */
    case 48:  /* sqrtdf2 */
    case 47:  /* sqrtsf2 */
    case 46:  /* divhf3 */
    case 45:  /* divdf3 */
    case 44:  /* divsf3 */
    case 43:  /* *umodsi3_extended */
    case 42:  /* *modsi3_extended */
    case 41:  /* *udivsi3_extended */
    case 40:  /* *divsi3_extended */
    case 39:  /* umoddi3 */
    case 38:  /* moddi3 */
    case 37:  /* udivdi3 */
    case 36:  /* divdi3 */
    case 35:  /* umodsi3 */
    case 34:  /* modsi3 */
    case 33:  /* udivsi3 */
    case 32:  /* divsi3 */
    case 31:  /* usmulsi3_highpart */
    case 30:  /* umulsi3_highpart */
    case 29:  /* smulsi3_highpart */
    case 28:  /* usmuldi3_highpart */
    case 27:  /* umuldi3_highpart */
    case 26:  /* smuldi3_highpart */
    case 25:  /* *mulsi3_extended2 */
    case 24:  /* *mulsi3_extended */
    case 23:  /* muldi3 */
    case 22:  /* mulsi3 */
    case 21:  /* mulhf3 */
    case 20:  /* muldf3 */
    case 19:  /* mulsf3 */
    case 18:  /* *negsi2_extended2 */
    case 17:  /* *negsi2_extended */
    case 16:  /* negsi2 */
    case 15:  /* negdi2 */
    case 14:  /* *subsi3_extended2 */
    case 13:  /* *subsi3_extended */
    case 12:  /* subsi3 */
    case 11:  /* subdi3 */
    case 10:  /* subhf3 */
    case 9:  /* subdf3 */
    case 8:  /* subsf3 */
    case 7:  /* *addsi3_extended2 */
    case 6:  /* *addsi3_extended */
    case 5:  /* adddi3 */
    case 4:  /* addsi3 */
    case 3:  /* addhf3 */
    case 2:  /* adddf3 */
    case 1:  /* addsf3 */
      return HAS_VTYPE_OP_FALSE;

    default:
      return HAS_VTYPE_OP_TRUE;

    }
}

int
get_attr_ma (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 4599:  /* pred_seriesvnx8di */
    case 4598:  /* pred_seriesvnx4di */
    case 4597:  /* pred_seriesvnx2di */
    case 4596:  /* pred_seriesvnx1di */
    case 4595:  /* pred_seriesvnx16si */
    case 4594:  /* pred_seriesvnx8si */
    case 4593:  /* pred_seriesvnx4si */
    case 4592:  /* pred_seriesvnx2si */
    case 4591:  /* pred_seriesvnx1si */
    case 4590:  /* pred_seriesvnx32hi */
    case 4589:  /* pred_seriesvnx16hi */
    case 4588:  /* pred_seriesvnx8hi */
    case 4587:  /* pred_seriesvnx4hi */
    case 4586:  /* pred_seriesvnx2hi */
    case 4585:  /* pred_seriesvnx1hi */
    case 4584:  /* pred_seriesvnx64qi */
    case 4583:  /* pred_seriesvnx32qi */
    case 4582:  /* pred_seriesvnx16qi */
    case 4581:  /* pred_seriesvnx8qi */
    case 4580:  /* pred_seriesvnx4qi */
    case 4579:  /* pred_seriesvnx2qi */
    case 4578:  /* pred_seriesvnx1qi */
    case 4555:  /* pred_sofvnx64bi */
    case 4554:  /* pred_sifvnx64bi */
    case 4553:  /* pred_sbfvnx64bi */
    case 4552:  /* pred_sofvnx32bi */
    case 4551:  /* pred_sifvnx32bi */
    case 4550:  /* pred_sbfvnx32bi */
    case 4549:  /* pred_sofvnx16bi */
    case 4548:  /* pred_sifvnx16bi */
    case 4547:  /* pred_sbfvnx16bi */
    case 4546:  /* pred_sofvnx8bi */
    case 4545:  /* pred_sifvnx8bi */
    case 4544:  /* pred_sbfvnx8bi */
    case 4543:  /* pred_sofvnx4bi */
    case 4542:  /* pred_sifvnx4bi */
    case 4541:  /* pred_sbfvnx4bi */
    case 4540:  /* pred_sofvnx2bi */
    case 4539:  /* pred_sifvnx2bi */
    case 4538:  /* pred_sbfvnx2bi */
    case 4537:  /* pred_sofvnx1bi */
    case 4536:  /* pred_sifvnx1bi */
    case 4535:  /* pred_sbfvnx1bi */
      extract_constrain_insn_cached (insn);
      return 
#line 314 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ma(operands[5]));

    case 4995:  /* *pred_mul_neg_subvnx8df_scalar */
    case 4994:  /* *pred_mul_neg_addvnx8df_scalar */
    case 4993:  /* *pred_mul_neg_subvnx4df_scalar */
    case 4992:  /* *pred_mul_neg_addvnx4df_scalar */
    case 4991:  /* *pred_mul_neg_subvnx2df_scalar */
    case 4990:  /* *pred_mul_neg_addvnx2df_scalar */
    case 4989:  /* *pred_mul_neg_subvnx1df_scalar */
    case 4988:  /* *pred_mul_neg_addvnx1df_scalar */
    case 4987:  /* *pred_mul_neg_subvnx16sf_scalar */
    case 4986:  /* *pred_mul_neg_addvnx16sf_scalar */
    case 4985:  /* *pred_mul_neg_subvnx8sf_scalar */
    case 4984:  /* *pred_mul_neg_addvnx8sf_scalar */
    case 4983:  /* *pred_mul_neg_subvnx4sf_scalar */
    case 4982:  /* *pred_mul_neg_addvnx4sf_scalar */
    case 4981:  /* *pred_mul_neg_subvnx2sf_scalar */
    case 4980:  /* *pred_mul_neg_addvnx2sf_scalar */
    case 4979:  /* *pred_mul_neg_subvnx1sf_scalar */
    case 4978:  /* *pred_mul_neg_addvnx1sf_scalar */
    case 4941:  /* *pred_mul_neg_subvnx8df */
    case 4940:  /* *pred_mul_neg_addvnx8df */
    case 4939:  /* *pred_mul_neg_subvnx4df */
    case 4938:  /* *pred_mul_neg_addvnx4df */
    case 4937:  /* *pred_mul_neg_subvnx2df */
    case 4936:  /* *pred_mul_neg_addvnx2df */
    case 4935:  /* *pred_mul_neg_subvnx1df */
    case 4934:  /* *pred_mul_neg_addvnx1df */
    case 4933:  /* *pred_mul_neg_subvnx16sf */
    case 4932:  /* *pred_mul_neg_addvnx16sf */
    case 4931:  /* *pred_mul_neg_subvnx8sf */
    case 4930:  /* *pred_mul_neg_addvnx8sf */
    case 4929:  /* *pred_mul_neg_subvnx4sf */
    case 4928:  /* *pred_mul_neg_addvnx4sf */
    case 4927:  /* *pred_mul_neg_subvnx2sf */
    case 4926:  /* *pred_mul_neg_addvnx2sf */
    case 4925:  /* *pred_mul_neg_subvnx1sf */
    case 4924:  /* *pred_mul_neg_addvnx1sf */
    case 4887:  /* *pred_mul_subvnx8df_scalar */
    case 4886:  /* *pred_mul_addvnx8df_scalar */
    case 4885:  /* *pred_mul_subvnx4df_scalar */
    case 4884:  /* *pred_mul_addvnx4df_scalar */
    case 4883:  /* *pred_mul_subvnx2df_scalar */
    case 4882:  /* *pred_mul_addvnx2df_scalar */
    case 4881:  /* *pred_mul_subvnx1df_scalar */
    case 4880:  /* *pred_mul_addvnx1df_scalar */
    case 4879:  /* *pred_mul_subvnx16sf_scalar */
    case 4878:  /* *pred_mul_addvnx16sf_scalar */
    case 4877:  /* *pred_mul_subvnx8sf_scalar */
    case 4876:  /* *pred_mul_addvnx8sf_scalar */
    case 4875:  /* *pred_mul_subvnx4sf_scalar */
    case 4874:  /* *pred_mul_addvnx4sf_scalar */
    case 4873:  /* *pred_mul_subvnx2sf_scalar */
    case 4872:  /* *pred_mul_addvnx2sf_scalar */
    case 4871:  /* *pred_mul_subvnx1sf_scalar */
    case 4870:  /* *pred_mul_addvnx1sf_scalar */
    case 4833:  /* *pred_mul_subvnx8df */
    case 4832:  /* *pred_mul_addvnx8df */
    case 4831:  /* *pred_mul_subvnx4df */
    case 4830:  /* *pred_mul_addvnx4df */
    case 4829:  /* *pred_mul_subvnx2df */
    case 4828:  /* *pred_mul_addvnx2df */
    case 4827:  /* *pred_mul_subvnx1df */
    case 4826:  /* *pred_mul_addvnx1df */
    case 4825:  /* *pred_mul_subvnx16sf */
    case 4824:  /* *pred_mul_addvnx16sf */
    case 4823:  /* *pred_mul_subvnx8sf */
    case 4822:  /* *pred_mul_addvnx8sf */
    case 4821:  /* *pred_mul_subvnx4sf */
    case 4820:  /* *pred_mul_addvnx4sf */
    case 4819:  /* *pred_mul_subvnx2sf */
    case 4818:  /* *pred_mul_addvnx2sf */
    case 4817:  /* *pred_mul_subvnx1sf */
    case 4816:  /* *pred_mul_addvnx1sf */
    case 4338:  /* *pred_minus_mulvnx8di_extended_scalar */
    case 4337:  /* *pred_minus_mulvnx4di_extended_scalar */
    case 4336:  /* *pred_minus_mulvnx2di_extended_scalar */
    case 4335:  /* *pred_minus_mulvnx1di_extended_scalar */
    case 4326:  /* *pred_minus_mulvnx8di_scalar */
    case 4325:  /* *pred_minus_mulvnx4di_scalar */
    case 4324:  /* *pred_minus_mulvnx2di_scalar */
    case 4323:  /* *pred_minus_mulvnx1di_scalar */
    case 4322:  /* *pred_minus_mulvnx16si_scalar */
    case 4321:  /* *pred_minus_mulvnx8si_scalar */
    case 4320:  /* *pred_minus_mulvnx4si_scalar */
    case 4319:  /* *pred_minus_mulvnx2si_scalar */
    case 4318:  /* *pred_minus_mulvnx1si_scalar */
    case 4317:  /* *pred_minus_mulvnx32hi_scalar */
    case 4316:  /* *pred_minus_mulvnx16hi_scalar */
    case 4315:  /* *pred_minus_mulvnx8hi_scalar */
    case 4314:  /* *pred_minus_mulvnx4hi_scalar */
    case 4313:  /* *pred_minus_mulvnx2hi_scalar */
    case 4312:  /* *pred_minus_mulvnx1hi_scalar */
    case 4311:  /* *pred_minus_mulvnx64qi_scalar */
    case 4310:  /* *pred_minus_mulvnx32qi_scalar */
    case 4309:  /* *pred_minus_mulvnx16qi_scalar */
    case 4308:  /* *pred_minus_mulvnx8qi_scalar */
    case 4307:  /* *pred_minus_mulvnx4qi_scalar */
    case 4306:  /* *pred_minus_mulvnx2qi_scalar */
    case 4305:  /* *pred_minus_mulvnx1qi_scalar */
    case 4260:  /* *pred_minus_mulvnx8di */
    case 4259:  /* *pred_minus_mulvnx4di */
    case 4258:  /* *pred_minus_mulvnx2di */
    case 4257:  /* *pred_minus_mulvnx1di */
    case 4256:  /* *pred_minus_mulvnx16si */
    case 4255:  /* *pred_minus_mulvnx8si */
    case 4254:  /* *pred_minus_mulvnx4si */
    case 4253:  /* *pred_minus_mulvnx2si */
    case 4252:  /* *pred_minus_mulvnx1si */
    case 4251:  /* *pred_minus_mulvnx32hi */
    case 4250:  /* *pred_minus_mulvnx16hi */
    case 4249:  /* *pred_minus_mulvnx8hi */
    case 4248:  /* *pred_minus_mulvnx4hi */
    case 4247:  /* *pred_minus_mulvnx2hi */
    case 4246:  /* *pred_minus_mulvnx1hi */
    case 4245:  /* *pred_minus_mulvnx64qi */
    case 4244:  /* *pred_minus_mulvnx32qi */
    case 4243:  /* *pred_minus_mulvnx16qi */
    case 4242:  /* *pred_minus_mulvnx8qi */
    case 4241:  /* *pred_minus_mulvnx4qi */
    case 4240:  /* *pred_minus_mulvnx2qi */
    case 4239:  /* *pred_minus_mulvnx1qi */
    case 4194:  /* *pred_mul_plusvnx8di_extended_scalar */
    case 4193:  /* *pred_mul_plusvnx4di_extended_scalar */
    case 4192:  /* *pred_mul_plusvnx2di_extended_scalar */
    case 4191:  /* *pred_mul_plusvnx1di_extended_scalar */
    case 4182:  /* *pred_mul_plusvnx8di_scalar */
    case 4181:  /* *pred_mul_plusvnx4di_scalar */
    case 4180:  /* *pred_mul_plusvnx2di_scalar */
    case 4179:  /* *pred_mul_plusvnx1di_scalar */
    case 4178:  /* *pred_mul_plusvnx16si_scalar */
    case 4177:  /* *pred_mul_plusvnx8si_scalar */
    case 4176:  /* *pred_mul_plusvnx4si_scalar */
    case 4175:  /* *pred_mul_plusvnx2si_scalar */
    case 4174:  /* *pred_mul_plusvnx1si_scalar */
    case 4173:  /* *pred_mul_plusvnx32hi_scalar */
    case 4172:  /* *pred_mul_plusvnx16hi_scalar */
    case 4171:  /* *pred_mul_plusvnx8hi_scalar */
    case 4170:  /* *pred_mul_plusvnx4hi_scalar */
    case 4169:  /* *pred_mul_plusvnx2hi_scalar */
    case 4168:  /* *pred_mul_plusvnx1hi_scalar */
    case 4167:  /* *pred_mul_plusvnx64qi_scalar */
    case 4166:  /* *pred_mul_plusvnx32qi_scalar */
    case 4165:  /* *pred_mul_plusvnx16qi_scalar */
    case 4164:  /* *pred_mul_plusvnx8qi_scalar */
    case 4163:  /* *pred_mul_plusvnx4qi_scalar */
    case 4162:  /* *pred_mul_plusvnx2qi_scalar */
    case 4161:  /* *pred_mul_plusvnx1qi_scalar */
    case 4116:  /* *pred_mul_plusvnx8di */
    case 4115:  /* *pred_mul_plusvnx4di */
    case 4114:  /* *pred_mul_plusvnx2di */
    case 4113:  /* *pred_mul_plusvnx1di */
    case 4112:  /* *pred_mul_plusvnx16si */
    case 4111:  /* *pred_mul_plusvnx8si */
    case 4110:  /* *pred_mul_plusvnx4si */
    case 4109:  /* *pred_mul_plusvnx2si */
    case 4108:  /* *pred_mul_plusvnx1si */
    case 4107:  /* *pred_mul_plusvnx32hi */
    case 4106:  /* *pred_mul_plusvnx16hi */
    case 4105:  /* *pred_mul_plusvnx8hi */
    case 4104:  /* *pred_mul_plusvnx4hi */
    case 4103:  /* *pred_mul_plusvnx2hi */
    case 4102:  /* *pred_mul_plusvnx1hi */
    case 4101:  /* *pred_mul_plusvnx64qi */
    case 4100:  /* *pred_mul_plusvnx32qi */
    case 4099:  /* *pred_mul_plusvnx16qi */
    case 4098:  /* *pred_mul_plusvnx8qi */
    case 4097:  /* *pred_mul_plusvnx4qi */
    case 4096:  /* *pred_mul_plusvnx2qi */
    case 4095:  /* *pred_mul_plusvnx1qi */
      extract_constrain_insn_cached (insn);
      return 
#line 311 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ma(operands[8]));

    case 998:  /* pred_strided_loadvnx8df */
    case 997:  /* pred_strided_loadvnx4df */
    case 996:  /* pred_strided_loadvnx2df */
    case 995:  /* pred_strided_loadvnx1df */
    case 994:  /* pred_strided_loadvnx16sf */
    case 993:  /* pred_strided_loadvnx8sf */
    case 992:  /* pred_strided_loadvnx4sf */
    case 991:  /* pred_strided_loadvnx2sf */
    case 990:  /* pred_strided_loadvnx1sf */
    case 989:  /* pred_strided_loadvnx8di */
    case 988:  /* pred_strided_loadvnx4di */
    case 987:  /* pred_strided_loadvnx2di */
    case 986:  /* pred_strided_loadvnx1di */
    case 985:  /* pred_strided_loadvnx16si */
    case 984:  /* pred_strided_loadvnx8si */
    case 983:  /* pred_strided_loadvnx4si */
    case 982:  /* pred_strided_loadvnx2si */
    case 981:  /* pred_strided_loadvnx1si */
    case 980:  /* pred_strided_loadvnx32hi */
    case 979:  /* pred_strided_loadvnx16hi */
    case 978:  /* pred_strided_loadvnx8hi */
    case 977:  /* pred_strided_loadvnx4hi */
    case 976:  /* pred_strided_loadvnx2hi */
    case 975:  /* pred_strided_loadvnx1hi */
    case 974:  /* pred_strided_loadvnx64qi */
    case 973:  /* pred_strided_loadvnx32qi */
    case 972:  /* pred_strided_loadvnx16qi */
    case 971:  /* pred_strided_loadvnx8qi */
    case 970:  /* pred_strided_loadvnx4qi */
    case 969:  /* pred_strided_loadvnx2qi */
    case 968:  /* pred_strided_loadvnx1qi */
      extract_constrain_insn_cached (insn);
      if (
#line 239 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(VECTOR_MODE_P (GET_MODE (operands[3]))))
        {
	  return 
#line 299 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ma(operands[7]));
        }
      else
        {
	  return 
#line 293 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ma(operands[6]));
        }

    case 963:  /* *pred_broadcastvnx8df */
    case 962:  /* *pred_broadcastvnx4df */
    case 961:  /* *pred_broadcastvnx2df */
    case 960:  /* *pred_broadcastvnx1df */
    case 959:  /* *pred_broadcastvnx16sf */
    case 958:  /* *pred_broadcastvnx8sf */
    case 957:  /* *pred_broadcastvnx4sf */
    case 956:  /* *pred_broadcastvnx2sf */
    case 955:  /* *pred_broadcastvnx1sf */
    case 954:  /* *pred_broadcastvnx8di */
    case 953:  /* *pred_broadcastvnx4di */
    case 952:  /* *pred_broadcastvnx2di */
    case 951:  /* *pred_broadcastvnx1di */
    case 950:  /* *pred_broadcastvnx16si */
    case 949:  /* *pred_broadcastvnx8si */
    case 948:  /* *pred_broadcastvnx4si */
    case 947:  /* *pred_broadcastvnx2si */
    case 946:  /* *pred_broadcastvnx1si */
    case 945:  /* *pred_broadcastvnx32hi */
    case 944:  /* *pred_broadcastvnx16hi */
    case 943:  /* *pred_broadcastvnx8hi */
    case 942:  /* *pred_broadcastvnx4hi */
    case 941:  /* *pred_broadcastvnx2hi */
    case 940:  /* *pred_broadcastvnx1hi */
    case 939:  /* *pred_broadcastvnx64qi */
    case 938:  /* *pred_broadcastvnx32qi */
    case 937:  /* *pred_broadcastvnx16qi */
    case 936:  /* *pred_broadcastvnx8qi */
    case 935:  /* *pred_broadcastvnx4qi */
    case 934:  /* *pred_broadcastvnx2qi */
    case 933:  /* *pred_broadcastvnx1qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3cULL))
        {
	  if (
#line 239 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(VECTOR_MODE_P (GET_MODE (operands[3]))))
	    {
	      return 
#line 299 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ma(operands[7]));
	    }
	  else
	    {
	      return 
#line 293 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ma(operands[6]));
	    }
        }
      else
        {
	  return 255 /* 0xff */;
        }

    case 830:  /* pred_movvnx8df */
    case 829:  /* pred_movvnx4df */
    case 828:  /* pred_movvnx2df */
    case 827:  /* pred_movvnx1df */
    case 826:  /* pred_movvnx16sf */
    case 825:  /* pred_movvnx8sf */
    case 824:  /* pred_movvnx4sf */
    case 823:  /* pred_movvnx2sf */
    case 822:  /* pred_movvnx1sf */
    case 821:  /* pred_movvnx8di */
    case 820:  /* pred_movvnx4di */
    case 819:  /* pred_movvnx2di */
    case 818:  /* pred_movvnx1di */
    case 817:  /* pred_movvnx16si */
    case 816:  /* pred_movvnx8si */
    case 815:  /* pred_movvnx4si */
    case 814:  /* pred_movvnx2si */
    case 813:  /* pred_movvnx1si */
    case 812:  /* pred_movvnx32hi */
    case 811:  /* pred_movvnx16hi */
    case 810:  /* pred_movvnx8hi */
    case 809:  /* pred_movvnx4hi */
    case 808:  /* pred_movvnx2hi */
    case 807:  /* pred_movvnx1hi */
    case 806:  /* pred_movvnx64qi */
    case 805:  /* pred_movvnx32qi */
    case 804:  /* pred_movvnx16qi */
    case 803:  /* pred_movvnx8qi */
    case 802:  /* pred_movvnx4qi */
    case 801:  /* pred_movvnx2qi */
    case 800:  /* pred_movvnx1qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return 
#line 293 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ma(operands[6]));
        }
      else
        {
	  return 255 /* 0xff */;
        }

    case 6036:  /* read_vldi_zero_extend */
    case 6035:  /* read_vlsi */
    case 6034:  /* pred_compressvnx8df */
    case 6033:  /* pred_compressvnx4df */
    case 6032:  /* pred_compressvnx2df */
    case 6031:  /* pred_compressvnx1df */
    case 6030:  /* pred_compressvnx16sf */
    case 6029:  /* pred_compressvnx8sf */
    case 6028:  /* pred_compressvnx4sf */
    case 6027:  /* pred_compressvnx2sf */
    case 6026:  /* pred_compressvnx1sf */
    case 6025:  /* pred_compressvnx8di */
    case 6024:  /* pred_compressvnx4di */
    case 6023:  /* pred_compressvnx2di */
    case 6022:  /* pred_compressvnx1di */
    case 6021:  /* pred_compressvnx16si */
    case 6020:  /* pred_compressvnx8si */
    case 6019:  /* pred_compressvnx4si */
    case 6018:  /* pred_compressvnx2si */
    case 6017:  /* pred_compressvnx1si */
    case 6016:  /* pred_compressvnx32hi */
    case 6015:  /* pred_compressvnx16hi */
    case 6014:  /* pred_compressvnx8hi */
    case 6013:  /* pred_compressvnx4hi */
    case 6012:  /* pred_compressvnx2hi */
    case 6011:  /* pred_compressvnx1hi */
    case 6010:  /* pred_compressvnx64qi */
    case 6009:  /* pred_compressvnx32qi */
    case 6008:  /* pred_compressvnx16qi */
    case 6007:  /* pred_compressvnx8qi */
    case 6006:  /* pred_compressvnx4qi */
    case 6005:  /* pred_compressvnx2qi */
    case 6004:  /* pred_compressvnx1qi */
    case 5779:  /* *pred_extract_firstvnx8df */
    case 5778:  /* *pred_extract_firstvnx4df */
    case 5777:  /* *pred_extract_firstvnx2df */
    case 5776:  /* *pred_extract_firstvnx1df */
    case 5775:  /* *pred_extract_firstvnx16sf */
    case 5774:  /* *pred_extract_firstvnx8sf */
    case 5773:  /* *pred_extract_firstvnx4sf */
    case 5772:  /* *pred_extract_firstvnx2sf */
    case 5771:  /* *pred_extract_firstvnx1sf */
    case 5770:  /* pred_extract_first_truncvnx8di */
    case 5769:  /* pred_extract_first_truncvnx4di */
    case 5768:  /* pred_extract_first_truncvnx2di */
    case 5767:  /* pred_extract_first_truncvnx1di */
    case 5766:  /* *pred_extract_firstvnx8di */
    case 5765:  /* *pred_extract_firstvnx4di */
    case 5764:  /* *pred_extract_firstvnx2di */
    case 5763:  /* *pred_extract_firstvnx1di */
    case 5762:  /* *pred_extract_firstvnx16si */
    case 5761:  /* *pred_extract_firstvnx8si */
    case 5760:  /* *pred_extract_firstvnx4si */
    case 5759:  /* *pred_extract_firstvnx2si */
    case 5758:  /* *pred_extract_firstvnx1si */
    case 5757:  /* *pred_extract_firstvnx32hi */
    case 5756:  /* *pred_extract_firstvnx16hi */
    case 5755:  /* *pred_extract_firstvnx8hi */
    case 5754:  /* *pred_extract_firstvnx4hi */
    case 5753:  /* *pred_extract_firstvnx2hi */
    case 5752:  /* *pred_extract_firstvnx1hi */
    case 5751:  /* *pred_extract_firstvnx64qi */
    case 5750:  /* *pred_extract_firstvnx32qi */
    case 5749:  /* *pred_extract_firstvnx16qi */
    case 5748:  /* *pred_extract_firstvnx8qi */
    case 5747:  /* *pred_extract_firstvnx4qi */
    case 5746:  /* *pred_extract_firstvnx2qi */
    case 5745:  /* *pred_extract_firstvnx1qi */
    case 5744:  /* pred_widen_reduc_plusuvnx16sfvnx1df */
    case 5743:  /* pred_widen_reduc_plusovnx16sfvnx1df */
    case 5742:  /* pred_widen_reduc_plusuvnx8sfvnx1df */
    case 5741:  /* pred_widen_reduc_plusovnx8sfvnx1df */
    case 5740:  /* pred_widen_reduc_plusuvnx4sfvnx1df */
    case 5739:  /* pred_widen_reduc_plusovnx4sfvnx1df */
    case 5738:  /* pred_widen_reduc_plusuvnx2sfvnx1df */
    case 5737:  /* pred_widen_reduc_plusovnx2sfvnx1df */
    case 5736:  /* pred_widen_reduc_plusuvnx1sfvnx1df */
    case 5735:  /* pred_widen_reduc_plusovnx1sfvnx1df */
    case 5734:  /* pred_reduc_plusuvnx8sfvnx1sf */
    case 5733:  /* pred_reduc_plusovnx8sfvnx1sf */
    case 5732:  /* pred_reduc_plusuvnx4sfvnx1sf */
    case 5731:  /* pred_reduc_plusovnx4sfvnx1sf */
    case 5730:  /* pred_reduc_plusuvnx2sfvnx1sf */
    case 5729:  /* pred_reduc_plusovnx2sfvnx1sf */
    case 5728:  /* pred_reduc_plusuvnx1sfvnx1sf */
    case 5727:  /* pred_reduc_plusovnx1sfvnx1sf */
    case 5726:  /* pred_reduc_plusuvnx8dfvnx1df */
    case 5725:  /* pred_reduc_plusovnx8dfvnx1df */
    case 5724:  /* pred_reduc_plusuvnx4dfvnx1df */
    case 5723:  /* pred_reduc_plusovnx4dfvnx1df */
    case 5722:  /* pred_reduc_plusuvnx2dfvnx1df */
    case 5721:  /* pred_reduc_plusovnx2dfvnx1df */
    case 5720:  /* pred_reduc_plusuvnx1dfvnx1df */
    case 5719:  /* pred_reduc_plusovnx1dfvnx1df */
    case 5718:  /* pred_reduc_plusuvnx16sfvnx2sf */
    case 5717:  /* pred_reduc_plusovnx16sfvnx2sf */
    case 5716:  /* pred_reduc_plusuvnx8sfvnx2sf */
    case 5715:  /* pred_reduc_plusovnx8sfvnx2sf */
    case 5714:  /* pred_reduc_plusuvnx4sfvnx2sf */
    case 5713:  /* pred_reduc_plusovnx4sfvnx2sf */
    case 5712:  /* pred_reduc_plusuvnx2sfvnx2sf */
    case 5711:  /* pred_reduc_plusovnx2sfvnx2sf */
    case 5710:  /* pred_reduc_plusuvnx1sfvnx2sf */
    case 5709:  /* pred_reduc_plusovnx1sfvnx2sf */
    case 5708:  /* pred_reduc_minvnx8sfvnx1sf */
    case 5707:  /* pred_reduc_maxvnx8sfvnx1sf */
    case 5706:  /* pred_reduc_minvnx4sfvnx1sf */
    case 5705:  /* pred_reduc_maxvnx4sfvnx1sf */
    case 5704:  /* pred_reduc_minvnx2sfvnx1sf */
    case 5703:  /* pred_reduc_maxvnx2sfvnx1sf */
    case 5702:  /* pred_reduc_minvnx1sfvnx1sf */
    case 5701:  /* pred_reduc_maxvnx1sfvnx1sf */
    case 5700:  /* pred_reduc_minvnx8dfvnx1df */
    case 5699:  /* pred_reduc_maxvnx8dfvnx1df */
    case 5698:  /* pred_reduc_minvnx4dfvnx1df */
    case 5697:  /* pred_reduc_maxvnx4dfvnx1df */
    case 5696:  /* pred_reduc_minvnx2dfvnx1df */
    case 5695:  /* pred_reduc_maxvnx2dfvnx1df */
    case 5694:  /* pred_reduc_minvnx1dfvnx1df */
    case 5693:  /* pred_reduc_maxvnx1dfvnx1df */
    case 5692:  /* pred_reduc_minvnx16sfvnx2sf */
    case 5691:  /* pred_reduc_maxvnx16sfvnx2sf */
    case 5690:  /* pred_reduc_minvnx8sfvnx2sf */
    case 5689:  /* pred_reduc_maxvnx8sfvnx2sf */
    case 5688:  /* pred_reduc_minvnx4sfvnx2sf */
    case 5687:  /* pred_reduc_maxvnx4sfvnx2sf */
    case 5686:  /* pred_reduc_minvnx2sfvnx2sf */
    case 5685:  /* pred_reduc_maxvnx2sfvnx2sf */
    case 5684:  /* pred_reduc_minvnx1sfvnx2sf */
    case 5683:  /* pred_reduc_maxvnx1sfvnx2sf */
    case 5682:  /* pred_widen_reduc_plusuvnx16hivnx1si */
    case 5681:  /* pred_widen_reduc_plusvnx16hivnx1si */
    case 5680:  /* pred_widen_reduc_plusuvnx8hivnx1si */
    case 5679:  /* pred_widen_reduc_plusvnx8hivnx1si */
    case 5678:  /* pred_widen_reduc_plusuvnx4hivnx1si */
    case 5677:  /* pred_widen_reduc_plusvnx4hivnx1si */
    case 5676:  /* pred_widen_reduc_plusuvnx2hivnx1si */
    case 5675:  /* pred_widen_reduc_plusvnx2hivnx1si */
    case 5674:  /* pred_widen_reduc_plusuvnx1hivnx1si */
    case 5673:  /* pred_widen_reduc_plusvnx1hivnx1si */
    case 5672:  /* pred_widen_reduc_plusuvnx32qivnx2hi */
    case 5671:  /* pred_widen_reduc_plusvnx32qivnx2hi */
    case 5670:  /* pred_widen_reduc_plusuvnx16qivnx2hi */
    case 5669:  /* pred_widen_reduc_plusvnx16qivnx2hi */
    case 5668:  /* pred_widen_reduc_plusuvnx8qivnx2hi */
    case 5667:  /* pred_widen_reduc_plusvnx8qivnx2hi */
    case 5666:  /* pred_widen_reduc_plusuvnx4qivnx2hi */
    case 5665:  /* pred_widen_reduc_plusvnx4qivnx2hi */
    case 5664:  /* pred_widen_reduc_plusuvnx2qivnx2hi */
    case 5663:  /* pred_widen_reduc_plusvnx2qivnx2hi */
    case 5662:  /* pred_widen_reduc_plusuvnx1qivnx2hi */
    case 5661:  /* pred_widen_reduc_plusvnx1qivnx2hi */
    case 5660:  /* pred_widen_reduc_plusuvnx16sivnx2di */
    case 5659:  /* pred_widen_reduc_plusvnx16sivnx2di */
    case 5658:  /* pred_widen_reduc_plusuvnx8sivnx2di */
    case 5657:  /* pred_widen_reduc_plusvnx8sivnx2di */
    case 5656:  /* pred_widen_reduc_plusuvnx4sivnx2di */
    case 5655:  /* pred_widen_reduc_plusvnx4sivnx2di */
    case 5654:  /* pred_widen_reduc_plusuvnx2sivnx2di */
    case 5653:  /* pred_widen_reduc_plusvnx2sivnx2di */
    case 5652:  /* pred_widen_reduc_plusuvnx1sivnx2di */
    case 5651:  /* pred_widen_reduc_plusvnx1sivnx2di */
    case 5650:  /* pred_widen_reduc_plusuvnx32hivnx2si */
    case 5649:  /* pred_widen_reduc_plusvnx32hivnx2si */
    case 5648:  /* pred_widen_reduc_plusuvnx16hivnx2si */
    case 5647:  /* pred_widen_reduc_plusvnx16hivnx2si */
    case 5646:  /* pred_widen_reduc_plusuvnx8hivnx2si */
    case 5645:  /* pred_widen_reduc_plusvnx8hivnx2si */
    case 5644:  /* pred_widen_reduc_plusuvnx4hivnx2si */
    case 5643:  /* pred_widen_reduc_plusvnx4hivnx2si */
    case 5642:  /* pred_widen_reduc_plusuvnx2hivnx2si */
    case 5641:  /* pred_widen_reduc_plusvnx2hivnx2si */
    case 5640:  /* pred_widen_reduc_plusuvnx1hivnx2si */
    case 5639:  /* pred_widen_reduc_plusvnx1hivnx2si */
    case 5638:  /* pred_widen_reduc_plusuvnx64qivnx4hi */
    case 5637:  /* pred_widen_reduc_plusvnx64qivnx4hi */
    case 5636:  /* pred_widen_reduc_plusuvnx32qivnx4hi */
    case 5635:  /* pred_widen_reduc_plusvnx32qivnx4hi */
    case 5634:  /* pred_widen_reduc_plusuvnx16qivnx4hi */
    case 5633:  /* pred_widen_reduc_plusvnx16qivnx4hi */
    case 5632:  /* pred_widen_reduc_plusuvnx8qivnx4hi */
    case 5631:  /* pred_widen_reduc_plusvnx8qivnx4hi */
    case 5630:  /* pred_widen_reduc_plusuvnx4qivnx4hi */
    case 5629:  /* pred_widen_reduc_plusvnx4qivnx4hi */
    case 5628:  /* pred_widen_reduc_plusuvnx2qivnx4hi */
    case 5627:  /* pred_widen_reduc_plusvnx2qivnx4hi */
    case 5626:  /* pred_widen_reduc_plusuvnx1qivnx4hi */
    case 5625:  /* pred_widen_reduc_plusvnx1qivnx4hi */
    case 5624:  /* pred_reduc_xorvnx8sivnx1si */
    case 5623:  /* pred_reduc_orvnx8sivnx1si */
    case 5622:  /* pred_reduc_andvnx8sivnx1si */
    case 5621:  /* pred_reduc_minvnx8sivnx1si */
    case 5620:  /* pred_reduc_minuvnx8sivnx1si */
    case 5619:  /* pred_reduc_maxvnx8sivnx1si */
    case 5618:  /* pred_reduc_maxuvnx8sivnx1si */
    case 5617:  /* pred_reduc_sumvnx8sivnx1si */
    case 5616:  /* pred_reduc_xorvnx4sivnx1si */
    case 5615:  /* pred_reduc_orvnx4sivnx1si */
    case 5614:  /* pred_reduc_andvnx4sivnx1si */
    case 5613:  /* pred_reduc_minvnx4sivnx1si */
    case 5612:  /* pred_reduc_minuvnx4sivnx1si */
    case 5611:  /* pred_reduc_maxvnx4sivnx1si */
    case 5610:  /* pred_reduc_maxuvnx4sivnx1si */
    case 5609:  /* pred_reduc_sumvnx4sivnx1si */
    case 5608:  /* pred_reduc_xorvnx2sivnx1si */
    case 5607:  /* pred_reduc_orvnx2sivnx1si */
    case 5606:  /* pred_reduc_andvnx2sivnx1si */
    case 5605:  /* pred_reduc_minvnx2sivnx1si */
    case 5604:  /* pred_reduc_minuvnx2sivnx1si */
    case 5603:  /* pred_reduc_maxvnx2sivnx1si */
    case 5602:  /* pred_reduc_maxuvnx2sivnx1si */
    case 5601:  /* pred_reduc_sumvnx2sivnx1si */
    case 5600:  /* pred_reduc_xorvnx1sivnx1si */
    case 5599:  /* pred_reduc_orvnx1sivnx1si */
    case 5598:  /* pred_reduc_andvnx1sivnx1si */
    case 5597:  /* pred_reduc_minvnx1sivnx1si */
    case 5596:  /* pred_reduc_minuvnx1sivnx1si */
    case 5595:  /* pred_reduc_maxvnx1sivnx1si */
    case 5594:  /* pred_reduc_maxuvnx1sivnx1si */
    case 5593:  /* pred_reduc_sumvnx1sivnx1si */
    case 5592:  /* pred_reduc_xorvnx16hivnx2hi */
    case 5591:  /* pred_reduc_orvnx16hivnx2hi */
    case 5590:  /* pred_reduc_andvnx16hivnx2hi */
    case 5589:  /* pred_reduc_minvnx16hivnx2hi */
    case 5588:  /* pred_reduc_minuvnx16hivnx2hi */
    case 5587:  /* pred_reduc_maxvnx16hivnx2hi */
    case 5586:  /* pred_reduc_maxuvnx16hivnx2hi */
    case 5585:  /* pred_reduc_sumvnx16hivnx2hi */
    case 5584:  /* pred_reduc_xorvnx8hivnx2hi */
    case 5583:  /* pred_reduc_orvnx8hivnx2hi */
    case 5582:  /* pred_reduc_andvnx8hivnx2hi */
    case 5581:  /* pred_reduc_minvnx8hivnx2hi */
    case 5580:  /* pred_reduc_minuvnx8hivnx2hi */
    case 5579:  /* pred_reduc_maxvnx8hivnx2hi */
    case 5578:  /* pred_reduc_maxuvnx8hivnx2hi */
    case 5577:  /* pred_reduc_sumvnx8hivnx2hi */
    case 5576:  /* pred_reduc_xorvnx4hivnx2hi */
    case 5575:  /* pred_reduc_orvnx4hivnx2hi */
    case 5574:  /* pred_reduc_andvnx4hivnx2hi */
    case 5573:  /* pred_reduc_minvnx4hivnx2hi */
    case 5572:  /* pred_reduc_minuvnx4hivnx2hi */
    case 5571:  /* pred_reduc_maxvnx4hivnx2hi */
    case 5570:  /* pred_reduc_maxuvnx4hivnx2hi */
    case 5569:  /* pred_reduc_sumvnx4hivnx2hi */
    case 5568:  /* pred_reduc_xorvnx2hivnx2hi */
    case 5567:  /* pred_reduc_orvnx2hivnx2hi */
    case 5566:  /* pred_reduc_andvnx2hivnx2hi */
    case 5565:  /* pred_reduc_minvnx2hivnx2hi */
    case 5564:  /* pred_reduc_minuvnx2hivnx2hi */
    case 5563:  /* pred_reduc_maxvnx2hivnx2hi */
    case 5562:  /* pred_reduc_maxuvnx2hivnx2hi */
    case 5561:  /* pred_reduc_sumvnx2hivnx2hi */
    case 5560:  /* pred_reduc_xorvnx1hivnx2hi */
    case 5559:  /* pred_reduc_orvnx1hivnx2hi */
    case 5558:  /* pred_reduc_andvnx1hivnx2hi */
    case 5557:  /* pred_reduc_minvnx1hivnx2hi */
    case 5556:  /* pred_reduc_minuvnx1hivnx2hi */
    case 5555:  /* pred_reduc_maxvnx1hivnx2hi */
    case 5554:  /* pred_reduc_maxuvnx1hivnx2hi */
    case 5553:  /* pred_reduc_sumvnx1hivnx2hi */
    case 5552:  /* pred_reduc_xorvnx32qivnx4qi */
    case 5551:  /* pred_reduc_orvnx32qivnx4qi */
    case 5550:  /* pred_reduc_andvnx32qivnx4qi */
    case 5549:  /* pred_reduc_minvnx32qivnx4qi */
    case 5548:  /* pred_reduc_minuvnx32qivnx4qi */
    case 5547:  /* pred_reduc_maxvnx32qivnx4qi */
    case 5546:  /* pred_reduc_maxuvnx32qivnx4qi */
    case 5545:  /* pred_reduc_sumvnx32qivnx4qi */
    case 5544:  /* pred_reduc_xorvnx16qivnx4qi */
    case 5543:  /* pred_reduc_orvnx16qivnx4qi */
    case 5542:  /* pred_reduc_andvnx16qivnx4qi */
    case 5541:  /* pred_reduc_minvnx16qivnx4qi */
    case 5540:  /* pred_reduc_minuvnx16qivnx4qi */
    case 5539:  /* pred_reduc_maxvnx16qivnx4qi */
    case 5538:  /* pred_reduc_maxuvnx16qivnx4qi */
    case 5537:  /* pred_reduc_sumvnx16qivnx4qi */
    case 5536:  /* pred_reduc_xorvnx8qivnx4qi */
    case 5535:  /* pred_reduc_orvnx8qivnx4qi */
    case 5534:  /* pred_reduc_andvnx8qivnx4qi */
    case 5533:  /* pred_reduc_minvnx8qivnx4qi */
    case 5532:  /* pred_reduc_minuvnx8qivnx4qi */
    case 5531:  /* pred_reduc_maxvnx8qivnx4qi */
    case 5530:  /* pred_reduc_maxuvnx8qivnx4qi */
    case 5529:  /* pred_reduc_sumvnx8qivnx4qi */
    case 5528:  /* pred_reduc_xorvnx4qivnx4qi */
    case 5527:  /* pred_reduc_orvnx4qivnx4qi */
    case 5526:  /* pred_reduc_andvnx4qivnx4qi */
    case 5525:  /* pred_reduc_minvnx4qivnx4qi */
    case 5524:  /* pred_reduc_minuvnx4qivnx4qi */
    case 5523:  /* pred_reduc_maxvnx4qivnx4qi */
    case 5522:  /* pred_reduc_maxuvnx4qivnx4qi */
    case 5521:  /* pred_reduc_sumvnx4qivnx4qi */
    case 5520:  /* pred_reduc_xorvnx2qivnx4qi */
    case 5519:  /* pred_reduc_orvnx2qivnx4qi */
    case 5518:  /* pred_reduc_andvnx2qivnx4qi */
    case 5517:  /* pred_reduc_minvnx2qivnx4qi */
    case 5516:  /* pred_reduc_minuvnx2qivnx4qi */
    case 5515:  /* pred_reduc_maxvnx2qivnx4qi */
    case 5514:  /* pred_reduc_maxuvnx2qivnx4qi */
    case 5513:  /* pred_reduc_sumvnx2qivnx4qi */
    case 5512:  /* pred_reduc_xorvnx1qivnx4qi */
    case 5511:  /* pred_reduc_orvnx1qivnx4qi */
    case 5510:  /* pred_reduc_andvnx1qivnx4qi */
    case 5509:  /* pred_reduc_minvnx1qivnx4qi */
    case 5508:  /* pred_reduc_minuvnx1qivnx4qi */
    case 5507:  /* pred_reduc_maxvnx1qivnx4qi */
    case 5506:  /* pred_reduc_maxuvnx1qivnx4qi */
    case 5505:  /* pred_reduc_sumvnx1qivnx4qi */
    case 5504:  /* pred_reduc_xorvnx8divnx1DI */
    case 5503:  /* pred_reduc_orvnx8divnx1DI */
    case 5502:  /* pred_reduc_andvnx8divnx1DI */
    case 5501:  /* pred_reduc_minvnx8divnx1DI */
    case 5500:  /* pred_reduc_minuvnx8divnx1DI */
    case 5499:  /* pred_reduc_maxvnx8divnx1DI */
    case 5498:  /* pred_reduc_maxuvnx8divnx1DI */
    case 5497:  /* pred_reduc_sumvnx8divnx1DI */
    case 5496:  /* pred_reduc_xorvnx4divnx1DI */
    case 5495:  /* pred_reduc_orvnx4divnx1DI */
    case 5494:  /* pred_reduc_andvnx4divnx1DI */
    case 5493:  /* pred_reduc_minvnx4divnx1DI */
    case 5492:  /* pred_reduc_minuvnx4divnx1DI */
    case 5491:  /* pred_reduc_maxvnx4divnx1DI */
    case 5490:  /* pred_reduc_maxuvnx4divnx1DI */
    case 5489:  /* pred_reduc_sumvnx4divnx1DI */
    case 5488:  /* pred_reduc_xorvnx2divnx1DI */
    case 5487:  /* pred_reduc_orvnx2divnx1DI */
    case 5486:  /* pred_reduc_andvnx2divnx1DI */
    case 5485:  /* pred_reduc_minvnx2divnx1DI */
    case 5484:  /* pred_reduc_minuvnx2divnx1DI */
    case 5483:  /* pred_reduc_maxvnx2divnx1DI */
    case 5482:  /* pred_reduc_maxuvnx2divnx1DI */
    case 5481:  /* pred_reduc_sumvnx2divnx1DI */
    case 5480:  /* pred_reduc_xorvnx1divnx1DI */
    case 5479:  /* pred_reduc_orvnx1divnx1DI */
    case 5478:  /* pred_reduc_andvnx1divnx1DI */
    case 5477:  /* pred_reduc_minvnx1divnx1DI */
    case 5476:  /* pred_reduc_minuvnx1divnx1DI */
    case 5475:  /* pred_reduc_maxvnx1divnx1DI */
    case 5474:  /* pred_reduc_maxuvnx1divnx1DI */
    case 5473:  /* pred_reduc_sumvnx1divnx1DI */
    case 5472:  /* pred_reduc_xorvnx16sivnx2si */
    case 5471:  /* pred_reduc_orvnx16sivnx2si */
    case 5470:  /* pred_reduc_andvnx16sivnx2si */
    case 5469:  /* pred_reduc_minvnx16sivnx2si */
    case 5468:  /* pred_reduc_minuvnx16sivnx2si */
    case 5467:  /* pred_reduc_maxvnx16sivnx2si */
    case 5466:  /* pred_reduc_maxuvnx16sivnx2si */
    case 5465:  /* pred_reduc_sumvnx16sivnx2si */
    case 5464:  /* pred_reduc_xorvnx8sivnx2si */
    case 5463:  /* pred_reduc_orvnx8sivnx2si */
    case 5462:  /* pred_reduc_andvnx8sivnx2si */
    case 5461:  /* pred_reduc_minvnx8sivnx2si */
    case 5460:  /* pred_reduc_minuvnx8sivnx2si */
    case 5459:  /* pred_reduc_maxvnx8sivnx2si */
    case 5458:  /* pred_reduc_maxuvnx8sivnx2si */
    case 5457:  /* pred_reduc_sumvnx8sivnx2si */
    case 5456:  /* pred_reduc_xorvnx4sivnx2si */
    case 5455:  /* pred_reduc_orvnx4sivnx2si */
    case 5454:  /* pred_reduc_andvnx4sivnx2si */
    case 5453:  /* pred_reduc_minvnx4sivnx2si */
    case 5452:  /* pred_reduc_minuvnx4sivnx2si */
    case 5451:  /* pred_reduc_maxvnx4sivnx2si */
    case 5450:  /* pred_reduc_maxuvnx4sivnx2si */
    case 5449:  /* pred_reduc_sumvnx4sivnx2si */
    case 5448:  /* pred_reduc_xorvnx2sivnx2si */
    case 5447:  /* pred_reduc_orvnx2sivnx2si */
    case 5446:  /* pred_reduc_andvnx2sivnx2si */
    case 5445:  /* pred_reduc_minvnx2sivnx2si */
    case 5444:  /* pred_reduc_minuvnx2sivnx2si */
    case 5443:  /* pred_reduc_maxvnx2sivnx2si */
    case 5442:  /* pred_reduc_maxuvnx2sivnx2si */
    case 5441:  /* pred_reduc_sumvnx2sivnx2si */
    case 5440:  /* pred_reduc_xorvnx1sivnx2si */
    case 5439:  /* pred_reduc_orvnx1sivnx2si */
    case 5438:  /* pred_reduc_andvnx1sivnx2si */
    case 5437:  /* pred_reduc_minvnx1sivnx2si */
    case 5436:  /* pred_reduc_minuvnx1sivnx2si */
    case 5435:  /* pred_reduc_maxvnx1sivnx2si */
    case 5434:  /* pred_reduc_maxuvnx1sivnx2si */
    case 5433:  /* pred_reduc_sumvnx1sivnx2si */
    case 5432:  /* pred_reduc_xorvnx32hivnx4hi */
    case 5431:  /* pred_reduc_orvnx32hivnx4hi */
    case 5430:  /* pred_reduc_andvnx32hivnx4hi */
    case 5429:  /* pred_reduc_minvnx32hivnx4hi */
    case 5428:  /* pred_reduc_minuvnx32hivnx4hi */
    case 5427:  /* pred_reduc_maxvnx32hivnx4hi */
    case 5426:  /* pred_reduc_maxuvnx32hivnx4hi */
    case 5425:  /* pred_reduc_sumvnx32hivnx4hi */
    case 5424:  /* pred_reduc_xorvnx16hivnx4hi */
    case 5423:  /* pred_reduc_orvnx16hivnx4hi */
    case 5422:  /* pred_reduc_andvnx16hivnx4hi */
    case 5421:  /* pred_reduc_minvnx16hivnx4hi */
    case 5420:  /* pred_reduc_minuvnx16hivnx4hi */
    case 5419:  /* pred_reduc_maxvnx16hivnx4hi */
    case 5418:  /* pred_reduc_maxuvnx16hivnx4hi */
    case 5417:  /* pred_reduc_sumvnx16hivnx4hi */
    case 5416:  /* pred_reduc_xorvnx8hivnx4hi */
    case 5415:  /* pred_reduc_orvnx8hivnx4hi */
    case 5414:  /* pred_reduc_andvnx8hivnx4hi */
    case 5413:  /* pred_reduc_minvnx8hivnx4hi */
    case 5412:  /* pred_reduc_minuvnx8hivnx4hi */
    case 5411:  /* pred_reduc_maxvnx8hivnx4hi */
    case 5410:  /* pred_reduc_maxuvnx8hivnx4hi */
    case 5409:  /* pred_reduc_sumvnx8hivnx4hi */
    case 5408:  /* pred_reduc_xorvnx4hivnx4hi */
    case 5407:  /* pred_reduc_orvnx4hivnx4hi */
    case 5406:  /* pred_reduc_andvnx4hivnx4hi */
    case 5405:  /* pred_reduc_minvnx4hivnx4hi */
    case 5404:  /* pred_reduc_minuvnx4hivnx4hi */
    case 5403:  /* pred_reduc_maxvnx4hivnx4hi */
    case 5402:  /* pred_reduc_maxuvnx4hivnx4hi */
    case 5401:  /* pred_reduc_sumvnx4hivnx4hi */
    case 5400:  /* pred_reduc_xorvnx2hivnx4hi */
    case 5399:  /* pred_reduc_orvnx2hivnx4hi */
    case 5398:  /* pred_reduc_andvnx2hivnx4hi */
    case 5397:  /* pred_reduc_minvnx2hivnx4hi */
    case 5396:  /* pred_reduc_minuvnx2hivnx4hi */
    case 5395:  /* pred_reduc_maxvnx2hivnx4hi */
    case 5394:  /* pred_reduc_maxuvnx2hivnx4hi */
    case 5393:  /* pred_reduc_sumvnx2hivnx4hi */
    case 5392:  /* pred_reduc_xorvnx1hivnx4hi */
    case 5391:  /* pred_reduc_orvnx1hivnx4hi */
    case 5390:  /* pred_reduc_andvnx1hivnx4hi */
    case 5389:  /* pred_reduc_minvnx1hivnx4hi */
    case 5388:  /* pred_reduc_minuvnx1hivnx4hi */
    case 5387:  /* pred_reduc_maxvnx1hivnx4hi */
    case 5386:  /* pred_reduc_maxuvnx1hivnx4hi */
    case 5385:  /* pred_reduc_sumvnx1hivnx4hi */
    case 5384:  /* pred_reduc_xorvnx64qivnx8qi */
    case 5383:  /* pred_reduc_orvnx64qivnx8qi */
    case 5382:  /* pred_reduc_andvnx64qivnx8qi */
    case 5381:  /* pred_reduc_minvnx64qivnx8qi */
    case 5380:  /* pred_reduc_minuvnx64qivnx8qi */
    case 5379:  /* pred_reduc_maxvnx64qivnx8qi */
    case 5378:  /* pred_reduc_maxuvnx64qivnx8qi */
    case 5377:  /* pred_reduc_sumvnx64qivnx8qi */
    case 5376:  /* pred_reduc_xorvnx32qivnx8qi */
    case 5375:  /* pred_reduc_orvnx32qivnx8qi */
    case 5374:  /* pred_reduc_andvnx32qivnx8qi */
    case 5373:  /* pred_reduc_minvnx32qivnx8qi */
    case 5372:  /* pred_reduc_minuvnx32qivnx8qi */
    case 5371:  /* pred_reduc_maxvnx32qivnx8qi */
    case 5370:  /* pred_reduc_maxuvnx32qivnx8qi */
    case 5369:  /* pred_reduc_sumvnx32qivnx8qi */
    case 5368:  /* pred_reduc_xorvnx16qivnx8qi */
    case 5367:  /* pred_reduc_orvnx16qivnx8qi */
    case 5366:  /* pred_reduc_andvnx16qivnx8qi */
    case 5365:  /* pred_reduc_minvnx16qivnx8qi */
    case 5364:  /* pred_reduc_minuvnx16qivnx8qi */
    case 5363:  /* pred_reduc_maxvnx16qivnx8qi */
    case 5362:  /* pred_reduc_maxuvnx16qivnx8qi */
    case 5361:  /* pred_reduc_sumvnx16qivnx8qi */
    case 5360:  /* pred_reduc_xorvnx8qivnx8qi */
    case 5359:  /* pred_reduc_orvnx8qivnx8qi */
    case 5358:  /* pred_reduc_andvnx8qivnx8qi */
    case 5357:  /* pred_reduc_minvnx8qivnx8qi */
    case 5356:  /* pred_reduc_minuvnx8qivnx8qi */
    case 5355:  /* pred_reduc_maxvnx8qivnx8qi */
    case 5354:  /* pred_reduc_maxuvnx8qivnx8qi */
    case 5353:  /* pred_reduc_sumvnx8qivnx8qi */
    case 5352:  /* pred_reduc_xorvnx4qivnx8qi */
    case 5351:  /* pred_reduc_orvnx4qivnx8qi */
    case 5350:  /* pred_reduc_andvnx4qivnx8qi */
    case 5349:  /* pred_reduc_minvnx4qivnx8qi */
    case 5348:  /* pred_reduc_minuvnx4qivnx8qi */
    case 5347:  /* pred_reduc_maxvnx4qivnx8qi */
    case 5346:  /* pred_reduc_maxuvnx4qivnx8qi */
    case 5345:  /* pred_reduc_sumvnx4qivnx8qi */
    case 5344:  /* pred_reduc_xorvnx2qivnx8qi */
    case 5343:  /* pred_reduc_orvnx2qivnx8qi */
    case 5342:  /* pred_reduc_andvnx2qivnx8qi */
    case 5341:  /* pred_reduc_minvnx2qivnx8qi */
    case 5340:  /* pred_reduc_minuvnx2qivnx8qi */
    case 5339:  /* pred_reduc_maxvnx2qivnx8qi */
    case 5338:  /* pred_reduc_maxuvnx2qivnx8qi */
    case 5337:  /* pred_reduc_sumvnx2qivnx8qi */
    case 5336:  /* pred_reduc_xorvnx1qivnx8qi */
    case 5335:  /* pred_reduc_orvnx1qivnx8qi */
    case 5334:  /* pred_reduc_andvnx1qivnx8qi */
    case 5333:  /* pred_reduc_minvnx1qivnx8qi */
    case 5332:  /* pred_reduc_minuvnx1qivnx8qi */
    case 5331:  /* pred_reduc_maxvnx1qivnx8qi */
    case 5330:  /* pred_reduc_maxuvnx1qivnx8qi */
    case 5329:  /* pred_reduc_sumvnx1qivnx8qi */
    case 5184:  /* pred_mergevnx8df_scalar */
    case 5183:  /* pred_mergevnx4df_scalar */
    case 5182:  /* pred_mergevnx2df_scalar */
    case 5181:  /* pred_mergevnx1df_scalar */
    case 5180:  /* pred_mergevnx16sf_scalar */
    case 5179:  /* pred_mergevnx8sf_scalar */
    case 5178:  /* pred_mergevnx4sf_scalar */
    case 5177:  /* pred_mergevnx2sf_scalar */
    case 5176:  /* pred_mergevnx1sf_scalar */
    case 4534:  /* pred_ffsvnx64bidi */
    case 4533:  /* pred_ffsvnx32bidi */
    case 4532:  /* pred_ffsvnx16bidi */
    case 4531:  /* pred_ffsvnx8bidi */
    case 4530:  /* pred_ffsvnx4bidi */
    case 4529:  /* pred_ffsvnx2bidi */
    case 4528:  /* pred_ffsvnx1bidi */
    case 4527:  /* pred_ffsvnx64bisi */
    case 4526:  /* pred_ffsvnx32bisi */
    case 4525:  /* pred_ffsvnx16bisi */
    case 4524:  /* pred_ffsvnx8bisi */
    case 4523:  /* pred_ffsvnx4bisi */
    case 4522:  /* pred_ffsvnx2bisi */
    case 4521:  /* pred_ffsvnx1bisi */
    case 4520:  /* pred_popcountvnx64bidi */
    case 4519:  /* pred_popcountvnx32bidi */
    case 4518:  /* pred_popcountvnx16bidi */
    case 4517:  /* pred_popcountvnx8bidi */
    case 4516:  /* pred_popcountvnx4bidi */
    case 4515:  /* pred_popcountvnx2bidi */
    case 4514:  /* pred_popcountvnx1bidi */
    case 4513:  /* pred_popcountvnx64bisi */
    case 4512:  /* pred_popcountvnx32bisi */
    case 4511:  /* pred_popcountvnx16bisi */
    case 4510:  /* pred_popcountvnx8bisi */
    case 4509:  /* pred_popcountvnx4bisi */
    case 4508:  /* pred_popcountvnx2bisi */
    case 4507:  /* pred_popcountvnx1bisi */
    case 4506:  /* pred_notvnx64bi */
    case 4505:  /* pred_notvnx32bi */
    case 4504:  /* pred_notvnx16bi */
    case 4503:  /* pred_notvnx8bi */
    case 4502:  /* pred_notvnx4bi */
    case 4501:  /* pred_notvnx2bi */
    case 4500:  /* pred_notvnx1bi */
    case 4499:  /* pred_iornotvnx64bi */
    case 4498:  /* pred_andnotvnx64bi */
    case 4497:  /* pred_iornotvnx32bi */
    case 4496:  /* pred_andnotvnx32bi */
    case 4495:  /* pred_iornotvnx16bi */
    case 4494:  /* pred_andnotvnx16bi */
    case 4493:  /* pred_iornotvnx8bi */
    case 4492:  /* pred_andnotvnx8bi */
    case 4491:  /* pred_iornotvnx4bi */
    case 4490:  /* pred_andnotvnx4bi */
    case 4489:  /* pred_iornotvnx2bi */
    case 4488:  /* pred_andnotvnx2bi */
    case 4487:  /* pred_iornotvnx1bi */
    case 4486:  /* pred_andnotvnx1bi */
    case 4485:  /* pred_nxorvnx64bi */
    case 4484:  /* pred_niorvnx64bi */
    case 4483:  /* pred_nandvnx64bi */
    case 4482:  /* pred_nxorvnx32bi */
    case 4481:  /* pred_niorvnx32bi */
    case 4480:  /* pred_nandvnx32bi */
    case 4479:  /* pred_nxorvnx16bi */
    case 4478:  /* pred_niorvnx16bi */
    case 4477:  /* pred_nandvnx16bi */
    case 4476:  /* pred_nxorvnx8bi */
    case 4475:  /* pred_niorvnx8bi */
    case 4474:  /* pred_nandvnx8bi */
    case 4473:  /* pred_nxorvnx4bi */
    case 4472:  /* pred_niorvnx4bi */
    case 4471:  /* pred_nandvnx4bi */
    case 4470:  /* pred_nxorvnx2bi */
    case 4469:  /* pred_niorvnx2bi */
    case 4468:  /* pred_nandvnx2bi */
    case 4467:  /* pred_nxorvnx1bi */
    case 4466:  /* pred_niorvnx1bi */
    case 4465:  /* pred_nandvnx1bi */
    case 4464:  /* pred_xorvnx64bi */
    case 4463:  /* pred_iorvnx64bi */
    case 4462:  /* pred_andvnx64bi */
    case 4461:  /* pred_xorvnx32bi */
    case 4460:  /* pred_iorvnx32bi */
    case 4459:  /* pred_andvnx32bi */
    case 4458:  /* pred_xorvnx16bi */
    case 4457:  /* pred_iorvnx16bi */
    case 4456:  /* pred_andvnx16bi */
    case 4455:  /* pred_xorvnx8bi */
    case 4454:  /* pred_iorvnx8bi */
    case 4453:  /* pred_andvnx8bi */
    case 4452:  /* pred_xorvnx4bi */
    case 4451:  /* pred_iorvnx4bi */
    case 4450:  /* pred_andvnx4bi */
    case 4449:  /* pred_xorvnx2bi */
    case 4448:  /* pred_iorvnx2bi */
    case 4447:  /* pred_andvnx2bi */
    case 4446:  /* pred_xorvnx1bi */
    case 4445:  /* pred_iorvnx1bi */
    case 4444:  /* pred_andvnx1bi */
    case 2743:  /* *pred_msbcvnx8di_overflow_extended_scalar */
    case 2742:  /* *pred_msbcvnx4di_overflow_extended_scalar */
    case 2741:  /* *pred_msbcvnx2di_overflow_extended_scalar */
    case 2740:  /* *pred_msbcvnx1di_overflow_extended_scalar */
    case 2739:  /* *pred_msbcvnx8di_overflow_scalar */
    case 2738:  /* *pred_msbcvnx4di_overflow_scalar */
    case 2737:  /* *pred_msbcvnx2di_overflow_scalar */
    case 2736:  /* *pred_msbcvnx1di_overflow_scalar */
    case 2735:  /* *pred_madcvnx8di_overflow_extended_scalar */
    case 2734:  /* *pred_madcvnx4di_overflow_extended_scalar */
    case 2733:  /* *pred_madcvnx2di_overflow_extended_scalar */
    case 2732:  /* *pred_madcvnx1di_overflow_extended_scalar */
    case 2731:  /* *pred_madcvnx8di_overflow_scalar */
    case 2730:  /* *pred_madcvnx4di_overflow_scalar */
    case 2729:  /* *pred_madcvnx2di_overflow_scalar */
    case 2728:  /* *pred_madcvnx1di_overflow_scalar */
    case 2727:  /* pred_msbcvnx16si_overflow_scalar */
    case 2726:  /* pred_msbcvnx8si_overflow_scalar */
    case 2725:  /* pred_msbcvnx4si_overflow_scalar */
    case 2724:  /* pred_msbcvnx2si_overflow_scalar */
    case 2723:  /* pred_msbcvnx1si_overflow_scalar */
    case 2722:  /* pred_msbcvnx32hi_overflow_scalar */
    case 2721:  /* pred_msbcvnx16hi_overflow_scalar */
    case 2720:  /* pred_msbcvnx8hi_overflow_scalar */
    case 2719:  /* pred_msbcvnx4hi_overflow_scalar */
    case 2718:  /* pred_msbcvnx2hi_overflow_scalar */
    case 2717:  /* pred_msbcvnx1hi_overflow_scalar */
    case 2716:  /* pred_msbcvnx64qi_overflow_scalar */
    case 2715:  /* pred_msbcvnx32qi_overflow_scalar */
    case 2714:  /* pred_msbcvnx16qi_overflow_scalar */
    case 2713:  /* pred_msbcvnx8qi_overflow_scalar */
    case 2712:  /* pred_msbcvnx4qi_overflow_scalar */
    case 2711:  /* pred_msbcvnx2qi_overflow_scalar */
    case 2710:  /* pred_msbcvnx1qi_overflow_scalar */
    case 2709:  /* pred_madcvnx16si_overflow_scalar */
    case 2708:  /* pred_madcvnx8si_overflow_scalar */
    case 2707:  /* pred_madcvnx4si_overflow_scalar */
    case 2706:  /* pred_madcvnx2si_overflow_scalar */
    case 2705:  /* pred_madcvnx1si_overflow_scalar */
    case 2704:  /* pred_madcvnx32hi_overflow_scalar */
    case 2703:  /* pred_madcvnx16hi_overflow_scalar */
    case 2702:  /* pred_madcvnx8hi_overflow_scalar */
    case 2701:  /* pred_madcvnx4hi_overflow_scalar */
    case 2700:  /* pred_madcvnx2hi_overflow_scalar */
    case 2699:  /* pred_madcvnx1hi_overflow_scalar */
    case 2698:  /* pred_madcvnx64qi_overflow_scalar */
    case 2697:  /* pred_madcvnx32qi_overflow_scalar */
    case 2696:  /* pred_madcvnx16qi_overflow_scalar */
    case 2695:  /* pred_madcvnx8qi_overflow_scalar */
    case 2694:  /* pred_madcvnx4qi_overflow_scalar */
    case 2693:  /* pred_madcvnx2qi_overflow_scalar */
    case 2692:  /* pred_madcvnx1qi_overflow_scalar */
    case 2691:  /* pred_msbcvnx8di_overflow */
    case 2690:  /* pred_msbcvnx4di_overflow */
    case 2689:  /* pred_msbcvnx2di_overflow */
    case 2688:  /* pred_msbcvnx1di_overflow */
    case 2687:  /* pred_msbcvnx16si_overflow */
    case 2686:  /* pred_msbcvnx8si_overflow */
    case 2685:  /* pred_msbcvnx4si_overflow */
    case 2684:  /* pred_msbcvnx2si_overflow */
    case 2683:  /* pred_msbcvnx1si_overflow */
    case 2682:  /* pred_msbcvnx32hi_overflow */
    case 2681:  /* pred_msbcvnx16hi_overflow */
    case 2680:  /* pred_msbcvnx8hi_overflow */
    case 2679:  /* pred_msbcvnx4hi_overflow */
    case 2678:  /* pred_msbcvnx2hi_overflow */
    case 2677:  /* pred_msbcvnx1hi_overflow */
    case 2676:  /* pred_msbcvnx64qi_overflow */
    case 2675:  /* pred_msbcvnx32qi_overflow */
    case 2674:  /* pred_msbcvnx16qi_overflow */
    case 2673:  /* pred_msbcvnx8qi_overflow */
    case 2672:  /* pred_msbcvnx4qi_overflow */
    case 2671:  /* pred_msbcvnx2qi_overflow */
    case 2670:  /* pred_msbcvnx1qi_overflow */
    case 2669:  /* pred_madcvnx8di_overflow */
    case 2668:  /* pred_madcvnx4di_overflow */
    case 2667:  /* pred_madcvnx2di_overflow */
    case 2666:  /* pred_madcvnx1di_overflow */
    case 2665:  /* pred_madcvnx16si_overflow */
    case 2664:  /* pred_madcvnx8si_overflow */
    case 2663:  /* pred_madcvnx4si_overflow */
    case 2662:  /* pred_madcvnx2si_overflow */
    case 2661:  /* pred_madcvnx1si_overflow */
    case 2660:  /* pred_madcvnx32hi_overflow */
    case 2659:  /* pred_madcvnx16hi_overflow */
    case 2658:  /* pred_madcvnx8hi_overflow */
    case 2657:  /* pred_madcvnx4hi_overflow */
    case 2656:  /* pred_madcvnx2hi_overflow */
    case 2655:  /* pred_madcvnx1hi_overflow */
    case 2654:  /* pred_madcvnx64qi_overflow */
    case 2653:  /* pred_madcvnx32qi_overflow */
    case 2652:  /* pred_madcvnx16qi_overflow */
    case 2651:  /* pred_madcvnx8qi_overflow */
    case 2650:  /* pred_madcvnx4qi_overflow */
    case 2649:  /* pred_madcvnx2qi_overflow */
    case 2648:  /* pred_madcvnx1qi_overflow */
    case 2647:  /* *pred_msbcvnx8di_extended_scalar */
    case 2646:  /* *pred_msbcvnx4di_extended_scalar */
    case 2645:  /* *pred_msbcvnx2di_extended_scalar */
    case 2644:  /* *pred_msbcvnx1di_extended_scalar */
    case 2643:  /* *pred_msbcvnx8di_scalar */
    case 2642:  /* *pred_msbcvnx4di_scalar */
    case 2641:  /* *pred_msbcvnx2di_scalar */
    case 2640:  /* *pred_msbcvnx1di_scalar */
    case 2639:  /* *pred_madcvnx8di_extended_scalar */
    case 2638:  /* *pred_madcvnx4di_extended_scalar */
    case 2637:  /* *pred_madcvnx2di_extended_scalar */
    case 2636:  /* *pred_madcvnx1di_extended_scalar */
    case 2635:  /* *pred_madcvnx8di_scalar */
    case 2634:  /* *pred_madcvnx4di_scalar */
    case 2633:  /* *pred_madcvnx2di_scalar */
    case 2632:  /* *pred_madcvnx1di_scalar */
    case 2631:  /* pred_msbcvnx16si_scalar */
    case 2630:  /* pred_msbcvnx8si_scalar */
    case 2629:  /* pred_msbcvnx4si_scalar */
    case 2628:  /* pred_msbcvnx2si_scalar */
    case 2627:  /* pred_msbcvnx1si_scalar */
    case 2626:  /* pred_msbcvnx32hi_scalar */
    case 2625:  /* pred_msbcvnx16hi_scalar */
    case 2624:  /* pred_msbcvnx8hi_scalar */
    case 2623:  /* pred_msbcvnx4hi_scalar */
    case 2622:  /* pred_msbcvnx2hi_scalar */
    case 2621:  /* pred_msbcvnx1hi_scalar */
    case 2620:  /* pred_msbcvnx64qi_scalar */
    case 2619:  /* pred_msbcvnx32qi_scalar */
    case 2618:  /* pred_msbcvnx16qi_scalar */
    case 2617:  /* pred_msbcvnx8qi_scalar */
    case 2616:  /* pred_msbcvnx4qi_scalar */
    case 2615:  /* pred_msbcvnx2qi_scalar */
    case 2614:  /* pred_msbcvnx1qi_scalar */
    case 2613:  /* pred_madcvnx16si_scalar */
    case 2612:  /* pred_madcvnx8si_scalar */
    case 2611:  /* pred_madcvnx4si_scalar */
    case 2610:  /* pred_madcvnx2si_scalar */
    case 2609:  /* pred_madcvnx1si_scalar */
    case 2608:  /* pred_madcvnx32hi_scalar */
    case 2607:  /* pred_madcvnx16hi_scalar */
    case 2606:  /* pred_madcvnx8hi_scalar */
    case 2605:  /* pred_madcvnx4hi_scalar */
    case 2604:  /* pred_madcvnx2hi_scalar */
    case 2603:  /* pred_madcvnx1hi_scalar */
    case 2602:  /* pred_madcvnx64qi_scalar */
    case 2601:  /* pred_madcvnx32qi_scalar */
    case 2600:  /* pred_madcvnx16qi_scalar */
    case 2599:  /* pred_madcvnx8qi_scalar */
    case 2598:  /* pred_madcvnx4qi_scalar */
    case 2597:  /* pred_madcvnx2qi_scalar */
    case 2596:  /* pred_madcvnx1qi_scalar */
    case 2595:  /* pred_msbcvnx8di */
    case 2594:  /* pred_msbcvnx4di */
    case 2593:  /* pred_msbcvnx2di */
    case 2592:  /* pred_msbcvnx1di */
    case 2591:  /* pred_msbcvnx16si */
    case 2590:  /* pred_msbcvnx8si */
    case 2589:  /* pred_msbcvnx4si */
    case 2588:  /* pred_msbcvnx2si */
    case 2587:  /* pred_msbcvnx1si */
    case 2586:  /* pred_msbcvnx32hi */
    case 2585:  /* pred_msbcvnx16hi */
    case 2584:  /* pred_msbcvnx8hi */
    case 2583:  /* pred_msbcvnx4hi */
    case 2582:  /* pred_msbcvnx2hi */
    case 2581:  /* pred_msbcvnx1hi */
    case 2580:  /* pred_msbcvnx64qi */
    case 2579:  /* pred_msbcvnx32qi */
    case 2578:  /* pred_msbcvnx16qi */
    case 2577:  /* pred_msbcvnx8qi */
    case 2576:  /* pred_msbcvnx4qi */
    case 2575:  /* pred_msbcvnx2qi */
    case 2574:  /* pred_msbcvnx1qi */
    case 2573:  /* pred_madcvnx8di */
    case 2572:  /* pred_madcvnx4di */
    case 2571:  /* pred_madcvnx2di */
    case 2570:  /* pred_madcvnx1di */
    case 2569:  /* pred_madcvnx16si */
    case 2568:  /* pred_madcvnx8si */
    case 2567:  /* pred_madcvnx4si */
    case 2566:  /* pred_madcvnx2si */
    case 2565:  /* pred_madcvnx1si */
    case 2564:  /* pred_madcvnx32hi */
    case 2563:  /* pred_madcvnx16hi */
    case 2562:  /* pred_madcvnx8hi */
    case 2561:  /* pred_madcvnx4hi */
    case 2560:  /* pred_madcvnx2hi */
    case 2559:  /* pred_madcvnx1hi */
    case 2558:  /* pred_madcvnx64qi */
    case 2557:  /* pred_madcvnx32qi */
    case 2556:  /* pred_madcvnx16qi */
    case 2555:  /* pred_madcvnx8qi */
    case 2554:  /* pred_madcvnx4qi */
    case 2553:  /* pred_madcvnx2qi */
    case 2552:  /* pred_madcvnx1qi */
    case 2551:  /* *pred_sbcvnx8di_extended_scalar */
    case 2550:  /* *pred_sbcvnx4di_extended_scalar */
    case 2549:  /* *pred_sbcvnx2di_extended_scalar */
    case 2548:  /* *pred_sbcvnx1di_extended_scalar */
    case 2547:  /* *pred_sbcvnx8di_scalar */
    case 2546:  /* *pred_sbcvnx4di_scalar */
    case 2545:  /* *pred_sbcvnx2di_scalar */
    case 2544:  /* *pred_sbcvnx1di_scalar */
    case 2543:  /* *pred_adcvnx8di_extended_scalar */
    case 2542:  /* *pred_adcvnx4di_extended_scalar */
    case 2541:  /* *pred_adcvnx2di_extended_scalar */
    case 2540:  /* *pred_adcvnx1di_extended_scalar */
    case 2539:  /* *pred_adcvnx8di_scalar */
    case 2538:  /* *pred_adcvnx4di_scalar */
    case 2537:  /* *pred_adcvnx2di_scalar */
    case 2536:  /* *pred_adcvnx1di_scalar */
    case 2535:  /* pred_sbcvnx16si_scalar */
    case 2534:  /* pred_sbcvnx8si_scalar */
    case 2533:  /* pred_sbcvnx4si_scalar */
    case 2532:  /* pred_sbcvnx2si_scalar */
    case 2531:  /* pred_sbcvnx1si_scalar */
    case 2530:  /* pred_sbcvnx32hi_scalar */
    case 2529:  /* pred_sbcvnx16hi_scalar */
    case 2528:  /* pred_sbcvnx8hi_scalar */
    case 2527:  /* pred_sbcvnx4hi_scalar */
    case 2526:  /* pred_sbcvnx2hi_scalar */
    case 2525:  /* pred_sbcvnx1hi_scalar */
    case 2524:  /* pred_sbcvnx64qi_scalar */
    case 2523:  /* pred_sbcvnx32qi_scalar */
    case 2522:  /* pred_sbcvnx16qi_scalar */
    case 2521:  /* pred_sbcvnx8qi_scalar */
    case 2520:  /* pred_sbcvnx4qi_scalar */
    case 2519:  /* pred_sbcvnx2qi_scalar */
    case 2518:  /* pred_sbcvnx1qi_scalar */
    case 2517:  /* pred_adcvnx16si_scalar */
    case 2516:  /* pred_adcvnx8si_scalar */
    case 2515:  /* pred_adcvnx4si_scalar */
    case 2514:  /* pred_adcvnx2si_scalar */
    case 2513:  /* pred_adcvnx1si_scalar */
    case 2512:  /* pred_adcvnx32hi_scalar */
    case 2511:  /* pred_adcvnx16hi_scalar */
    case 2510:  /* pred_adcvnx8hi_scalar */
    case 2509:  /* pred_adcvnx4hi_scalar */
    case 2508:  /* pred_adcvnx2hi_scalar */
    case 2507:  /* pred_adcvnx1hi_scalar */
    case 2506:  /* pred_adcvnx64qi_scalar */
    case 2505:  /* pred_adcvnx32qi_scalar */
    case 2504:  /* pred_adcvnx16qi_scalar */
    case 2503:  /* pred_adcvnx8qi_scalar */
    case 2502:  /* pred_adcvnx4qi_scalar */
    case 2501:  /* pred_adcvnx2qi_scalar */
    case 2500:  /* pred_adcvnx1qi_scalar */
    case 2499:  /* pred_sbcvnx8di */
    case 2498:  /* pred_sbcvnx4di */
    case 2497:  /* pred_sbcvnx2di */
    case 2496:  /* pred_sbcvnx1di */
    case 2495:  /* pred_sbcvnx16si */
    case 2494:  /* pred_sbcvnx8si */
    case 2493:  /* pred_sbcvnx4si */
    case 2492:  /* pred_sbcvnx2si */
    case 2491:  /* pred_sbcvnx1si */
    case 2490:  /* pred_sbcvnx32hi */
    case 2489:  /* pred_sbcvnx16hi */
    case 2488:  /* pred_sbcvnx8hi */
    case 2487:  /* pred_sbcvnx4hi */
    case 2486:  /* pred_sbcvnx2hi */
    case 2485:  /* pred_sbcvnx1hi */
    case 2484:  /* pred_sbcvnx64qi */
    case 2483:  /* pred_sbcvnx32qi */
    case 2482:  /* pred_sbcvnx16qi */
    case 2481:  /* pred_sbcvnx8qi */
    case 2480:  /* pred_sbcvnx4qi */
    case 2479:  /* pred_sbcvnx2qi */
    case 2478:  /* pred_sbcvnx1qi */
    case 2477:  /* pred_adcvnx8di */
    case 2476:  /* pred_adcvnx4di */
    case 2475:  /* pred_adcvnx2di */
    case 2474:  /* pred_adcvnx1di */
    case 2473:  /* pred_adcvnx16si */
    case 2472:  /* pred_adcvnx8si */
    case 2471:  /* pred_adcvnx4si */
    case 2470:  /* pred_adcvnx2si */
    case 2469:  /* pred_adcvnx1si */
    case 2468:  /* pred_adcvnx32hi */
    case 2467:  /* pred_adcvnx16hi */
    case 2466:  /* pred_adcvnx8hi */
    case 2465:  /* pred_adcvnx4hi */
    case 2464:  /* pred_adcvnx2hi */
    case 2463:  /* pred_adcvnx1hi */
    case 2462:  /* pred_adcvnx64qi */
    case 2461:  /* pred_adcvnx32qi */
    case 2460:  /* pred_adcvnx16qi */
    case 2459:  /* pred_adcvnx8qi */
    case 2458:  /* pred_adcvnx4qi */
    case 2457:  /* pred_adcvnx2qi */
    case 2456:  /* pred_adcvnx1qi */
    case 1481:  /* pred_indexed_ustorevnx64qivnx64qi */
    case 1480:  /* pred_indexed_ostorevnx64qivnx64qi */
    case 1479:  /* pred_indexed_ustorevnx32hivnx32hi */
    case 1478:  /* pred_indexed_ostorevnx32hivnx32hi */
    case 1477:  /* pred_indexed_ustorevnx32hivnx32qi */
    case 1476:  /* pred_indexed_ostorevnx32hivnx32qi */
    case 1475:  /* pred_indexed_ustorevnx32qivnx32hi */
    case 1474:  /* pred_indexed_ostorevnx32qivnx32hi */
    case 1473:  /* pred_indexed_ustorevnx32qivnx32qi */
    case 1472:  /* pred_indexed_ostorevnx32qivnx32qi */
    case 1471:  /* pred_indexed_ustorevnx16sfvnx16si */
    case 1470:  /* pred_indexed_ostorevnx16sfvnx16si */
    case 1469:  /* pred_indexed_ustorevnx16sivnx16si */
    case 1468:  /* pred_indexed_ostorevnx16sivnx16si */
    case 1467:  /* pred_indexed_ustorevnx16hivnx16si */
    case 1466:  /* pred_indexed_ostorevnx16hivnx16si */
    case 1465:  /* pred_indexed_ustorevnx16qivnx16si */
    case 1464:  /* pred_indexed_ostorevnx16qivnx16si */
    case 1463:  /* pred_indexed_ustorevnx16sfvnx16hi */
    case 1462:  /* pred_indexed_ostorevnx16sfvnx16hi */
    case 1461:  /* pred_indexed_ustorevnx16sivnx16hi */
    case 1460:  /* pred_indexed_ostorevnx16sivnx16hi */
    case 1459:  /* pred_indexed_ustorevnx16hivnx16hi */
    case 1458:  /* pred_indexed_ostorevnx16hivnx16hi */
    case 1457:  /* pred_indexed_ustorevnx16qivnx16hi */
    case 1456:  /* pred_indexed_ostorevnx16qivnx16hi */
    case 1455:  /* pred_indexed_ustorevnx16sfvnx16qi */
    case 1454:  /* pred_indexed_ostorevnx16sfvnx16qi */
    case 1453:  /* pred_indexed_ustorevnx16sivnx16qi */
    case 1452:  /* pred_indexed_ostorevnx16sivnx16qi */
    case 1451:  /* pred_indexed_ustorevnx16hivnx16qi */
    case 1450:  /* pred_indexed_ostorevnx16hivnx16qi */
    case 1449:  /* pred_indexed_ustorevnx16qivnx16qi */
    case 1448:  /* pred_indexed_ostorevnx16qivnx16qi */
    case 1447:  /* pred_indexed_ustorevnx8dfvnx8di */
    case 1446:  /* pred_indexed_ostorevnx8dfvnx8di */
    case 1445:  /* pred_indexed_ustorevnx8sfvnx8di */
    case 1444:  /* pred_indexed_ostorevnx8sfvnx8di */
    case 1443:  /* pred_indexed_ustorevnx8divnx8di */
    case 1442:  /* pred_indexed_ostorevnx8divnx8di */
    case 1441:  /* pred_indexed_ustorevnx8sivnx8di */
    case 1440:  /* pred_indexed_ostorevnx8sivnx8di */
    case 1439:  /* pred_indexed_ustorevnx8hivnx8di */
    case 1438:  /* pred_indexed_ostorevnx8hivnx8di */
    case 1437:  /* pred_indexed_ustorevnx8qivnx8di */
    case 1436:  /* pred_indexed_ostorevnx8qivnx8di */
    case 1435:  /* pred_indexed_ustorevnx8dfvnx8si */
    case 1434:  /* pred_indexed_ostorevnx8dfvnx8si */
    case 1433:  /* pred_indexed_ustorevnx8sfvnx8si */
    case 1432:  /* pred_indexed_ostorevnx8sfvnx8si */
    case 1431:  /* pred_indexed_ustorevnx8divnx8si */
    case 1430:  /* pred_indexed_ostorevnx8divnx8si */
    case 1429:  /* pred_indexed_ustorevnx8sivnx8si */
    case 1428:  /* pred_indexed_ostorevnx8sivnx8si */
    case 1427:  /* pred_indexed_ustorevnx8hivnx8si */
    case 1426:  /* pred_indexed_ostorevnx8hivnx8si */
    case 1425:  /* pred_indexed_ustorevnx8qivnx8si */
    case 1424:  /* pred_indexed_ostorevnx8qivnx8si */
    case 1423:  /* pred_indexed_ustorevnx8dfvnx8hi */
    case 1422:  /* pred_indexed_ostorevnx8dfvnx8hi */
    case 1421:  /* pred_indexed_ustorevnx8sfvnx8hi */
    case 1420:  /* pred_indexed_ostorevnx8sfvnx8hi */
    case 1419:  /* pred_indexed_ustorevnx8divnx8hi */
    case 1418:  /* pred_indexed_ostorevnx8divnx8hi */
    case 1417:  /* pred_indexed_ustorevnx8sivnx8hi */
    case 1416:  /* pred_indexed_ostorevnx8sivnx8hi */
    case 1415:  /* pred_indexed_ustorevnx8hivnx8hi */
    case 1414:  /* pred_indexed_ostorevnx8hivnx8hi */
    case 1413:  /* pred_indexed_ustorevnx8qivnx8hi */
    case 1412:  /* pred_indexed_ostorevnx8qivnx8hi */
    case 1411:  /* pred_indexed_ustorevnx8dfvnx8qi */
    case 1410:  /* pred_indexed_ostorevnx8dfvnx8qi */
    case 1409:  /* pred_indexed_ustorevnx8sfvnx8qi */
    case 1408:  /* pred_indexed_ostorevnx8sfvnx8qi */
    case 1407:  /* pred_indexed_ustorevnx8divnx8qi */
    case 1406:  /* pred_indexed_ostorevnx8divnx8qi */
    case 1405:  /* pred_indexed_ustorevnx8sivnx8qi */
    case 1404:  /* pred_indexed_ostorevnx8sivnx8qi */
    case 1403:  /* pred_indexed_ustorevnx8hivnx8qi */
    case 1402:  /* pred_indexed_ostorevnx8hivnx8qi */
    case 1401:  /* pred_indexed_ustorevnx8qivnx8qi */
    case 1400:  /* pred_indexed_ostorevnx8qivnx8qi */
    case 1399:  /* pred_indexed_ustorevnx4dfvnx4di */
    case 1398:  /* pred_indexed_ostorevnx4dfvnx4di */
    case 1397:  /* pred_indexed_ustorevnx4sfvnx4di */
    case 1396:  /* pred_indexed_ostorevnx4sfvnx4di */
    case 1395:  /* pred_indexed_ustorevnx4divnx4di */
    case 1394:  /* pred_indexed_ostorevnx4divnx4di */
    case 1393:  /* pred_indexed_ustorevnx4sivnx4di */
    case 1392:  /* pred_indexed_ostorevnx4sivnx4di */
    case 1391:  /* pred_indexed_ustorevnx4hivnx4di */
    case 1390:  /* pred_indexed_ostorevnx4hivnx4di */
    case 1389:  /* pred_indexed_ustorevnx4qivnx4di */
    case 1388:  /* pred_indexed_ostorevnx4qivnx4di */
    case 1387:  /* pred_indexed_ustorevnx4dfvnx4si */
    case 1386:  /* pred_indexed_ostorevnx4dfvnx4si */
    case 1385:  /* pred_indexed_ustorevnx4sfvnx4si */
    case 1384:  /* pred_indexed_ostorevnx4sfvnx4si */
    case 1383:  /* pred_indexed_ustorevnx4divnx4si */
    case 1382:  /* pred_indexed_ostorevnx4divnx4si */
    case 1381:  /* pred_indexed_ustorevnx4sivnx4si */
    case 1380:  /* pred_indexed_ostorevnx4sivnx4si */
    case 1379:  /* pred_indexed_ustorevnx4hivnx4si */
    case 1378:  /* pred_indexed_ostorevnx4hivnx4si */
    case 1377:  /* pred_indexed_ustorevnx4qivnx4si */
    case 1376:  /* pred_indexed_ostorevnx4qivnx4si */
    case 1375:  /* pred_indexed_ustorevnx4dfvnx4hi */
    case 1374:  /* pred_indexed_ostorevnx4dfvnx4hi */
    case 1373:  /* pred_indexed_ustorevnx4sfvnx4hi */
    case 1372:  /* pred_indexed_ostorevnx4sfvnx4hi */
    case 1371:  /* pred_indexed_ustorevnx4divnx4hi */
    case 1370:  /* pred_indexed_ostorevnx4divnx4hi */
    case 1369:  /* pred_indexed_ustorevnx4sivnx4hi */
    case 1368:  /* pred_indexed_ostorevnx4sivnx4hi */
    case 1367:  /* pred_indexed_ustorevnx4hivnx4hi */
    case 1366:  /* pred_indexed_ostorevnx4hivnx4hi */
    case 1365:  /* pred_indexed_ustorevnx4qivnx4hi */
    case 1364:  /* pred_indexed_ostorevnx4qivnx4hi */
    case 1363:  /* pred_indexed_ustorevnx4dfvnx4qi */
    case 1362:  /* pred_indexed_ostorevnx4dfvnx4qi */
    case 1361:  /* pred_indexed_ustorevnx4sfvnx4qi */
    case 1360:  /* pred_indexed_ostorevnx4sfvnx4qi */
    case 1359:  /* pred_indexed_ustorevnx4divnx4qi */
    case 1358:  /* pred_indexed_ostorevnx4divnx4qi */
    case 1357:  /* pred_indexed_ustorevnx4sivnx4qi */
    case 1356:  /* pred_indexed_ostorevnx4sivnx4qi */
    case 1355:  /* pred_indexed_ustorevnx4hivnx4qi */
    case 1354:  /* pred_indexed_ostorevnx4hivnx4qi */
    case 1353:  /* pred_indexed_ustorevnx4qivnx4qi */
    case 1352:  /* pred_indexed_ostorevnx4qivnx4qi */
    case 1351:  /* pred_indexed_ustorevnx2dfvnx2di */
    case 1350:  /* pred_indexed_ostorevnx2dfvnx2di */
    case 1349:  /* pred_indexed_ustorevnx2sfvnx2di */
    case 1348:  /* pred_indexed_ostorevnx2sfvnx2di */
    case 1347:  /* pred_indexed_ustorevnx2divnx2di */
    case 1346:  /* pred_indexed_ostorevnx2divnx2di */
    case 1345:  /* pred_indexed_ustorevnx2sivnx2di */
    case 1344:  /* pred_indexed_ostorevnx2sivnx2di */
    case 1343:  /* pred_indexed_ustorevnx2hivnx2di */
    case 1342:  /* pred_indexed_ostorevnx2hivnx2di */
    case 1341:  /* pred_indexed_ustorevnx2qivnx2di */
    case 1340:  /* pred_indexed_ostorevnx2qivnx2di */
    case 1339:  /* pred_indexed_ustorevnx2dfvnx2si */
    case 1338:  /* pred_indexed_ostorevnx2dfvnx2si */
    case 1337:  /* pred_indexed_ustorevnx2sfvnx2si */
    case 1336:  /* pred_indexed_ostorevnx2sfvnx2si */
    case 1335:  /* pred_indexed_ustorevnx2divnx2si */
    case 1334:  /* pred_indexed_ostorevnx2divnx2si */
    case 1333:  /* pred_indexed_ustorevnx2sivnx2si */
    case 1332:  /* pred_indexed_ostorevnx2sivnx2si */
    case 1331:  /* pred_indexed_ustorevnx2hivnx2si */
    case 1330:  /* pred_indexed_ostorevnx2hivnx2si */
    case 1329:  /* pred_indexed_ustorevnx2qivnx2si */
    case 1328:  /* pred_indexed_ostorevnx2qivnx2si */
    case 1327:  /* pred_indexed_ustorevnx2dfvnx2hi */
    case 1326:  /* pred_indexed_ostorevnx2dfvnx2hi */
    case 1325:  /* pred_indexed_ustorevnx2sfvnx2hi */
    case 1324:  /* pred_indexed_ostorevnx2sfvnx2hi */
    case 1323:  /* pred_indexed_ustorevnx2divnx2hi */
    case 1322:  /* pred_indexed_ostorevnx2divnx2hi */
    case 1321:  /* pred_indexed_ustorevnx2sivnx2hi */
    case 1320:  /* pred_indexed_ostorevnx2sivnx2hi */
    case 1319:  /* pred_indexed_ustorevnx2hivnx2hi */
    case 1318:  /* pred_indexed_ostorevnx2hivnx2hi */
    case 1317:  /* pred_indexed_ustorevnx2qivnx2hi */
    case 1316:  /* pred_indexed_ostorevnx2qivnx2hi */
    case 1315:  /* pred_indexed_ustorevnx2dfvnx2qi */
    case 1314:  /* pred_indexed_ostorevnx2dfvnx2qi */
    case 1313:  /* pred_indexed_ustorevnx2sfvnx2qi */
    case 1312:  /* pred_indexed_ostorevnx2sfvnx2qi */
    case 1311:  /* pred_indexed_ustorevnx2divnx2qi */
    case 1310:  /* pred_indexed_ostorevnx2divnx2qi */
    case 1309:  /* pred_indexed_ustorevnx2sivnx2qi */
    case 1308:  /* pred_indexed_ostorevnx2sivnx2qi */
    case 1307:  /* pred_indexed_ustorevnx2hivnx2qi */
    case 1306:  /* pred_indexed_ostorevnx2hivnx2qi */
    case 1305:  /* pred_indexed_ustorevnx2qivnx2qi */
    case 1304:  /* pred_indexed_ostorevnx2qivnx2qi */
    case 1303:  /* pred_indexed_ustorevnx1dfvnx1di */
    case 1302:  /* pred_indexed_ostorevnx1dfvnx1di */
    case 1301:  /* pred_indexed_ustorevnx1dfvnx1si */
    case 1300:  /* pred_indexed_ostorevnx1dfvnx1si */
    case 1299:  /* pred_indexed_ustorevnx1dfvnx1hi */
    case 1298:  /* pred_indexed_ostorevnx1dfvnx1hi */
    case 1297:  /* pred_indexed_ustorevnx1dfvnx1qi */
    case 1296:  /* pred_indexed_ostorevnx1dfvnx1qi */
    case 1295:  /* pred_indexed_ustorevnx1sfvnx1di */
    case 1294:  /* pred_indexed_ostorevnx1sfvnx1di */
    case 1293:  /* pred_indexed_ustorevnx1sfvnx1si */
    case 1292:  /* pred_indexed_ostorevnx1sfvnx1si */
    case 1291:  /* pred_indexed_ustorevnx1sfvnx1hi */
    case 1290:  /* pred_indexed_ostorevnx1sfvnx1hi */
    case 1289:  /* pred_indexed_ustorevnx1sfvnx1qi */
    case 1288:  /* pred_indexed_ostorevnx1sfvnx1qi */
    case 1287:  /* pred_indexed_ustorevnx1divnx1di */
    case 1286:  /* pred_indexed_ostorevnx1divnx1di */
    case 1285:  /* pred_indexed_ustorevnx1divnx1si */
    case 1284:  /* pred_indexed_ostorevnx1divnx1si */
    case 1283:  /* pred_indexed_ustorevnx1divnx1hi */
    case 1282:  /* pred_indexed_ostorevnx1divnx1hi */
    case 1281:  /* pred_indexed_ustorevnx1divnx1qi */
    case 1280:  /* pred_indexed_ostorevnx1divnx1qi */
    case 1279:  /* pred_indexed_ustorevnx1sivnx1di */
    case 1278:  /* pred_indexed_ostorevnx1sivnx1di */
    case 1277:  /* pred_indexed_ustorevnx1sivnx1si */
    case 1276:  /* pred_indexed_ostorevnx1sivnx1si */
    case 1275:  /* pred_indexed_ustorevnx1sivnx1hi */
    case 1274:  /* pred_indexed_ostorevnx1sivnx1hi */
    case 1273:  /* pred_indexed_ustorevnx1sivnx1qi */
    case 1272:  /* pred_indexed_ostorevnx1sivnx1qi */
    case 1271:  /* pred_indexed_ustorevnx1hivnx1di */
    case 1270:  /* pred_indexed_ostorevnx1hivnx1di */
    case 1269:  /* pred_indexed_ustorevnx1hivnx1si */
    case 1268:  /* pred_indexed_ostorevnx1hivnx1si */
    case 1267:  /* pred_indexed_ustorevnx1hivnx1hi */
    case 1266:  /* pred_indexed_ostorevnx1hivnx1hi */
    case 1265:  /* pred_indexed_ustorevnx1hivnx1qi */
    case 1264:  /* pred_indexed_ostorevnx1hivnx1qi */
    case 1263:  /* pred_indexed_ustorevnx1qivnx1di */
    case 1262:  /* pred_indexed_ostorevnx1qivnx1di */
    case 1261:  /* pred_indexed_ustorevnx1qivnx1si */
    case 1260:  /* pred_indexed_ostorevnx1qivnx1si */
    case 1259:  /* pred_indexed_ustorevnx1qivnx1hi */
    case 1258:  /* pred_indexed_ostorevnx1qivnx1hi */
    case 1257:  /* pred_indexed_ustorevnx1qivnx1qi */
    case 1256:  /* pred_indexed_ostorevnx1qivnx1qi */
    case 1029:  /* pred_strided_storevnx8df */
    case 1028:  /* pred_strided_storevnx4df */
    case 1027:  /* pred_strided_storevnx2df */
    case 1026:  /* pred_strided_storevnx1df */
    case 1025:  /* pred_strided_storevnx16sf */
    case 1024:  /* pred_strided_storevnx8sf */
    case 1023:  /* pred_strided_storevnx4sf */
    case 1022:  /* pred_strided_storevnx2sf */
    case 1021:  /* pred_strided_storevnx1sf */
    case 1020:  /* pred_strided_storevnx8di */
    case 1019:  /* pred_strided_storevnx4di */
    case 1018:  /* pred_strided_storevnx2di */
    case 1017:  /* pred_strided_storevnx1di */
    case 1016:  /* pred_strided_storevnx16si */
    case 1015:  /* pred_strided_storevnx8si */
    case 1014:  /* pred_strided_storevnx4si */
    case 1013:  /* pred_strided_storevnx2si */
    case 1012:  /* pred_strided_storevnx1si */
    case 1011:  /* pred_strided_storevnx32hi */
    case 1010:  /* pred_strided_storevnx16hi */
    case 1009:  /* pred_strided_storevnx8hi */
    case 1008:  /* pred_strided_storevnx4hi */
    case 1007:  /* pred_strided_storevnx2hi */
    case 1006:  /* pred_strided_storevnx1hi */
    case 1005:  /* pred_strided_storevnx64qi */
    case 1004:  /* pred_strided_storevnx32qi */
    case 1003:  /* pred_strided_storevnx16qi */
    case 1002:  /* pred_strided_storevnx8qi */
    case 1001:  /* pred_strided_storevnx4qi */
    case 1000:  /* pred_strided_storevnx2qi */
    case 999:  /* pred_strided_storevnx1qi */
    case 967:  /* *pred_broadcastvnx8di_extended_scalar */
    case 966:  /* *pred_broadcastvnx4di_extended_scalar */
    case 965:  /* *pred_broadcastvnx2di_extended_scalar */
    case 964:  /* *pred_broadcastvnx1di_extended_scalar */
    case 932:  /* *pred_mergevnx8di_extended_scalar */
    case 931:  /* *pred_mergevnx4di_extended_scalar */
    case 930:  /* *pred_mergevnx2di_extended_scalar */
    case 929:  /* *pred_mergevnx1di_extended_scalar */
    case 928:  /* *pred_mergevnx8di_scalar */
    case 927:  /* *pred_mergevnx4di_scalar */
    case 926:  /* *pred_mergevnx2di_scalar */
    case 925:  /* *pred_mergevnx1di_scalar */
    case 924:  /* pred_mergevnx16si_scalar */
    case 923:  /* pred_mergevnx8si_scalar */
    case 922:  /* pred_mergevnx4si_scalar */
    case 921:  /* pred_mergevnx2si_scalar */
    case 920:  /* pred_mergevnx1si_scalar */
    case 919:  /* pred_mergevnx32hi_scalar */
    case 918:  /* pred_mergevnx16hi_scalar */
    case 917:  /* pred_mergevnx8hi_scalar */
    case 916:  /* pred_mergevnx4hi_scalar */
    case 915:  /* pred_mergevnx2hi_scalar */
    case 914:  /* pred_mergevnx1hi_scalar */
    case 913:  /* pred_mergevnx64qi_scalar */
    case 912:  /* pred_mergevnx32qi_scalar */
    case 911:  /* pred_mergevnx16qi_scalar */
    case 910:  /* pred_mergevnx8qi_scalar */
    case 909:  /* pred_mergevnx4qi_scalar */
    case 908:  /* pred_mergevnx2qi_scalar */
    case 907:  /* pred_mergevnx1qi_scalar */
    case 906:  /* pred_mergevnx8df */
    case 905:  /* pred_mergevnx4df */
    case 904:  /* pred_mergevnx2df */
    case 903:  /* pred_mergevnx1df */
    case 902:  /* pred_mergevnx16sf */
    case 901:  /* pred_mergevnx8sf */
    case 900:  /* pred_mergevnx4sf */
    case 899:  /* pred_mergevnx2sf */
    case 898:  /* pred_mergevnx1sf */
    case 897:  /* pred_mergevnx8di */
    case 896:  /* pred_mergevnx4di */
    case 895:  /* pred_mergevnx2di */
    case 894:  /* pred_mergevnx1di */
    case 893:  /* pred_mergevnx16si */
    case 892:  /* pred_mergevnx8si */
    case 891:  /* pred_mergevnx4si */
    case 890:  /* pred_mergevnx2si */
    case 889:  /* pred_mergevnx1si */
    case 888:  /* pred_mergevnx32hi */
    case 887:  /* pred_mergevnx16hi */
    case 886:  /* pred_mergevnx8hi */
    case 885:  /* pred_mergevnx4hi */
    case 884:  /* pred_mergevnx2hi */
    case 883:  /* pred_mergevnx1hi */
    case 882:  /* pred_mergevnx64qi */
    case 881:  /* pred_mergevnx32qi */
    case 880:  /* pred_mergevnx16qi */
    case 879:  /* pred_mergevnx8qi */
    case 878:  /* pred_mergevnx4qi */
    case 877:  /* pred_mergevnx2qi */
    case 876:  /* pred_mergevnx1qi */
    case 875:  /* pred_storevnx64bi */
    case 874:  /* pred_storevnx32bi */
    case 873:  /* pred_storevnx16bi */
    case 872:  /* pred_storevnx8bi */
    case 871:  /* pred_storevnx4bi */
    case 870:  /* pred_storevnx2bi */
    case 869:  /* pred_storevnx1bi */
    case 868:  /* pred_movvnx64bi */
    case 867:  /* pred_movvnx32bi */
    case 866:  /* pred_movvnx16bi */
    case 865:  /* pred_movvnx8bi */
    case 864:  /* pred_movvnx4bi */
    case 863:  /* pred_movvnx2bi */
    case 862:  /* pred_movvnx1bi */
    case 861:  /* pred_storevnx8df */
    case 860:  /* pred_storevnx4df */
    case 859:  /* pred_storevnx2df */
    case 858:  /* pred_storevnx1df */
    case 857:  /* pred_storevnx16sf */
    case 856:  /* pred_storevnx8sf */
    case 855:  /* pred_storevnx4sf */
    case 854:  /* pred_storevnx2sf */
    case 853:  /* pred_storevnx1sf */
    case 852:  /* pred_storevnx8di */
    case 851:  /* pred_storevnx4di */
    case 850:  /* pred_storevnx2di */
    case 849:  /* pred_storevnx1di */
    case 848:  /* pred_storevnx16si */
    case 847:  /* pred_storevnx8si */
    case 846:  /* pred_storevnx4si */
    case 845:  /* pred_storevnx2si */
    case 844:  /* pred_storevnx1si */
    case 843:  /* pred_storevnx32hi */
    case 842:  /* pred_storevnx16hi */
    case 841:  /* pred_storevnx8hi */
    case 840:  /* pred_storevnx4hi */
    case 839:  /* pred_storevnx2hi */
    case 838:  /* pred_storevnx1hi */
    case 837:  /* pred_storevnx64qi */
    case 836:  /* pred_storevnx32qi */
    case 835:  /* pred_storevnx16qi */
    case 834:  /* pred_storevnx8qi */
    case 833:  /* pred_storevnx4qi */
    case 832:  /* pred_storevnx2qi */
    case 831:  /* pred_storevnx1qi */
    case 799:  /* vsetvldi_no_side_effects */
    case 798:  /* vsetvlsi_no_side_effects */
    case 795:  /* vsetvl_vtype_change_only */
    case 792:  /* *movvnx64bidi_lra */
    case 791:  /* *movvnx32bidi_lra */
    case 790:  /* *movvnx16bidi_lra */
    case 789:  /* *movvnx8bidi_lra */
    case 788:  /* *movvnx4bidi_lra */
    case 787:  /* *movvnx2bidi_lra */
    case 786:  /* *movvnx1bidi_lra */
    case 785:  /* *movvnx64bisi_lra */
    case 784:  /* *movvnx32bisi_lra */
    case 783:  /* *movvnx16bisi_lra */
    case 782:  /* *movvnx8bisi_lra */
    case 781:  /* *movvnx4bisi_lra */
    case 780:  /* *movvnx2bisi_lra */
    case 779:  /* *movvnx1bisi_lra */
    case 778:  /* *movvnx1sfdi_lra */
    case 777:  /* *movvnx1sfsi_lra */
    case 776:  /* *movvnx1sidi_lra */
    case 775:  /* *movvnx1sisi_lra */
    case 774:  /* *movvnx2hidi_lra */
    case 773:  /* *movvnx2hisi_lra */
    case 772:  /* *movvnx1hidi_lra */
    case 771:  /* *movvnx1hisi_lra */
    case 770:  /* *movvnx4qidi_lra */
    case 769:  /* *movvnx4qisi_lra */
    case 768:  /* *movvnx2qidi_lra */
    case 767:  /* *movvnx2qisi_lra */
    case 766:  /* *movvnx1qidi_lra */
    case 765:  /* *movvnx1qisi_lra */
    case 764:  /* *movvnx64bi */
    case 763:  /* *movvnx32bi */
    case 762:  /* *movvnx16bi */
    case 761:  /* *movvnx8bi */
    case 760:  /* *movvnx4bi */
    case 759:  /* *movvnx2bi */
    case 758:  /* *movvnx1bi */
    case 757:  /* *movvnx1sf_fract */
    case 756:  /* *movvnx1si_fract */
    case 755:  /* *movvnx2hi_fract */
    case 754:  /* *movvnx1hi_fract */
    case 753:  /* *movvnx4qi_fract */
    case 752:  /* *movvnx2qi_fract */
    case 751:  /* *movvnx1qi_fract */
    case 750:  /* *movvnx8df_whole */
    case 749:  /* *movvnx4df_whole */
    case 748:  /* *movvnx2df_whole */
    case 747:  /* *movvnx1df_whole */
    case 746:  /* *movvnx16sf_whole */
    case 745:  /* *movvnx8sf_whole */
    case 744:  /* *movvnx4sf_whole */
    case 743:  /* *movvnx2sf_whole */
    case 742:  /* *movvnx1sf_whole */
    case 741:  /* *movvnx8di_whole */
    case 740:  /* *movvnx4di_whole */
    case 739:  /* *movvnx2di_whole */
    case 738:  /* *movvnx1di_whole */
    case 737:  /* *movvnx16si_whole */
    case 736:  /* *movvnx8si_whole */
    case 735:  /* *movvnx4si_whole */
    case 734:  /* *movvnx2si_whole */
    case 733:  /* *movvnx1si_whole */
    case 732:  /* *movvnx32hi_whole */
    case 731:  /* *movvnx16hi_whole */
    case 730:  /* *movvnx8hi_whole */
    case 729:  /* *movvnx4hi_whole */
    case 728:  /* *movvnx2hi_whole */
    case 727:  /* *movvnx64qi_whole */
    case 726:  /* *movvnx32qi_whole */
    case 725:  /* *movvnx16qi_whole */
    case 724:  /* *movvnx8qi_whole */
    case 723:  /* *movvnx4qi_whole */
    case 722:  /* vlmax_avldi */
    case 721:  /* vlmax_avlsi */
    case 720:  /* *vlmul_extx64vnx1qi */
    case 719:  /* *vlmul_extx32vnx1hi */
    case 718:  /* *vlmul_extx32vnx2qi */
    case 717:  /* *vlmul_extx32vnx1qi */
    case 716:  /* *vlmul_extx16vnx1sf */
    case 715:  /* *vlmul_extx16vnx1si */
    case 714:  /* *vlmul_extx16vnx2hi */
    case 713:  /* *vlmul_extx16vnx1hi */
    case 712:  /* *vlmul_extx16vnx4qi */
    case 711:  /* *vlmul_extx16vnx2qi */
    case 710:  /* *vlmul_extx16vnx1qi */
    case 709:  /* *vlmul_extx8vnx1df */
    case 708:  /* *vlmul_extx8vnx2sf */
    case 707:  /* *vlmul_extx8vnx1sf */
    case 706:  /* *vlmul_extx8vnx1di */
    case 705:  /* *vlmul_extx8vnx2si */
    case 704:  /* *vlmul_extx8vnx1si */
    case 703:  /* *vlmul_extx8vnx4hi */
    case 702:  /* *vlmul_extx8vnx2hi */
    case 701:  /* *vlmul_extx8vnx1hi */
    case 700:  /* *vlmul_extx8vnx8qi */
    case 699:  /* *vlmul_extx8vnx4qi */
    case 698:  /* *vlmul_extx8vnx2qi */
    case 697:  /* *vlmul_extx8vnx1qi */
    case 696:  /* *vlmul_extx4vnx2df */
    case 695:  /* *vlmul_extx4vnx1df */
    case 694:  /* *vlmul_extx4vnx4sf */
    case 693:  /* *vlmul_extx4vnx2sf */
    case 692:  /* *vlmul_extx4vnx1sf */
    case 691:  /* *vlmul_extx4vnx2di */
    case 690:  /* *vlmul_extx4vnx1di */
    case 689:  /* *vlmul_extx4vnx4si */
    case 688:  /* *vlmul_extx4vnx2si */
    case 687:  /* *vlmul_extx4vnx1si */
    case 686:  /* *vlmul_extx4vnx8hi */
    case 685:  /* *vlmul_extx4vnx4hi */
    case 684:  /* *vlmul_extx4vnx2hi */
    case 683:  /* *vlmul_extx4vnx1hi */
    case 682:  /* *vlmul_extx4vnx16qi */
    case 681:  /* *vlmul_extx4vnx8qi */
    case 680:  /* *vlmul_extx4vnx4qi */
    case 679:  /* *vlmul_extx4vnx2qi */
    case 678:  /* *vlmul_extx4vnx1qi */
    case 677:  /* *vlmul_extx2vnx4df */
    case 676:  /* *vlmul_extx2vnx2df */
    case 675:  /* *vlmul_extx2vnx1df */
    case 674:  /* *vlmul_extx2vnx8sf */
    case 673:  /* *vlmul_extx2vnx4sf */
    case 672:  /* *vlmul_extx2vnx2sf */
    case 671:  /* *vlmul_extx2vnx1sf */
    case 670:  /* *vlmul_extx2vnx4di */
    case 669:  /* *vlmul_extx2vnx2di */
    case 668:  /* *vlmul_extx2vnx1di */
    case 667:  /* *vlmul_extx2vnx8si */
    case 666:  /* *vlmul_extx2vnx4si */
    case 665:  /* *vlmul_extx2vnx2si */
    case 664:  /* *vlmul_extx2vnx1si */
    case 663:  /* *vlmul_extx2vnx16hi */
    case 662:  /* *vlmul_extx2vnx8hi */
    case 661:  /* *vlmul_extx2vnx4hi */
    case 660:  /* *vlmul_extx2vnx2hi */
    case 659:  /* *vlmul_extx2vnx1hi */
    case 658:  /* *vlmul_extx2vnx32qi */
    case 657:  /* *vlmul_extx2vnx16qi */
    case 656:  /* *vlmul_extx2vnx8qi */
    case 655:  /* *vlmul_extx2vnx4qi */
    case 654:  /* *vlmul_extx2vnx2qi */
    case 653:  /* *vlmul_extx2vnx1qi */
    case 652:  /* vundefinedvnx64bi */
    case 651:  /* vundefinedvnx32bi */
    case 650:  /* vundefinedvnx16bi */
    case 649:  /* vundefinedvnx8bi */
    case 648:  /* vundefinedvnx4bi */
    case 647:  /* vundefinedvnx2bi */
    case 646:  /* vundefinedvnx1bi */
    case 645:  /* vundefinedvnx8df */
    case 644:  /* vundefinedvnx4df */
    case 643:  /* vundefinedvnx2df */
    case 642:  /* vundefinedvnx1df */
    case 641:  /* vundefinedvnx16sf */
    case 640:  /* vundefinedvnx8sf */
    case 639:  /* vundefinedvnx4sf */
    case 638:  /* vundefinedvnx2sf */
    case 637:  /* vundefinedvnx1sf */
    case 636:  /* vundefinedvnx8di */
    case 635:  /* vundefinedvnx4di */
    case 634:  /* vundefinedvnx2di */
    case 633:  /* vundefinedvnx1di */
    case 632:  /* vundefinedvnx16si */
    case 631:  /* vundefinedvnx8si */
    case 630:  /* vundefinedvnx4si */
    case 629:  /* vundefinedvnx2si */
    case 628:  /* vundefinedvnx1si */
    case 627:  /* vundefinedvnx32hi */
    case 626:  /* vundefinedvnx16hi */
    case 625:  /* vundefinedvnx8hi */
    case 624:  /* vundefinedvnx4hi */
    case 623:  /* vundefinedvnx2hi */
    case 622:  /* vundefinedvnx1hi */
    case 621:  /* vundefinedvnx64qi */
    case 620:  /* vundefinedvnx32qi */
    case 619:  /* vundefinedvnx16qi */
    case 618:  /* vundefinedvnx8qi */
    case 617:  /* vundefinedvnx4qi */
    case 616:  /* vundefinedvnx2qi */
    case 615:  /* vundefinedvnx1qi */
    case 614:  /* *th_mempair_load_zero_extendsidi2 */
    case 613:  /* *th_mempair_load_extendsidi2 */
    case 612:  /* *th_mempair_store_di2 */
    case 611:  /* *th_mempair_store_si2 */
    case 610:  /* *th_mempair_load_di2 */
    case 609:  /* *th_mempair_load_si2 */
    case 608:  /* *th_sextw_msubhisi4 */
    case 607:  /* *th_msubhisi4 */
    case 606:  /* *th_mulswsi2 */
    case 605:  /* *th_mulswsi */
    case 604:  /* *th_mulsdi */
    case 603:  /* *th_mulssi */
    case 602:  /* *th_sextw_maddhisi4 */
    case 601:  /* *th_maddhisi4 */
    case 600:  /* *th_mulawsi2 */
    case 599:  /* *th_mulawsi */
    case 598:  /* *th_muladi */
    case 597:  /* *th_mulasi */
    case 596:  /* th_fmv_x_hw */
    case 595:  /* th_fmv_x_w */
    case 594:  /* th_fmv_hw_w_x */
    case 593:  /* *th_cond_gpr_movdidi */
    case 592:  /* *th_cond_gpr_movsidi */
    case 591:  /* *th_cond_gpr_movdisi */
    case 590:  /* *th_cond_gpr_movsisi */
    case 589:  /* *th_cond_movdidi */
    case 588:  /* *th_cond_movsidi */
    case 587:  /* *th_cond_movdisi */
    case 586:  /* *th_cond_movsisi */
    case 585:  /* *th_tstdi3 */
    case 584:  /* *th_tstsi3 */
    case 583:  /* *th_revdi2 */
    case 582:  /* *th_revsi2 */
    case 581:  /* *th_clzdi2 */
    case 580:  /* *th_clzsi2 */
    case 579:  /* *th_extudi4 */
    case 578:  /* *th_extusi4 */
    case 577:  /* *th_extdi4 */
    case 576:  /* *th_extsi4 */
    case 575:  /* *th_srridi3 */
    case 574:  /* *th_srrisi3 */
    case 573:  /* *th_addsldi4 */
    case 572:  /* *th_addslsi4 */
    case 571:  /* *local_pic_store_sfhf */
    case 570:  /* *local_pic_store_sfdf */
    case 569:  /* *local_pic_store_sfsf */
    case 568:  /* *local_pic_store_sfhf */
    case 567:  /* *local_pic_store_sfdf */
    case 566:  /* *local_pic_store_sfsf */
    case 565:  /* *local_pic_store_32dhf */
    case 564:  /* *local_pic_store_32ddf */
    case 563:  /* *local_pic_store_32dsf */
    case 562:  /* *local_pic_store_32dhf */
    case 561:  /* *local_pic_store_32ddf */
    case 560:  /* *local_pic_store_32dsf */
    case 559:  /* *local_pic_storehf */
    case 558:  /* *local_pic_storedf */
    case 557:  /* *local_pic_storesf */
    case 556:  /* *local_pic_storehf */
    case 555:  /* *local_pic_storedf */
    case 554:  /* *local_pic_storesf */
    case 553:  /* *local_pic_storedi */
    case 552:  /* *local_pic_storesi */
    case 551:  /* *local_pic_storehi */
    case 550:  /* *local_pic_storeqi */
    case 549:  /* *local_pic_storedi */
    case 548:  /* *local_pic_storesi */
    case 547:  /* *local_pic_storehi */
    case 546:  /* *local_pic_storeqi */
    case 545:  /* *local_pic_load_sfhf */
    case 544:  /* *local_pic_load_sfdf */
    case 543:  /* *local_pic_load_sfsf */
    case 542:  /* *local_pic_load_32dhf */
    case 541:  /* *local_pic_load_32ddf */
    case 540:  /* *local_pic_load_32dsf */
    case 539:  /* *local_pic_load_32dhf */
    case 538:  /* *local_pic_load_32ddf */
    case 537:  /* *local_pic_load_32dsf */
    case 536:  /* *local_pic_loadhf */
    case 535:  /* *local_pic_loaddf */
    case 534:  /* *local_pic_loadsf */
    case 533:  /* *local_pic_loadhf */
    case 532:  /* *local_pic_loaddf */
    case 531:  /* *local_pic_loadsf */
    case 530:  /* *local_pic_load_usi */
    case 529:  /* *local_pic_load_usi */
    case 528:  /* *local_pic_load_usi */
    case 527:  /* *local_pic_load_uhi */
    case 526:  /* *local_pic_load_uhi */
    case 525:  /* *local_pic_load_uhi */
    case 524:  /* *local_pic_load_uqi */
    case 523:  /* *local_pic_load_uqi */
    case 522:  /* *local_pic_load_uqi */
    case 521:  /* *local_pic_load_ssi */
    case 520:  /* *local_pic_load_ssi */
    case 519:  /* *local_pic_load_ssi */
    case 518:  /* *local_pic_load_shi */
    case 517:  /* *local_pic_load_shi */
    case 516:  /* *local_pic_load_shi */
    case 515:  /* *local_pic_load_sqi */
    case 514:  /* *local_pic_load_sqi */
    case 513:  /* *local_pic_load_sqi */
    case 512:  /* *local_pic_loaddi */
    case 511:  /* *local_pic_loadsi */
    case 510:  /* *local_pic_loadhi */
    case 509:  /* *local_pic_loadqi */
    case 508:  /* subword_atomic_cas_strong */
    case 507:  /* atomic_cas_value_strongdi */
    case 506:  /* atomic_cas_value_strongsi */
    case 505:  /* subword_atomic_exchange_strong */
    case 504:  /* atomic_exchangedi */
    case 503:  /* atomic_exchangesi */
    case 502:  /* subword_atomic_fetch_strong_nand */
    case 501:  /* subword_atomic_fetch_strong_and */
    case 500:  /* subword_atomic_fetch_strong_xor */
    case 499:  /* subword_atomic_fetch_strong_or */
    case 498:  /* subword_atomic_fetch_strong_add */
    case 497:  /* atomic_fetch_anddi */
    case 496:  /* atomic_fetch_xordi */
    case 495:  /* atomic_fetch_ordi */
    case 494:  /* atomic_fetch_adddi */
    case 493:  /* atomic_fetch_andsi */
    case 492:  /* atomic_fetch_xorsi */
    case 491:  /* atomic_fetch_orsi */
    case 490:  /* atomic_fetch_addsi */
    case 489:  /* atomic_anddi */
    case 488:  /* atomic_xordi */
    case 487:  /* atomic_ordi */
    case 486:  /* atomic_adddi */
    case 485:  /* atomic_andsi */
    case 484:  /* atomic_xorsi */
    case 483:  /* atomic_orsi */
    case 482:  /* atomic_addsi */
    case 481:  /* atomic_storedi */
    case 480:  /* atomic_storesi */
    case 479:  /* atomic_loaddi */
    case 478:  /* atomic_loadsi */
    case 477:  /* mem_thread_fence_1 */
    case 476:  /* riscv_sm4ks_di */
    case 475:  /* riscv_sm4ks_si */
    case 474:  /* riscv_sm4ed_di */
    case 473:  /* riscv_sm4ed_si */
    case 472:  /* riscv_sm3p1_di */
    case 471:  /* riscv_sm3p1_si */
    case 470:  /* riscv_sm3p0_di */
    case 469:  /* riscv_sm3p0_si */
    case 468:  /* riscv_sha512sum1 */
    case 467:  /* riscv_sha512sum0 */
    case 466:  /* riscv_sha512sig1 */
    case 465:  /* riscv_sha512sig0 */
    case 464:  /* riscv_sha512sum1r */
    case 463:  /* riscv_sha512sum0r */
    case 462:  /* riscv_sha512sig1l */
    case 461:  /* riscv_sha512sig1h */
    case 460:  /* riscv_sha512sig0l */
    case 459:  /* riscv_sha512sig0h */
    case 458:  /* riscv_sha256sum1_di */
    case 457:  /* riscv_sha256sum1_si */
    case 456:  /* riscv_sha256sum0_di */
    case 455:  /* riscv_sha256sum0_si */
    case 454:  /* riscv_sha256sig1_di */
    case 453:  /* riscv_sha256sig1_si */
    case 452:  /* riscv_sha256sig0_di */
    case 451:  /* riscv_sha256sig0_si */
    case 450:  /* riscv_aes64esm */
    case 449:  /* riscv_aes64es */
    case 448:  /* riscv_aes32esmi */
    case 447:  /* riscv_aes32esi */
    case 446:  /* riscv_aes64ks2 */
    case 445:  /* riscv_aes64ks1i */
    case 444:  /* riscv_aes64im */
    case 443:  /* riscv_aes64dsm */
    case 442:  /* riscv_aes64ds */
    case 441:  /* riscv_aes32dsmi */
    case 440:  /* riscv_aes32dsi */
    case 439:  /* riscv_xperm8_di */
    case 438:  /* riscv_xperm8_si */
    case 437:  /* riscv_xperm4_di */
    case 436:  /* riscv_xperm4_si */
    case 435:  /* riscv_clmulh_di */
    case 434:  /* riscv_clmulh_si */
    case 433:  /* riscv_clmul_di */
    case 432:  /* riscv_clmul_si */
    case 431:  /* riscv_packw */
    case 430:  /* riscv_packh_di */
    case 429:  /* riscv_packh_si */
    case 428:  /* riscv_pack_disi */
    case 427:  /* riscv_pack_dihi */
    case 426:  /* riscv_pack_sisi */
    case 425:  /* riscv_pack_sihi */
    case 424:  /* riscv_unzip */
    case 423:  /* riscv_zip */
    case 422:  /* riscv_brev8_di */
    case 421:  /* riscv_brev8_si */
    case 420:  /* *branchdi_mask_twobits_equals_singlebit */
    case 419:  /* *branchsi_mask_twobits_equals_singlebit */
    case 418:  /* *andidi_extrabit */
    case 417:  /* *andisi_extrabit */
    case 416:  /* *xoridi_extrabit */
    case 415:  /* *ioridi_extrabit */
    case 414:  /* *xorisi_extrabit */
    case 413:  /* *iorisi_extrabit */
    case 412:  /* *bexti */
    case 411:  /* *bexti */
    case 410:  /* *bextdi */
    case 409:  /* *bextsi */
    case 408:  /* *bextdi */
    case 407:  /* *bextsi */
    case 406:  /* *binvidi */
    case 405:  /* *binvisi */
    case 404:  /* *binvdi */
    case 403:  /* *binvsi */
    case 402:  /* *bclridisi_nottwobits */
    case 401:  /* *bclridi_nottwobits */
    case 400:  /* *bclrisi_nottwobits */
    case 399:  /* *bclridi */
    case 398:  /* *bclrisi */
    case 397:  /* *bclrdi */
    case 396:  /* *bclrsi */
    case 395:  /* *bsetidisi */
    case 394:  /* *bsetidi */
    case 393:  /* *bsetisi */
    case 392:  /* *bsetdi_1_mask */
    case 391:  /* *bsetsi_1_mask */
    case 390:  /* *bsetdi_1 */
    case 389:  /* *bsetsi_1 */
    case 388:  /* *bsetdi_mask */
    case 387:  /* *bsetsi_mask */
    case 386:  /* *bsetdi */
    case 385:  /* *bsetsi */
    case 384:  /* *minmax */
    case 383:  /* *minmax */
    case 382:  /* *minmax */
    case 381:  /* *minmax */
    case 380:  /* umaxdi3 */
    case 379:  /* smaxdi3 */
    case 378:  /* umindi3 */
    case 377:  /* smindi3 */
    case 376:  /* umaxsi3 */
    case 375:  /* smaxsi3 */
    case 374:  /* uminsi3 */
    case 373:  /* sminsi3 */
    case 372:  /* *bswapdi2 */
    case 371:  /* *bswapsi2 */
    case 370:  /* orcbdi2 */
    case 369:  /* orcbsi2 */
    case 368:  /* rotlsi3_sext */
    case 367:  /* rotldi3 */
    case 366:  /* rotlsi3 */
    case 365:  /* *rotrsi3_sext */
    case 364:  /* *rotrdi3 */
    case 363:  /* *rotrsi3 */
    case 362:  /* *zero_extendhidi2_zbb */
    case 361:  /* *zero_extendhisi2_zbb */
    case 360:  /* *extendhidi2_zbb */
    case 359:  /* *extendhisi2_zbb */
    case 358:  /* *extendhihi2_zbb */
    case 357:  /* *extendqidi2_zbb */
    case 356:  /* *extendqisi2_zbb */
    case 355:  /* *extendqihi2_zbb */
    case 354:  /* *zero_extendhidi2_bitmanip */
    case 353:  /* *zero_extendhisi2_bitmanip */
    case 352:  /* *popcountdi2 */
    case 351:  /* *ctzdi2 */
    case 350:  /* *clzdi2 */
    case 349:  /* *popcountdisi2 */
    case 348:  /* *ctzdisi2 */
    case 347:  /* *clzdisi2 */
    case 346:  /* *popcountsi2 */
    case 345:  /* *ctzsi2 */
    case 344:  /* *clzsi2 */
    case 343:  /* *xor_notdi */
    case 342:  /* *xor_notsi */
    case 341:  /* *ior_notdi */
    case 340:  /* *and_notdi */
    case 339:  /* *ior_notsi */
    case 338:  /* *and_notsi */
    case 337:  /* *slliuw */
    case 336:  /* *add.uw */
    case 335:  /* *shNadduw */
    case 334:  /* *andi_add.uw */
    case 333:  /* *shNadd */
    case 332:  /* *shNadd */
    case 331:  /* *zero_extendsidi2_bitmanip */
    case 330:  /* riscv_prefetchi_di */
    case 329:  /* riscv_prefetchi_si */
    case 328:  /* prefetch */
    case 327:  /* riscv_zero_di */
    case 326:  /* riscv_zero_si */
    case 325:  /* riscv_inval_di */
    case 324:  /* riscv_inval_si */
    case 323:  /* riscv_flush_di */
    case 322:  /* riscv_flush_si */
    case 321:  /* riscv_clean_di */
    case 320:  /* riscv_clean_si */
    case 319:  /* stack_protect_test_di */
    case 318:  /* stack_protect_test_si */
    case 317:  /* stack_protect_set_di */
    case 316:  /* stack_protect_set_si */
    case 315:  /* stack_tiedi */
    case 314:  /* stack_tiesi */
    case 313:  /* riscv_uret */
    case 312:  /* riscv_sret */
    case 311:  /* riscv_mret */
    case 310:  /* *riscv_fsnvsnanhf2 */
    case 309:  /* *riscv_fsnvsnandf2 */
    case 308:  /* *riscv_fsnvsnansf2 */
    case 307:  /* riscv_fsflags */
    case 306:  /* riscv_frflags */
    case 305:  /* gpr_restore_return */
    case 304:  /* gpr_restore */
    case 303:  /* gpr_save */
    case 302:  /* trap */
    case 301:  /* nop */
    case 300:  /* call_value_internal */
    case 299:  /* call_internal */
    case 298:  /* sibcall_value_internal */
    case 297:  /* sibcall_internal */
    case 296:  /* eh_return_internal */
    case 295:  /* eh_set_lr_di */
    case 294:  /* eh_set_lr_si */
    case 293:  /* simple_return_internal */
    case 292:  /* simple_return */
    case 291:  /* blockage */
    case 290:  /* tablejumpdi */
    case 289:  /* tablejumpsi */
    case 288:  /* indirect_jumpdi */
    case 287:  /* indirect_jumpsi */
    case 286:  /* jump */
    case 285:  /* *sleu_didi */
    case 284:  /* *sle_didi */
    case 283:  /* *sleu_disi */
    case 282:  /* *sle_disi */
    case 281:  /* *sleu_sisi */
    case 280:  /* *sle_sisi */
    case 279:  /* *sltu_didi */
    case 278:  /* *slt_didi */
    case 277:  /* *sltu_disi */
    case 276:  /* *slt_disi */
    case 275:  /* *sltu_sisi */
    case 274:  /* *slt_sisi */
    case 273:  /* *sgeu_didi */
    case 272:  /* *sge_didi */
    case 271:  /* *sgeu_disi */
    case 270:  /* *sge_disi */
    case 269:  /* *sgeu_sisi */
    case 268:  /* *sge_sisi */
    case 267:  /* *sgtu_didi */
    case 266:  /* *sgt_didi */
    case 265:  /* *sgtu_disi */
    case 264:  /* *sgt_disi */
    case 263:  /* *sgtu_sisi */
    case 262:  /* *sgt_sisi */
    case 261:  /* *sne_zero_didi */
    case 260:  /* *sne_zero_disi */
    case 259:  /* *sne_zero_sisi */
    case 258:  /* *seq_zero_didi */
    case 257:  /* *seq_zero_disi */
    case 256:  /* *seq_zero_sisi */
    case 255:  /* *cstorehfdi4 */
    case 254:  /* *cstorehfsi4 */
    case 253:  /* *cstoredfdi4 */
    case 252:  /* *cstoredfsi4 */
    case 251:  /* *cstoresfdi4 */
    case 250:  /* *cstoresfsi4 */
    case 249:  /* *branch_on_bit_rangedi */
    case 248:  /* *branch_on_bit_rangesi */
    case 247:  /* *branch_on_bitdi */
    case 246:  /* *branch_on_bitsi */
    case 245:  /* *movdidicc */
    case 244:  /* *movsidicc */
    case 243:  /* *movsisicc */
    case 242:  /* *branchdi */
    case 241:  /* *branchsi */
    case 240:  /* *branchdi_shiftedmask_equals_zero */
    case 239:  /* *branchsi_shiftedmask_equals_zero */
    case 238:  /* *branchhi_shiftedmask_equals_zero */
    case 237:  /* *branchqi_shiftedmask_equals_zero */
    case 236:  /* *branchdi_shiftedmask_equals_zero */
    case 235:  /* *branchsi_shiftedmask_equals_zero */
    case 234:  /* *branchhi_shiftedmask_equals_zero */
    case 233:  /* *branchqi_shiftedmask_equals_zero */
    case 232:  /* *branchdi_shiftedarith_equals_zero */
    case 231:  /* *branchsi_shiftedarith_equals_zero */
    case 230:  /* *branchhi_shiftedarith_equals_zero */
    case 229:  /* *branchqi_shiftedarith_equals_zero */
    case 228:  /* *branchsi_shiftedarith_equals_zero */
    case 227:  /* *branchhi_shiftedarith_equals_zero */
    case 226:  /* *branchqi_shiftedarith_equals_zero */
    case 225:  /* zero_extendsidi2_shifted */
    case 224:  /* *lshrsi3_zero_extend_3 */
    case 223:  /* *lshrsi3_zero_extend_2 */
    case 222:  /* *lshrsi3_zero_extend_1 */
    case 221:  /* *lshrsi3_extend_mask_1 */
    case 220:  /* *ashrsi3_extend_mask_1 */
    case 219:  /* *ashlsi3_extend_mask_1 */
    case 218:  /* *lshrsi3_extend_mask */
    case 217:  /* *ashrsi3_extend_mask */
    case 216:  /* *ashlsi3_extend_mask */
    case 215:  /* *lshrsi3_extend */
    case 214:  /* *ashrsi3_extend */
    case 213:  /* *ashlsi3_extend */
    case 212:  /* *lshrdi3_mask_1 */
    case 211:  /* *ashrdi3_mask_1 */
    case 210:  /* *ashldi3_mask_1 */
    case 209:  /* *lshrdi3_mask */
    case 208:  /* *ashrdi3_mask */
    case 207:  /* *ashldi3_mask */
    case 206:  /* lshrdi3 */
    case 205:  /* ashrdi3 */
    case 204:  /* ashldi3 */
    case 203:  /* *lshrsi3_mask_1 */
    case 202:  /* *ashrsi3_mask_1 */
    case 201:  /* *ashlsi3_mask_1 */
    case 200:  /* *lshrsi3_mask */
    case 199:  /* *ashrsi3_mask */
    case 198:  /* *ashlsi3_mask */
    case 197:  /* lshrsi3 */
    case 196:  /* ashrsi3 */
    case 195:  /* ashlsi3 */
    case 194:  /* riscv_pause */
    case 193:  /* fence_i */
    case 192:  /* fence */
    case 191:  /* *movdf_softfloat */
    case 190:  /* *movdf_hardfloat_rv64 */
    case 189:  /* *movdf_hardfloat_rv32 */
    case 188:  /* *movsf_softfloat */
    case 187:  /* *movsf_hardfloat */
    case 186:  /* *movqi_internal */
    case 185:  /* *xorsihi3 */
    case 184:  /* *xorhihi3 */
    case 183:  /* *addsihi3 */
    case 182:  /* *addhihi3 */
    case 181:  /* *movhi_internal */
    case 180:  /* *movsi_internal */
    case 179:  /* *movdi_64bit */
    case 178:  /* *movdi_32bit */
    case 177:  /* *mvconst_internal */
    case 176:  /* *mvconst_internal */
    case 175:  /* *lowdi */
    case 174:  /* *lowsi */
    case 173:  /* auipcdi */
    case 172:  /* auipcsi */
    case 171:  /* got_load_tls_iedi */
    case 170:  /* got_load_tls_iesi */
    case 169:  /* got_load_tls_gddi */
    case 168:  /* got_load_tls_gdsi */
    case 167:  /* tls_add_tp_ledi */
    case 166:  /* tls_add_tp_lesi */
    case 165:  /* got_loaddi */
    case 164:  /* got_loadsi */
    case 163:  /* lroundhfdi2 */
    case 162:  /* lrinthfdi2 */
    case 161:  /* lroundhfsi2 */
    case 160:  /* lrinthfsi2 */
    case 159:  /* lrounddfdi2 */
    case 158:  /* lrintdfdi2 */
    case 157:  /* lrounddfsi2 */
    case 156:  /* lrintdfsi2 */
    case 155:  /* lroundsfdi2 */
    case 154:  /* lrintsfdi2 */
    case 153:  /* lroundsfsi2 */
    case 152:  /* lrintsfsi2 */
    case 151:  /* floatunsdihf2 */
    case 150:  /* floatunssihf2 */
    case 149:  /* floatunsdidf2 */
    case 148:  /* floatunssidf2 */
    case 147:  /* floatunsdisf2 */
    case 146:  /* floatunssisf2 */
    case 145:  /* floatdihf2 */
    case 144:  /* floatsihf2 */
    case 143:  /* floatdidf2 */
    case 142:  /* floatsidf2 */
    case 141:  /* floatdisf2 */
    case 140:  /* floatsisf2 */
    case 139:  /* fixuns_trunchfdi2 */
    case 138:  /* fixuns_trunchfsi2 */
    case 137:  /* fixuns_truncdfdi2 */
    case 136:  /* fixuns_truncdfsi2 */
    case 135:  /* fixuns_truncsfdi2 */
    case 134:  /* fixuns_truncsfsi2 */
    case 133:  /* fix_trunchfdi2 */
    case 132:  /* fix_trunchfsi2 */
    case 131:  /* fix_truncdfdi2 */
    case 130:  /* fix_truncdfsi2 */
    case 129:  /* fix_truncsfdi2 */
    case 128:  /* fix_truncsfsi2 */
    case 127:  /* *movhf_softfloat */
    case 126:  /* *movhf_hardfloat */
    case 125:  /* extendhfdf2 */
    case 124:  /* extendsfdf2 */
    case 123:  /* extendhfsf2 */
    case 122:  /* *extendhidi2 */
    case 121:  /* *extendhisi2 */
    case 120:  /* *extendhihi2 */
    case 119:  /* *extendqidi2 */
    case 118:  /* *extendqisi2 */
    case 117:  /* *extendqihi2 */
    case 116:  /* extendsidi2 */
    case 115:  /* zero_extendqidi2 */
    case 114:  /* zero_extendqisi2 */
    case 113:  /* zero_extendqihi2 */
    case 112:  /* *zero_extendhidi2 */
    case 111:  /* *zero_extendhisi2 */
    case 110:  /* *zero_extendsidi2_internal */
    case 109:  /* truncdfhf2 */
    case 108:  /* truncsfhf2 */
    case 107:  /* truncdfsf2 */
    case 106:  /* *one_cmplsi2_internal */
    case 105:  /* one_cmpldi2 */
    case 104:  /* one_cmplsi2 */
    case 103:  /* *xorsi3_internal */
    case 102:  /* *iorsi3_internal */
    case 101:  /* *andsi3_internal */
    case 100:  /* xordi3 */
    case 99:  /* iordi3 */
    case 98:  /* anddi3 */
    case 97:  /* xorsi3 */
    case 96:  /* iorsi3 */
    case 95:  /* andsi3 */
    case 94:  /* smaxhf3 */
    case 93:  /* smaxdf3 */
    case 92:  /* smaxsf3 */
    case 91:  /* sminhf3 */
    case 90:  /* smindf3 */
    case 89:  /* sminsf3 */
    case 88:  /* fmaxhf3 */
    case 87:  /* fmaxdf3 */
    case 86:  /* fmaxsf3 */
    case 85:  /* fminhf3 */
    case 84:  /* fmindf3 */
    case 83:  /* fminsf3 */
    case 82:  /* neghf2 */
    case 81:  /* negdf2 */
    case 80:  /* negsf2 */
    case 79:  /* copysignhf3 */
    case 78:  /* copysigndf3 */
    case 77:  /* copysignsf3 */
    case 76:  /* abshf2 */
    case 75:  /* absdf2 */
    case 74:  /* abssf2 */
    case 73:  /* *fnmahf4 */
    case 72:  /* *fnmadf4 */
    case 71:  /* *fnmasf4 */
    case 70:  /* *fnmshf4 */
    case 69:  /* *fnmsdf4 */
    case 68:  /* *fnmssf4 */
    case 67:  /* *fmshf4 */
    case 66:  /* *fmsdf4 */
    case 65:  /* *fmssf4 */
    case 64:  /* *fmahf4 */
    case 63:  /* *fmadf4 */
    case 62:  /* *fmasf4 */
    case 61:  /* fnmahf4 */
    case 60:  /* fnmadf4 */
    case 59:  /* fnmasf4 */
    case 58:  /* fnmshf4 */
    case 57:  /* fnmsdf4 */
    case 56:  /* fnmssf4 */
    case 55:  /* fmshf4 */
    case 54:  /* fmsdf4 */
    case 53:  /* fmssf4 */
    case 52:  /* fmahf4 */
    case 51:  /* fmadf4 */
    case 50:  /* fmasf4 */
    case 49:  /* sqrthf2 */
    case 48:  /* sqrtdf2 */
    case 47:  /* sqrtsf2 */
    case 46:  /* divhf3 */
    case 45:  /* divdf3 */
    case 44:  /* divsf3 */
    case 43:  /* *umodsi3_extended */
    case 42:  /* *modsi3_extended */
    case 41:  /* *udivsi3_extended */
    case 40:  /* *divsi3_extended */
    case 39:  /* umoddi3 */
    case 38:  /* moddi3 */
    case 37:  /* udivdi3 */
    case 36:  /* divdi3 */
    case 35:  /* umodsi3 */
    case 34:  /* modsi3 */
    case 33:  /* udivsi3 */
    case 32:  /* divsi3 */
    case 31:  /* usmulsi3_highpart */
    case 30:  /* umulsi3_highpart */
    case 29:  /* smulsi3_highpart */
    case 28:  /* usmuldi3_highpart */
    case 27:  /* umuldi3_highpart */
    case 26:  /* smuldi3_highpart */
    case 25:  /* *mulsi3_extended2 */
    case 24:  /* *mulsi3_extended */
    case 23:  /* muldi3 */
    case 22:  /* mulsi3 */
    case 21:  /* mulhf3 */
    case 20:  /* muldf3 */
    case 19:  /* mulsf3 */
    case 18:  /* *negsi2_extended2 */
    case 17:  /* *negsi2_extended */
    case 16:  /* negsi2 */
    case 15:  /* negdi2 */
    case 14:  /* *subsi3_extended2 */
    case 13:  /* *subsi3_extended */
    case 12:  /* subsi3 */
    case 11:  /* subdi3 */
    case 10:  /* subhf3 */
    case 9:  /* subdf3 */
    case 8:  /* subsf3 */
    case 7:  /* *addsi3_extended2 */
    case 6:  /* *addsi3_extended */
    case 5:  /* adddi3 */
    case 4:  /* addsi3 */
    case 3:  /* addhf3 */
    case 2:  /* adddf3 */
    case 1:  /* addsf3 */
      return 255 /* 0xff */;

    case 793:  /* vsetvlsi */
    case 794:  /* vsetvldi */
      extract_constrain_insn_cached (insn);
      return 
#line 326 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[5]));

    case 796:  /* vsetvl_discard_resultsi */
    case 797:  /* vsetvl_discard_resultdi */
      extract_constrain_insn_cached (insn);
      return 
#line 351 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[4]));

    case 6067:  /* pred_fault_loadvnx8df */
    case 6066:  /* pred_fault_loadvnx4df */
    case 6065:  /* pred_fault_loadvnx2df */
    case 6064:  /* pred_fault_loadvnx1df */
    case 6063:  /* pred_fault_loadvnx16sf */
    case 6062:  /* pred_fault_loadvnx8sf */
    case 6061:  /* pred_fault_loadvnx4sf */
    case 6060:  /* pred_fault_loadvnx2sf */
    case 6059:  /* pred_fault_loadvnx1sf */
    case 6058:  /* pred_fault_loadvnx8di */
    case 6057:  /* pred_fault_loadvnx4di */
    case 6056:  /* pred_fault_loadvnx2di */
    case 6055:  /* pred_fault_loadvnx1di */
    case 6054:  /* pred_fault_loadvnx16si */
    case 6053:  /* pred_fault_loadvnx8si */
    case 6052:  /* pred_fault_loadvnx4si */
    case 6051:  /* pred_fault_loadvnx2si */
    case 6050:  /* pred_fault_loadvnx1si */
    case 6049:  /* pred_fault_loadvnx32hi */
    case 6048:  /* pred_fault_loadvnx16hi */
    case 6047:  /* pred_fault_loadvnx8hi */
    case 6046:  /* pred_fault_loadvnx4hi */
    case 6045:  /* pred_fault_loadvnx2hi */
    case 6044:  /* pred_fault_loadvnx1hi */
    case 6043:  /* pred_fault_loadvnx64qi */
    case 6042:  /* pred_fault_loadvnx32qi */
    case 6041:  /* pred_fault_loadvnx16qi */
    case 6040:  /* pred_fault_loadvnx8qi */
    case 6039:  /* pred_fault_loadvnx4qi */
    case 6038:  /* pred_fault_loadvnx2qi */
    case 6037:  /* pred_fault_loadvnx1qi */
    case 5328:  /* pred_rod_truncvnx8df */
    case 5327:  /* pred_rod_truncvnx4df */
    case 5326:  /* pred_rod_truncvnx2df */
    case 5325:  /* pred_rod_truncvnx1df */
    case 5324:  /* pred_truncvnx8df */
    case 5323:  /* pred_truncvnx4df */
    case 5322:  /* pred_truncvnx2df */
    case 5321:  /* pred_truncvnx1df */
    case 5320:  /* pred_narrow_floatunsvnx8di */
    case 5319:  /* pred_narrow_floatvnx8di */
    case 5318:  /* pred_narrow_floatunsvnx4di */
    case 5317:  /* pred_narrow_floatvnx4di */
    case 5316:  /* pred_narrow_floatunsvnx2di */
    case 5315:  /* pred_narrow_floatvnx2di */
    case 5314:  /* pred_narrow_floatunsvnx1di */
    case 5313:  /* pred_narrow_floatvnx1di */
    case 5312:  /* pred_narrow_fixuns_truncvnx8df */
    case 5311:  /* pred_narrow_fix_truncvnx8df */
    case 5310:  /* pred_narrow_fixuns_truncvnx4df */
    case 5309:  /* pred_narrow_fix_truncvnx4df */
    case 5308:  /* pred_narrow_fixuns_truncvnx2df */
    case 5307:  /* pred_narrow_fix_truncvnx2df */
    case 5306:  /* pred_narrow_fixuns_truncvnx1df */
    case 5305:  /* pred_narrow_fix_truncvnx1df */
    case 5304:  /* pred_narrow_fixuns_truncvnx16sf */
    case 5303:  /* pred_narrow_fix_truncvnx16sf */
    case 5302:  /* pred_narrow_fixuns_truncvnx8sf */
    case 5301:  /* pred_narrow_fix_truncvnx8sf */
    case 5300:  /* pred_narrow_fixuns_truncvnx4sf */
    case 5299:  /* pred_narrow_fix_truncvnx4sf */
    case 5298:  /* pred_narrow_fixuns_truncvnx2sf */
    case 5297:  /* pred_narrow_fix_truncvnx2sf */
    case 5296:  /* pred_narrow_fixuns_truncvnx1sf */
    case 5295:  /* pred_narrow_fix_truncvnx1sf */
    case 5294:  /* pred_narrow_fcvt_xu_fvnx8df */
    case 5293:  /* pred_narrow_fcvt_x_fvnx8df */
    case 5292:  /* pred_narrow_fcvt_xu_fvnx4df */
    case 5291:  /* pred_narrow_fcvt_x_fvnx4df */
    case 5290:  /* pred_narrow_fcvt_xu_fvnx2df */
    case 5289:  /* pred_narrow_fcvt_x_fvnx2df */
    case 5288:  /* pred_narrow_fcvt_xu_fvnx1df */
    case 5287:  /* pred_narrow_fcvt_x_fvnx1df */
    case 5286:  /* pred_narrow_fcvt_xu_fvnx16sf */
    case 5285:  /* pred_narrow_fcvt_x_fvnx16sf */
    case 5284:  /* pred_narrow_fcvt_xu_fvnx8sf */
    case 5283:  /* pred_narrow_fcvt_x_fvnx8sf */
    case 5282:  /* pred_narrow_fcvt_xu_fvnx4sf */
    case 5281:  /* pred_narrow_fcvt_x_fvnx4sf */
    case 5280:  /* pred_narrow_fcvt_xu_fvnx2sf */
    case 5279:  /* pred_narrow_fcvt_x_fvnx2sf */
    case 5278:  /* pred_narrow_fcvt_xu_fvnx1sf */
    case 5277:  /* pred_narrow_fcvt_x_fvnx1sf */
    case 5276:  /* pred_extendvnx8df */
    case 5275:  /* pred_extendvnx4df */
    case 5274:  /* pred_extendvnx2df */
    case 5273:  /* pred_extendvnx1df */
    case 5272:  /* pred_widen_floatunsvnx8df */
    case 5271:  /* pred_widen_floatvnx8df */
    case 5270:  /* pred_widen_floatunsvnx4df */
    case 5269:  /* pred_widen_floatvnx4df */
    case 5268:  /* pred_widen_floatunsvnx2df */
    case 5267:  /* pred_widen_floatvnx2df */
    case 5266:  /* pred_widen_floatunsvnx1df */
    case 5265:  /* pred_widen_floatvnx1df */
    case 5264:  /* pred_widen_floatunsvnx16sf */
    case 5263:  /* pred_widen_floatvnx16sf */
    case 5262:  /* pred_widen_floatunsvnx8sf */
    case 5261:  /* pred_widen_floatvnx8sf */
    case 5260:  /* pred_widen_floatunsvnx4sf */
    case 5259:  /* pred_widen_floatvnx4sf */
    case 5258:  /* pred_widen_floatunsvnx2sf */
    case 5257:  /* pred_widen_floatvnx2sf */
    case 5256:  /* pred_widen_floatunsvnx1sf */
    case 5255:  /* pred_widen_floatvnx1sf */
    case 5254:  /* pred_widen_fixuns_truncvnx8di */
    case 5253:  /* pred_widen_fix_truncvnx8di */
    case 5252:  /* pred_widen_fixuns_truncvnx4di */
    case 5251:  /* pred_widen_fix_truncvnx4di */
    case 5250:  /* pred_widen_fixuns_truncvnx2di */
    case 5249:  /* pred_widen_fix_truncvnx2di */
    case 5248:  /* pred_widen_fixuns_truncvnx1di */
    case 5247:  /* pred_widen_fix_truncvnx1di */
    case 5246:  /* pred_widen_fcvt_xu_fvnx8di */
    case 5245:  /* pred_widen_fcvt_x_fvnx8di */
    case 5244:  /* pred_widen_fcvt_xu_fvnx4di */
    case 5243:  /* pred_widen_fcvt_x_fvnx4di */
    case 5242:  /* pred_widen_fcvt_xu_fvnx2di */
    case 5241:  /* pred_widen_fcvt_x_fvnx2di */
    case 5240:  /* pred_widen_fcvt_xu_fvnx1di */
    case 5239:  /* pred_widen_fcvt_x_fvnx1di */
    case 5238:  /* pred_floatunsvnx8df */
    case 5237:  /* pred_floatvnx8df */
    case 5236:  /* pred_floatunsvnx4df */
    case 5235:  /* pred_floatvnx4df */
    case 5234:  /* pred_floatunsvnx2df */
    case 5233:  /* pred_floatvnx2df */
    case 5232:  /* pred_floatunsvnx1df */
    case 5231:  /* pred_floatvnx1df */
    case 5230:  /* pred_floatunsvnx16sf */
    case 5229:  /* pred_floatvnx16sf */
    case 5228:  /* pred_floatunsvnx8sf */
    case 5227:  /* pred_floatvnx8sf */
    case 5226:  /* pred_floatunsvnx4sf */
    case 5225:  /* pred_floatvnx4sf */
    case 5224:  /* pred_floatunsvnx2sf */
    case 5223:  /* pred_floatvnx2sf */
    case 5222:  /* pred_floatunsvnx1sf */
    case 5221:  /* pred_floatvnx1sf */
    case 5220:  /* pred_fixuns_truncvnx8df */
    case 5219:  /* pred_fix_truncvnx8df */
    case 5218:  /* pred_fixuns_truncvnx4df */
    case 5217:  /* pred_fix_truncvnx4df */
    case 5216:  /* pred_fixuns_truncvnx2df */
    case 5215:  /* pred_fix_truncvnx2df */
    case 5214:  /* pred_fixuns_truncvnx1df */
    case 5213:  /* pred_fix_truncvnx1df */
    case 5212:  /* pred_fixuns_truncvnx16sf */
    case 5211:  /* pred_fix_truncvnx16sf */
    case 5210:  /* pred_fixuns_truncvnx8sf */
    case 5209:  /* pred_fix_truncvnx8sf */
    case 5208:  /* pred_fixuns_truncvnx4sf */
    case 5207:  /* pred_fix_truncvnx4sf */
    case 5206:  /* pred_fixuns_truncvnx2sf */
    case 5205:  /* pred_fix_truncvnx2sf */
    case 5204:  /* pred_fixuns_truncvnx1sf */
    case 5203:  /* pred_fix_truncvnx1sf */
    case 5202:  /* pred_fcvt_xu_fvnx8df */
    case 5201:  /* pred_fcvt_x_fvnx8df */
    case 5200:  /* pred_fcvt_xu_fvnx4df */
    case 5199:  /* pred_fcvt_x_fvnx4df */
    case 5198:  /* pred_fcvt_xu_fvnx2df */
    case 5197:  /* pred_fcvt_x_fvnx2df */
    case 5196:  /* pred_fcvt_xu_fvnx1df */
    case 5195:  /* pred_fcvt_x_fvnx1df */
    case 5194:  /* pred_fcvt_xu_fvnx16sf */
    case 5193:  /* pred_fcvt_x_fvnx16sf */
    case 5192:  /* pred_fcvt_xu_fvnx8sf */
    case 5191:  /* pred_fcvt_x_fvnx8sf */
    case 5190:  /* pred_fcvt_xu_fvnx4sf */
    case 5189:  /* pred_fcvt_x_fvnx4sf */
    case 5188:  /* pred_fcvt_xu_fvnx2sf */
    case 5187:  /* pred_fcvt_x_fvnx2sf */
    case 5186:  /* pred_fcvt_xu_fvnx1sf */
    case 5185:  /* pred_fcvt_x_fvnx1sf */
    case 5049:  /* pred_classvnx8df */
    case 5048:  /* pred_classvnx4df */
    case 5047:  /* pred_classvnx2df */
    case 5046:  /* pred_classvnx1df */
    case 5045:  /* pred_classvnx16sf */
    case 5044:  /* pred_classvnx8sf */
    case 5043:  /* pred_classvnx4sf */
    case 5042:  /* pred_classvnx2sf */
    case 5041:  /* pred_classvnx1sf */
    case 5040:  /* pred_rec7vnx8df */
    case 5039:  /* pred_rsqrt7vnx8df */
    case 5038:  /* pred_rec7vnx4df */
    case 5037:  /* pred_rsqrt7vnx4df */
    case 5036:  /* pred_rec7vnx2df */
    case 5035:  /* pred_rsqrt7vnx2df */
    case 5034:  /* pred_rec7vnx1df */
    case 5033:  /* pred_rsqrt7vnx1df */
    case 5032:  /* pred_rec7vnx16sf */
    case 5031:  /* pred_rsqrt7vnx16sf */
    case 5030:  /* pred_rec7vnx8sf */
    case 5029:  /* pred_rsqrt7vnx8sf */
    case 5028:  /* pred_rec7vnx4sf */
    case 5027:  /* pred_rsqrt7vnx4sf */
    case 5026:  /* pred_rec7vnx2sf */
    case 5025:  /* pred_rsqrt7vnx2sf */
    case 5024:  /* pred_rec7vnx1sf */
    case 5023:  /* pred_rsqrt7vnx1sf */
    case 4577:  /* pred_iotavnx8di */
    case 4576:  /* pred_iotavnx4di */
    case 4575:  /* pred_iotavnx2di */
    case 4574:  /* pred_iotavnx1di */
    case 4573:  /* pred_iotavnx16si */
    case 4572:  /* pred_iotavnx8si */
    case 4571:  /* pred_iotavnx4si */
    case 4570:  /* pred_iotavnx2si */
    case 4569:  /* pred_iotavnx1si */
    case 4568:  /* pred_iotavnx32hi */
    case 4567:  /* pred_iotavnx16hi */
    case 4566:  /* pred_iotavnx8hi */
    case 4565:  /* pred_iotavnx4hi */
    case 4564:  /* pred_iotavnx2hi */
    case 4563:  /* pred_iotavnx1hi */
    case 4562:  /* pred_iotavnx64qi */
    case 4561:  /* pred_iotavnx32qi */
    case 4560:  /* pred_iotavnx16qi */
    case 4559:  /* pred_iotavnx8qi */
    case 4558:  /* pred_iotavnx4qi */
    case 4557:  /* pred_iotavnx2qi */
    case 4556:  /* pred_iotavnx1qi */
    case 2843:  /* pred_zero_extendvnx8di_vf8 */
    case 2842:  /* pred_extendvnx8di_vf8 */
    case 2841:  /* pred_zero_extendvnx4di_vf8 */
    case 2840:  /* pred_extendvnx4di_vf8 */
    case 2839:  /* pred_zero_extendvnx2di_vf8 */
    case 2838:  /* pred_extendvnx2di_vf8 */
    case 2837:  /* pred_zero_extendvnx1di_vf8 */
    case 2836:  /* pred_extendvnx1di_vf8 */
    case 2835:  /* pred_zero_extendvnx8di_vf4 */
    case 2834:  /* pred_extendvnx8di_vf4 */
    case 2833:  /* pred_zero_extendvnx4di_vf4 */
    case 2832:  /* pred_extendvnx4di_vf4 */
    case 2831:  /* pred_zero_extendvnx2di_vf4 */
    case 2830:  /* pred_extendvnx2di_vf4 */
    case 2829:  /* pred_zero_extendvnx1di_vf4 */
    case 2828:  /* pred_extendvnx1di_vf4 */
    case 2827:  /* pred_zero_extendvnx16si_vf4 */
    case 2826:  /* pred_extendvnx16si_vf4 */
    case 2825:  /* pred_zero_extendvnx8si_vf4 */
    case 2824:  /* pred_extendvnx8si_vf4 */
    case 2823:  /* pred_zero_extendvnx4si_vf4 */
    case 2822:  /* pred_extendvnx4si_vf4 */
    case 2821:  /* pred_zero_extendvnx2si_vf4 */
    case 2820:  /* pred_extendvnx2si_vf4 */
    case 2819:  /* pred_zero_extendvnx1si_vf4 */
    case 2818:  /* pred_extendvnx1si_vf4 */
    case 2817:  /* pred_zero_extendvnx8di_vf2 */
    case 2816:  /* pred_extendvnx8di_vf2 */
    case 2815:  /* pred_zero_extendvnx4di_vf2 */
    case 2814:  /* pred_extendvnx4di_vf2 */
    case 2813:  /* pred_zero_extendvnx2di_vf2 */
    case 2812:  /* pred_extendvnx2di_vf2 */
    case 2811:  /* pred_zero_extendvnx1di_vf2 */
    case 2810:  /* pred_extendvnx1di_vf2 */
    case 2809:  /* pred_zero_extendvnx16si_vf2 */
    case 2808:  /* pred_extendvnx16si_vf2 */
    case 2807:  /* pred_zero_extendvnx8si_vf2 */
    case 2806:  /* pred_extendvnx8si_vf2 */
    case 2805:  /* pred_zero_extendvnx4si_vf2 */
    case 2804:  /* pred_extendvnx4si_vf2 */
    case 2803:  /* pred_zero_extendvnx2si_vf2 */
    case 2802:  /* pred_extendvnx2si_vf2 */
    case 2801:  /* pred_zero_extendvnx1si_vf2 */
    case 2800:  /* pred_extendvnx1si_vf2 */
    case 2799:  /* pred_zero_extendvnx32hi_vf2 */
    case 2798:  /* pred_extendvnx32hi_vf2 */
    case 2797:  /* pred_zero_extendvnx16hi_vf2 */
    case 2796:  /* pred_extendvnx16hi_vf2 */
    case 2795:  /* pred_zero_extendvnx8hi_vf2 */
    case 2794:  /* pred_extendvnx8hi_vf2 */
    case 2793:  /* pred_zero_extendvnx4hi_vf2 */
    case 2792:  /* pred_extendvnx4hi_vf2 */
    case 2791:  /* pred_zero_extendvnx2hi_vf2 */
    case 2790:  /* pred_extendvnx2hi_vf2 */
    case 2789:  /* pred_zero_extendvnx1hi_vf2 */
    case 2788:  /* pred_extendvnx1hi_vf2 */
    case 2744:  /* pred_negvnx1qi */
    case 2745:  /* pred_one_cmplvnx1qi */
    case 2746:  /* pred_negvnx2qi */
    case 2747:  /* pred_one_cmplvnx2qi */
    case 2748:  /* pred_negvnx4qi */
    case 2749:  /* pred_one_cmplvnx4qi */
    case 2750:  /* pred_negvnx8qi */
    case 2751:  /* pred_one_cmplvnx8qi */
    case 2752:  /* pred_negvnx16qi */
    case 2753:  /* pred_one_cmplvnx16qi */
    case 2754:  /* pred_negvnx32qi */
    case 2755:  /* pred_one_cmplvnx32qi */
    case 2756:  /* pred_negvnx64qi */
    case 2757:  /* pred_one_cmplvnx64qi */
    case 2758:  /* pred_negvnx1hi */
    case 2759:  /* pred_one_cmplvnx1hi */
    case 2760:  /* pred_negvnx2hi */
    case 2761:  /* pred_one_cmplvnx2hi */
    case 2762:  /* pred_negvnx4hi */
    case 2763:  /* pred_one_cmplvnx4hi */
    case 2764:  /* pred_negvnx8hi */
    case 2765:  /* pred_one_cmplvnx8hi */
    case 2766:  /* pred_negvnx16hi */
    case 2767:  /* pred_one_cmplvnx16hi */
    case 2768:  /* pred_negvnx32hi */
    case 2769:  /* pred_one_cmplvnx32hi */
    case 2770:  /* pred_negvnx1si */
    case 2771:  /* pred_one_cmplvnx1si */
    case 2772:  /* pred_negvnx2si */
    case 2773:  /* pred_one_cmplvnx2si */
    case 2774:  /* pred_negvnx4si */
    case 2775:  /* pred_one_cmplvnx4si */
    case 2776:  /* pred_negvnx8si */
    case 2777:  /* pred_one_cmplvnx8si */
    case 2778:  /* pred_negvnx16si */
    case 2779:  /* pred_one_cmplvnx16si */
    case 2780:  /* pred_negvnx1di */
    case 2781:  /* pred_one_cmplvnx1di */
    case 2782:  /* pred_negvnx2di */
    case 2783:  /* pred_one_cmplvnx2di */
    case 2784:  /* pred_negvnx4di */
    case 2785:  /* pred_one_cmplvnx4di */
    case 2786:  /* pred_negvnx8di */
    case 2787:  /* pred_one_cmplvnx8di */
    case 3174:  /* pred_extendvnx1hi */
    case 3175:  /* pred_zero_extendvnx1hi */
    case 3176:  /* pred_extendvnx2hi */
    case 3177:  /* pred_zero_extendvnx2hi */
    case 3178:  /* pred_extendvnx4hi */
    case 3179:  /* pred_zero_extendvnx4hi */
    case 3180:  /* pred_extendvnx8hi */
    case 3181:  /* pred_zero_extendvnx8hi */
    case 3182:  /* pred_extendvnx16hi */
    case 3183:  /* pred_zero_extendvnx16hi */
    case 3184:  /* pred_extendvnx32hi */
    case 3185:  /* pred_zero_extendvnx32hi */
    case 3186:  /* pred_extendvnx1si */
    case 3187:  /* pred_zero_extendvnx1si */
    case 3188:  /* pred_extendvnx2si */
    case 3189:  /* pred_zero_extendvnx2si */
    case 3190:  /* pred_extendvnx4si */
    case 3191:  /* pred_zero_extendvnx4si */
    case 3192:  /* pred_extendvnx8si */
    case 3193:  /* pred_zero_extendvnx8si */
    case 3194:  /* pred_extendvnx16si */
    case 3195:  /* pred_zero_extendvnx16si */
    case 3196:  /* pred_extendvnx1di */
    case 3197:  /* pred_zero_extendvnx1di */
    case 3198:  /* pred_extendvnx2di */
    case 3199:  /* pred_zero_extendvnx2di */
    case 3200:  /* pred_extendvnx4di */
    case 3201:  /* pred_zero_extendvnx4di */
    case 3202:  /* pred_extendvnx8di */
    case 3203:  /* pred_zero_extendvnx8di */
    case 3264:  /* pred_truncvnx1hi */
    case 3265:  /* pred_truncvnx2hi */
    case 3266:  /* pred_truncvnx4hi */
    case 3267:  /* pred_truncvnx8hi */
    case 3268:  /* pred_truncvnx16hi */
    case 3269:  /* pred_truncvnx32hi */
    case 3270:  /* pred_truncvnx1si */
    case 3271:  /* pred_truncvnx2si */
    case 3272:  /* pred_truncvnx4si */
    case 3273:  /* pred_truncvnx8si */
    case 3274:  /* pred_truncvnx16si */
    case 3275:  /* pred_truncvnx1di */
    case 3276:  /* pred_truncvnx2di */
    case 3277:  /* pred_truncvnx4di */
    case 3278:  /* pred_truncvnx8di */
    case 4996:  /* pred_negvnx1sf */
    case 4997:  /* pred_absvnx1sf */
    case 4998:  /* pred_sqrtvnx1sf */
    case 4999:  /* pred_negvnx2sf */
    case 5000:  /* pred_absvnx2sf */
    case 5001:  /* pred_sqrtvnx2sf */
    case 5002:  /* pred_negvnx4sf */
    case 5003:  /* pred_absvnx4sf */
    case 5004:  /* pred_sqrtvnx4sf */
    case 5005:  /* pred_negvnx8sf */
    case 5006:  /* pred_absvnx8sf */
    case 5007:  /* pred_sqrtvnx8sf */
    case 5008:  /* pred_negvnx16sf */
    case 5009:  /* pred_absvnx16sf */
    case 5010:  /* pred_sqrtvnx16sf */
    case 5011:  /* pred_negvnx1df */
    case 5012:  /* pred_absvnx1df */
    case 5013:  /* pred_sqrtvnx1df */
    case 5014:  /* pred_negvnx2df */
    case 5015:  /* pred_absvnx2df */
    case 5016:  /* pred_sqrtvnx2df */
    case 5017:  /* pred_negvnx4df */
    case 5018:  /* pred_absvnx4df */
    case 5019:  /* pred_sqrtvnx4df */
    case 5020:  /* pred_negvnx8df */
    case 5021:  /* pred_absvnx8df */
    case 5022:  /* pred_sqrtvnx8df */
      extract_constrain_insn_cached (insn);
      return 
#line 293 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ma(operands[6]));

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      extract_constrain_insn_cached (insn);
      if (((cached_type = get_attr_type (insn)) == TYPE_VLDE) || (cached_type == TYPE_VEXT) || (cached_type == TYPE_VMIOTA) || (cached_type == TYPE_VFSQRT) || (cached_type == TYPE_VFRECP) || (cached_type == TYPE_VFCVTITOF) || (cached_type == TYPE_VFCVTFTOI) || (cached_type == TYPE_VFWCVTITOF) || (cached_type == TYPE_VFWCVTFTOI) || (cached_type == TYPE_VFWCVTFTOF) || (cached_type == TYPE_VFNCVTITOF) || (cached_type == TYPE_VFNCVTFTOI) || (cached_type == TYPE_VFNCVTFTOF) || (cached_type == TYPE_VFCLASS) || (cached_type == TYPE_VLDFF))
        {
	  return 
#line 293 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ma(operands[6]));
        }
      else if (cached_type == TYPE_VLDS)
        {
	  if (
#line 239 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(VECTOR_MODE_P (GET_MODE (operands[3]))))
	    {
	      return 
#line 299 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ma(operands[7]));
	    }
	  else
	    {
	      return 
#line 293 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ma(operands[6]));
	    }
        }
      else if ((cached_type == TYPE_VLDUX) || (cached_type == TYPE_VLDOX) || (cached_type == TYPE_VIALU) || (cached_type == TYPE_VSHIFT) || (cached_type == TYPE_VIMINMAX) || (cached_type == TYPE_VIMUL) || (cached_type == TYPE_VIDIV) || (cached_type == TYPE_VSALU) || (cached_type == TYPE_VIWALU) || (cached_type == TYPE_VIWMUL) || (cached_type == TYPE_VNSHIFT) || (cached_type == TYPE_VAALU) || (cached_type == TYPE_VSMUL) || (cached_type == TYPE_VSSHIFT) || (cached_type == TYPE_VNCLIP) || (cached_type == TYPE_VICMP) || (cached_type == TYPE_VFALU) || (cached_type == TYPE_VFMUL) || (cached_type == TYPE_VFMINMAX) || (cached_type == TYPE_VFDIV) || (cached_type == TYPE_VFWALU) || (cached_type == TYPE_VFWMUL) || (cached_type == TYPE_VFSGNJ) || (cached_type == TYPE_VFCMP) || (cached_type == TYPE_VSLIDEUP) || (cached_type == TYPE_VSLIDEDOWN) || (cached_type == TYPE_VISLIDE1UP) || (cached_type == TYPE_VISLIDE1DOWN) || (cached_type == TYPE_VFSLIDE1UP) || (cached_type == TYPE_VFSLIDE1DOWN) || (cached_type == TYPE_VGATHER) || (cached_type == TYPE_VIWMULADD) || (cached_type == TYPE_VFWMULADD))
        {
	  return 
#line 299 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ma(operands[7]));
        }
      else if ((cached_type == TYPE_VIMULADD) || (cached_type == TYPE_VFMULADD))
        {
	  return 
#line 311 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ma(operands[8]));
        }
      else if ((cached_type == TYPE_VMSFS) || (cached_type == TYPE_VMIDX))
        {
	  return 
#line 314 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ma(operands[5]));
        }
      else
        {
	  return 255 /* 0xff */;
        }

    default:
      extract_constrain_insn_cached (insn);
      return 
#line 299 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ma(operands[7]));

    }
}

int
get_attr_merge_op_idx (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 4995:  /* *pred_mul_neg_subvnx8df_scalar */
    case 4994:  /* *pred_mul_neg_addvnx8df_scalar */
    case 4993:  /* *pred_mul_neg_subvnx4df_scalar */
    case 4992:  /* *pred_mul_neg_addvnx4df_scalar */
    case 4991:  /* *pred_mul_neg_subvnx2df_scalar */
    case 4990:  /* *pred_mul_neg_addvnx2df_scalar */
    case 4989:  /* *pred_mul_neg_subvnx1df_scalar */
    case 4988:  /* *pred_mul_neg_addvnx1df_scalar */
    case 4987:  /* *pred_mul_neg_subvnx16sf_scalar */
    case 4986:  /* *pred_mul_neg_addvnx16sf_scalar */
    case 4985:  /* *pred_mul_neg_subvnx8sf_scalar */
    case 4984:  /* *pred_mul_neg_addvnx8sf_scalar */
    case 4983:  /* *pred_mul_neg_subvnx4sf_scalar */
    case 4982:  /* *pred_mul_neg_addvnx4sf_scalar */
    case 4981:  /* *pred_mul_neg_subvnx2sf_scalar */
    case 4980:  /* *pred_mul_neg_addvnx2sf_scalar */
    case 4979:  /* *pred_mul_neg_subvnx1sf_scalar */
    case 4978:  /* *pred_mul_neg_addvnx1sf_scalar */
    case 4941:  /* *pred_mul_neg_subvnx8df */
    case 4940:  /* *pred_mul_neg_addvnx8df */
    case 4939:  /* *pred_mul_neg_subvnx4df */
    case 4938:  /* *pred_mul_neg_addvnx4df */
    case 4937:  /* *pred_mul_neg_subvnx2df */
    case 4936:  /* *pred_mul_neg_addvnx2df */
    case 4935:  /* *pred_mul_neg_subvnx1df */
    case 4934:  /* *pred_mul_neg_addvnx1df */
    case 4933:  /* *pred_mul_neg_subvnx16sf */
    case 4932:  /* *pred_mul_neg_addvnx16sf */
    case 4931:  /* *pred_mul_neg_subvnx8sf */
    case 4930:  /* *pred_mul_neg_addvnx8sf */
    case 4929:  /* *pred_mul_neg_subvnx4sf */
    case 4928:  /* *pred_mul_neg_addvnx4sf */
    case 4927:  /* *pred_mul_neg_subvnx2sf */
    case 4926:  /* *pred_mul_neg_addvnx2sf */
    case 4925:  /* *pred_mul_neg_subvnx1sf */
    case 4924:  /* *pred_mul_neg_addvnx1sf */
    case 4887:  /* *pred_mul_subvnx8df_scalar */
    case 4886:  /* *pred_mul_addvnx8df_scalar */
    case 4885:  /* *pred_mul_subvnx4df_scalar */
    case 4884:  /* *pred_mul_addvnx4df_scalar */
    case 4883:  /* *pred_mul_subvnx2df_scalar */
    case 4882:  /* *pred_mul_addvnx2df_scalar */
    case 4881:  /* *pred_mul_subvnx1df_scalar */
    case 4880:  /* *pred_mul_addvnx1df_scalar */
    case 4879:  /* *pred_mul_subvnx16sf_scalar */
    case 4878:  /* *pred_mul_addvnx16sf_scalar */
    case 4877:  /* *pred_mul_subvnx8sf_scalar */
    case 4876:  /* *pred_mul_addvnx8sf_scalar */
    case 4875:  /* *pred_mul_subvnx4sf_scalar */
    case 4874:  /* *pred_mul_addvnx4sf_scalar */
    case 4873:  /* *pred_mul_subvnx2sf_scalar */
    case 4872:  /* *pred_mul_addvnx2sf_scalar */
    case 4871:  /* *pred_mul_subvnx1sf_scalar */
    case 4870:  /* *pred_mul_addvnx1sf_scalar */
    case 4833:  /* *pred_mul_subvnx8df */
    case 4832:  /* *pred_mul_addvnx8df */
    case 4831:  /* *pred_mul_subvnx4df */
    case 4830:  /* *pred_mul_addvnx4df */
    case 4829:  /* *pred_mul_subvnx2df */
    case 4828:  /* *pred_mul_addvnx2df */
    case 4827:  /* *pred_mul_subvnx1df */
    case 4826:  /* *pred_mul_addvnx1df */
    case 4825:  /* *pred_mul_subvnx16sf */
    case 4824:  /* *pred_mul_addvnx16sf */
    case 4823:  /* *pred_mul_subvnx8sf */
    case 4822:  /* *pred_mul_addvnx8sf */
    case 4821:  /* *pred_mul_subvnx4sf */
    case 4820:  /* *pred_mul_addvnx4sf */
    case 4819:  /* *pred_mul_subvnx2sf */
    case 4818:  /* *pred_mul_addvnx2sf */
    case 4817:  /* *pred_mul_subvnx1sf */
    case 4816:  /* *pred_mul_addvnx1sf */
    case 4338:  /* *pred_minus_mulvnx8di_extended_scalar */
    case 4337:  /* *pred_minus_mulvnx4di_extended_scalar */
    case 4336:  /* *pred_minus_mulvnx2di_extended_scalar */
    case 4335:  /* *pred_minus_mulvnx1di_extended_scalar */
    case 4326:  /* *pred_minus_mulvnx8di_scalar */
    case 4325:  /* *pred_minus_mulvnx4di_scalar */
    case 4324:  /* *pred_minus_mulvnx2di_scalar */
    case 4323:  /* *pred_minus_mulvnx1di_scalar */
    case 4322:  /* *pred_minus_mulvnx16si_scalar */
    case 4321:  /* *pred_minus_mulvnx8si_scalar */
    case 4320:  /* *pred_minus_mulvnx4si_scalar */
    case 4319:  /* *pred_minus_mulvnx2si_scalar */
    case 4318:  /* *pred_minus_mulvnx1si_scalar */
    case 4317:  /* *pred_minus_mulvnx32hi_scalar */
    case 4316:  /* *pred_minus_mulvnx16hi_scalar */
    case 4315:  /* *pred_minus_mulvnx8hi_scalar */
    case 4314:  /* *pred_minus_mulvnx4hi_scalar */
    case 4313:  /* *pred_minus_mulvnx2hi_scalar */
    case 4312:  /* *pred_minus_mulvnx1hi_scalar */
    case 4311:  /* *pred_minus_mulvnx64qi_scalar */
    case 4310:  /* *pred_minus_mulvnx32qi_scalar */
    case 4309:  /* *pred_minus_mulvnx16qi_scalar */
    case 4308:  /* *pred_minus_mulvnx8qi_scalar */
    case 4307:  /* *pred_minus_mulvnx4qi_scalar */
    case 4306:  /* *pred_minus_mulvnx2qi_scalar */
    case 4305:  /* *pred_minus_mulvnx1qi_scalar */
    case 4260:  /* *pred_minus_mulvnx8di */
    case 4259:  /* *pred_minus_mulvnx4di */
    case 4258:  /* *pred_minus_mulvnx2di */
    case 4257:  /* *pred_minus_mulvnx1di */
    case 4256:  /* *pred_minus_mulvnx16si */
    case 4255:  /* *pred_minus_mulvnx8si */
    case 4254:  /* *pred_minus_mulvnx4si */
    case 4253:  /* *pred_minus_mulvnx2si */
    case 4252:  /* *pred_minus_mulvnx1si */
    case 4251:  /* *pred_minus_mulvnx32hi */
    case 4250:  /* *pred_minus_mulvnx16hi */
    case 4249:  /* *pred_minus_mulvnx8hi */
    case 4248:  /* *pred_minus_mulvnx4hi */
    case 4247:  /* *pred_minus_mulvnx2hi */
    case 4246:  /* *pred_minus_mulvnx1hi */
    case 4245:  /* *pred_minus_mulvnx64qi */
    case 4244:  /* *pred_minus_mulvnx32qi */
    case 4243:  /* *pred_minus_mulvnx16qi */
    case 4242:  /* *pred_minus_mulvnx8qi */
    case 4241:  /* *pred_minus_mulvnx4qi */
    case 4240:  /* *pred_minus_mulvnx2qi */
    case 4239:  /* *pred_minus_mulvnx1qi */
    case 4194:  /* *pred_mul_plusvnx8di_extended_scalar */
    case 4193:  /* *pred_mul_plusvnx4di_extended_scalar */
    case 4192:  /* *pred_mul_plusvnx2di_extended_scalar */
    case 4191:  /* *pred_mul_plusvnx1di_extended_scalar */
    case 4182:  /* *pred_mul_plusvnx8di_scalar */
    case 4181:  /* *pred_mul_plusvnx4di_scalar */
    case 4180:  /* *pred_mul_plusvnx2di_scalar */
    case 4179:  /* *pred_mul_plusvnx1di_scalar */
    case 4178:  /* *pred_mul_plusvnx16si_scalar */
    case 4177:  /* *pred_mul_plusvnx8si_scalar */
    case 4176:  /* *pred_mul_plusvnx4si_scalar */
    case 4175:  /* *pred_mul_plusvnx2si_scalar */
    case 4174:  /* *pred_mul_plusvnx1si_scalar */
    case 4173:  /* *pred_mul_plusvnx32hi_scalar */
    case 4172:  /* *pred_mul_plusvnx16hi_scalar */
    case 4171:  /* *pred_mul_plusvnx8hi_scalar */
    case 4170:  /* *pred_mul_plusvnx4hi_scalar */
    case 4169:  /* *pred_mul_plusvnx2hi_scalar */
    case 4168:  /* *pred_mul_plusvnx1hi_scalar */
    case 4167:  /* *pred_mul_plusvnx64qi_scalar */
    case 4166:  /* *pred_mul_plusvnx32qi_scalar */
    case 4165:  /* *pred_mul_plusvnx16qi_scalar */
    case 4164:  /* *pred_mul_plusvnx8qi_scalar */
    case 4163:  /* *pred_mul_plusvnx4qi_scalar */
    case 4162:  /* *pred_mul_plusvnx2qi_scalar */
    case 4161:  /* *pred_mul_plusvnx1qi_scalar */
    case 4116:  /* *pred_mul_plusvnx8di */
    case 4115:  /* *pred_mul_plusvnx4di */
    case 4114:  /* *pred_mul_plusvnx2di */
    case 4113:  /* *pred_mul_plusvnx1di */
    case 4112:  /* *pred_mul_plusvnx16si */
    case 4111:  /* *pred_mul_plusvnx8si */
    case 4110:  /* *pred_mul_plusvnx4si */
    case 4109:  /* *pred_mul_plusvnx2si */
    case 4108:  /* *pred_mul_plusvnx1si */
    case 4107:  /* *pred_mul_plusvnx32hi */
    case 4106:  /* *pred_mul_plusvnx16hi */
    case 4105:  /* *pred_mul_plusvnx8hi */
    case 4104:  /* *pred_mul_plusvnx4hi */
    case 4103:  /* *pred_mul_plusvnx2hi */
    case 4102:  /* *pred_mul_plusvnx1hi */
    case 4101:  /* *pred_mul_plusvnx64qi */
    case 4100:  /* *pred_mul_plusvnx32qi */
    case 4099:  /* *pred_mul_plusvnx16qi */
    case 4098:  /* *pred_mul_plusvnx8qi */
    case 4097:  /* *pred_mul_plusvnx4qi */
    case 4096:  /* *pred_mul_plusvnx2qi */
    case 4095:  /* *pred_mul_plusvnx1qi */
      return 5;

    case 868:  /* pred_movvnx64bi */
    case 867:  /* pred_movvnx32bi */
    case 866:  /* pred_movvnx16bi */
    case 865:  /* pred_movvnx8bi */
    case 864:  /* pred_movvnx4bi */
    case 863:  /* pred_movvnx2bi */
    case 862:  /* pred_movvnx1bi */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 1)
        {
	  return 2;
        }
      else
        {
	  return 255 /* 0xff */;
        }

    case 830:  /* pred_movvnx8df */
    case 829:  /* pred_movvnx4df */
    case 828:  /* pred_movvnx2df */
    case 827:  /* pred_movvnx1df */
    case 826:  /* pred_movvnx16sf */
    case 825:  /* pred_movvnx8sf */
    case 824:  /* pred_movvnx4sf */
    case 823:  /* pred_movvnx2sf */
    case 822:  /* pred_movvnx1sf */
    case 821:  /* pred_movvnx8di */
    case 820:  /* pred_movvnx4di */
    case 819:  /* pred_movvnx2di */
    case 818:  /* pred_movvnx1di */
    case 817:  /* pred_movvnx16si */
    case 816:  /* pred_movvnx8si */
    case 815:  /* pred_movvnx4si */
    case 814:  /* pred_movvnx2si */
    case 813:  /* pred_movvnx1si */
    case 812:  /* pred_movvnx32hi */
    case 811:  /* pred_movvnx16hi */
    case 810:  /* pred_movvnx8hi */
    case 809:  /* pred_movvnx4hi */
    case 808:  /* pred_movvnx2hi */
    case 807:  /* pred_movvnx1hi */
    case 806:  /* pred_movvnx64qi */
    case 805:  /* pred_movvnx32qi */
    case 804:  /* pred_movvnx16qi */
    case 803:  /* pred_movvnx8qi */
    case 802:  /* pred_movvnx4qi */
    case 801:  /* pred_movvnx2qi */
    case 800:  /* pred_movvnx1qi */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 3)
        {
	  return 2;
        }
      else
        {
	  return 255 /* 0xff */;
        }

    case 6036:  /* read_vldi_zero_extend */
    case 6035:  /* read_vlsi */
    case 5779:  /* *pred_extract_firstvnx8df */
    case 5778:  /* *pred_extract_firstvnx4df */
    case 5777:  /* *pred_extract_firstvnx2df */
    case 5776:  /* *pred_extract_firstvnx1df */
    case 5775:  /* *pred_extract_firstvnx16sf */
    case 5774:  /* *pred_extract_firstvnx8sf */
    case 5773:  /* *pred_extract_firstvnx4sf */
    case 5772:  /* *pred_extract_firstvnx2sf */
    case 5771:  /* *pred_extract_firstvnx1sf */
    case 5770:  /* pred_extract_first_truncvnx8di */
    case 5769:  /* pred_extract_first_truncvnx4di */
    case 5768:  /* pred_extract_first_truncvnx2di */
    case 5767:  /* pred_extract_first_truncvnx1di */
    case 5766:  /* *pred_extract_firstvnx8di */
    case 5765:  /* *pred_extract_firstvnx4di */
    case 5764:  /* *pred_extract_firstvnx2di */
    case 5763:  /* *pred_extract_firstvnx1di */
    case 5762:  /* *pred_extract_firstvnx16si */
    case 5761:  /* *pred_extract_firstvnx8si */
    case 5760:  /* *pred_extract_firstvnx4si */
    case 5759:  /* *pred_extract_firstvnx2si */
    case 5758:  /* *pred_extract_firstvnx1si */
    case 5757:  /* *pred_extract_firstvnx32hi */
    case 5756:  /* *pred_extract_firstvnx16hi */
    case 5755:  /* *pred_extract_firstvnx8hi */
    case 5754:  /* *pred_extract_firstvnx4hi */
    case 5753:  /* *pred_extract_firstvnx2hi */
    case 5752:  /* *pred_extract_firstvnx1hi */
    case 5751:  /* *pred_extract_firstvnx64qi */
    case 5750:  /* *pred_extract_firstvnx32qi */
    case 5749:  /* *pred_extract_firstvnx16qi */
    case 5748:  /* *pred_extract_firstvnx8qi */
    case 5747:  /* *pred_extract_firstvnx4qi */
    case 5746:  /* *pred_extract_firstvnx2qi */
    case 5745:  /* *pred_extract_firstvnx1qi */
    case 4534:  /* pred_ffsvnx64bidi */
    case 4533:  /* pred_ffsvnx32bidi */
    case 4532:  /* pred_ffsvnx16bidi */
    case 4531:  /* pred_ffsvnx8bidi */
    case 4530:  /* pred_ffsvnx4bidi */
    case 4529:  /* pred_ffsvnx2bidi */
    case 4528:  /* pred_ffsvnx1bidi */
    case 4527:  /* pred_ffsvnx64bisi */
    case 4526:  /* pred_ffsvnx32bisi */
    case 4525:  /* pred_ffsvnx16bisi */
    case 4524:  /* pred_ffsvnx8bisi */
    case 4523:  /* pred_ffsvnx4bisi */
    case 4522:  /* pred_ffsvnx2bisi */
    case 4521:  /* pred_ffsvnx1bisi */
    case 4520:  /* pred_popcountvnx64bidi */
    case 4519:  /* pred_popcountvnx32bidi */
    case 4518:  /* pred_popcountvnx16bidi */
    case 4517:  /* pred_popcountvnx8bidi */
    case 4516:  /* pred_popcountvnx4bidi */
    case 4515:  /* pred_popcountvnx2bidi */
    case 4514:  /* pred_popcountvnx1bidi */
    case 4513:  /* pred_popcountvnx64bisi */
    case 4512:  /* pred_popcountvnx32bisi */
    case 4511:  /* pred_popcountvnx16bisi */
    case 4510:  /* pred_popcountvnx8bisi */
    case 4509:  /* pred_popcountvnx4bisi */
    case 4508:  /* pred_popcountvnx2bisi */
    case 4507:  /* pred_popcountvnx1bisi */
    case 2743:  /* *pred_msbcvnx8di_overflow_extended_scalar */
    case 2742:  /* *pred_msbcvnx4di_overflow_extended_scalar */
    case 2741:  /* *pred_msbcvnx2di_overflow_extended_scalar */
    case 2740:  /* *pred_msbcvnx1di_overflow_extended_scalar */
    case 2739:  /* *pred_msbcvnx8di_overflow_scalar */
    case 2738:  /* *pred_msbcvnx4di_overflow_scalar */
    case 2737:  /* *pred_msbcvnx2di_overflow_scalar */
    case 2736:  /* *pred_msbcvnx1di_overflow_scalar */
    case 2735:  /* *pred_madcvnx8di_overflow_extended_scalar */
    case 2734:  /* *pred_madcvnx4di_overflow_extended_scalar */
    case 2733:  /* *pred_madcvnx2di_overflow_extended_scalar */
    case 2732:  /* *pred_madcvnx1di_overflow_extended_scalar */
    case 2731:  /* *pred_madcvnx8di_overflow_scalar */
    case 2730:  /* *pred_madcvnx4di_overflow_scalar */
    case 2729:  /* *pred_madcvnx2di_overflow_scalar */
    case 2728:  /* *pred_madcvnx1di_overflow_scalar */
    case 2727:  /* pred_msbcvnx16si_overflow_scalar */
    case 2726:  /* pred_msbcvnx8si_overflow_scalar */
    case 2725:  /* pred_msbcvnx4si_overflow_scalar */
    case 2724:  /* pred_msbcvnx2si_overflow_scalar */
    case 2723:  /* pred_msbcvnx1si_overflow_scalar */
    case 2722:  /* pred_msbcvnx32hi_overflow_scalar */
    case 2721:  /* pred_msbcvnx16hi_overflow_scalar */
    case 2720:  /* pred_msbcvnx8hi_overflow_scalar */
    case 2719:  /* pred_msbcvnx4hi_overflow_scalar */
    case 2718:  /* pred_msbcvnx2hi_overflow_scalar */
    case 2717:  /* pred_msbcvnx1hi_overflow_scalar */
    case 2716:  /* pred_msbcvnx64qi_overflow_scalar */
    case 2715:  /* pred_msbcvnx32qi_overflow_scalar */
    case 2714:  /* pred_msbcvnx16qi_overflow_scalar */
    case 2713:  /* pred_msbcvnx8qi_overflow_scalar */
    case 2712:  /* pred_msbcvnx4qi_overflow_scalar */
    case 2711:  /* pred_msbcvnx2qi_overflow_scalar */
    case 2710:  /* pred_msbcvnx1qi_overflow_scalar */
    case 2709:  /* pred_madcvnx16si_overflow_scalar */
    case 2708:  /* pred_madcvnx8si_overflow_scalar */
    case 2707:  /* pred_madcvnx4si_overflow_scalar */
    case 2706:  /* pred_madcvnx2si_overflow_scalar */
    case 2705:  /* pred_madcvnx1si_overflow_scalar */
    case 2704:  /* pred_madcvnx32hi_overflow_scalar */
    case 2703:  /* pred_madcvnx16hi_overflow_scalar */
    case 2702:  /* pred_madcvnx8hi_overflow_scalar */
    case 2701:  /* pred_madcvnx4hi_overflow_scalar */
    case 2700:  /* pred_madcvnx2hi_overflow_scalar */
    case 2699:  /* pred_madcvnx1hi_overflow_scalar */
    case 2698:  /* pred_madcvnx64qi_overflow_scalar */
    case 2697:  /* pred_madcvnx32qi_overflow_scalar */
    case 2696:  /* pred_madcvnx16qi_overflow_scalar */
    case 2695:  /* pred_madcvnx8qi_overflow_scalar */
    case 2694:  /* pred_madcvnx4qi_overflow_scalar */
    case 2693:  /* pred_madcvnx2qi_overflow_scalar */
    case 2692:  /* pred_madcvnx1qi_overflow_scalar */
    case 2691:  /* pred_msbcvnx8di_overflow */
    case 2690:  /* pred_msbcvnx4di_overflow */
    case 2689:  /* pred_msbcvnx2di_overflow */
    case 2688:  /* pred_msbcvnx1di_overflow */
    case 2687:  /* pred_msbcvnx16si_overflow */
    case 2686:  /* pred_msbcvnx8si_overflow */
    case 2685:  /* pred_msbcvnx4si_overflow */
    case 2684:  /* pred_msbcvnx2si_overflow */
    case 2683:  /* pred_msbcvnx1si_overflow */
    case 2682:  /* pred_msbcvnx32hi_overflow */
    case 2681:  /* pred_msbcvnx16hi_overflow */
    case 2680:  /* pred_msbcvnx8hi_overflow */
    case 2679:  /* pred_msbcvnx4hi_overflow */
    case 2678:  /* pred_msbcvnx2hi_overflow */
    case 2677:  /* pred_msbcvnx1hi_overflow */
    case 2676:  /* pred_msbcvnx64qi_overflow */
    case 2675:  /* pred_msbcvnx32qi_overflow */
    case 2674:  /* pred_msbcvnx16qi_overflow */
    case 2673:  /* pred_msbcvnx8qi_overflow */
    case 2672:  /* pred_msbcvnx4qi_overflow */
    case 2671:  /* pred_msbcvnx2qi_overflow */
    case 2670:  /* pred_msbcvnx1qi_overflow */
    case 2669:  /* pred_madcvnx8di_overflow */
    case 2668:  /* pred_madcvnx4di_overflow */
    case 2667:  /* pred_madcvnx2di_overflow */
    case 2666:  /* pred_madcvnx1di_overflow */
    case 2665:  /* pred_madcvnx16si_overflow */
    case 2664:  /* pred_madcvnx8si_overflow */
    case 2663:  /* pred_madcvnx4si_overflow */
    case 2662:  /* pred_madcvnx2si_overflow */
    case 2661:  /* pred_madcvnx1si_overflow */
    case 2660:  /* pred_madcvnx32hi_overflow */
    case 2659:  /* pred_madcvnx16hi_overflow */
    case 2658:  /* pred_madcvnx8hi_overflow */
    case 2657:  /* pred_madcvnx4hi_overflow */
    case 2656:  /* pred_madcvnx2hi_overflow */
    case 2655:  /* pred_madcvnx1hi_overflow */
    case 2654:  /* pred_madcvnx64qi_overflow */
    case 2653:  /* pred_madcvnx32qi_overflow */
    case 2652:  /* pred_madcvnx16qi_overflow */
    case 2651:  /* pred_madcvnx8qi_overflow */
    case 2650:  /* pred_madcvnx4qi_overflow */
    case 2649:  /* pred_madcvnx2qi_overflow */
    case 2648:  /* pred_madcvnx1qi_overflow */
    case 2647:  /* *pred_msbcvnx8di_extended_scalar */
    case 2646:  /* *pred_msbcvnx4di_extended_scalar */
    case 2645:  /* *pred_msbcvnx2di_extended_scalar */
    case 2644:  /* *pred_msbcvnx1di_extended_scalar */
    case 2643:  /* *pred_msbcvnx8di_scalar */
    case 2642:  /* *pred_msbcvnx4di_scalar */
    case 2641:  /* *pred_msbcvnx2di_scalar */
    case 2640:  /* *pred_msbcvnx1di_scalar */
    case 2639:  /* *pred_madcvnx8di_extended_scalar */
    case 2638:  /* *pred_madcvnx4di_extended_scalar */
    case 2637:  /* *pred_madcvnx2di_extended_scalar */
    case 2636:  /* *pred_madcvnx1di_extended_scalar */
    case 2635:  /* *pred_madcvnx8di_scalar */
    case 2634:  /* *pred_madcvnx4di_scalar */
    case 2633:  /* *pred_madcvnx2di_scalar */
    case 2632:  /* *pred_madcvnx1di_scalar */
    case 2631:  /* pred_msbcvnx16si_scalar */
    case 2630:  /* pred_msbcvnx8si_scalar */
    case 2629:  /* pred_msbcvnx4si_scalar */
    case 2628:  /* pred_msbcvnx2si_scalar */
    case 2627:  /* pred_msbcvnx1si_scalar */
    case 2626:  /* pred_msbcvnx32hi_scalar */
    case 2625:  /* pred_msbcvnx16hi_scalar */
    case 2624:  /* pred_msbcvnx8hi_scalar */
    case 2623:  /* pred_msbcvnx4hi_scalar */
    case 2622:  /* pred_msbcvnx2hi_scalar */
    case 2621:  /* pred_msbcvnx1hi_scalar */
    case 2620:  /* pred_msbcvnx64qi_scalar */
    case 2619:  /* pred_msbcvnx32qi_scalar */
    case 2618:  /* pred_msbcvnx16qi_scalar */
    case 2617:  /* pred_msbcvnx8qi_scalar */
    case 2616:  /* pred_msbcvnx4qi_scalar */
    case 2615:  /* pred_msbcvnx2qi_scalar */
    case 2614:  /* pred_msbcvnx1qi_scalar */
    case 2613:  /* pred_madcvnx16si_scalar */
    case 2612:  /* pred_madcvnx8si_scalar */
    case 2611:  /* pred_madcvnx4si_scalar */
    case 2610:  /* pred_madcvnx2si_scalar */
    case 2609:  /* pred_madcvnx1si_scalar */
    case 2608:  /* pred_madcvnx32hi_scalar */
    case 2607:  /* pred_madcvnx16hi_scalar */
    case 2606:  /* pred_madcvnx8hi_scalar */
    case 2605:  /* pred_madcvnx4hi_scalar */
    case 2604:  /* pred_madcvnx2hi_scalar */
    case 2603:  /* pred_madcvnx1hi_scalar */
    case 2602:  /* pred_madcvnx64qi_scalar */
    case 2601:  /* pred_madcvnx32qi_scalar */
    case 2600:  /* pred_madcvnx16qi_scalar */
    case 2599:  /* pred_madcvnx8qi_scalar */
    case 2598:  /* pred_madcvnx4qi_scalar */
    case 2597:  /* pred_madcvnx2qi_scalar */
    case 2596:  /* pred_madcvnx1qi_scalar */
    case 2595:  /* pred_msbcvnx8di */
    case 2594:  /* pred_msbcvnx4di */
    case 2593:  /* pred_msbcvnx2di */
    case 2592:  /* pred_msbcvnx1di */
    case 2591:  /* pred_msbcvnx16si */
    case 2590:  /* pred_msbcvnx8si */
    case 2589:  /* pred_msbcvnx4si */
    case 2588:  /* pred_msbcvnx2si */
    case 2587:  /* pred_msbcvnx1si */
    case 2586:  /* pred_msbcvnx32hi */
    case 2585:  /* pred_msbcvnx16hi */
    case 2584:  /* pred_msbcvnx8hi */
    case 2583:  /* pred_msbcvnx4hi */
    case 2582:  /* pred_msbcvnx2hi */
    case 2581:  /* pred_msbcvnx1hi */
    case 2580:  /* pred_msbcvnx64qi */
    case 2579:  /* pred_msbcvnx32qi */
    case 2578:  /* pred_msbcvnx16qi */
    case 2577:  /* pred_msbcvnx8qi */
    case 2576:  /* pred_msbcvnx4qi */
    case 2575:  /* pred_msbcvnx2qi */
    case 2574:  /* pred_msbcvnx1qi */
    case 2573:  /* pred_madcvnx8di */
    case 2572:  /* pred_madcvnx4di */
    case 2571:  /* pred_madcvnx2di */
    case 2570:  /* pred_madcvnx1di */
    case 2569:  /* pred_madcvnx16si */
    case 2568:  /* pred_madcvnx8si */
    case 2567:  /* pred_madcvnx4si */
    case 2566:  /* pred_madcvnx2si */
    case 2565:  /* pred_madcvnx1si */
    case 2564:  /* pred_madcvnx32hi */
    case 2563:  /* pred_madcvnx16hi */
    case 2562:  /* pred_madcvnx8hi */
    case 2561:  /* pred_madcvnx4hi */
    case 2560:  /* pred_madcvnx2hi */
    case 2559:  /* pred_madcvnx1hi */
    case 2558:  /* pred_madcvnx64qi */
    case 2557:  /* pred_madcvnx32qi */
    case 2556:  /* pred_madcvnx16qi */
    case 2555:  /* pred_madcvnx8qi */
    case 2554:  /* pred_madcvnx4qi */
    case 2553:  /* pred_madcvnx2qi */
    case 2552:  /* pred_madcvnx1qi */
    case 1481:  /* pred_indexed_ustorevnx64qivnx64qi */
    case 1480:  /* pred_indexed_ostorevnx64qivnx64qi */
    case 1479:  /* pred_indexed_ustorevnx32hivnx32hi */
    case 1478:  /* pred_indexed_ostorevnx32hivnx32hi */
    case 1477:  /* pred_indexed_ustorevnx32hivnx32qi */
    case 1476:  /* pred_indexed_ostorevnx32hivnx32qi */
    case 1475:  /* pred_indexed_ustorevnx32qivnx32hi */
    case 1474:  /* pred_indexed_ostorevnx32qivnx32hi */
    case 1473:  /* pred_indexed_ustorevnx32qivnx32qi */
    case 1472:  /* pred_indexed_ostorevnx32qivnx32qi */
    case 1471:  /* pred_indexed_ustorevnx16sfvnx16si */
    case 1470:  /* pred_indexed_ostorevnx16sfvnx16si */
    case 1469:  /* pred_indexed_ustorevnx16sivnx16si */
    case 1468:  /* pred_indexed_ostorevnx16sivnx16si */
    case 1467:  /* pred_indexed_ustorevnx16hivnx16si */
    case 1466:  /* pred_indexed_ostorevnx16hivnx16si */
    case 1465:  /* pred_indexed_ustorevnx16qivnx16si */
    case 1464:  /* pred_indexed_ostorevnx16qivnx16si */
    case 1463:  /* pred_indexed_ustorevnx16sfvnx16hi */
    case 1462:  /* pred_indexed_ostorevnx16sfvnx16hi */
    case 1461:  /* pred_indexed_ustorevnx16sivnx16hi */
    case 1460:  /* pred_indexed_ostorevnx16sivnx16hi */
    case 1459:  /* pred_indexed_ustorevnx16hivnx16hi */
    case 1458:  /* pred_indexed_ostorevnx16hivnx16hi */
    case 1457:  /* pred_indexed_ustorevnx16qivnx16hi */
    case 1456:  /* pred_indexed_ostorevnx16qivnx16hi */
    case 1455:  /* pred_indexed_ustorevnx16sfvnx16qi */
    case 1454:  /* pred_indexed_ostorevnx16sfvnx16qi */
    case 1453:  /* pred_indexed_ustorevnx16sivnx16qi */
    case 1452:  /* pred_indexed_ostorevnx16sivnx16qi */
    case 1451:  /* pred_indexed_ustorevnx16hivnx16qi */
    case 1450:  /* pred_indexed_ostorevnx16hivnx16qi */
    case 1449:  /* pred_indexed_ustorevnx16qivnx16qi */
    case 1448:  /* pred_indexed_ostorevnx16qivnx16qi */
    case 1447:  /* pred_indexed_ustorevnx8dfvnx8di */
    case 1446:  /* pred_indexed_ostorevnx8dfvnx8di */
    case 1445:  /* pred_indexed_ustorevnx8sfvnx8di */
    case 1444:  /* pred_indexed_ostorevnx8sfvnx8di */
    case 1443:  /* pred_indexed_ustorevnx8divnx8di */
    case 1442:  /* pred_indexed_ostorevnx8divnx8di */
    case 1441:  /* pred_indexed_ustorevnx8sivnx8di */
    case 1440:  /* pred_indexed_ostorevnx8sivnx8di */
    case 1439:  /* pred_indexed_ustorevnx8hivnx8di */
    case 1438:  /* pred_indexed_ostorevnx8hivnx8di */
    case 1437:  /* pred_indexed_ustorevnx8qivnx8di */
    case 1436:  /* pred_indexed_ostorevnx8qivnx8di */
    case 1435:  /* pred_indexed_ustorevnx8dfvnx8si */
    case 1434:  /* pred_indexed_ostorevnx8dfvnx8si */
    case 1433:  /* pred_indexed_ustorevnx8sfvnx8si */
    case 1432:  /* pred_indexed_ostorevnx8sfvnx8si */
    case 1431:  /* pred_indexed_ustorevnx8divnx8si */
    case 1430:  /* pred_indexed_ostorevnx8divnx8si */
    case 1429:  /* pred_indexed_ustorevnx8sivnx8si */
    case 1428:  /* pred_indexed_ostorevnx8sivnx8si */
    case 1427:  /* pred_indexed_ustorevnx8hivnx8si */
    case 1426:  /* pred_indexed_ostorevnx8hivnx8si */
    case 1425:  /* pred_indexed_ustorevnx8qivnx8si */
    case 1424:  /* pred_indexed_ostorevnx8qivnx8si */
    case 1423:  /* pred_indexed_ustorevnx8dfvnx8hi */
    case 1422:  /* pred_indexed_ostorevnx8dfvnx8hi */
    case 1421:  /* pred_indexed_ustorevnx8sfvnx8hi */
    case 1420:  /* pred_indexed_ostorevnx8sfvnx8hi */
    case 1419:  /* pred_indexed_ustorevnx8divnx8hi */
    case 1418:  /* pred_indexed_ostorevnx8divnx8hi */
    case 1417:  /* pred_indexed_ustorevnx8sivnx8hi */
    case 1416:  /* pred_indexed_ostorevnx8sivnx8hi */
    case 1415:  /* pred_indexed_ustorevnx8hivnx8hi */
    case 1414:  /* pred_indexed_ostorevnx8hivnx8hi */
    case 1413:  /* pred_indexed_ustorevnx8qivnx8hi */
    case 1412:  /* pred_indexed_ostorevnx8qivnx8hi */
    case 1411:  /* pred_indexed_ustorevnx8dfvnx8qi */
    case 1410:  /* pred_indexed_ostorevnx8dfvnx8qi */
    case 1409:  /* pred_indexed_ustorevnx8sfvnx8qi */
    case 1408:  /* pred_indexed_ostorevnx8sfvnx8qi */
    case 1407:  /* pred_indexed_ustorevnx8divnx8qi */
    case 1406:  /* pred_indexed_ostorevnx8divnx8qi */
    case 1405:  /* pred_indexed_ustorevnx8sivnx8qi */
    case 1404:  /* pred_indexed_ostorevnx8sivnx8qi */
    case 1403:  /* pred_indexed_ustorevnx8hivnx8qi */
    case 1402:  /* pred_indexed_ostorevnx8hivnx8qi */
    case 1401:  /* pred_indexed_ustorevnx8qivnx8qi */
    case 1400:  /* pred_indexed_ostorevnx8qivnx8qi */
    case 1399:  /* pred_indexed_ustorevnx4dfvnx4di */
    case 1398:  /* pred_indexed_ostorevnx4dfvnx4di */
    case 1397:  /* pred_indexed_ustorevnx4sfvnx4di */
    case 1396:  /* pred_indexed_ostorevnx4sfvnx4di */
    case 1395:  /* pred_indexed_ustorevnx4divnx4di */
    case 1394:  /* pred_indexed_ostorevnx4divnx4di */
    case 1393:  /* pred_indexed_ustorevnx4sivnx4di */
    case 1392:  /* pred_indexed_ostorevnx4sivnx4di */
    case 1391:  /* pred_indexed_ustorevnx4hivnx4di */
    case 1390:  /* pred_indexed_ostorevnx4hivnx4di */
    case 1389:  /* pred_indexed_ustorevnx4qivnx4di */
    case 1388:  /* pred_indexed_ostorevnx4qivnx4di */
    case 1387:  /* pred_indexed_ustorevnx4dfvnx4si */
    case 1386:  /* pred_indexed_ostorevnx4dfvnx4si */
    case 1385:  /* pred_indexed_ustorevnx4sfvnx4si */
    case 1384:  /* pred_indexed_ostorevnx4sfvnx4si */
    case 1383:  /* pred_indexed_ustorevnx4divnx4si */
    case 1382:  /* pred_indexed_ostorevnx4divnx4si */
    case 1381:  /* pred_indexed_ustorevnx4sivnx4si */
    case 1380:  /* pred_indexed_ostorevnx4sivnx4si */
    case 1379:  /* pred_indexed_ustorevnx4hivnx4si */
    case 1378:  /* pred_indexed_ostorevnx4hivnx4si */
    case 1377:  /* pred_indexed_ustorevnx4qivnx4si */
    case 1376:  /* pred_indexed_ostorevnx4qivnx4si */
    case 1375:  /* pred_indexed_ustorevnx4dfvnx4hi */
    case 1374:  /* pred_indexed_ostorevnx4dfvnx4hi */
    case 1373:  /* pred_indexed_ustorevnx4sfvnx4hi */
    case 1372:  /* pred_indexed_ostorevnx4sfvnx4hi */
    case 1371:  /* pred_indexed_ustorevnx4divnx4hi */
    case 1370:  /* pred_indexed_ostorevnx4divnx4hi */
    case 1369:  /* pred_indexed_ustorevnx4sivnx4hi */
    case 1368:  /* pred_indexed_ostorevnx4sivnx4hi */
    case 1367:  /* pred_indexed_ustorevnx4hivnx4hi */
    case 1366:  /* pred_indexed_ostorevnx4hivnx4hi */
    case 1365:  /* pred_indexed_ustorevnx4qivnx4hi */
    case 1364:  /* pred_indexed_ostorevnx4qivnx4hi */
    case 1363:  /* pred_indexed_ustorevnx4dfvnx4qi */
    case 1362:  /* pred_indexed_ostorevnx4dfvnx4qi */
    case 1361:  /* pred_indexed_ustorevnx4sfvnx4qi */
    case 1360:  /* pred_indexed_ostorevnx4sfvnx4qi */
    case 1359:  /* pred_indexed_ustorevnx4divnx4qi */
    case 1358:  /* pred_indexed_ostorevnx4divnx4qi */
    case 1357:  /* pred_indexed_ustorevnx4sivnx4qi */
    case 1356:  /* pred_indexed_ostorevnx4sivnx4qi */
    case 1355:  /* pred_indexed_ustorevnx4hivnx4qi */
    case 1354:  /* pred_indexed_ostorevnx4hivnx4qi */
    case 1353:  /* pred_indexed_ustorevnx4qivnx4qi */
    case 1352:  /* pred_indexed_ostorevnx4qivnx4qi */
    case 1351:  /* pred_indexed_ustorevnx2dfvnx2di */
    case 1350:  /* pred_indexed_ostorevnx2dfvnx2di */
    case 1349:  /* pred_indexed_ustorevnx2sfvnx2di */
    case 1348:  /* pred_indexed_ostorevnx2sfvnx2di */
    case 1347:  /* pred_indexed_ustorevnx2divnx2di */
    case 1346:  /* pred_indexed_ostorevnx2divnx2di */
    case 1345:  /* pred_indexed_ustorevnx2sivnx2di */
    case 1344:  /* pred_indexed_ostorevnx2sivnx2di */
    case 1343:  /* pred_indexed_ustorevnx2hivnx2di */
    case 1342:  /* pred_indexed_ostorevnx2hivnx2di */
    case 1341:  /* pred_indexed_ustorevnx2qivnx2di */
    case 1340:  /* pred_indexed_ostorevnx2qivnx2di */
    case 1339:  /* pred_indexed_ustorevnx2dfvnx2si */
    case 1338:  /* pred_indexed_ostorevnx2dfvnx2si */
    case 1337:  /* pred_indexed_ustorevnx2sfvnx2si */
    case 1336:  /* pred_indexed_ostorevnx2sfvnx2si */
    case 1335:  /* pred_indexed_ustorevnx2divnx2si */
    case 1334:  /* pred_indexed_ostorevnx2divnx2si */
    case 1333:  /* pred_indexed_ustorevnx2sivnx2si */
    case 1332:  /* pred_indexed_ostorevnx2sivnx2si */
    case 1331:  /* pred_indexed_ustorevnx2hivnx2si */
    case 1330:  /* pred_indexed_ostorevnx2hivnx2si */
    case 1329:  /* pred_indexed_ustorevnx2qivnx2si */
    case 1328:  /* pred_indexed_ostorevnx2qivnx2si */
    case 1327:  /* pred_indexed_ustorevnx2dfvnx2hi */
    case 1326:  /* pred_indexed_ostorevnx2dfvnx2hi */
    case 1325:  /* pred_indexed_ustorevnx2sfvnx2hi */
    case 1324:  /* pred_indexed_ostorevnx2sfvnx2hi */
    case 1323:  /* pred_indexed_ustorevnx2divnx2hi */
    case 1322:  /* pred_indexed_ostorevnx2divnx2hi */
    case 1321:  /* pred_indexed_ustorevnx2sivnx2hi */
    case 1320:  /* pred_indexed_ostorevnx2sivnx2hi */
    case 1319:  /* pred_indexed_ustorevnx2hivnx2hi */
    case 1318:  /* pred_indexed_ostorevnx2hivnx2hi */
    case 1317:  /* pred_indexed_ustorevnx2qivnx2hi */
    case 1316:  /* pred_indexed_ostorevnx2qivnx2hi */
    case 1315:  /* pred_indexed_ustorevnx2dfvnx2qi */
    case 1314:  /* pred_indexed_ostorevnx2dfvnx2qi */
    case 1313:  /* pred_indexed_ustorevnx2sfvnx2qi */
    case 1312:  /* pred_indexed_ostorevnx2sfvnx2qi */
    case 1311:  /* pred_indexed_ustorevnx2divnx2qi */
    case 1310:  /* pred_indexed_ostorevnx2divnx2qi */
    case 1309:  /* pred_indexed_ustorevnx2sivnx2qi */
    case 1308:  /* pred_indexed_ostorevnx2sivnx2qi */
    case 1307:  /* pred_indexed_ustorevnx2hivnx2qi */
    case 1306:  /* pred_indexed_ostorevnx2hivnx2qi */
    case 1305:  /* pred_indexed_ustorevnx2qivnx2qi */
    case 1304:  /* pred_indexed_ostorevnx2qivnx2qi */
    case 1303:  /* pred_indexed_ustorevnx1dfvnx1di */
    case 1302:  /* pred_indexed_ostorevnx1dfvnx1di */
    case 1301:  /* pred_indexed_ustorevnx1dfvnx1si */
    case 1300:  /* pred_indexed_ostorevnx1dfvnx1si */
    case 1299:  /* pred_indexed_ustorevnx1dfvnx1hi */
    case 1298:  /* pred_indexed_ostorevnx1dfvnx1hi */
    case 1297:  /* pred_indexed_ustorevnx1dfvnx1qi */
    case 1296:  /* pred_indexed_ostorevnx1dfvnx1qi */
    case 1295:  /* pred_indexed_ustorevnx1sfvnx1di */
    case 1294:  /* pred_indexed_ostorevnx1sfvnx1di */
    case 1293:  /* pred_indexed_ustorevnx1sfvnx1si */
    case 1292:  /* pred_indexed_ostorevnx1sfvnx1si */
    case 1291:  /* pred_indexed_ustorevnx1sfvnx1hi */
    case 1290:  /* pred_indexed_ostorevnx1sfvnx1hi */
    case 1289:  /* pred_indexed_ustorevnx1sfvnx1qi */
    case 1288:  /* pred_indexed_ostorevnx1sfvnx1qi */
    case 1287:  /* pred_indexed_ustorevnx1divnx1di */
    case 1286:  /* pred_indexed_ostorevnx1divnx1di */
    case 1285:  /* pred_indexed_ustorevnx1divnx1si */
    case 1284:  /* pred_indexed_ostorevnx1divnx1si */
    case 1283:  /* pred_indexed_ustorevnx1divnx1hi */
    case 1282:  /* pred_indexed_ostorevnx1divnx1hi */
    case 1281:  /* pred_indexed_ustorevnx1divnx1qi */
    case 1280:  /* pred_indexed_ostorevnx1divnx1qi */
    case 1279:  /* pred_indexed_ustorevnx1sivnx1di */
    case 1278:  /* pred_indexed_ostorevnx1sivnx1di */
    case 1277:  /* pred_indexed_ustorevnx1sivnx1si */
    case 1276:  /* pred_indexed_ostorevnx1sivnx1si */
    case 1275:  /* pred_indexed_ustorevnx1sivnx1hi */
    case 1274:  /* pred_indexed_ostorevnx1sivnx1hi */
    case 1273:  /* pred_indexed_ustorevnx1sivnx1qi */
    case 1272:  /* pred_indexed_ostorevnx1sivnx1qi */
    case 1271:  /* pred_indexed_ustorevnx1hivnx1di */
    case 1270:  /* pred_indexed_ostorevnx1hivnx1di */
    case 1269:  /* pred_indexed_ustorevnx1hivnx1si */
    case 1268:  /* pred_indexed_ostorevnx1hivnx1si */
    case 1267:  /* pred_indexed_ustorevnx1hivnx1hi */
    case 1266:  /* pred_indexed_ostorevnx1hivnx1hi */
    case 1265:  /* pred_indexed_ustorevnx1hivnx1qi */
    case 1264:  /* pred_indexed_ostorevnx1hivnx1qi */
    case 1263:  /* pred_indexed_ustorevnx1qivnx1di */
    case 1262:  /* pred_indexed_ostorevnx1qivnx1di */
    case 1261:  /* pred_indexed_ustorevnx1qivnx1si */
    case 1260:  /* pred_indexed_ostorevnx1qivnx1si */
    case 1259:  /* pred_indexed_ustorevnx1qivnx1hi */
    case 1258:  /* pred_indexed_ostorevnx1qivnx1hi */
    case 1257:  /* pred_indexed_ustorevnx1qivnx1qi */
    case 1256:  /* pred_indexed_ostorevnx1qivnx1qi */
    case 1029:  /* pred_strided_storevnx8df */
    case 1028:  /* pred_strided_storevnx4df */
    case 1027:  /* pred_strided_storevnx2df */
    case 1026:  /* pred_strided_storevnx1df */
    case 1025:  /* pred_strided_storevnx16sf */
    case 1024:  /* pred_strided_storevnx8sf */
    case 1023:  /* pred_strided_storevnx4sf */
    case 1022:  /* pred_strided_storevnx2sf */
    case 1021:  /* pred_strided_storevnx1sf */
    case 1020:  /* pred_strided_storevnx8di */
    case 1019:  /* pred_strided_storevnx4di */
    case 1018:  /* pred_strided_storevnx2di */
    case 1017:  /* pred_strided_storevnx1di */
    case 1016:  /* pred_strided_storevnx16si */
    case 1015:  /* pred_strided_storevnx8si */
    case 1014:  /* pred_strided_storevnx4si */
    case 1013:  /* pred_strided_storevnx2si */
    case 1012:  /* pred_strided_storevnx1si */
    case 1011:  /* pred_strided_storevnx32hi */
    case 1010:  /* pred_strided_storevnx16hi */
    case 1009:  /* pred_strided_storevnx8hi */
    case 1008:  /* pred_strided_storevnx4hi */
    case 1007:  /* pred_strided_storevnx2hi */
    case 1006:  /* pred_strided_storevnx1hi */
    case 1005:  /* pred_strided_storevnx64qi */
    case 1004:  /* pred_strided_storevnx32qi */
    case 1003:  /* pred_strided_storevnx16qi */
    case 1002:  /* pred_strided_storevnx8qi */
    case 1001:  /* pred_strided_storevnx4qi */
    case 1000:  /* pred_strided_storevnx2qi */
    case 999:  /* pred_strided_storevnx1qi */
    case 875:  /* pred_storevnx64bi */
    case 874:  /* pred_storevnx32bi */
    case 873:  /* pred_storevnx16bi */
    case 872:  /* pred_storevnx8bi */
    case 871:  /* pred_storevnx4bi */
    case 870:  /* pred_storevnx2bi */
    case 869:  /* pred_storevnx1bi */
    case 861:  /* pred_storevnx8df */
    case 860:  /* pred_storevnx4df */
    case 859:  /* pred_storevnx2df */
    case 858:  /* pred_storevnx1df */
    case 857:  /* pred_storevnx16sf */
    case 856:  /* pred_storevnx8sf */
    case 855:  /* pred_storevnx4sf */
    case 854:  /* pred_storevnx2sf */
    case 853:  /* pred_storevnx1sf */
    case 852:  /* pred_storevnx8di */
    case 851:  /* pred_storevnx4di */
    case 850:  /* pred_storevnx2di */
    case 849:  /* pred_storevnx1di */
    case 848:  /* pred_storevnx16si */
    case 847:  /* pred_storevnx8si */
    case 846:  /* pred_storevnx4si */
    case 845:  /* pred_storevnx2si */
    case 844:  /* pred_storevnx1si */
    case 843:  /* pred_storevnx32hi */
    case 842:  /* pred_storevnx16hi */
    case 841:  /* pred_storevnx8hi */
    case 840:  /* pred_storevnx4hi */
    case 839:  /* pred_storevnx2hi */
    case 838:  /* pred_storevnx1hi */
    case 837:  /* pred_storevnx64qi */
    case 836:  /* pred_storevnx32qi */
    case 835:  /* pred_storevnx16qi */
    case 834:  /* pred_storevnx8qi */
    case 833:  /* pred_storevnx4qi */
    case 832:  /* pred_storevnx2qi */
    case 831:  /* pred_storevnx1qi */
    case 799:  /* vsetvldi_no_side_effects */
    case 798:  /* vsetvlsi_no_side_effects */
    case 797:  /* vsetvl_discard_resultdi */
    case 796:  /* vsetvl_discard_resultsi */
    case 795:  /* vsetvl_vtype_change_only */
    case 794:  /* vsetvldi */
    case 793:  /* vsetvlsi */
    case 792:  /* *movvnx64bidi_lra */
    case 791:  /* *movvnx32bidi_lra */
    case 790:  /* *movvnx16bidi_lra */
    case 789:  /* *movvnx8bidi_lra */
    case 788:  /* *movvnx4bidi_lra */
    case 787:  /* *movvnx2bidi_lra */
    case 786:  /* *movvnx1bidi_lra */
    case 785:  /* *movvnx64bisi_lra */
    case 784:  /* *movvnx32bisi_lra */
    case 783:  /* *movvnx16bisi_lra */
    case 782:  /* *movvnx8bisi_lra */
    case 781:  /* *movvnx4bisi_lra */
    case 780:  /* *movvnx2bisi_lra */
    case 779:  /* *movvnx1bisi_lra */
    case 778:  /* *movvnx1sfdi_lra */
    case 777:  /* *movvnx1sfsi_lra */
    case 776:  /* *movvnx1sidi_lra */
    case 775:  /* *movvnx1sisi_lra */
    case 774:  /* *movvnx2hidi_lra */
    case 773:  /* *movvnx2hisi_lra */
    case 772:  /* *movvnx1hidi_lra */
    case 771:  /* *movvnx1hisi_lra */
    case 770:  /* *movvnx4qidi_lra */
    case 769:  /* *movvnx4qisi_lra */
    case 768:  /* *movvnx2qidi_lra */
    case 767:  /* *movvnx2qisi_lra */
    case 766:  /* *movvnx1qidi_lra */
    case 765:  /* *movvnx1qisi_lra */
    case 764:  /* *movvnx64bi */
    case 763:  /* *movvnx32bi */
    case 762:  /* *movvnx16bi */
    case 761:  /* *movvnx8bi */
    case 760:  /* *movvnx4bi */
    case 759:  /* *movvnx2bi */
    case 758:  /* *movvnx1bi */
    case 757:  /* *movvnx1sf_fract */
    case 756:  /* *movvnx1si_fract */
    case 755:  /* *movvnx2hi_fract */
    case 754:  /* *movvnx1hi_fract */
    case 753:  /* *movvnx4qi_fract */
    case 752:  /* *movvnx2qi_fract */
    case 751:  /* *movvnx1qi_fract */
    case 750:  /* *movvnx8df_whole */
    case 749:  /* *movvnx4df_whole */
    case 748:  /* *movvnx2df_whole */
    case 747:  /* *movvnx1df_whole */
    case 746:  /* *movvnx16sf_whole */
    case 745:  /* *movvnx8sf_whole */
    case 744:  /* *movvnx4sf_whole */
    case 743:  /* *movvnx2sf_whole */
    case 742:  /* *movvnx1sf_whole */
    case 741:  /* *movvnx8di_whole */
    case 740:  /* *movvnx4di_whole */
    case 739:  /* *movvnx2di_whole */
    case 738:  /* *movvnx1di_whole */
    case 737:  /* *movvnx16si_whole */
    case 736:  /* *movvnx8si_whole */
    case 735:  /* *movvnx4si_whole */
    case 734:  /* *movvnx2si_whole */
    case 733:  /* *movvnx1si_whole */
    case 732:  /* *movvnx32hi_whole */
    case 731:  /* *movvnx16hi_whole */
    case 730:  /* *movvnx8hi_whole */
    case 729:  /* *movvnx4hi_whole */
    case 728:  /* *movvnx2hi_whole */
    case 727:  /* *movvnx64qi_whole */
    case 726:  /* *movvnx32qi_whole */
    case 725:  /* *movvnx16qi_whole */
    case 724:  /* *movvnx8qi_whole */
    case 723:  /* *movvnx4qi_whole */
    case 722:  /* vlmax_avldi */
    case 721:  /* vlmax_avlsi */
    case 720:  /* *vlmul_extx64vnx1qi */
    case 719:  /* *vlmul_extx32vnx1hi */
    case 718:  /* *vlmul_extx32vnx2qi */
    case 717:  /* *vlmul_extx32vnx1qi */
    case 716:  /* *vlmul_extx16vnx1sf */
    case 715:  /* *vlmul_extx16vnx1si */
    case 714:  /* *vlmul_extx16vnx2hi */
    case 713:  /* *vlmul_extx16vnx1hi */
    case 712:  /* *vlmul_extx16vnx4qi */
    case 711:  /* *vlmul_extx16vnx2qi */
    case 710:  /* *vlmul_extx16vnx1qi */
    case 709:  /* *vlmul_extx8vnx1df */
    case 708:  /* *vlmul_extx8vnx2sf */
    case 707:  /* *vlmul_extx8vnx1sf */
    case 706:  /* *vlmul_extx8vnx1di */
    case 705:  /* *vlmul_extx8vnx2si */
    case 704:  /* *vlmul_extx8vnx1si */
    case 703:  /* *vlmul_extx8vnx4hi */
    case 702:  /* *vlmul_extx8vnx2hi */
    case 701:  /* *vlmul_extx8vnx1hi */
    case 700:  /* *vlmul_extx8vnx8qi */
    case 699:  /* *vlmul_extx8vnx4qi */
    case 698:  /* *vlmul_extx8vnx2qi */
    case 697:  /* *vlmul_extx8vnx1qi */
    case 696:  /* *vlmul_extx4vnx2df */
    case 695:  /* *vlmul_extx4vnx1df */
    case 694:  /* *vlmul_extx4vnx4sf */
    case 693:  /* *vlmul_extx4vnx2sf */
    case 692:  /* *vlmul_extx4vnx1sf */
    case 691:  /* *vlmul_extx4vnx2di */
    case 690:  /* *vlmul_extx4vnx1di */
    case 689:  /* *vlmul_extx4vnx4si */
    case 688:  /* *vlmul_extx4vnx2si */
    case 687:  /* *vlmul_extx4vnx1si */
    case 686:  /* *vlmul_extx4vnx8hi */
    case 685:  /* *vlmul_extx4vnx4hi */
    case 684:  /* *vlmul_extx4vnx2hi */
    case 683:  /* *vlmul_extx4vnx1hi */
    case 682:  /* *vlmul_extx4vnx16qi */
    case 681:  /* *vlmul_extx4vnx8qi */
    case 680:  /* *vlmul_extx4vnx4qi */
    case 679:  /* *vlmul_extx4vnx2qi */
    case 678:  /* *vlmul_extx4vnx1qi */
    case 677:  /* *vlmul_extx2vnx4df */
    case 676:  /* *vlmul_extx2vnx2df */
    case 675:  /* *vlmul_extx2vnx1df */
    case 674:  /* *vlmul_extx2vnx8sf */
    case 673:  /* *vlmul_extx2vnx4sf */
    case 672:  /* *vlmul_extx2vnx2sf */
    case 671:  /* *vlmul_extx2vnx1sf */
    case 670:  /* *vlmul_extx2vnx4di */
    case 669:  /* *vlmul_extx2vnx2di */
    case 668:  /* *vlmul_extx2vnx1di */
    case 667:  /* *vlmul_extx2vnx8si */
    case 666:  /* *vlmul_extx2vnx4si */
    case 665:  /* *vlmul_extx2vnx2si */
    case 664:  /* *vlmul_extx2vnx1si */
    case 663:  /* *vlmul_extx2vnx16hi */
    case 662:  /* *vlmul_extx2vnx8hi */
    case 661:  /* *vlmul_extx2vnx4hi */
    case 660:  /* *vlmul_extx2vnx2hi */
    case 659:  /* *vlmul_extx2vnx1hi */
    case 658:  /* *vlmul_extx2vnx32qi */
    case 657:  /* *vlmul_extx2vnx16qi */
    case 656:  /* *vlmul_extx2vnx8qi */
    case 655:  /* *vlmul_extx2vnx4qi */
    case 654:  /* *vlmul_extx2vnx2qi */
    case 653:  /* *vlmul_extx2vnx1qi */
    case 652:  /* vundefinedvnx64bi */
    case 651:  /* vundefinedvnx32bi */
    case 650:  /* vundefinedvnx16bi */
    case 649:  /* vundefinedvnx8bi */
    case 648:  /* vundefinedvnx4bi */
    case 647:  /* vundefinedvnx2bi */
    case 646:  /* vundefinedvnx1bi */
    case 645:  /* vundefinedvnx8df */
    case 644:  /* vundefinedvnx4df */
    case 643:  /* vundefinedvnx2df */
    case 642:  /* vundefinedvnx1df */
    case 641:  /* vundefinedvnx16sf */
    case 640:  /* vundefinedvnx8sf */
    case 639:  /* vundefinedvnx4sf */
    case 638:  /* vundefinedvnx2sf */
    case 637:  /* vundefinedvnx1sf */
    case 636:  /* vundefinedvnx8di */
    case 635:  /* vundefinedvnx4di */
    case 634:  /* vundefinedvnx2di */
    case 633:  /* vundefinedvnx1di */
    case 632:  /* vundefinedvnx16si */
    case 631:  /* vundefinedvnx8si */
    case 630:  /* vundefinedvnx4si */
    case 629:  /* vundefinedvnx2si */
    case 628:  /* vundefinedvnx1si */
    case 627:  /* vundefinedvnx32hi */
    case 626:  /* vundefinedvnx16hi */
    case 625:  /* vundefinedvnx8hi */
    case 624:  /* vundefinedvnx4hi */
    case 623:  /* vundefinedvnx2hi */
    case 622:  /* vundefinedvnx1hi */
    case 621:  /* vundefinedvnx64qi */
    case 620:  /* vundefinedvnx32qi */
    case 619:  /* vundefinedvnx16qi */
    case 618:  /* vundefinedvnx8qi */
    case 617:  /* vundefinedvnx4qi */
    case 616:  /* vundefinedvnx2qi */
    case 615:  /* vundefinedvnx1qi */
    case 614:  /* *th_mempair_load_zero_extendsidi2 */
    case 613:  /* *th_mempair_load_extendsidi2 */
    case 612:  /* *th_mempair_store_di2 */
    case 611:  /* *th_mempair_store_si2 */
    case 610:  /* *th_mempair_load_di2 */
    case 609:  /* *th_mempair_load_si2 */
    case 608:  /* *th_sextw_msubhisi4 */
    case 607:  /* *th_msubhisi4 */
    case 606:  /* *th_mulswsi2 */
    case 605:  /* *th_mulswsi */
    case 604:  /* *th_mulsdi */
    case 603:  /* *th_mulssi */
    case 602:  /* *th_sextw_maddhisi4 */
    case 601:  /* *th_maddhisi4 */
    case 600:  /* *th_mulawsi2 */
    case 599:  /* *th_mulawsi */
    case 598:  /* *th_muladi */
    case 597:  /* *th_mulasi */
    case 596:  /* th_fmv_x_hw */
    case 595:  /* th_fmv_x_w */
    case 594:  /* th_fmv_hw_w_x */
    case 593:  /* *th_cond_gpr_movdidi */
    case 592:  /* *th_cond_gpr_movsidi */
    case 591:  /* *th_cond_gpr_movdisi */
    case 590:  /* *th_cond_gpr_movsisi */
    case 589:  /* *th_cond_movdidi */
    case 588:  /* *th_cond_movsidi */
    case 587:  /* *th_cond_movdisi */
    case 586:  /* *th_cond_movsisi */
    case 585:  /* *th_tstdi3 */
    case 584:  /* *th_tstsi3 */
    case 583:  /* *th_revdi2 */
    case 582:  /* *th_revsi2 */
    case 581:  /* *th_clzdi2 */
    case 580:  /* *th_clzsi2 */
    case 579:  /* *th_extudi4 */
    case 578:  /* *th_extusi4 */
    case 577:  /* *th_extdi4 */
    case 576:  /* *th_extsi4 */
    case 575:  /* *th_srridi3 */
    case 574:  /* *th_srrisi3 */
    case 573:  /* *th_addsldi4 */
    case 572:  /* *th_addslsi4 */
    case 571:  /* *local_pic_store_sfhf */
    case 570:  /* *local_pic_store_sfdf */
    case 569:  /* *local_pic_store_sfsf */
    case 568:  /* *local_pic_store_sfhf */
    case 567:  /* *local_pic_store_sfdf */
    case 566:  /* *local_pic_store_sfsf */
    case 565:  /* *local_pic_store_32dhf */
    case 564:  /* *local_pic_store_32ddf */
    case 563:  /* *local_pic_store_32dsf */
    case 562:  /* *local_pic_store_32dhf */
    case 561:  /* *local_pic_store_32ddf */
    case 560:  /* *local_pic_store_32dsf */
    case 559:  /* *local_pic_storehf */
    case 558:  /* *local_pic_storedf */
    case 557:  /* *local_pic_storesf */
    case 556:  /* *local_pic_storehf */
    case 555:  /* *local_pic_storedf */
    case 554:  /* *local_pic_storesf */
    case 553:  /* *local_pic_storedi */
    case 552:  /* *local_pic_storesi */
    case 551:  /* *local_pic_storehi */
    case 550:  /* *local_pic_storeqi */
    case 549:  /* *local_pic_storedi */
    case 548:  /* *local_pic_storesi */
    case 547:  /* *local_pic_storehi */
    case 546:  /* *local_pic_storeqi */
    case 545:  /* *local_pic_load_sfhf */
    case 544:  /* *local_pic_load_sfdf */
    case 543:  /* *local_pic_load_sfsf */
    case 542:  /* *local_pic_load_32dhf */
    case 541:  /* *local_pic_load_32ddf */
    case 540:  /* *local_pic_load_32dsf */
    case 539:  /* *local_pic_load_32dhf */
    case 538:  /* *local_pic_load_32ddf */
    case 537:  /* *local_pic_load_32dsf */
    case 536:  /* *local_pic_loadhf */
    case 535:  /* *local_pic_loaddf */
    case 534:  /* *local_pic_loadsf */
    case 533:  /* *local_pic_loadhf */
    case 532:  /* *local_pic_loaddf */
    case 531:  /* *local_pic_loadsf */
    case 530:  /* *local_pic_load_usi */
    case 529:  /* *local_pic_load_usi */
    case 528:  /* *local_pic_load_usi */
    case 527:  /* *local_pic_load_uhi */
    case 526:  /* *local_pic_load_uhi */
    case 525:  /* *local_pic_load_uhi */
    case 524:  /* *local_pic_load_uqi */
    case 523:  /* *local_pic_load_uqi */
    case 522:  /* *local_pic_load_uqi */
    case 521:  /* *local_pic_load_ssi */
    case 520:  /* *local_pic_load_ssi */
    case 519:  /* *local_pic_load_ssi */
    case 518:  /* *local_pic_load_shi */
    case 517:  /* *local_pic_load_shi */
    case 516:  /* *local_pic_load_shi */
    case 515:  /* *local_pic_load_sqi */
    case 514:  /* *local_pic_load_sqi */
    case 513:  /* *local_pic_load_sqi */
    case 512:  /* *local_pic_loaddi */
    case 511:  /* *local_pic_loadsi */
    case 510:  /* *local_pic_loadhi */
    case 509:  /* *local_pic_loadqi */
    case 508:  /* subword_atomic_cas_strong */
    case 507:  /* atomic_cas_value_strongdi */
    case 506:  /* atomic_cas_value_strongsi */
    case 505:  /* subword_atomic_exchange_strong */
    case 504:  /* atomic_exchangedi */
    case 503:  /* atomic_exchangesi */
    case 502:  /* subword_atomic_fetch_strong_nand */
    case 501:  /* subword_atomic_fetch_strong_and */
    case 500:  /* subword_atomic_fetch_strong_xor */
    case 499:  /* subword_atomic_fetch_strong_or */
    case 498:  /* subword_atomic_fetch_strong_add */
    case 497:  /* atomic_fetch_anddi */
    case 496:  /* atomic_fetch_xordi */
    case 495:  /* atomic_fetch_ordi */
    case 494:  /* atomic_fetch_adddi */
    case 493:  /* atomic_fetch_andsi */
    case 492:  /* atomic_fetch_xorsi */
    case 491:  /* atomic_fetch_orsi */
    case 490:  /* atomic_fetch_addsi */
    case 489:  /* atomic_anddi */
    case 488:  /* atomic_xordi */
    case 487:  /* atomic_ordi */
    case 486:  /* atomic_adddi */
    case 485:  /* atomic_andsi */
    case 484:  /* atomic_xorsi */
    case 483:  /* atomic_orsi */
    case 482:  /* atomic_addsi */
    case 481:  /* atomic_storedi */
    case 480:  /* atomic_storesi */
    case 479:  /* atomic_loaddi */
    case 478:  /* atomic_loadsi */
    case 477:  /* mem_thread_fence_1 */
    case 476:  /* riscv_sm4ks_di */
    case 475:  /* riscv_sm4ks_si */
    case 474:  /* riscv_sm4ed_di */
    case 473:  /* riscv_sm4ed_si */
    case 472:  /* riscv_sm3p1_di */
    case 471:  /* riscv_sm3p1_si */
    case 470:  /* riscv_sm3p0_di */
    case 469:  /* riscv_sm3p0_si */
    case 468:  /* riscv_sha512sum1 */
    case 467:  /* riscv_sha512sum0 */
    case 466:  /* riscv_sha512sig1 */
    case 465:  /* riscv_sha512sig0 */
    case 464:  /* riscv_sha512sum1r */
    case 463:  /* riscv_sha512sum0r */
    case 462:  /* riscv_sha512sig1l */
    case 461:  /* riscv_sha512sig1h */
    case 460:  /* riscv_sha512sig0l */
    case 459:  /* riscv_sha512sig0h */
    case 458:  /* riscv_sha256sum1_di */
    case 457:  /* riscv_sha256sum1_si */
    case 456:  /* riscv_sha256sum0_di */
    case 455:  /* riscv_sha256sum0_si */
    case 454:  /* riscv_sha256sig1_di */
    case 453:  /* riscv_sha256sig1_si */
    case 452:  /* riscv_sha256sig0_di */
    case 451:  /* riscv_sha256sig0_si */
    case 450:  /* riscv_aes64esm */
    case 449:  /* riscv_aes64es */
    case 448:  /* riscv_aes32esmi */
    case 447:  /* riscv_aes32esi */
    case 446:  /* riscv_aes64ks2 */
    case 445:  /* riscv_aes64ks1i */
    case 444:  /* riscv_aes64im */
    case 443:  /* riscv_aes64dsm */
    case 442:  /* riscv_aes64ds */
    case 441:  /* riscv_aes32dsmi */
    case 440:  /* riscv_aes32dsi */
    case 439:  /* riscv_xperm8_di */
    case 438:  /* riscv_xperm8_si */
    case 437:  /* riscv_xperm4_di */
    case 436:  /* riscv_xperm4_si */
    case 435:  /* riscv_clmulh_di */
    case 434:  /* riscv_clmulh_si */
    case 433:  /* riscv_clmul_di */
    case 432:  /* riscv_clmul_si */
    case 431:  /* riscv_packw */
    case 430:  /* riscv_packh_di */
    case 429:  /* riscv_packh_si */
    case 428:  /* riscv_pack_disi */
    case 427:  /* riscv_pack_dihi */
    case 426:  /* riscv_pack_sisi */
    case 425:  /* riscv_pack_sihi */
    case 424:  /* riscv_unzip */
    case 423:  /* riscv_zip */
    case 422:  /* riscv_brev8_di */
    case 421:  /* riscv_brev8_si */
    case 420:  /* *branchdi_mask_twobits_equals_singlebit */
    case 419:  /* *branchsi_mask_twobits_equals_singlebit */
    case 418:  /* *andidi_extrabit */
    case 417:  /* *andisi_extrabit */
    case 416:  /* *xoridi_extrabit */
    case 415:  /* *ioridi_extrabit */
    case 414:  /* *xorisi_extrabit */
    case 413:  /* *iorisi_extrabit */
    case 412:  /* *bexti */
    case 411:  /* *bexti */
    case 410:  /* *bextdi */
    case 409:  /* *bextsi */
    case 408:  /* *bextdi */
    case 407:  /* *bextsi */
    case 406:  /* *binvidi */
    case 405:  /* *binvisi */
    case 404:  /* *binvdi */
    case 403:  /* *binvsi */
    case 402:  /* *bclridisi_nottwobits */
    case 401:  /* *bclridi_nottwobits */
    case 400:  /* *bclrisi_nottwobits */
    case 399:  /* *bclridi */
    case 398:  /* *bclrisi */
    case 397:  /* *bclrdi */
    case 396:  /* *bclrsi */
    case 395:  /* *bsetidisi */
    case 394:  /* *bsetidi */
    case 393:  /* *bsetisi */
    case 392:  /* *bsetdi_1_mask */
    case 391:  /* *bsetsi_1_mask */
    case 390:  /* *bsetdi_1 */
    case 389:  /* *bsetsi_1 */
    case 388:  /* *bsetdi_mask */
    case 387:  /* *bsetsi_mask */
    case 386:  /* *bsetdi */
    case 385:  /* *bsetsi */
    case 384:  /* *minmax */
    case 383:  /* *minmax */
    case 382:  /* *minmax */
    case 381:  /* *minmax */
    case 380:  /* umaxdi3 */
    case 379:  /* smaxdi3 */
    case 378:  /* umindi3 */
    case 377:  /* smindi3 */
    case 376:  /* umaxsi3 */
    case 375:  /* smaxsi3 */
    case 374:  /* uminsi3 */
    case 373:  /* sminsi3 */
    case 372:  /* *bswapdi2 */
    case 371:  /* *bswapsi2 */
    case 370:  /* orcbdi2 */
    case 369:  /* orcbsi2 */
    case 368:  /* rotlsi3_sext */
    case 367:  /* rotldi3 */
    case 366:  /* rotlsi3 */
    case 365:  /* *rotrsi3_sext */
    case 364:  /* *rotrdi3 */
    case 363:  /* *rotrsi3 */
    case 362:  /* *zero_extendhidi2_zbb */
    case 361:  /* *zero_extendhisi2_zbb */
    case 360:  /* *extendhidi2_zbb */
    case 359:  /* *extendhisi2_zbb */
    case 358:  /* *extendhihi2_zbb */
    case 357:  /* *extendqidi2_zbb */
    case 356:  /* *extendqisi2_zbb */
    case 355:  /* *extendqihi2_zbb */
    case 354:  /* *zero_extendhidi2_bitmanip */
    case 353:  /* *zero_extendhisi2_bitmanip */
    case 352:  /* *popcountdi2 */
    case 351:  /* *ctzdi2 */
    case 350:  /* *clzdi2 */
    case 349:  /* *popcountdisi2 */
    case 348:  /* *ctzdisi2 */
    case 347:  /* *clzdisi2 */
    case 346:  /* *popcountsi2 */
    case 345:  /* *ctzsi2 */
    case 344:  /* *clzsi2 */
    case 343:  /* *xor_notdi */
    case 342:  /* *xor_notsi */
    case 341:  /* *ior_notdi */
    case 340:  /* *and_notdi */
    case 339:  /* *ior_notsi */
    case 338:  /* *and_notsi */
    case 337:  /* *slliuw */
    case 336:  /* *add.uw */
    case 335:  /* *shNadduw */
    case 334:  /* *andi_add.uw */
    case 333:  /* *shNadd */
    case 332:  /* *shNadd */
    case 331:  /* *zero_extendsidi2_bitmanip */
    case 330:  /* riscv_prefetchi_di */
    case 329:  /* riscv_prefetchi_si */
    case 328:  /* prefetch */
    case 327:  /* riscv_zero_di */
    case 326:  /* riscv_zero_si */
    case 325:  /* riscv_inval_di */
    case 324:  /* riscv_inval_si */
    case 323:  /* riscv_flush_di */
    case 322:  /* riscv_flush_si */
    case 321:  /* riscv_clean_di */
    case 320:  /* riscv_clean_si */
    case 319:  /* stack_protect_test_di */
    case 318:  /* stack_protect_test_si */
    case 317:  /* stack_protect_set_di */
    case 316:  /* stack_protect_set_si */
    case 315:  /* stack_tiedi */
    case 314:  /* stack_tiesi */
    case 313:  /* riscv_uret */
    case 312:  /* riscv_sret */
    case 311:  /* riscv_mret */
    case 310:  /* *riscv_fsnvsnanhf2 */
    case 309:  /* *riscv_fsnvsnandf2 */
    case 308:  /* *riscv_fsnvsnansf2 */
    case 307:  /* riscv_fsflags */
    case 306:  /* riscv_frflags */
    case 305:  /* gpr_restore_return */
    case 304:  /* gpr_restore */
    case 303:  /* gpr_save */
    case 302:  /* trap */
    case 301:  /* nop */
    case 300:  /* call_value_internal */
    case 299:  /* call_internal */
    case 298:  /* sibcall_value_internal */
    case 297:  /* sibcall_internal */
    case 296:  /* eh_return_internal */
    case 295:  /* eh_set_lr_di */
    case 294:  /* eh_set_lr_si */
    case 293:  /* simple_return_internal */
    case 292:  /* simple_return */
    case 291:  /* blockage */
    case 290:  /* tablejumpdi */
    case 289:  /* tablejumpsi */
    case 288:  /* indirect_jumpdi */
    case 287:  /* indirect_jumpsi */
    case 286:  /* jump */
    case 285:  /* *sleu_didi */
    case 284:  /* *sle_didi */
    case 283:  /* *sleu_disi */
    case 282:  /* *sle_disi */
    case 281:  /* *sleu_sisi */
    case 280:  /* *sle_sisi */
    case 279:  /* *sltu_didi */
    case 278:  /* *slt_didi */
    case 277:  /* *sltu_disi */
    case 276:  /* *slt_disi */
    case 275:  /* *sltu_sisi */
    case 274:  /* *slt_sisi */
    case 273:  /* *sgeu_didi */
    case 272:  /* *sge_didi */
    case 271:  /* *sgeu_disi */
    case 270:  /* *sge_disi */
    case 269:  /* *sgeu_sisi */
    case 268:  /* *sge_sisi */
    case 267:  /* *sgtu_didi */
    case 266:  /* *sgt_didi */
    case 265:  /* *sgtu_disi */
    case 264:  /* *sgt_disi */
    case 263:  /* *sgtu_sisi */
    case 262:  /* *sgt_sisi */
    case 261:  /* *sne_zero_didi */
    case 260:  /* *sne_zero_disi */
    case 259:  /* *sne_zero_sisi */
    case 258:  /* *seq_zero_didi */
    case 257:  /* *seq_zero_disi */
    case 256:  /* *seq_zero_sisi */
    case 255:  /* *cstorehfdi4 */
    case 254:  /* *cstorehfsi4 */
    case 253:  /* *cstoredfdi4 */
    case 252:  /* *cstoredfsi4 */
    case 251:  /* *cstoresfdi4 */
    case 250:  /* *cstoresfsi4 */
    case 249:  /* *branch_on_bit_rangedi */
    case 248:  /* *branch_on_bit_rangesi */
    case 247:  /* *branch_on_bitdi */
    case 246:  /* *branch_on_bitsi */
    case 245:  /* *movdidicc */
    case 244:  /* *movsidicc */
    case 243:  /* *movsisicc */
    case 242:  /* *branchdi */
    case 241:  /* *branchsi */
    case 240:  /* *branchdi_shiftedmask_equals_zero */
    case 239:  /* *branchsi_shiftedmask_equals_zero */
    case 238:  /* *branchhi_shiftedmask_equals_zero */
    case 237:  /* *branchqi_shiftedmask_equals_zero */
    case 236:  /* *branchdi_shiftedmask_equals_zero */
    case 235:  /* *branchsi_shiftedmask_equals_zero */
    case 234:  /* *branchhi_shiftedmask_equals_zero */
    case 233:  /* *branchqi_shiftedmask_equals_zero */
    case 232:  /* *branchdi_shiftedarith_equals_zero */
    case 231:  /* *branchsi_shiftedarith_equals_zero */
    case 230:  /* *branchhi_shiftedarith_equals_zero */
    case 229:  /* *branchqi_shiftedarith_equals_zero */
    case 228:  /* *branchsi_shiftedarith_equals_zero */
    case 227:  /* *branchhi_shiftedarith_equals_zero */
    case 226:  /* *branchqi_shiftedarith_equals_zero */
    case 225:  /* zero_extendsidi2_shifted */
    case 224:  /* *lshrsi3_zero_extend_3 */
    case 223:  /* *lshrsi3_zero_extend_2 */
    case 222:  /* *lshrsi3_zero_extend_1 */
    case 221:  /* *lshrsi3_extend_mask_1 */
    case 220:  /* *ashrsi3_extend_mask_1 */
    case 219:  /* *ashlsi3_extend_mask_1 */
    case 218:  /* *lshrsi3_extend_mask */
    case 217:  /* *ashrsi3_extend_mask */
    case 216:  /* *ashlsi3_extend_mask */
    case 215:  /* *lshrsi3_extend */
    case 214:  /* *ashrsi3_extend */
    case 213:  /* *ashlsi3_extend */
    case 212:  /* *lshrdi3_mask_1 */
    case 211:  /* *ashrdi3_mask_1 */
    case 210:  /* *ashldi3_mask_1 */
    case 209:  /* *lshrdi3_mask */
    case 208:  /* *ashrdi3_mask */
    case 207:  /* *ashldi3_mask */
    case 206:  /* lshrdi3 */
    case 205:  /* ashrdi3 */
    case 204:  /* ashldi3 */
    case 203:  /* *lshrsi3_mask_1 */
    case 202:  /* *ashrsi3_mask_1 */
    case 201:  /* *ashlsi3_mask_1 */
    case 200:  /* *lshrsi3_mask */
    case 199:  /* *ashrsi3_mask */
    case 198:  /* *ashlsi3_mask */
    case 197:  /* lshrsi3 */
    case 196:  /* ashrsi3 */
    case 195:  /* ashlsi3 */
    case 194:  /* riscv_pause */
    case 193:  /* fence_i */
    case 192:  /* fence */
    case 191:  /* *movdf_softfloat */
    case 190:  /* *movdf_hardfloat_rv64 */
    case 189:  /* *movdf_hardfloat_rv32 */
    case 188:  /* *movsf_softfloat */
    case 187:  /* *movsf_hardfloat */
    case 186:  /* *movqi_internal */
    case 185:  /* *xorsihi3 */
    case 184:  /* *xorhihi3 */
    case 183:  /* *addsihi3 */
    case 182:  /* *addhihi3 */
    case 181:  /* *movhi_internal */
    case 180:  /* *movsi_internal */
    case 179:  /* *movdi_64bit */
    case 178:  /* *movdi_32bit */
    case 177:  /* *mvconst_internal */
    case 176:  /* *mvconst_internal */
    case 175:  /* *lowdi */
    case 174:  /* *lowsi */
    case 173:  /* auipcdi */
    case 172:  /* auipcsi */
    case 171:  /* got_load_tls_iedi */
    case 170:  /* got_load_tls_iesi */
    case 169:  /* got_load_tls_gddi */
    case 168:  /* got_load_tls_gdsi */
    case 167:  /* tls_add_tp_ledi */
    case 166:  /* tls_add_tp_lesi */
    case 165:  /* got_loaddi */
    case 164:  /* got_loadsi */
    case 163:  /* lroundhfdi2 */
    case 162:  /* lrinthfdi2 */
    case 161:  /* lroundhfsi2 */
    case 160:  /* lrinthfsi2 */
    case 159:  /* lrounddfdi2 */
    case 158:  /* lrintdfdi2 */
    case 157:  /* lrounddfsi2 */
    case 156:  /* lrintdfsi2 */
    case 155:  /* lroundsfdi2 */
    case 154:  /* lrintsfdi2 */
    case 153:  /* lroundsfsi2 */
    case 152:  /* lrintsfsi2 */
    case 151:  /* floatunsdihf2 */
    case 150:  /* floatunssihf2 */
    case 149:  /* floatunsdidf2 */
    case 148:  /* floatunssidf2 */
    case 147:  /* floatunsdisf2 */
    case 146:  /* floatunssisf2 */
    case 145:  /* floatdihf2 */
    case 144:  /* floatsihf2 */
    case 143:  /* floatdidf2 */
    case 142:  /* floatsidf2 */
    case 141:  /* floatdisf2 */
    case 140:  /* floatsisf2 */
    case 139:  /* fixuns_trunchfdi2 */
    case 138:  /* fixuns_trunchfsi2 */
    case 137:  /* fixuns_truncdfdi2 */
    case 136:  /* fixuns_truncdfsi2 */
    case 135:  /* fixuns_truncsfdi2 */
    case 134:  /* fixuns_truncsfsi2 */
    case 133:  /* fix_trunchfdi2 */
    case 132:  /* fix_trunchfsi2 */
    case 131:  /* fix_truncdfdi2 */
    case 130:  /* fix_truncdfsi2 */
    case 129:  /* fix_truncsfdi2 */
    case 128:  /* fix_truncsfsi2 */
    case 127:  /* *movhf_softfloat */
    case 126:  /* *movhf_hardfloat */
    case 125:  /* extendhfdf2 */
    case 124:  /* extendsfdf2 */
    case 123:  /* extendhfsf2 */
    case 122:  /* *extendhidi2 */
    case 121:  /* *extendhisi2 */
    case 120:  /* *extendhihi2 */
    case 119:  /* *extendqidi2 */
    case 118:  /* *extendqisi2 */
    case 117:  /* *extendqihi2 */
    case 116:  /* extendsidi2 */
    case 115:  /* zero_extendqidi2 */
    case 114:  /* zero_extendqisi2 */
    case 113:  /* zero_extendqihi2 */
    case 112:  /* *zero_extendhidi2 */
    case 111:  /* *zero_extendhisi2 */
    case 110:  /* *zero_extendsidi2_internal */
    case 109:  /* truncdfhf2 */
    case 108:  /* truncsfhf2 */
    case 107:  /* truncdfsf2 */
    case 106:  /* *one_cmplsi2_internal */
    case 105:  /* one_cmpldi2 */
    case 104:  /* one_cmplsi2 */
    case 103:  /* *xorsi3_internal */
    case 102:  /* *iorsi3_internal */
    case 101:  /* *andsi3_internal */
    case 100:  /* xordi3 */
    case 99:  /* iordi3 */
    case 98:  /* anddi3 */
    case 97:  /* xorsi3 */
    case 96:  /* iorsi3 */
    case 95:  /* andsi3 */
    case 94:  /* smaxhf3 */
    case 93:  /* smaxdf3 */
    case 92:  /* smaxsf3 */
    case 91:  /* sminhf3 */
    case 90:  /* smindf3 */
    case 89:  /* sminsf3 */
    case 88:  /* fmaxhf3 */
    case 87:  /* fmaxdf3 */
    case 86:  /* fmaxsf3 */
    case 85:  /* fminhf3 */
    case 84:  /* fmindf3 */
    case 83:  /* fminsf3 */
    case 82:  /* neghf2 */
    case 81:  /* negdf2 */
    case 80:  /* negsf2 */
    case 79:  /* copysignhf3 */
    case 78:  /* copysigndf3 */
    case 77:  /* copysignsf3 */
    case 76:  /* abshf2 */
    case 75:  /* absdf2 */
    case 74:  /* abssf2 */
    case 73:  /* *fnmahf4 */
    case 72:  /* *fnmadf4 */
    case 71:  /* *fnmasf4 */
    case 70:  /* *fnmshf4 */
    case 69:  /* *fnmsdf4 */
    case 68:  /* *fnmssf4 */
    case 67:  /* *fmshf4 */
    case 66:  /* *fmsdf4 */
    case 65:  /* *fmssf4 */
    case 64:  /* *fmahf4 */
    case 63:  /* *fmadf4 */
    case 62:  /* *fmasf4 */
    case 61:  /* fnmahf4 */
    case 60:  /* fnmadf4 */
    case 59:  /* fnmasf4 */
    case 58:  /* fnmshf4 */
    case 57:  /* fnmsdf4 */
    case 56:  /* fnmssf4 */
    case 55:  /* fmshf4 */
    case 54:  /* fmsdf4 */
    case 53:  /* fmssf4 */
    case 52:  /* fmahf4 */
    case 51:  /* fmadf4 */
    case 50:  /* fmasf4 */
    case 49:  /* sqrthf2 */
    case 48:  /* sqrtdf2 */
    case 47:  /* sqrtsf2 */
    case 46:  /* divhf3 */
    case 45:  /* divdf3 */
    case 44:  /* divsf3 */
    case 43:  /* *umodsi3_extended */
    case 42:  /* *modsi3_extended */
    case 41:  /* *udivsi3_extended */
    case 40:  /* *divsi3_extended */
    case 39:  /* umoddi3 */
    case 38:  /* moddi3 */
    case 37:  /* udivdi3 */
    case 36:  /* divdi3 */
    case 35:  /* umodsi3 */
    case 34:  /* modsi3 */
    case 33:  /* udivsi3 */
    case 32:  /* divsi3 */
    case 31:  /* usmulsi3_highpart */
    case 30:  /* umulsi3_highpart */
    case 29:  /* smulsi3_highpart */
    case 28:  /* usmuldi3_highpart */
    case 27:  /* umuldi3_highpart */
    case 26:  /* smuldi3_highpart */
    case 25:  /* *mulsi3_extended2 */
    case 24:  /* *mulsi3_extended */
    case 23:  /* muldi3 */
    case 22:  /* mulsi3 */
    case 21:  /* mulhf3 */
    case 20:  /* muldf3 */
    case 19:  /* mulsf3 */
    case 18:  /* *negsi2_extended2 */
    case 17:  /* *negsi2_extended */
    case 16:  /* negsi2 */
    case 15:  /* negdi2 */
    case 14:  /* *subsi3_extended2 */
    case 13:  /* *subsi3_extended */
    case 12:  /* subsi3 */
    case 11:  /* subdi3 */
    case 10:  /* subhf3 */
    case 9:  /* subdf3 */
    case 8:  /* subsf3 */
    case 7:  /* *addsi3_extended2 */
    case 6:  /* *addsi3_extended */
    case 5:  /* adddi3 */
    case 4:  /* addsi3 */
    case 3:  /* addhf3 */
    case 2:  /* adddf3 */
    case 1:  /* addsf3 */
      return 255 /* 0xff */;

    case 6034:  /* pred_compressvnx8df */
    case 6033:  /* pred_compressvnx4df */
    case 6032:  /* pred_compressvnx2df */
    case 6031:  /* pred_compressvnx1df */
    case 6030:  /* pred_compressvnx16sf */
    case 6029:  /* pred_compressvnx8sf */
    case 6028:  /* pred_compressvnx4sf */
    case 6027:  /* pred_compressvnx2sf */
    case 6026:  /* pred_compressvnx1sf */
    case 6025:  /* pred_compressvnx8di */
    case 6024:  /* pred_compressvnx4di */
    case 6023:  /* pred_compressvnx2di */
    case 6022:  /* pred_compressvnx1di */
    case 6021:  /* pred_compressvnx16si */
    case 6020:  /* pred_compressvnx8si */
    case 6019:  /* pred_compressvnx4si */
    case 6018:  /* pred_compressvnx2si */
    case 6017:  /* pred_compressvnx1si */
    case 6016:  /* pred_compressvnx32hi */
    case 6015:  /* pred_compressvnx16hi */
    case 6014:  /* pred_compressvnx8hi */
    case 6013:  /* pred_compressvnx4hi */
    case 6012:  /* pred_compressvnx2hi */
    case 6011:  /* pred_compressvnx1hi */
    case 6010:  /* pred_compressvnx64qi */
    case 6009:  /* pred_compressvnx32qi */
    case 6008:  /* pred_compressvnx16qi */
    case 6007:  /* pred_compressvnx8qi */
    case 6006:  /* pred_compressvnx4qi */
    case 6005:  /* pred_compressvnx2qi */
    case 6004:  /* pred_compressvnx1qi */
    case 5184:  /* pred_mergevnx8df_scalar */
    case 5183:  /* pred_mergevnx4df_scalar */
    case 5182:  /* pred_mergevnx2df_scalar */
    case 5181:  /* pred_mergevnx1df_scalar */
    case 5180:  /* pred_mergevnx16sf_scalar */
    case 5179:  /* pred_mergevnx8sf_scalar */
    case 5178:  /* pred_mergevnx4sf_scalar */
    case 5177:  /* pred_mergevnx2sf_scalar */
    case 5176:  /* pred_mergevnx1sf_scalar */
    case 932:  /* *pred_mergevnx8di_extended_scalar */
    case 931:  /* *pred_mergevnx4di_extended_scalar */
    case 930:  /* *pred_mergevnx2di_extended_scalar */
    case 929:  /* *pred_mergevnx1di_extended_scalar */
    case 928:  /* *pred_mergevnx8di_scalar */
    case 927:  /* *pred_mergevnx4di_scalar */
    case 926:  /* *pred_mergevnx2di_scalar */
    case 925:  /* *pred_mergevnx1di_scalar */
    case 924:  /* pred_mergevnx16si_scalar */
    case 923:  /* pred_mergevnx8si_scalar */
    case 922:  /* pred_mergevnx4si_scalar */
    case 921:  /* pred_mergevnx2si_scalar */
    case 920:  /* pred_mergevnx1si_scalar */
    case 919:  /* pred_mergevnx32hi_scalar */
    case 918:  /* pred_mergevnx16hi_scalar */
    case 917:  /* pred_mergevnx8hi_scalar */
    case 916:  /* pred_mergevnx4hi_scalar */
    case 915:  /* pred_mergevnx2hi_scalar */
    case 914:  /* pred_mergevnx1hi_scalar */
    case 913:  /* pred_mergevnx64qi_scalar */
    case 912:  /* pred_mergevnx32qi_scalar */
    case 911:  /* pred_mergevnx16qi_scalar */
    case 910:  /* pred_mergevnx8qi_scalar */
    case 909:  /* pred_mergevnx4qi_scalar */
    case 908:  /* pred_mergevnx2qi_scalar */
    case 907:  /* pred_mergevnx1qi_scalar */
    case 906:  /* pred_mergevnx8df */
    case 905:  /* pred_mergevnx4df */
    case 904:  /* pred_mergevnx2df */
    case 903:  /* pred_mergevnx1df */
    case 902:  /* pred_mergevnx16sf */
    case 901:  /* pred_mergevnx8sf */
    case 900:  /* pred_mergevnx4sf */
    case 899:  /* pred_mergevnx2sf */
    case 898:  /* pred_mergevnx1sf */
    case 897:  /* pred_mergevnx8di */
    case 896:  /* pred_mergevnx4di */
    case 895:  /* pred_mergevnx2di */
    case 894:  /* pred_mergevnx1di */
    case 893:  /* pred_mergevnx16si */
    case 892:  /* pred_mergevnx8si */
    case 891:  /* pred_mergevnx4si */
    case 890:  /* pred_mergevnx2si */
    case 889:  /* pred_mergevnx1si */
    case 888:  /* pred_mergevnx32hi */
    case 887:  /* pred_mergevnx16hi */
    case 886:  /* pred_mergevnx8hi */
    case 885:  /* pred_mergevnx4hi */
    case 884:  /* pred_mergevnx2hi */
    case 883:  /* pred_mergevnx1hi */
    case 882:  /* pred_mergevnx64qi */
    case 881:  /* pred_mergevnx32qi */
    case 880:  /* pred_mergevnx16qi */
    case 879:  /* pred_mergevnx8qi */
    case 878:  /* pred_mergevnx4qi */
    case 877:  /* pred_mergevnx2qi */
    case 876:  /* pred_mergevnx1qi */
    case 2456:  /* pred_adcvnx1qi */
    case 2457:  /* pred_adcvnx2qi */
    case 2458:  /* pred_adcvnx4qi */
    case 2459:  /* pred_adcvnx8qi */
    case 2460:  /* pred_adcvnx16qi */
    case 2461:  /* pred_adcvnx32qi */
    case 2462:  /* pred_adcvnx64qi */
    case 2463:  /* pred_adcvnx1hi */
    case 2464:  /* pred_adcvnx2hi */
    case 2465:  /* pred_adcvnx4hi */
    case 2466:  /* pred_adcvnx8hi */
    case 2467:  /* pred_adcvnx16hi */
    case 2468:  /* pred_adcvnx32hi */
    case 2469:  /* pred_adcvnx1si */
    case 2470:  /* pred_adcvnx2si */
    case 2471:  /* pred_adcvnx4si */
    case 2472:  /* pred_adcvnx8si */
    case 2473:  /* pred_adcvnx16si */
    case 2474:  /* pred_adcvnx1di */
    case 2475:  /* pred_adcvnx2di */
    case 2476:  /* pred_adcvnx4di */
    case 2477:  /* pred_adcvnx8di */
    case 2478:  /* pred_sbcvnx1qi */
    case 2479:  /* pred_sbcvnx2qi */
    case 2480:  /* pred_sbcvnx4qi */
    case 2481:  /* pred_sbcvnx8qi */
    case 2482:  /* pred_sbcvnx16qi */
    case 2483:  /* pred_sbcvnx32qi */
    case 2484:  /* pred_sbcvnx64qi */
    case 2485:  /* pred_sbcvnx1hi */
    case 2486:  /* pred_sbcvnx2hi */
    case 2487:  /* pred_sbcvnx4hi */
    case 2488:  /* pred_sbcvnx8hi */
    case 2489:  /* pred_sbcvnx16hi */
    case 2490:  /* pred_sbcvnx32hi */
    case 2491:  /* pred_sbcvnx1si */
    case 2492:  /* pred_sbcvnx2si */
    case 2493:  /* pred_sbcvnx4si */
    case 2494:  /* pred_sbcvnx8si */
    case 2495:  /* pred_sbcvnx16si */
    case 2496:  /* pred_sbcvnx1di */
    case 2497:  /* pred_sbcvnx2di */
    case 2498:  /* pred_sbcvnx4di */
    case 2499:  /* pred_sbcvnx8di */
    case 2500:  /* pred_adcvnx1qi_scalar */
    case 2501:  /* pred_adcvnx2qi_scalar */
    case 2502:  /* pred_adcvnx4qi_scalar */
    case 2503:  /* pred_adcvnx8qi_scalar */
    case 2504:  /* pred_adcvnx16qi_scalar */
    case 2505:  /* pred_adcvnx32qi_scalar */
    case 2506:  /* pred_adcvnx64qi_scalar */
    case 2507:  /* pred_adcvnx1hi_scalar */
    case 2508:  /* pred_adcvnx2hi_scalar */
    case 2509:  /* pred_adcvnx4hi_scalar */
    case 2510:  /* pred_adcvnx8hi_scalar */
    case 2511:  /* pred_adcvnx16hi_scalar */
    case 2512:  /* pred_adcvnx32hi_scalar */
    case 2513:  /* pred_adcvnx1si_scalar */
    case 2514:  /* pred_adcvnx2si_scalar */
    case 2515:  /* pred_adcvnx4si_scalar */
    case 2516:  /* pred_adcvnx8si_scalar */
    case 2517:  /* pred_adcvnx16si_scalar */
    case 2518:  /* pred_sbcvnx1qi_scalar */
    case 2519:  /* pred_sbcvnx2qi_scalar */
    case 2520:  /* pred_sbcvnx4qi_scalar */
    case 2521:  /* pred_sbcvnx8qi_scalar */
    case 2522:  /* pred_sbcvnx16qi_scalar */
    case 2523:  /* pred_sbcvnx32qi_scalar */
    case 2524:  /* pred_sbcvnx64qi_scalar */
    case 2525:  /* pred_sbcvnx1hi_scalar */
    case 2526:  /* pred_sbcvnx2hi_scalar */
    case 2527:  /* pred_sbcvnx4hi_scalar */
    case 2528:  /* pred_sbcvnx8hi_scalar */
    case 2529:  /* pred_sbcvnx16hi_scalar */
    case 2530:  /* pred_sbcvnx32hi_scalar */
    case 2531:  /* pred_sbcvnx1si_scalar */
    case 2532:  /* pred_sbcvnx2si_scalar */
    case 2533:  /* pred_sbcvnx4si_scalar */
    case 2534:  /* pred_sbcvnx8si_scalar */
    case 2535:  /* pred_sbcvnx16si_scalar */
    case 2536:  /* *pred_adcvnx1di_scalar */
    case 2537:  /* *pred_adcvnx2di_scalar */
    case 2538:  /* *pred_adcvnx4di_scalar */
    case 2539:  /* *pred_adcvnx8di_scalar */
    case 2540:  /* *pred_adcvnx1di_extended_scalar */
    case 2541:  /* *pred_adcvnx2di_extended_scalar */
    case 2542:  /* *pred_adcvnx4di_extended_scalar */
    case 2543:  /* *pred_adcvnx8di_extended_scalar */
    case 2544:  /* *pred_sbcvnx1di_scalar */
    case 2545:  /* *pred_sbcvnx2di_scalar */
    case 2546:  /* *pred_sbcvnx4di_scalar */
    case 2547:  /* *pred_sbcvnx8di_scalar */
    case 2548:  /* *pred_sbcvnx1di_extended_scalar */
    case 2549:  /* *pred_sbcvnx2di_extended_scalar */
    case 2550:  /* *pred_sbcvnx4di_extended_scalar */
    case 2551:  /* *pred_sbcvnx8di_extended_scalar */
      return 1;

    case 4051:  /* *pred_maddvnx1qi */
    case 4052:  /* *pred_maddvnx2qi */
    case 4053:  /* *pred_maddvnx4qi */
    case 4054:  /* *pred_maddvnx8qi */
    case 4055:  /* *pred_maddvnx16qi */
    case 4056:  /* *pred_maddvnx32qi */
    case 4057:  /* *pred_maddvnx64qi */
    case 4058:  /* *pred_maddvnx1hi */
    case 4059:  /* *pred_maddvnx2hi */
    case 4060:  /* *pred_maddvnx4hi */
    case 4061:  /* *pred_maddvnx8hi */
    case 4062:  /* *pred_maddvnx16hi */
    case 4063:  /* *pred_maddvnx32hi */
    case 4064:  /* *pred_maddvnx1si */
    case 4065:  /* *pred_maddvnx2si */
    case 4066:  /* *pred_maddvnx4si */
    case 4067:  /* *pred_maddvnx8si */
    case 4068:  /* *pred_maddvnx16si */
    case 4069:  /* *pred_maddvnx1di */
    case 4070:  /* *pred_maddvnx2di */
    case 4071:  /* *pred_maddvnx4di */
    case 4072:  /* *pred_maddvnx8di */
    case 4117:  /* *pred_maddvnx1qi_scalar */
    case 4118:  /* *pred_maddvnx2qi_scalar */
    case 4119:  /* *pred_maddvnx4qi_scalar */
    case 4120:  /* *pred_maddvnx8qi_scalar */
    case 4121:  /* *pred_maddvnx16qi_scalar */
    case 4122:  /* *pred_maddvnx32qi_scalar */
    case 4123:  /* *pred_maddvnx64qi_scalar */
    case 4124:  /* *pred_maddvnx1hi_scalar */
    case 4125:  /* *pred_maddvnx2hi_scalar */
    case 4126:  /* *pred_maddvnx4hi_scalar */
    case 4127:  /* *pred_maddvnx8hi_scalar */
    case 4128:  /* *pred_maddvnx16hi_scalar */
    case 4129:  /* *pred_maddvnx32hi_scalar */
    case 4130:  /* *pred_maddvnx1si_scalar */
    case 4131:  /* *pred_maddvnx2si_scalar */
    case 4132:  /* *pred_maddvnx4si_scalar */
    case 4133:  /* *pred_maddvnx8si_scalar */
    case 4134:  /* *pred_maddvnx16si_scalar */
    case 4135:  /* *pred_maddvnx1di_scalar */
    case 4136:  /* *pred_maddvnx2di_scalar */
    case 4137:  /* *pred_maddvnx4di_scalar */
    case 4138:  /* *pred_maddvnx8di_scalar */
    case 4183:  /* *pred_maddvnx1di_extended_scalar */
    case 4184:  /* *pred_maddvnx2di_extended_scalar */
    case 4185:  /* *pred_maddvnx4di_extended_scalar */
    case 4186:  /* *pred_maddvnx8di_extended_scalar */
    case 4195:  /* *pred_nmsubvnx1qi */
    case 4196:  /* *pred_nmsubvnx2qi */
    case 4197:  /* *pred_nmsubvnx4qi */
    case 4198:  /* *pred_nmsubvnx8qi */
    case 4199:  /* *pred_nmsubvnx16qi */
    case 4200:  /* *pred_nmsubvnx32qi */
    case 4201:  /* *pred_nmsubvnx64qi */
    case 4202:  /* *pred_nmsubvnx1hi */
    case 4203:  /* *pred_nmsubvnx2hi */
    case 4204:  /* *pred_nmsubvnx4hi */
    case 4205:  /* *pred_nmsubvnx8hi */
    case 4206:  /* *pred_nmsubvnx16hi */
    case 4207:  /* *pred_nmsubvnx32hi */
    case 4208:  /* *pred_nmsubvnx1si */
    case 4209:  /* *pred_nmsubvnx2si */
    case 4210:  /* *pred_nmsubvnx4si */
    case 4211:  /* *pred_nmsubvnx8si */
    case 4212:  /* *pred_nmsubvnx16si */
    case 4213:  /* *pred_nmsubvnx1di */
    case 4214:  /* *pred_nmsubvnx2di */
    case 4215:  /* *pred_nmsubvnx4di */
    case 4216:  /* *pred_nmsubvnx8di */
    case 4261:  /* *pred_nmsubvnx1qi_scalar */
    case 4262:  /* *pred_nmsubvnx2qi_scalar */
    case 4263:  /* *pred_nmsubvnx4qi_scalar */
    case 4264:  /* *pred_nmsubvnx8qi_scalar */
    case 4265:  /* *pred_nmsubvnx16qi_scalar */
    case 4266:  /* *pred_nmsubvnx32qi_scalar */
    case 4267:  /* *pred_nmsubvnx64qi_scalar */
    case 4268:  /* *pred_nmsubvnx1hi_scalar */
    case 4269:  /* *pred_nmsubvnx2hi_scalar */
    case 4270:  /* *pred_nmsubvnx4hi_scalar */
    case 4271:  /* *pred_nmsubvnx8hi_scalar */
    case 4272:  /* *pred_nmsubvnx16hi_scalar */
    case 4273:  /* *pred_nmsubvnx32hi_scalar */
    case 4274:  /* *pred_nmsubvnx1si_scalar */
    case 4275:  /* *pred_nmsubvnx2si_scalar */
    case 4276:  /* *pred_nmsubvnx4si_scalar */
    case 4277:  /* *pred_nmsubvnx8si_scalar */
    case 4278:  /* *pred_nmsubvnx16si_scalar */
    case 4279:  /* *pred_nmsubvnx1di_scalar */
    case 4280:  /* *pred_nmsubvnx2di_scalar */
    case 4281:  /* *pred_nmsubvnx4di_scalar */
    case 4282:  /* *pred_nmsubvnx8di_scalar */
    case 4327:  /* *pred_nmsubvnx1di_extended_scalar */
    case 4328:  /* *pred_nmsubvnx2di_extended_scalar */
    case 4329:  /* *pred_nmsubvnx4di_extended_scalar */
    case 4330:  /* *pred_nmsubvnx8di_extended_scalar */
    case 4780:  /* *pred_maddvnx1sf */
    case 4781:  /* *pred_msubvnx1sf */
    case 4782:  /* *pred_maddvnx2sf */
    case 4783:  /* *pred_msubvnx2sf */
    case 4784:  /* *pred_maddvnx4sf */
    case 4785:  /* *pred_msubvnx4sf */
    case 4786:  /* *pred_maddvnx8sf */
    case 4787:  /* *pred_msubvnx8sf */
    case 4788:  /* *pred_maddvnx16sf */
    case 4789:  /* *pred_msubvnx16sf */
    case 4790:  /* *pred_maddvnx1df */
    case 4791:  /* *pred_msubvnx1df */
    case 4792:  /* *pred_maddvnx2df */
    case 4793:  /* *pred_msubvnx2df */
    case 4794:  /* *pred_maddvnx4df */
    case 4795:  /* *pred_msubvnx4df */
    case 4796:  /* *pred_maddvnx8df */
    case 4797:  /* *pred_msubvnx8df */
    case 4834:  /* *pred_maddvnx1sf_scalar */
    case 4835:  /* *pred_msubvnx1sf_scalar */
    case 4836:  /* *pred_maddvnx2sf_scalar */
    case 4837:  /* *pred_msubvnx2sf_scalar */
    case 4838:  /* *pred_maddvnx4sf_scalar */
    case 4839:  /* *pred_msubvnx4sf_scalar */
    case 4840:  /* *pred_maddvnx8sf_scalar */
    case 4841:  /* *pred_msubvnx8sf_scalar */
    case 4842:  /* *pred_maddvnx16sf_scalar */
    case 4843:  /* *pred_msubvnx16sf_scalar */
    case 4844:  /* *pred_maddvnx1df_scalar */
    case 4845:  /* *pred_msubvnx1df_scalar */
    case 4846:  /* *pred_maddvnx2df_scalar */
    case 4847:  /* *pred_msubvnx2df_scalar */
    case 4848:  /* *pred_maddvnx4df_scalar */
    case 4849:  /* *pred_msubvnx4df_scalar */
    case 4850:  /* *pred_maddvnx8df_scalar */
    case 4851:  /* *pred_msubvnx8df_scalar */
    case 4888:  /* *pred_nmsubvnx1sf */
    case 4889:  /* *pred_nmaddvnx1sf */
    case 4890:  /* *pred_nmsubvnx2sf */
    case 4891:  /* *pred_nmaddvnx2sf */
    case 4892:  /* *pred_nmsubvnx4sf */
    case 4893:  /* *pred_nmaddvnx4sf */
    case 4894:  /* *pred_nmsubvnx8sf */
    case 4895:  /* *pred_nmaddvnx8sf */
    case 4896:  /* *pred_nmsubvnx16sf */
    case 4897:  /* *pred_nmaddvnx16sf */
    case 4898:  /* *pred_nmsubvnx1df */
    case 4899:  /* *pred_nmaddvnx1df */
    case 4900:  /* *pred_nmsubvnx2df */
    case 4901:  /* *pred_nmaddvnx2df */
    case 4902:  /* *pred_nmsubvnx4df */
    case 4903:  /* *pred_nmaddvnx4df */
    case 4904:  /* *pred_nmsubvnx8df */
    case 4905:  /* *pred_nmaddvnx8df */
    case 4942:  /* *pred_nmsubvnx1sf_scalar */
    case 4943:  /* *pred_nmaddvnx1sf_scalar */
    case 4944:  /* *pred_nmsubvnx2sf_scalar */
    case 4945:  /* *pred_nmaddvnx2sf_scalar */
    case 4946:  /* *pred_nmsubvnx4sf_scalar */
    case 4947:  /* *pred_nmaddvnx4sf_scalar */
    case 4948:  /* *pred_nmsubvnx8sf_scalar */
    case 4949:  /* *pred_nmaddvnx8sf_scalar */
    case 4950:  /* *pred_nmsubvnx16sf_scalar */
    case 4951:  /* *pred_nmaddvnx16sf_scalar */
    case 4952:  /* *pred_nmsubvnx1df_scalar */
    case 4953:  /* *pred_nmaddvnx1df_scalar */
    case 4954:  /* *pred_nmsubvnx2df_scalar */
    case 4955:  /* *pred_nmaddvnx2df_scalar */
    case 4956:  /* *pred_nmsubvnx4df_scalar */
    case 4957:  /* *pred_nmaddvnx4df_scalar */
    case 4958:  /* *pred_nmsubvnx8df_scalar */
    case 4959:  /* *pred_nmaddvnx8df_scalar */
      return 4;

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_VLDE) || (cached_type == TYPE_VIMOV) || (cached_type == TYPE_VFMOV) || (cached_type == TYPE_VLDM) || (cached_type == TYPE_VLDS) || (cached_type == TYPE_VMALU) || (cached_type == TYPE_VLDUX) || (cached_type == TYPE_VLDOX) || (cached_type == TYPE_VICMP) || (cached_type == TYPE_VIALU) || (cached_type == TYPE_VSHIFT) || (cached_type == TYPE_VIMINMAX) || (cached_type == TYPE_VIMUL) || (cached_type == TYPE_VIDIV) || (cached_type == TYPE_VSALU) || (cached_type == TYPE_VEXT) || (cached_type == TYPE_VIWALU) || (cached_type == TYPE_VIWMUL) || (cached_type == TYPE_VNSHIFT) || (cached_type == TYPE_VAALU) || (cached_type == TYPE_VSMUL) || (cached_type == TYPE_VSSHIFT) || (cached_type == TYPE_VNCLIP) || (cached_type == TYPE_VMSFS) || (cached_type == TYPE_VMIOTA) || (cached_type == TYPE_VMIDX) || (cached_type == TYPE_VFALU) || (cached_type == TYPE_VFMUL) || (cached_type == TYPE_VFMINMAX) || (cached_type == TYPE_VFDIV) || (cached_type == TYPE_VFWALU) || (cached_type == TYPE_VFWMUL) || (cached_type == TYPE_VFSQRT) || (cached_type == TYPE_VFRECP) || (cached_type == TYPE_VFSGNJ) || (cached_type == TYPE_VFCMP) || (cached_type == TYPE_VFCVTITOF) || (cached_type == TYPE_VFCVTFTOI) || (cached_type == TYPE_VFWCVTITOF) || (cached_type == TYPE_VFWCVTFTOI) || (cached_type == TYPE_VFWCVTFTOF) || (cached_type == TYPE_VFNCVTITOF) || (cached_type == TYPE_VFNCVTFTOI) || (cached_type == TYPE_VFNCVTFTOF) || (cached_type == TYPE_VFCLASS) || (cached_type == TYPE_VIRED) || (cached_type == TYPE_VIWRED) || (cached_type == TYPE_VFREDU) || (cached_type == TYPE_VFREDO) || (cached_type == TYPE_VFWREDU) || (cached_type == TYPE_VFWREDO) || (cached_type == TYPE_VIMOVXV) || (cached_type == TYPE_VFMOVFV) || (cached_type == TYPE_VSLIDEUP) || (cached_type == TYPE_VSLIDEDOWN) || (cached_type == TYPE_VISLIDE1UP) || (cached_type == TYPE_VISLIDE1DOWN) || (cached_type == TYPE_VFSLIDE1UP) || (cached_type == TYPE_VFSLIDE1DOWN) || (cached_type == TYPE_VGATHER) || (cached_type == TYPE_VLDFF) || (cached_type == TYPE_VIWMULADD) || (cached_type == TYPE_VFWMULADD))
        {
	  return 2;
        }
      else if ((cached_type == TYPE_VIMERGE) || (cached_type == TYPE_VFMERGE) || (cached_type == TYPE_VCOMPRESS))
        {
	  return 1;
        }
      else if ((cached_type == TYPE_VIMULADD) || (cached_type == TYPE_VFMULADD))
        {
	  return 5;
        }
      else
        {
	  return 255 /* 0xff */;
        }

    default:
      return 2;

    }
}

enum attr_mode
get_attr_mode (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 750:  /* *movvnx8df_whole */
    case 830:  /* pred_movvnx8df */
    case 861:  /* pred_storevnx8df */
    case 906:  /* pred_mergevnx8df */
    case 963:  /* *pred_broadcastvnx8df */
    case 998:  /* pred_strided_loadvnx8df */
    case 1029:  /* pred_strided_storevnx8df */
    case 1090:  /* pred_indexed_oloadvnx8df_same_eew */
    case 1091:  /* pred_indexed_uloadvnx8df_same_eew */
    case 1138:  /* pred_indexed_oloadvnx8df_x2_greater_eew */
    case 1139:  /* pred_indexed_uloadvnx8df_x2_greater_eew */
    case 1174:  /* pred_indexed_oloadvnx8df_x4_greater_eew */
    case 1175:  /* pred_indexed_uloadvnx8df_x4_greater_eew */
    case 1190:  /* pred_indexed_oloadvnx8df_x8_greater_eew */
    case 1191:  /* pred_indexed_uloadvnx8df_x8_greater_eew */
    case 1410:  /* pred_indexed_ostorevnx8dfvnx8qi */
    case 1411:  /* pred_indexed_ustorevnx8dfvnx8qi */
    case 1422:  /* pred_indexed_ostorevnx8dfvnx8hi */
    case 1423:  /* pred_indexed_ustorevnx8dfvnx8hi */
    case 1434:  /* pred_indexed_ostorevnx8dfvnx8si */
    case 1435:  /* pred_indexed_ustorevnx8dfvnx8si */
    case 1446:  /* pred_indexed_ostorevnx8dfvnx8di */
    case 1447:  /* pred_indexed_ustorevnx8dfvnx8di */
    case 4648:  /* pred_addvnx8df */
    case 4649:  /* pred_mulvnx8df */
    case 4650:  /* pred_smaxvnx8df */
    case 4651:  /* pred_sminvnx8df */
    case 4652:  /* pred_subvnx8df */
    case 4653:  /* pred_divvnx8df */
    case 4686:  /* pred_addvnx8df_scalar */
    case 4687:  /* pred_mulvnx8df_scalar */
    case 4688:  /* pred_smaxvnx8df_scalar */
    case 4689:  /* pred_sminvnx8df_scalar */
    case 4706:  /* pred_subvnx8df_scalar */
    case 4707:  /* pred_divvnx8df_scalar */
    case 4724:  /* pred_subvnx8df_reverse_scalar */
    case 4725:  /* pred_divvnx8df_reverse_scalar */
    case 4750:  /* pred_copysignvnx8df */
    case 4751:  /* pred_ncopysignvnx8df */
    case 4752:  /* pred_xorsignvnx8df */
    case 4777:  /* pred_copysignvnx8df_scalar */
    case 4778:  /* pred_ncopysignvnx8df_scalar */
    case 4779:  /* pred_xorsignvnx8df_scalar */
    case 4796:  /* *pred_maddvnx8df */
    case 4797:  /* *pred_msubvnx8df */
    case 4814:  /* *pred_maccvnx8df */
    case 4815:  /* *pred_msacvnx8df */
    case 4832:  /* *pred_mul_addvnx8df */
    case 4833:  /* *pred_mul_subvnx8df */
    case 4850:  /* *pred_maddvnx8df_scalar */
    case 4851:  /* *pred_msubvnx8df_scalar */
    case 4868:  /* *pred_maccvnx8df_scalar */
    case 4869:  /* *pred_msacvnx8df_scalar */
    case 4886:  /* *pred_mul_addvnx8df_scalar */
    case 4887:  /* *pred_mul_subvnx8df_scalar */
    case 4904:  /* *pred_nmsubvnx8df */
    case 4905:  /* *pred_nmaddvnx8df */
    case 4922:  /* *pred_nmsacvnx8df */
    case 4923:  /* *pred_nmaccvnx8df */
    case 4940:  /* *pred_mul_neg_addvnx8df */
    case 4941:  /* *pred_mul_neg_subvnx8df */
    case 4958:  /* *pred_nmsubvnx8df_scalar */
    case 4959:  /* *pred_nmaddvnx8df_scalar */
    case 4976:  /* *pred_nmsacvnx8df_scalar */
    case 4977:  /* *pred_nmaccvnx8df_scalar */
    case 4994:  /* *pred_mul_neg_addvnx8df_scalar */
    case 4995:  /* *pred_mul_neg_subvnx8df_scalar */
    case 5020:  /* pred_negvnx8df */
    case 5021:  /* pred_absvnx8df */
    case 5022:  /* pred_sqrtvnx8df */
    case 5039:  /* pred_rsqrt7vnx8df */
    case 5040:  /* pred_rec7vnx8df */
    case 5049:  /* pred_classvnx8df */
    case 5130:  /* *pred_cmpvnx8df */
    case 5139:  /* *pred_cmpvnx8df_narrow */
    case 5148:  /* *pred_cmpvnx8df_scalar */
    case 5157:  /* *pred_cmpvnx8df_scalar_narrow */
    case 5166:  /* *pred_eqnevnx8df_scalar */
    case 5175:  /* *pred_eqnevnx8df_scalar_narrow */
    case 5184:  /* pred_mergevnx8df_scalar */
    case 5201:  /* pred_fcvt_x_fvnx8df */
    case 5202:  /* pred_fcvt_xu_fvnx8df */
    case 5219:  /* pred_fix_truncvnx8df */
    case 5220:  /* pred_fixuns_truncvnx8df */
    case 5237:  /* pred_floatvnx8df */
    case 5238:  /* pred_floatunsvnx8df */
    case 5699:  /* pred_reduc_maxvnx8dfvnx1df */
    case 5700:  /* pred_reduc_minvnx8dfvnx1df */
    case 5725:  /* pred_reduc_plusovnx8dfvnx1df */
    case 5726:  /* pred_reduc_plusuvnx8dfvnx1df */
    case 5779:  /* *pred_extract_firstvnx8df */
    case 5840:  /* pred_slideupvnx8df */
    case 5841:  /* pred_slidedownvnx8df */
    case 5910:  /* pred_slide1upvnx8df */
    case 5911:  /* pred_slide1downvnx8df */
    case 5942:  /* pred_gathervnx8df */
    case 5973:  /* pred_gathervnx8df_scalar */
    case 6003:  /* pred_gatherei16vnx8df */
    case 6034:  /* pred_compressvnx8df */
    case 6067:  /* pred_fault_loadvnx8df */
      return MODE_VNX8DF;

    case 749:  /* *movvnx4df_whole */
    case 829:  /* pred_movvnx4df */
    case 860:  /* pred_storevnx4df */
    case 905:  /* pred_mergevnx4df */
    case 962:  /* *pred_broadcastvnx4df */
    case 997:  /* pred_strided_loadvnx4df */
    case 1028:  /* pred_strided_storevnx4df */
    case 1088:  /* pred_indexed_oloadvnx4df_same_eew */
    case 1089:  /* pred_indexed_uloadvnx4df_same_eew */
    case 1136:  /* pred_indexed_oloadvnx4df_x2_greater_eew */
    case 1137:  /* pred_indexed_uloadvnx4df_x2_greater_eew */
    case 1172:  /* pred_indexed_oloadvnx4df_x4_greater_eew */
    case 1173:  /* pred_indexed_uloadvnx4df_x4_greater_eew */
    case 1188:  /* pred_indexed_oloadvnx4df_x8_greater_eew */
    case 1189:  /* pred_indexed_uloadvnx4df_x8_greater_eew */
    case 1362:  /* pred_indexed_ostorevnx4dfvnx4qi */
    case 1363:  /* pred_indexed_ustorevnx4dfvnx4qi */
    case 1374:  /* pred_indexed_ostorevnx4dfvnx4hi */
    case 1375:  /* pred_indexed_ustorevnx4dfvnx4hi */
    case 1386:  /* pred_indexed_ostorevnx4dfvnx4si */
    case 1387:  /* pred_indexed_ustorevnx4dfvnx4si */
    case 1398:  /* pred_indexed_ostorevnx4dfvnx4di */
    case 1399:  /* pred_indexed_ustorevnx4dfvnx4di */
    case 4642:  /* pred_addvnx4df */
    case 4643:  /* pred_mulvnx4df */
    case 4644:  /* pred_smaxvnx4df */
    case 4645:  /* pred_sminvnx4df */
    case 4646:  /* pred_subvnx4df */
    case 4647:  /* pred_divvnx4df */
    case 4682:  /* pred_addvnx4df_scalar */
    case 4683:  /* pred_mulvnx4df_scalar */
    case 4684:  /* pred_smaxvnx4df_scalar */
    case 4685:  /* pred_sminvnx4df_scalar */
    case 4704:  /* pred_subvnx4df_scalar */
    case 4705:  /* pred_divvnx4df_scalar */
    case 4722:  /* pred_subvnx4df_reverse_scalar */
    case 4723:  /* pred_divvnx4df_reverse_scalar */
    case 4747:  /* pred_copysignvnx4df */
    case 4748:  /* pred_ncopysignvnx4df */
    case 4749:  /* pred_xorsignvnx4df */
    case 4774:  /* pred_copysignvnx4df_scalar */
    case 4775:  /* pred_ncopysignvnx4df_scalar */
    case 4776:  /* pred_xorsignvnx4df_scalar */
    case 4794:  /* *pred_maddvnx4df */
    case 4795:  /* *pred_msubvnx4df */
    case 4812:  /* *pred_maccvnx4df */
    case 4813:  /* *pred_msacvnx4df */
    case 4830:  /* *pred_mul_addvnx4df */
    case 4831:  /* *pred_mul_subvnx4df */
    case 4848:  /* *pred_maddvnx4df_scalar */
    case 4849:  /* *pred_msubvnx4df_scalar */
    case 4866:  /* *pred_maccvnx4df_scalar */
    case 4867:  /* *pred_msacvnx4df_scalar */
    case 4884:  /* *pred_mul_addvnx4df_scalar */
    case 4885:  /* *pred_mul_subvnx4df_scalar */
    case 4902:  /* *pred_nmsubvnx4df */
    case 4903:  /* *pred_nmaddvnx4df */
    case 4920:  /* *pred_nmsacvnx4df */
    case 4921:  /* *pred_nmaccvnx4df */
    case 4938:  /* *pred_mul_neg_addvnx4df */
    case 4939:  /* *pred_mul_neg_subvnx4df */
    case 4956:  /* *pred_nmsubvnx4df_scalar */
    case 4957:  /* *pred_nmaddvnx4df_scalar */
    case 4974:  /* *pred_nmsacvnx4df_scalar */
    case 4975:  /* *pred_nmaccvnx4df_scalar */
    case 4992:  /* *pred_mul_neg_addvnx4df_scalar */
    case 4993:  /* *pred_mul_neg_subvnx4df_scalar */
    case 5017:  /* pred_negvnx4df */
    case 5018:  /* pred_absvnx4df */
    case 5019:  /* pred_sqrtvnx4df */
    case 5037:  /* pred_rsqrt7vnx4df */
    case 5038:  /* pred_rec7vnx4df */
    case 5048:  /* pred_classvnx4df */
    case 5129:  /* *pred_cmpvnx4df */
    case 5138:  /* *pred_cmpvnx4df_narrow */
    case 5147:  /* *pred_cmpvnx4df_scalar */
    case 5156:  /* *pred_cmpvnx4df_scalar_narrow */
    case 5165:  /* *pred_eqnevnx4df_scalar */
    case 5174:  /* *pred_eqnevnx4df_scalar_narrow */
    case 5183:  /* pred_mergevnx4df_scalar */
    case 5199:  /* pred_fcvt_x_fvnx4df */
    case 5200:  /* pred_fcvt_xu_fvnx4df */
    case 5217:  /* pred_fix_truncvnx4df */
    case 5218:  /* pred_fixuns_truncvnx4df */
    case 5235:  /* pred_floatvnx4df */
    case 5236:  /* pred_floatunsvnx4df */
    case 5697:  /* pred_reduc_maxvnx4dfvnx1df */
    case 5698:  /* pred_reduc_minvnx4dfvnx1df */
    case 5723:  /* pred_reduc_plusovnx4dfvnx1df */
    case 5724:  /* pred_reduc_plusuvnx4dfvnx1df */
    case 5778:  /* *pred_extract_firstvnx4df */
    case 5838:  /* pred_slideupvnx4df */
    case 5839:  /* pred_slidedownvnx4df */
    case 5908:  /* pred_slide1upvnx4df */
    case 5909:  /* pred_slide1downvnx4df */
    case 5941:  /* pred_gathervnx4df */
    case 5972:  /* pred_gathervnx4df_scalar */
    case 6002:  /* pred_gatherei16vnx4df */
    case 6033:  /* pred_compressvnx4df */
    case 6066:  /* pred_fault_loadvnx4df */
      return MODE_VNX4DF;

    case 748:  /* *movvnx2df_whole */
    case 828:  /* pred_movvnx2df */
    case 859:  /* pred_storevnx2df */
    case 904:  /* pred_mergevnx2df */
    case 961:  /* *pred_broadcastvnx2df */
    case 996:  /* pred_strided_loadvnx2df */
    case 1027:  /* pred_strided_storevnx2df */
    case 1086:  /* pred_indexed_oloadvnx2df_same_eew */
    case 1087:  /* pred_indexed_uloadvnx2df_same_eew */
    case 1134:  /* pred_indexed_oloadvnx2df_x2_greater_eew */
    case 1135:  /* pred_indexed_uloadvnx2df_x2_greater_eew */
    case 1170:  /* pred_indexed_oloadvnx2df_x4_greater_eew */
    case 1171:  /* pred_indexed_uloadvnx2df_x4_greater_eew */
    case 1186:  /* pred_indexed_oloadvnx2df_x8_greater_eew */
    case 1187:  /* pred_indexed_uloadvnx2df_x8_greater_eew */
    case 1314:  /* pred_indexed_ostorevnx2dfvnx2qi */
    case 1315:  /* pred_indexed_ustorevnx2dfvnx2qi */
    case 1326:  /* pred_indexed_ostorevnx2dfvnx2hi */
    case 1327:  /* pred_indexed_ustorevnx2dfvnx2hi */
    case 1338:  /* pred_indexed_ostorevnx2dfvnx2si */
    case 1339:  /* pred_indexed_ustorevnx2dfvnx2si */
    case 1350:  /* pred_indexed_ostorevnx2dfvnx2di */
    case 1351:  /* pred_indexed_ustorevnx2dfvnx2di */
    case 4636:  /* pred_addvnx2df */
    case 4637:  /* pred_mulvnx2df */
    case 4638:  /* pred_smaxvnx2df */
    case 4639:  /* pred_sminvnx2df */
    case 4640:  /* pred_subvnx2df */
    case 4641:  /* pred_divvnx2df */
    case 4678:  /* pred_addvnx2df_scalar */
    case 4679:  /* pred_mulvnx2df_scalar */
    case 4680:  /* pred_smaxvnx2df_scalar */
    case 4681:  /* pred_sminvnx2df_scalar */
    case 4702:  /* pred_subvnx2df_scalar */
    case 4703:  /* pred_divvnx2df_scalar */
    case 4720:  /* pred_subvnx2df_reverse_scalar */
    case 4721:  /* pred_divvnx2df_reverse_scalar */
    case 4744:  /* pred_copysignvnx2df */
    case 4745:  /* pred_ncopysignvnx2df */
    case 4746:  /* pred_xorsignvnx2df */
    case 4771:  /* pred_copysignvnx2df_scalar */
    case 4772:  /* pred_ncopysignvnx2df_scalar */
    case 4773:  /* pred_xorsignvnx2df_scalar */
    case 4792:  /* *pred_maddvnx2df */
    case 4793:  /* *pred_msubvnx2df */
    case 4810:  /* *pred_maccvnx2df */
    case 4811:  /* *pred_msacvnx2df */
    case 4828:  /* *pred_mul_addvnx2df */
    case 4829:  /* *pred_mul_subvnx2df */
    case 4846:  /* *pred_maddvnx2df_scalar */
    case 4847:  /* *pred_msubvnx2df_scalar */
    case 4864:  /* *pred_maccvnx2df_scalar */
    case 4865:  /* *pred_msacvnx2df_scalar */
    case 4882:  /* *pred_mul_addvnx2df_scalar */
    case 4883:  /* *pred_mul_subvnx2df_scalar */
    case 4900:  /* *pred_nmsubvnx2df */
    case 4901:  /* *pred_nmaddvnx2df */
    case 4918:  /* *pred_nmsacvnx2df */
    case 4919:  /* *pred_nmaccvnx2df */
    case 4936:  /* *pred_mul_neg_addvnx2df */
    case 4937:  /* *pred_mul_neg_subvnx2df */
    case 4954:  /* *pred_nmsubvnx2df_scalar */
    case 4955:  /* *pred_nmaddvnx2df_scalar */
    case 4972:  /* *pred_nmsacvnx2df_scalar */
    case 4973:  /* *pred_nmaccvnx2df_scalar */
    case 4990:  /* *pred_mul_neg_addvnx2df_scalar */
    case 4991:  /* *pred_mul_neg_subvnx2df_scalar */
    case 5014:  /* pred_negvnx2df */
    case 5015:  /* pred_absvnx2df */
    case 5016:  /* pred_sqrtvnx2df */
    case 5035:  /* pred_rsqrt7vnx2df */
    case 5036:  /* pred_rec7vnx2df */
    case 5047:  /* pred_classvnx2df */
    case 5128:  /* *pred_cmpvnx2df */
    case 5137:  /* *pred_cmpvnx2df_narrow */
    case 5146:  /* *pred_cmpvnx2df_scalar */
    case 5155:  /* *pred_cmpvnx2df_scalar_narrow */
    case 5164:  /* *pred_eqnevnx2df_scalar */
    case 5173:  /* *pred_eqnevnx2df_scalar_narrow */
    case 5182:  /* pred_mergevnx2df_scalar */
    case 5197:  /* pred_fcvt_x_fvnx2df */
    case 5198:  /* pred_fcvt_xu_fvnx2df */
    case 5215:  /* pred_fix_truncvnx2df */
    case 5216:  /* pred_fixuns_truncvnx2df */
    case 5233:  /* pred_floatvnx2df */
    case 5234:  /* pred_floatunsvnx2df */
    case 5695:  /* pred_reduc_maxvnx2dfvnx1df */
    case 5696:  /* pred_reduc_minvnx2dfvnx1df */
    case 5721:  /* pred_reduc_plusovnx2dfvnx1df */
    case 5722:  /* pred_reduc_plusuvnx2dfvnx1df */
    case 5777:  /* *pred_extract_firstvnx2df */
    case 5836:  /* pred_slideupvnx2df */
    case 5837:  /* pred_slidedownvnx2df */
    case 5906:  /* pred_slide1upvnx2df */
    case 5907:  /* pred_slide1downvnx2df */
    case 5940:  /* pred_gathervnx2df */
    case 5971:  /* pred_gathervnx2df_scalar */
    case 6001:  /* pred_gatherei16vnx2df */
    case 6032:  /* pred_compressvnx2df */
    case 6065:  /* pred_fault_loadvnx2df */
      return MODE_VNX2DF;

    case 747:  /* *movvnx1df_whole */
    case 827:  /* pred_movvnx1df */
    case 858:  /* pred_storevnx1df */
    case 903:  /* pred_mergevnx1df */
    case 960:  /* *pred_broadcastvnx1df */
    case 995:  /* pred_strided_loadvnx1df */
    case 1026:  /* pred_strided_storevnx1df */
    case 1084:  /* pred_indexed_oloadvnx1df_same_eew */
    case 1085:  /* pred_indexed_uloadvnx1df_same_eew */
    case 1132:  /* pred_indexed_oloadvnx1df_x2_greater_eew */
    case 1133:  /* pred_indexed_uloadvnx1df_x2_greater_eew */
    case 1168:  /* pred_indexed_oloadvnx1df_x4_greater_eew */
    case 1169:  /* pred_indexed_uloadvnx1df_x4_greater_eew */
    case 1184:  /* pred_indexed_oloadvnx1df_x8_greater_eew */
    case 1185:  /* pred_indexed_uloadvnx1df_x8_greater_eew */
    case 1296:  /* pred_indexed_ostorevnx1dfvnx1qi */
    case 1297:  /* pred_indexed_ustorevnx1dfvnx1qi */
    case 1298:  /* pred_indexed_ostorevnx1dfvnx1hi */
    case 1299:  /* pred_indexed_ustorevnx1dfvnx1hi */
    case 1300:  /* pred_indexed_ostorevnx1dfvnx1si */
    case 1301:  /* pred_indexed_ustorevnx1dfvnx1si */
    case 1302:  /* pred_indexed_ostorevnx1dfvnx1di */
    case 1303:  /* pred_indexed_ustorevnx1dfvnx1di */
    case 4630:  /* pred_addvnx1df */
    case 4631:  /* pred_mulvnx1df */
    case 4632:  /* pred_smaxvnx1df */
    case 4633:  /* pred_sminvnx1df */
    case 4634:  /* pred_subvnx1df */
    case 4635:  /* pred_divvnx1df */
    case 4674:  /* pred_addvnx1df_scalar */
    case 4675:  /* pred_mulvnx1df_scalar */
    case 4676:  /* pred_smaxvnx1df_scalar */
    case 4677:  /* pred_sminvnx1df_scalar */
    case 4700:  /* pred_subvnx1df_scalar */
    case 4701:  /* pred_divvnx1df_scalar */
    case 4718:  /* pred_subvnx1df_reverse_scalar */
    case 4719:  /* pred_divvnx1df_reverse_scalar */
    case 4741:  /* pred_copysignvnx1df */
    case 4742:  /* pred_ncopysignvnx1df */
    case 4743:  /* pred_xorsignvnx1df */
    case 4768:  /* pred_copysignvnx1df_scalar */
    case 4769:  /* pred_ncopysignvnx1df_scalar */
    case 4770:  /* pred_xorsignvnx1df_scalar */
    case 4790:  /* *pred_maddvnx1df */
    case 4791:  /* *pred_msubvnx1df */
    case 4808:  /* *pred_maccvnx1df */
    case 4809:  /* *pred_msacvnx1df */
    case 4826:  /* *pred_mul_addvnx1df */
    case 4827:  /* *pred_mul_subvnx1df */
    case 4844:  /* *pred_maddvnx1df_scalar */
    case 4845:  /* *pred_msubvnx1df_scalar */
    case 4862:  /* *pred_maccvnx1df_scalar */
    case 4863:  /* *pred_msacvnx1df_scalar */
    case 4880:  /* *pred_mul_addvnx1df_scalar */
    case 4881:  /* *pred_mul_subvnx1df_scalar */
    case 4898:  /* *pred_nmsubvnx1df */
    case 4899:  /* *pred_nmaddvnx1df */
    case 4916:  /* *pred_nmsacvnx1df */
    case 4917:  /* *pred_nmaccvnx1df */
    case 4934:  /* *pred_mul_neg_addvnx1df */
    case 4935:  /* *pred_mul_neg_subvnx1df */
    case 4952:  /* *pred_nmsubvnx1df_scalar */
    case 4953:  /* *pred_nmaddvnx1df_scalar */
    case 4970:  /* *pred_nmsacvnx1df_scalar */
    case 4971:  /* *pred_nmaccvnx1df_scalar */
    case 4988:  /* *pred_mul_neg_addvnx1df_scalar */
    case 4989:  /* *pred_mul_neg_subvnx1df_scalar */
    case 5011:  /* pred_negvnx1df */
    case 5012:  /* pred_absvnx1df */
    case 5013:  /* pred_sqrtvnx1df */
    case 5033:  /* pred_rsqrt7vnx1df */
    case 5034:  /* pred_rec7vnx1df */
    case 5046:  /* pred_classvnx1df */
    case 5127:  /* *pred_cmpvnx1df */
    case 5136:  /* *pred_cmpvnx1df_narrow */
    case 5145:  /* *pred_cmpvnx1df_scalar */
    case 5154:  /* *pred_cmpvnx1df_scalar_narrow */
    case 5163:  /* *pred_eqnevnx1df_scalar */
    case 5172:  /* *pred_eqnevnx1df_scalar_narrow */
    case 5181:  /* pred_mergevnx1df_scalar */
    case 5195:  /* pred_fcvt_x_fvnx1df */
    case 5196:  /* pred_fcvt_xu_fvnx1df */
    case 5213:  /* pred_fix_truncvnx1df */
    case 5214:  /* pred_fixuns_truncvnx1df */
    case 5231:  /* pred_floatvnx1df */
    case 5232:  /* pred_floatunsvnx1df */
    case 5693:  /* pred_reduc_maxvnx1dfvnx1df */
    case 5694:  /* pred_reduc_minvnx1dfvnx1df */
    case 5719:  /* pred_reduc_plusovnx1dfvnx1df */
    case 5720:  /* pred_reduc_plusuvnx1dfvnx1df */
    case 5776:  /* *pred_extract_firstvnx1df */
    case 5834:  /* pred_slideupvnx1df */
    case 5835:  /* pred_slidedownvnx1df */
    case 5904:  /* pred_slide1upvnx1df */
    case 5905:  /* pred_slide1downvnx1df */
    case 5939:  /* pred_gathervnx1df */
    case 5970:  /* pred_gathervnx1df_scalar */
    case 6000:  /* pred_gatherei16vnx1df */
    case 6031:  /* pred_compressvnx1df */
    case 6064:  /* pred_fault_loadvnx1df */
      return MODE_VNX1DF;

    case 746:  /* *movvnx16sf_whole */
    case 826:  /* pred_movvnx16sf */
    case 857:  /* pred_storevnx16sf */
    case 902:  /* pred_mergevnx16sf */
    case 959:  /* *pred_broadcastvnx16sf */
    case 994:  /* pred_strided_loadvnx16sf */
    case 1025:  /* pred_strided_storevnx16sf */
    case 1082:  /* pred_indexed_oloadvnx16sf_same_eew */
    case 1083:  /* pred_indexed_uloadvnx16sf_same_eew */
    case 1130:  /* pred_indexed_oloadvnx16sf_x2_greater_eew */
    case 1131:  /* pred_indexed_uloadvnx16sf_x2_greater_eew */
    case 1166:  /* pred_indexed_oloadvnx16sf_x4_greater_eew */
    case 1167:  /* pred_indexed_uloadvnx16sf_x4_greater_eew */
    case 1454:  /* pred_indexed_ostorevnx16sfvnx16qi */
    case 1455:  /* pred_indexed_ustorevnx16sfvnx16qi */
    case 1462:  /* pred_indexed_ostorevnx16sfvnx16hi */
    case 1463:  /* pred_indexed_ustorevnx16sfvnx16hi */
    case 1470:  /* pred_indexed_ostorevnx16sfvnx16si */
    case 1471:  /* pred_indexed_ustorevnx16sfvnx16si */
    case 4624:  /* pred_addvnx16sf */
    case 4625:  /* pred_mulvnx16sf */
    case 4626:  /* pred_smaxvnx16sf */
    case 4627:  /* pred_sminvnx16sf */
    case 4628:  /* pred_subvnx16sf */
    case 4629:  /* pred_divvnx16sf */
    case 4670:  /* pred_addvnx16sf_scalar */
    case 4671:  /* pred_mulvnx16sf_scalar */
    case 4672:  /* pred_smaxvnx16sf_scalar */
    case 4673:  /* pred_sminvnx16sf_scalar */
    case 4698:  /* pred_subvnx16sf_scalar */
    case 4699:  /* pred_divvnx16sf_scalar */
    case 4716:  /* pred_subvnx16sf_reverse_scalar */
    case 4717:  /* pred_divvnx16sf_reverse_scalar */
    case 4738:  /* pred_copysignvnx16sf */
    case 4739:  /* pred_ncopysignvnx16sf */
    case 4740:  /* pred_xorsignvnx16sf */
    case 4765:  /* pred_copysignvnx16sf_scalar */
    case 4766:  /* pred_ncopysignvnx16sf_scalar */
    case 4767:  /* pred_xorsignvnx16sf_scalar */
    case 4788:  /* *pred_maddvnx16sf */
    case 4789:  /* *pred_msubvnx16sf */
    case 4806:  /* *pred_maccvnx16sf */
    case 4807:  /* *pred_msacvnx16sf */
    case 4824:  /* *pred_mul_addvnx16sf */
    case 4825:  /* *pred_mul_subvnx16sf */
    case 4842:  /* *pred_maddvnx16sf_scalar */
    case 4843:  /* *pred_msubvnx16sf_scalar */
    case 4860:  /* *pred_maccvnx16sf_scalar */
    case 4861:  /* *pred_msacvnx16sf_scalar */
    case 4878:  /* *pred_mul_addvnx16sf_scalar */
    case 4879:  /* *pred_mul_subvnx16sf_scalar */
    case 4896:  /* *pred_nmsubvnx16sf */
    case 4897:  /* *pred_nmaddvnx16sf */
    case 4914:  /* *pred_nmsacvnx16sf */
    case 4915:  /* *pred_nmaccvnx16sf */
    case 4932:  /* *pred_mul_neg_addvnx16sf */
    case 4933:  /* *pred_mul_neg_subvnx16sf */
    case 4950:  /* *pred_nmsubvnx16sf_scalar */
    case 4951:  /* *pred_nmaddvnx16sf_scalar */
    case 4968:  /* *pred_nmsacvnx16sf_scalar */
    case 4969:  /* *pred_nmaccvnx16sf_scalar */
    case 4986:  /* *pred_mul_neg_addvnx16sf_scalar */
    case 4987:  /* *pred_mul_neg_subvnx16sf_scalar */
    case 5008:  /* pred_negvnx16sf */
    case 5009:  /* pred_absvnx16sf */
    case 5010:  /* pred_sqrtvnx16sf */
    case 5031:  /* pred_rsqrt7vnx16sf */
    case 5032:  /* pred_rec7vnx16sf */
    case 5045:  /* pred_classvnx16sf */
    case 5126:  /* *pred_cmpvnx16sf */
    case 5135:  /* *pred_cmpvnx16sf_narrow */
    case 5144:  /* *pred_cmpvnx16sf_scalar */
    case 5153:  /* *pred_cmpvnx16sf_scalar_narrow */
    case 5162:  /* *pred_eqnevnx16sf_scalar */
    case 5171:  /* *pred_eqnevnx16sf_scalar_narrow */
    case 5180:  /* pred_mergevnx16sf_scalar */
    case 5193:  /* pred_fcvt_x_fvnx16sf */
    case 5194:  /* pred_fcvt_xu_fvnx16sf */
    case 5211:  /* pred_fix_truncvnx16sf */
    case 5212:  /* pred_fixuns_truncvnx16sf */
    case 5229:  /* pred_floatvnx16sf */
    case 5230:  /* pred_floatunsvnx16sf */
    case 5691:  /* pred_reduc_maxvnx16sfvnx2sf */
    case 5692:  /* pred_reduc_minvnx16sfvnx2sf */
    case 5717:  /* pred_reduc_plusovnx16sfvnx2sf */
    case 5718:  /* pred_reduc_plusuvnx16sfvnx2sf */
    case 5743:  /* pred_widen_reduc_plusovnx16sfvnx1df */
    case 5744:  /* pred_widen_reduc_plusuvnx16sfvnx1df */
    case 5775:  /* *pred_extract_firstvnx16sf */
    case 5832:  /* pred_slideupvnx16sf */
    case 5833:  /* pred_slidedownvnx16sf */
    case 5902:  /* pred_slide1upvnx16sf */
    case 5903:  /* pred_slide1downvnx16sf */
    case 5938:  /* pred_gathervnx16sf */
    case 5969:  /* pred_gathervnx16sf_scalar */
    case 5999:  /* pred_gatherei16vnx16sf */
    case 6030:  /* pred_compressvnx16sf */
    case 6063:  /* pred_fault_loadvnx16sf */
      return MODE_VNX16SF;

    case 745:  /* *movvnx8sf_whole */
    case 825:  /* pred_movvnx8sf */
    case 856:  /* pred_storevnx8sf */
    case 901:  /* pred_mergevnx8sf */
    case 958:  /* *pred_broadcastvnx8sf */
    case 993:  /* pred_strided_loadvnx8sf */
    case 1024:  /* pred_strided_storevnx8sf */
    case 1080:  /* pred_indexed_oloadvnx8sf_same_eew */
    case 1081:  /* pred_indexed_uloadvnx8sf_same_eew */
    case 1128:  /* pred_indexed_oloadvnx8sf_x2_greater_eew */
    case 1129:  /* pred_indexed_uloadvnx8sf_x2_greater_eew */
    case 1164:  /* pred_indexed_oloadvnx8sf_x4_greater_eew */
    case 1165:  /* pred_indexed_uloadvnx8sf_x4_greater_eew */
    case 1228:  /* pred_indexed_oloadvnx8sf_x2_smaller_eew */
    case 1229:  /* pred_indexed_uloadvnx8sf_x2_smaller_eew */
    case 1408:  /* pred_indexed_ostorevnx8sfvnx8qi */
    case 1409:  /* pred_indexed_ustorevnx8sfvnx8qi */
    case 1420:  /* pred_indexed_ostorevnx8sfvnx8hi */
    case 1421:  /* pred_indexed_ustorevnx8sfvnx8hi */
    case 1432:  /* pred_indexed_ostorevnx8sfvnx8si */
    case 1433:  /* pred_indexed_ustorevnx8sfvnx8si */
    case 1444:  /* pred_indexed_ostorevnx8sfvnx8di */
    case 1445:  /* pred_indexed_ustorevnx8sfvnx8di */
    case 4618:  /* pred_addvnx8sf */
    case 4619:  /* pred_mulvnx8sf */
    case 4620:  /* pred_smaxvnx8sf */
    case 4621:  /* pred_sminvnx8sf */
    case 4622:  /* pred_subvnx8sf */
    case 4623:  /* pred_divvnx8sf */
    case 4666:  /* pred_addvnx8sf_scalar */
    case 4667:  /* pred_mulvnx8sf_scalar */
    case 4668:  /* pred_smaxvnx8sf_scalar */
    case 4669:  /* pred_sminvnx8sf_scalar */
    case 4696:  /* pred_subvnx8sf_scalar */
    case 4697:  /* pred_divvnx8sf_scalar */
    case 4714:  /* pred_subvnx8sf_reverse_scalar */
    case 4715:  /* pred_divvnx8sf_reverse_scalar */
    case 4735:  /* pred_copysignvnx8sf */
    case 4736:  /* pred_ncopysignvnx8sf */
    case 4737:  /* pred_xorsignvnx8sf */
    case 4762:  /* pred_copysignvnx8sf_scalar */
    case 4763:  /* pred_ncopysignvnx8sf_scalar */
    case 4764:  /* pred_xorsignvnx8sf_scalar */
    case 4786:  /* *pred_maddvnx8sf */
    case 4787:  /* *pred_msubvnx8sf */
    case 4804:  /* *pred_maccvnx8sf */
    case 4805:  /* *pred_msacvnx8sf */
    case 4822:  /* *pred_mul_addvnx8sf */
    case 4823:  /* *pred_mul_subvnx8sf */
    case 4840:  /* *pred_maddvnx8sf_scalar */
    case 4841:  /* *pred_msubvnx8sf_scalar */
    case 4858:  /* *pred_maccvnx8sf_scalar */
    case 4859:  /* *pred_msacvnx8sf_scalar */
    case 4876:  /* *pred_mul_addvnx8sf_scalar */
    case 4877:  /* *pred_mul_subvnx8sf_scalar */
    case 4894:  /* *pred_nmsubvnx8sf */
    case 4895:  /* *pred_nmaddvnx8sf */
    case 4912:  /* *pred_nmsacvnx8sf */
    case 4913:  /* *pred_nmaccvnx8sf */
    case 4930:  /* *pred_mul_neg_addvnx8sf */
    case 4931:  /* *pred_mul_neg_subvnx8sf */
    case 4948:  /* *pred_nmsubvnx8sf_scalar */
    case 4949:  /* *pred_nmaddvnx8sf_scalar */
    case 4966:  /* *pred_nmsacvnx8sf_scalar */
    case 4967:  /* *pred_nmaccvnx8sf_scalar */
    case 4984:  /* *pred_mul_neg_addvnx8sf_scalar */
    case 4985:  /* *pred_mul_neg_subvnx8sf_scalar */
    case 5005:  /* pred_negvnx8sf */
    case 5006:  /* pred_absvnx8sf */
    case 5007:  /* pred_sqrtvnx8sf */
    case 5029:  /* pred_rsqrt7vnx8sf */
    case 5030:  /* pred_rec7vnx8sf */
    case 5044:  /* pred_classvnx8sf */
    case 5059:  /* pred_dual_widen_addvnx8df */
    case 5060:  /* pred_dual_widen_subvnx8df */
    case 5061:  /* pred_dual_widen_mulvnx8df */
    case 5071:  /* pred_dual_widen_addvnx8df_scalar */
    case 5072:  /* pred_dual_widen_subvnx8df_scalar */
    case 5073:  /* pred_dual_widen_mulvnx8df_scalar */
    case 5080:  /* pred_single_widen_addvnx8df */
    case 5081:  /* pred_single_widen_subvnx8df */
    case 5088:  /* pred_single_widen_addvnx8df_scalar */
    case 5089:  /* pred_single_widen_subvnx8df_scalar */
    case 5096:  /* pred_widen_mul_addvnx8df */
    case 5097:  /* pred_widen_mul_subvnx8df */
    case 5104:  /* pred_widen_mul_addvnx8df_scalar */
    case 5105:  /* pred_widen_mul_subvnx8df_scalar */
    case 5112:  /* pred_widen_mul_neg_addvnx8df */
    case 5113:  /* pred_widen_mul_neg_subvnx8df */
    case 5120:  /* pred_widen_mul_neg_addvnx8df_scalar */
    case 5121:  /* pred_widen_mul_neg_subvnx8df_scalar */
    case 5125:  /* *pred_cmpvnx8sf */
    case 5134:  /* *pred_cmpvnx8sf_narrow */
    case 5143:  /* *pred_cmpvnx8sf_scalar */
    case 5152:  /* *pred_cmpvnx8sf_scalar_narrow */
    case 5161:  /* *pred_eqnevnx8sf_scalar */
    case 5170:  /* *pred_eqnevnx8sf_scalar_narrow */
    case 5179:  /* pred_mergevnx8sf_scalar */
    case 5191:  /* pred_fcvt_x_fvnx8sf */
    case 5192:  /* pred_fcvt_xu_fvnx8sf */
    case 5209:  /* pred_fix_truncvnx8sf */
    case 5210:  /* pred_fixuns_truncvnx8sf */
    case 5227:  /* pred_floatvnx8sf */
    case 5228:  /* pred_floatunsvnx8sf */
    case 5245:  /* pred_widen_fcvt_x_fvnx8di */
    case 5246:  /* pred_widen_fcvt_xu_fvnx8di */
    case 5253:  /* pred_widen_fix_truncvnx8di */
    case 5254:  /* pred_widen_fixuns_truncvnx8di */
    case 5276:  /* pred_extendvnx8df */
    case 5319:  /* pred_narrow_floatvnx8di */
    case 5320:  /* pred_narrow_floatunsvnx8di */
    case 5324:  /* pred_truncvnx8df */
    case 5328:  /* pred_rod_truncvnx8df */
    case 5689:  /* pred_reduc_maxvnx8sfvnx2sf */
    case 5690:  /* pred_reduc_minvnx8sfvnx2sf */
    case 5707:  /* pred_reduc_maxvnx8sfvnx1sf */
    case 5708:  /* pred_reduc_minvnx8sfvnx1sf */
    case 5715:  /* pred_reduc_plusovnx8sfvnx2sf */
    case 5716:  /* pred_reduc_plusuvnx8sfvnx2sf */
    case 5733:  /* pred_reduc_plusovnx8sfvnx1sf */
    case 5734:  /* pred_reduc_plusuvnx8sfvnx1sf */
    case 5741:  /* pred_widen_reduc_plusovnx8sfvnx1df */
    case 5742:  /* pred_widen_reduc_plusuvnx8sfvnx1df */
    case 5774:  /* *pred_extract_firstvnx8sf */
    case 5830:  /* pred_slideupvnx8sf */
    case 5831:  /* pred_slidedownvnx8sf */
    case 5900:  /* pred_slide1upvnx8sf */
    case 5901:  /* pred_slide1downvnx8sf */
    case 5937:  /* pred_gathervnx8sf */
    case 5968:  /* pred_gathervnx8sf_scalar */
    case 5998:  /* pred_gatherei16vnx8sf */
    case 6029:  /* pred_compressvnx8sf */
    case 6062:  /* pred_fault_loadvnx8sf */
      return MODE_VNX8SF;

    case 744:  /* *movvnx4sf_whole */
    case 824:  /* pred_movvnx4sf */
    case 855:  /* pred_storevnx4sf */
    case 900:  /* pred_mergevnx4sf */
    case 957:  /* *pred_broadcastvnx4sf */
    case 992:  /* pred_strided_loadvnx4sf */
    case 1023:  /* pred_strided_storevnx4sf */
    case 1078:  /* pred_indexed_oloadvnx4sf_same_eew */
    case 1079:  /* pred_indexed_uloadvnx4sf_same_eew */
    case 1126:  /* pred_indexed_oloadvnx4sf_x2_greater_eew */
    case 1127:  /* pred_indexed_uloadvnx4sf_x2_greater_eew */
    case 1162:  /* pred_indexed_oloadvnx4sf_x4_greater_eew */
    case 1163:  /* pred_indexed_uloadvnx4sf_x4_greater_eew */
    case 1226:  /* pred_indexed_oloadvnx4sf_x2_smaller_eew */
    case 1227:  /* pred_indexed_uloadvnx4sf_x2_smaller_eew */
    case 1360:  /* pred_indexed_ostorevnx4sfvnx4qi */
    case 1361:  /* pred_indexed_ustorevnx4sfvnx4qi */
    case 1372:  /* pred_indexed_ostorevnx4sfvnx4hi */
    case 1373:  /* pred_indexed_ustorevnx4sfvnx4hi */
    case 1384:  /* pred_indexed_ostorevnx4sfvnx4si */
    case 1385:  /* pred_indexed_ustorevnx4sfvnx4si */
    case 1396:  /* pred_indexed_ostorevnx4sfvnx4di */
    case 1397:  /* pred_indexed_ustorevnx4sfvnx4di */
    case 4612:  /* pred_addvnx4sf */
    case 4613:  /* pred_mulvnx4sf */
    case 4614:  /* pred_smaxvnx4sf */
    case 4615:  /* pred_sminvnx4sf */
    case 4616:  /* pred_subvnx4sf */
    case 4617:  /* pred_divvnx4sf */
    case 4662:  /* pred_addvnx4sf_scalar */
    case 4663:  /* pred_mulvnx4sf_scalar */
    case 4664:  /* pred_smaxvnx4sf_scalar */
    case 4665:  /* pred_sminvnx4sf_scalar */
    case 4694:  /* pred_subvnx4sf_scalar */
    case 4695:  /* pred_divvnx4sf_scalar */
    case 4712:  /* pred_subvnx4sf_reverse_scalar */
    case 4713:  /* pred_divvnx4sf_reverse_scalar */
    case 4732:  /* pred_copysignvnx4sf */
    case 4733:  /* pred_ncopysignvnx4sf */
    case 4734:  /* pred_xorsignvnx4sf */
    case 4759:  /* pred_copysignvnx4sf_scalar */
    case 4760:  /* pred_ncopysignvnx4sf_scalar */
    case 4761:  /* pred_xorsignvnx4sf_scalar */
    case 4784:  /* *pred_maddvnx4sf */
    case 4785:  /* *pred_msubvnx4sf */
    case 4802:  /* *pred_maccvnx4sf */
    case 4803:  /* *pred_msacvnx4sf */
    case 4820:  /* *pred_mul_addvnx4sf */
    case 4821:  /* *pred_mul_subvnx4sf */
    case 4838:  /* *pred_maddvnx4sf_scalar */
    case 4839:  /* *pred_msubvnx4sf_scalar */
    case 4856:  /* *pred_maccvnx4sf_scalar */
    case 4857:  /* *pred_msacvnx4sf_scalar */
    case 4874:  /* *pred_mul_addvnx4sf_scalar */
    case 4875:  /* *pred_mul_subvnx4sf_scalar */
    case 4892:  /* *pred_nmsubvnx4sf */
    case 4893:  /* *pred_nmaddvnx4sf */
    case 4910:  /* *pred_nmsacvnx4sf */
    case 4911:  /* *pred_nmaccvnx4sf */
    case 4928:  /* *pred_mul_neg_addvnx4sf */
    case 4929:  /* *pred_mul_neg_subvnx4sf */
    case 4946:  /* *pred_nmsubvnx4sf_scalar */
    case 4947:  /* *pred_nmaddvnx4sf_scalar */
    case 4964:  /* *pred_nmsacvnx4sf_scalar */
    case 4965:  /* *pred_nmaccvnx4sf_scalar */
    case 4982:  /* *pred_mul_neg_addvnx4sf_scalar */
    case 4983:  /* *pred_mul_neg_subvnx4sf_scalar */
    case 5002:  /* pred_negvnx4sf */
    case 5003:  /* pred_absvnx4sf */
    case 5004:  /* pred_sqrtvnx4sf */
    case 5027:  /* pred_rsqrt7vnx4sf */
    case 5028:  /* pred_rec7vnx4sf */
    case 5043:  /* pred_classvnx4sf */
    case 5056:  /* pred_dual_widen_addvnx4df */
    case 5057:  /* pred_dual_widen_subvnx4df */
    case 5058:  /* pred_dual_widen_mulvnx4df */
    case 5068:  /* pred_dual_widen_addvnx4df_scalar */
    case 5069:  /* pred_dual_widen_subvnx4df_scalar */
    case 5070:  /* pred_dual_widen_mulvnx4df_scalar */
    case 5078:  /* pred_single_widen_addvnx4df */
    case 5079:  /* pred_single_widen_subvnx4df */
    case 5086:  /* pred_single_widen_addvnx4df_scalar */
    case 5087:  /* pred_single_widen_subvnx4df_scalar */
    case 5094:  /* pred_widen_mul_addvnx4df */
    case 5095:  /* pred_widen_mul_subvnx4df */
    case 5102:  /* pred_widen_mul_addvnx4df_scalar */
    case 5103:  /* pred_widen_mul_subvnx4df_scalar */
    case 5110:  /* pred_widen_mul_neg_addvnx4df */
    case 5111:  /* pred_widen_mul_neg_subvnx4df */
    case 5118:  /* pred_widen_mul_neg_addvnx4df_scalar */
    case 5119:  /* pred_widen_mul_neg_subvnx4df_scalar */
    case 5124:  /* *pred_cmpvnx4sf */
    case 5133:  /* *pred_cmpvnx4sf_narrow */
    case 5142:  /* *pred_cmpvnx4sf_scalar */
    case 5151:  /* *pred_cmpvnx4sf_scalar_narrow */
    case 5160:  /* *pred_eqnevnx4sf_scalar */
    case 5169:  /* *pred_eqnevnx4sf_scalar_narrow */
    case 5178:  /* pred_mergevnx4sf_scalar */
    case 5189:  /* pred_fcvt_x_fvnx4sf */
    case 5190:  /* pred_fcvt_xu_fvnx4sf */
    case 5207:  /* pred_fix_truncvnx4sf */
    case 5208:  /* pred_fixuns_truncvnx4sf */
    case 5225:  /* pred_floatvnx4sf */
    case 5226:  /* pred_floatunsvnx4sf */
    case 5243:  /* pred_widen_fcvt_x_fvnx4di */
    case 5244:  /* pred_widen_fcvt_xu_fvnx4di */
    case 5251:  /* pred_widen_fix_truncvnx4di */
    case 5252:  /* pred_widen_fixuns_truncvnx4di */
    case 5275:  /* pred_extendvnx4df */
    case 5317:  /* pred_narrow_floatvnx4di */
    case 5318:  /* pred_narrow_floatunsvnx4di */
    case 5323:  /* pred_truncvnx4df */
    case 5327:  /* pred_rod_truncvnx4df */
    case 5687:  /* pred_reduc_maxvnx4sfvnx2sf */
    case 5688:  /* pred_reduc_minvnx4sfvnx2sf */
    case 5705:  /* pred_reduc_maxvnx4sfvnx1sf */
    case 5706:  /* pred_reduc_minvnx4sfvnx1sf */
    case 5713:  /* pred_reduc_plusovnx4sfvnx2sf */
    case 5714:  /* pred_reduc_plusuvnx4sfvnx2sf */
    case 5731:  /* pred_reduc_plusovnx4sfvnx1sf */
    case 5732:  /* pred_reduc_plusuvnx4sfvnx1sf */
    case 5739:  /* pred_widen_reduc_plusovnx4sfvnx1df */
    case 5740:  /* pred_widen_reduc_plusuvnx4sfvnx1df */
    case 5773:  /* *pred_extract_firstvnx4sf */
    case 5828:  /* pred_slideupvnx4sf */
    case 5829:  /* pred_slidedownvnx4sf */
    case 5898:  /* pred_slide1upvnx4sf */
    case 5899:  /* pred_slide1downvnx4sf */
    case 5936:  /* pred_gathervnx4sf */
    case 5967:  /* pred_gathervnx4sf_scalar */
    case 5997:  /* pred_gatherei16vnx4sf */
    case 6028:  /* pred_compressvnx4sf */
    case 6061:  /* pred_fault_loadvnx4sf */
      return MODE_VNX4SF;

    case 743:  /* *movvnx2sf_whole */
    case 823:  /* pred_movvnx2sf */
    case 854:  /* pred_storevnx2sf */
    case 899:  /* pred_mergevnx2sf */
    case 956:  /* *pred_broadcastvnx2sf */
    case 991:  /* pred_strided_loadvnx2sf */
    case 1022:  /* pred_strided_storevnx2sf */
    case 1076:  /* pred_indexed_oloadvnx2sf_same_eew */
    case 1077:  /* pred_indexed_uloadvnx2sf_same_eew */
    case 1124:  /* pred_indexed_oloadvnx2sf_x2_greater_eew */
    case 1125:  /* pred_indexed_uloadvnx2sf_x2_greater_eew */
    case 1160:  /* pred_indexed_oloadvnx2sf_x4_greater_eew */
    case 1161:  /* pred_indexed_uloadvnx2sf_x4_greater_eew */
    case 1224:  /* pred_indexed_oloadvnx2sf_x2_smaller_eew */
    case 1225:  /* pred_indexed_uloadvnx2sf_x2_smaller_eew */
    case 1312:  /* pred_indexed_ostorevnx2sfvnx2qi */
    case 1313:  /* pred_indexed_ustorevnx2sfvnx2qi */
    case 1324:  /* pred_indexed_ostorevnx2sfvnx2hi */
    case 1325:  /* pred_indexed_ustorevnx2sfvnx2hi */
    case 1336:  /* pred_indexed_ostorevnx2sfvnx2si */
    case 1337:  /* pred_indexed_ustorevnx2sfvnx2si */
    case 1348:  /* pred_indexed_ostorevnx2sfvnx2di */
    case 1349:  /* pred_indexed_ustorevnx2sfvnx2di */
    case 4606:  /* pred_addvnx2sf */
    case 4607:  /* pred_mulvnx2sf */
    case 4608:  /* pred_smaxvnx2sf */
    case 4609:  /* pred_sminvnx2sf */
    case 4610:  /* pred_subvnx2sf */
    case 4611:  /* pred_divvnx2sf */
    case 4658:  /* pred_addvnx2sf_scalar */
    case 4659:  /* pred_mulvnx2sf_scalar */
    case 4660:  /* pred_smaxvnx2sf_scalar */
    case 4661:  /* pred_sminvnx2sf_scalar */
    case 4692:  /* pred_subvnx2sf_scalar */
    case 4693:  /* pred_divvnx2sf_scalar */
    case 4710:  /* pred_subvnx2sf_reverse_scalar */
    case 4711:  /* pred_divvnx2sf_reverse_scalar */
    case 4729:  /* pred_copysignvnx2sf */
    case 4730:  /* pred_ncopysignvnx2sf */
    case 4731:  /* pred_xorsignvnx2sf */
    case 4756:  /* pred_copysignvnx2sf_scalar */
    case 4757:  /* pred_ncopysignvnx2sf_scalar */
    case 4758:  /* pred_xorsignvnx2sf_scalar */
    case 4782:  /* *pred_maddvnx2sf */
    case 4783:  /* *pred_msubvnx2sf */
    case 4800:  /* *pred_maccvnx2sf */
    case 4801:  /* *pred_msacvnx2sf */
    case 4818:  /* *pred_mul_addvnx2sf */
    case 4819:  /* *pred_mul_subvnx2sf */
    case 4836:  /* *pred_maddvnx2sf_scalar */
    case 4837:  /* *pred_msubvnx2sf_scalar */
    case 4854:  /* *pred_maccvnx2sf_scalar */
    case 4855:  /* *pred_msacvnx2sf_scalar */
    case 4872:  /* *pred_mul_addvnx2sf_scalar */
    case 4873:  /* *pred_mul_subvnx2sf_scalar */
    case 4890:  /* *pred_nmsubvnx2sf */
    case 4891:  /* *pred_nmaddvnx2sf */
    case 4908:  /* *pred_nmsacvnx2sf */
    case 4909:  /* *pred_nmaccvnx2sf */
    case 4926:  /* *pred_mul_neg_addvnx2sf */
    case 4927:  /* *pred_mul_neg_subvnx2sf */
    case 4944:  /* *pred_nmsubvnx2sf_scalar */
    case 4945:  /* *pred_nmaddvnx2sf_scalar */
    case 4962:  /* *pred_nmsacvnx2sf_scalar */
    case 4963:  /* *pred_nmaccvnx2sf_scalar */
    case 4980:  /* *pred_mul_neg_addvnx2sf_scalar */
    case 4981:  /* *pred_mul_neg_subvnx2sf_scalar */
    case 4999:  /* pred_negvnx2sf */
    case 5000:  /* pred_absvnx2sf */
    case 5001:  /* pred_sqrtvnx2sf */
    case 5025:  /* pred_rsqrt7vnx2sf */
    case 5026:  /* pred_rec7vnx2sf */
    case 5042:  /* pred_classvnx2sf */
    case 5053:  /* pred_dual_widen_addvnx2df */
    case 5054:  /* pred_dual_widen_subvnx2df */
    case 5055:  /* pred_dual_widen_mulvnx2df */
    case 5065:  /* pred_dual_widen_addvnx2df_scalar */
    case 5066:  /* pred_dual_widen_subvnx2df_scalar */
    case 5067:  /* pred_dual_widen_mulvnx2df_scalar */
    case 5076:  /* pred_single_widen_addvnx2df */
    case 5077:  /* pred_single_widen_subvnx2df */
    case 5084:  /* pred_single_widen_addvnx2df_scalar */
    case 5085:  /* pred_single_widen_subvnx2df_scalar */
    case 5092:  /* pred_widen_mul_addvnx2df */
    case 5093:  /* pred_widen_mul_subvnx2df */
    case 5100:  /* pred_widen_mul_addvnx2df_scalar */
    case 5101:  /* pred_widen_mul_subvnx2df_scalar */
    case 5108:  /* pred_widen_mul_neg_addvnx2df */
    case 5109:  /* pred_widen_mul_neg_subvnx2df */
    case 5116:  /* pred_widen_mul_neg_addvnx2df_scalar */
    case 5117:  /* pred_widen_mul_neg_subvnx2df_scalar */
    case 5123:  /* *pred_cmpvnx2sf */
    case 5132:  /* *pred_cmpvnx2sf_narrow */
    case 5141:  /* *pred_cmpvnx2sf_scalar */
    case 5150:  /* *pred_cmpvnx2sf_scalar_narrow */
    case 5159:  /* *pred_eqnevnx2sf_scalar */
    case 5168:  /* *pred_eqnevnx2sf_scalar_narrow */
    case 5177:  /* pred_mergevnx2sf_scalar */
    case 5187:  /* pred_fcvt_x_fvnx2sf */
    case 5188:  /* pred_fcvt_xu_fvnx2sf */
    case 5205:  /* pred_fix_truncvnx2sf */
    case 5206:  /* pred_fixuns_truncvnx2sf */
    case 5223:  /* pred_floatvnx2sf */
    case 5224:  /* pred_floatunsvnx2sf */
    case 5241:  /* pred_widen_fcvt_x_fvnx2di */
    case 5242:  /* pred_widen_fcvt_xu_fvnx2di */
    case 5249:  /* pred_widen_fix_truncvnx2di */
    case 5250:  /* pred_widen_fixuns_truncvnx2di */
    case 5274:  /* pred_extendvnx2df */
    case 5315:  /* pred_narrow_floatvnx2di */
    case 5316:  /* pred_narrow_floatunsvnx2di */
    case 5322:  /* pred_truncvnx2df */
    case 5326:  /* pred_rod_truncvnx2df */
    case 5685:  /* pred_reduc_maxvnx2sfvnx2sf */
    case 5686:  /* pred_reduc_minvnx2sfvnx2sf */
    case 5703:  /* pred_reduc_maxvnx2sfvnx1sf */
    case 5704:  /* pred_reduc_minvnx2sfvnx1sf */
    case 5711:  /* pred_reduc_plusovnx2sfvnx2sf */
    case 5712:  /* pred_reduc_plusuvnx2sfvnx2sf */
    case 5729:  /* pred_reduc_plusovnx2sfvnx1sf */
    case 5730:  /* pred_reduc_plusuvnx2sfvnx1sf */
    case 5737:  /* pred_widen_reduc_plusovnx2sfvnx1df */
    case 5738:  /* pred_widen_reduc_plusuvnx2sfvnx1df */
    case 5772:  /* *pred_extract_firstvnx2sf */
    case 5826:  /* pred_slideupvnx2sf */
    case 5827:  /* pred_slidedownvnx2sf */
    case 5896:  /* pred_slide1upvnx2sf */
    case 5897:  /* pred_slide1downvnx2sf */
    case 5935:  /* pred_gathervnx2sf */
    case 5966:  /* pred_gathervnx2sf_scalar */
    case 5996:  /* pred_gatherei16vnx2sf */
    case 6027:  /* pred_compressvnx2sf */
    case 6060:  /* pred_fault_loadvnx2sf */
      return MODE_VNX2SF;

    case 742:  /* *movvnx1sf_whole */
    case 757:  /* *movvnx1sf_fract */
    case 822:  /* pred_movvnx1sf */
    case 853:  /* pred_storevnx1sf */
    case 898:  /* pred_mergevnx1sf */
    case 955:  /* *pred_broadcastvnx1sf */
    case 990:  /* pred_strided_loadvnx1sf */
    case 1021:  /* pred_strided_storevnx1sf */
    case 1074:  /* pred_indexed_oloadvnx1sf_same_eew */
    case 1075:  /* pred_indexed_uloadvnx1sf_same_eew */
    case 1122:  /* pred_indexed_oloadvnx1sf_x2_greater_eew */
    case 1123:  /* pred_indexed_uloadvnx1sf_x2_greater_eew */
    case 1158:  /* pred_indexed_oloadvnx1sf_x4_greater_eew */
    case 1159:  /* pred_indexed_uloadvnx1sf_x4_greater_eew */
    case 1222:  /* pred_indexed_oloadvnx1sf_x2_smaller_eew */
    case 1223:  /* pred_indexed_uloadvnx1sf_x2_smaller_eew */
    case 1288:  /* pred_indexed_ostorevnx1sfvnx1qi */
    case 1289:  /* pred_indexed_ustorevnx1sfvnx1qi */
    case 1290:  /* pred_indexed_ostorevnx1sfvnx1hi */
    case 1291:  /* pred_indexed_ustorevnx1sfvnx1hi */
    case 1292:  /* pred_indexed_ostorevnx1sfvnx1si */
    case 1293:  /* pred_indexed_ustorevnx1sfvnx1si */
    case 1294:  /* pred_indexed_ostorevnx1sfvnx1di */
    case 1295:  /* pred_indexed_ustorevnx1sfvnx1di */
    case 4600:  /* pred_addvnx1sf */
    case 4601:  /* pred_mulvnx1sf */
    case 4602:  /* pred_smaxvnx1sf */
    case 4603:  /* pred_sminvnx1sf */
    case 4604:  /* pred_subvnx1sf */
    case 4605:  /* pred_divvnx1sf */
    case 4654:  /* pred_addvnx1sf_scalar */
    case 4655:  /* pred_mulvnx1sf_scalar */
    case 4656:  /* pred_smaxvnx1sf_scalar */
    case 4657:  /* pred_sminvnx1sf_scalar */
    case 4690:  /* pred_subvnx1sf_scalar */
    case 4691:  /* pred_divvnx1sf_scalar */
    case 4708:  /* pred_subvnx1sf_reverse_scalar */
    case 4709:  /* pred_divvnx1sf_reverse_scalar */
    case 4726:  /* pred_copysignvnx1sf */
    case 4727:  /* pred_ncopysignvnx1sf */
    case 4728:  /* pred_xorsignvnx1sf */
    case 4753:  /* pred_copysignvnx1sf_scalar */
    case 4754:  /* pred_ncopysignvnx1sf_scalar */
    case 4755:  /* pred_xorsignvnx1sf_scalar */
    case 4780:  /* *pred_maddvnx1sf */
    case 4781:  /* *pred_msubvnx1sf */
    case 4798:  /* *pred_maccvnx1sf */
    case 4799:  /* *pred_msacvnx1sf */
    case 4816:  /* *pred_mul_addvnx1sf */
    case 4817:  /* *pred_mul_subvnx1sf */
    case 4834:  /* *pred_maddvnx1sf_scalar */
    case 4835:  /* *pred_msubvnx1sf_scalar */
    case 4852:  /* *pred_maccvnx1sf_scalar */
    case 4853:  /* *pred_msacvnx1sf_scalar */
    case 4870:  /* *pred_mul_addvnx1sf_scalar */
    case 4871:  /* *pred_mul_subvnx1sf_scalar */
    case 4888:  /* *pred_nmsubvnx1sf */
    case 4889:  /* *pred_nmaddvnx1sf */
    case 4906:  /* *pred_nmsacvnx1sf */
    case 4907:  /* *pred_nmaccvnx1sf */
    case 4924:  /* *pred_mul_neg_addvnx1sf */
    case 4925:  /* *pred_mul_neg_subvnx1sf */
    case 4942:  /* *pred_nmsubvnx1sf_scalar */
    case 4943:  /* *pred_nmaddvnx1sf_scalar */
    case 4960:  /* *pred_nmsacvnx1sf_scalar */
    case 4961:  /* *pred_nmaccvnx1sf_scalar */
    case 4978:  /* *pred_mul_neg_addvnx1sf_scalar */
    case 4979:  /* *pred_mul_neg_subvnx1sf_scalar */
    case 4996:  /* pred_negvnx1sf */
    case 4997:  /* pred_absvnx1sf */
    case 4998:  /* pred_sqrtvnx1sf */
    case 5023:  /* pred_rsqrt7vnx1sf */
    case 5024:  /* pred_rec7vnx1sf */
    case 5041:  /* pred_classvnx1sf */
    case 5050:  /* pred_dual_widen_addvnx1df */
    case 5051:  /* pred_dual_widen_subvnx1df */
    case 5052:  /* pred_dual_widen_mulvnx1df */
    case 5062:  /* pred_dual_widen_addvnx1df_scalar */
    case 5063:  /* pred_dual_widen_subvnx1df_scalar */
    case 5064:  /* pred_dual_widen_mulvnx1df_scalar */
    case 5074:  /* pred_single_widen_addvnx1df */
    case 5075:  /* pred_single_widen_subvnx1df */
    case 5082:  /* pred_single_widen_addvnx1df_scalar */
    case 5083:  /* pred_single_widen_subvnx1df_scalar */
    case 5090:  /* pred_widen_mul_addvnx1df */
    case 5091:  /* pred_widen_mul_subvnx1df */
    case 5098:  /* pred_widen_mul_addvnx1df_scalar */
    case 5099:  /* pred_widen_mul_subvnx1df_scalar */
    case 5106:  /* pred_widen_mul_neg_addvnx1df */
    case 5107:  /* pred_widen_mul_neg_subvnx1df */
    case 5114:  /* pred_widen_mul_neg_addvnx1df_scalar */
    case 5115:  /* pred_widen_mul_neg_subvnx1df_scalar */
    case 5122:  /* *pred_cmpvnx1sf */
    case 5131:  /* *pred_cmpvnx1sf_narrow */
    case 5140:  /* *pred_cmpvnx1sf_scalar */
    case 5149:  /* *pred_cmpvnx1sf_scalar_narrow */
    case 5158:  /* *pred_eqnevnx1sf_scalar */
    case 5167:  /* *pred_eqnevnx1sf_scalar_narrow */
    case 5176:  /* pred_mergevnx1sf_scalar */
    case 5185:  /* pred_fcvt_x_fvnx1sf */
    case 5186:  /* pred_fcvt_xu_fvnx1sf */
    case 5203:  /* pred_fix_truncvnx1sf */
    case 5204:  /* pred_fixuns_truncvnx1sf */
    case 5221:  /* pred_floatvnx1sf */
    case 5222:  /* pred_floatunsvnx1sf */
    case 5239:  /* pred_widen_fcvt_x_fvnx1di */
    case 5240:  /* pred_widen_fcvt_xu_fvnx1di */
    case 5247:  /* pred_widen_fix_truncvnx1di */
    case 5248:  /* pred_widen_fixuns_truncvnx1di */
    case 5273:  /* pred_extendvnx1df */
    case 5313:  /* pred_narrow_floatvnx1di */
    case 5314:  /* pred_narrow_floatunsvnx1di */
    case 5321:  /* pred_truncvnx1df */
    case 5325:  /* pred_rod_truncvnx1df */
    case 5683:  /* pred_reduc_maxvnx1sfvnx2sf */
    case 5684:  /* pred_reduc_minvnx1sfvnx2sf */
    case 5701:  /* pred_reduc_maxvnx1sfvnx1sf */
    case 5702:  /* pred_reduc_minvnx1sfvnx1sf */
    case 5709:  /* pred_reduc_plusovnx1sfvnx2sf */
    case 5710:  /* pred_reduc_plusuvnx1sfvnx2sf */
    case 5727:  /* pred_reduc_plusovnx1sfvnx1sf */
    case 5728:  /* pred_reduc_plusuvnx1sfvnx1sf */
    case 5735:  /* pred_widen_reduc_plusovnx1sfvnx1df */
    case 5736:  /* pred_widen_reduc_plusuvnx1sfvnx1df */
    case 5771:  /* *pred_extract_firstvnx1sf */
    case 5824:  /* pred_slideupvnx1sf */
    case 5825:  /* pred_slidedownvnx1sf */
    case 5894:  /* pred_slide1upvnx1sf */
    case 5895:  /* pred_slide1downvnx1sf */
    case 5934:  /* pred_gathervnx1sf */
    case 5965:  /* pred_gathervnx1sf_scalar */
    case 5995:  /* pred_gatherei16vnx1sf */
    case 6026:  /* pred_compressvnx1sf */
    case 6059:  /* pred_fault_loadvnx1sf */
      return MODE_VNX1SF;

    case 741:  /* *movvnx8di_whole */
    case 821:  /* pred_movvnx8di */
    case 852:  /* pred_storevnx8di */
    case 897:  /* pred_mergevnx8di */
    case 928:  /* *pred_mergevnx8di_scalar */
    case 932:  /* *pred_mergevnx8di_extended_scalar */
    case 954:  /* *pred_broadcastvnx8di */
    case 967:  /* *pred_broadcastvnx8di_extended_scalar */
    case 989:  /* pred_strided_loadvnx8di */
    case 1020:  /* pred_strided_storevnx8di */
    case 1072:  /* pred_indexed_oloadvnx8di_same_eew */
    case 1073:  /* pred_indexed_uloadvnx8di_same_eew */
    case 1120:  /* pred_indexed_oloadvnx8di_x2_greater_eew */
    case 1121:  /* pred_indexed_uloadvnx8di_x2_greater_eew */
    case 1156:  /* pred_indexed_oloadvnx8di_x4_greater_eew */
    case 1157:  /* pred_indexed_uloadvnx8di_x4_greater_eew */
    case 1182:  /* pred_indexed_oloadvnx8di_x8_greater_eew */
    case 1183:  /* pred_indexed_uloadvnx8di_x8_greater_eew */
    case 1406:  /* pred_indexed_ostorevnx8divnx8qi */
    case 1407:  /* pred_indexed_ustorevnx8divnx8qi */
    case 1418:  /* pred_indexed_ostorevnx8divnx8hi */
    case 1419:  /* pred_indexed_ustorevnx8divnx8hi */
    case 1430:  /* pred_indexed_ostorevnx8divnx8si */
    case 1431:  /* pred_indexed_ustorevnx8divnx8si */
    case 1442:  /* pred_indexed_ostorevnx8divnx8di */
    case 1443:  /* pred_indexed_ustorevnx8divnx8di */
    case 1839:  /* pred_addvnx8di */
    case 1840:  /* pred_subvnx8di */
    case 1841:  /* pred_andvnx8di */
    case 1842:  /* pred_iorvnx8di */
    case 1843:  /* pred_xorvnx8di */
    case 1844:  /* pred_ashlvnx8di */
    case 1845:  /* pred_ashrvnx8di */
    case 1846:  /* pred_lshrvnx8di */
    case 1847:  /* pred_smaxvnx8di */
    case 1848:  /* pred_umaxvnx8di */
    case 1849:  /* pred_sminvnx8di */
    case 1850:  /* pred_uminvnx8di */
    case 1851:  /* pred_mulvnx8di */
    case 1852:  /* pred_divvnx8di */
    case 1853:  /* pred_udivvnx8di */
    case 1854:  /* pred_modvnx8di */
    case 1855:  /* pred_umodvnx8di */
    case 1919:  /* pred_ashlvnx8di_scalar */
    case 1920:  /* pred_ashrvnx8di_scalar */
    case 1921:  /* pred_lshrvnx8di_scalar */
    case 2219:  /* *pred_addvnx8di_scalar */
    case 2220:  /* *pred_andvnx8di_scalar */
    case 2221:  /* *pred_iorvnx8di_scalar */
    case 2222:  /* *pred_xorvnx8di_scalar */
    case 2223:  /* *pred_smaxvnx8di_scalar */
    case 2224:  /* *pred_umaxvnx8di_scalar */
    case 2225:  /* *pred_sminvnx8di_scalar */
    case 2226:  /* *pred_uminvnx8di_scalar */
    case 2227:  /* *pred_mulvnx8di_scalar */
    case 2255:  /* *pred_addvnx8di_extended_scalar */
    case 2256:  /* *pred_andvnx8di_extended_scalar */
    case 2257:  /* *pred_iorvnx8di_extended_scalar */
    case 2258:  /* *pred_xorvnx8di_extended_scalar */
    case 2259:  /* *pred_smaxvnx8di_extended_scalar */
    case 2260:  /* *pred_umaxvnx8di_extended_scalar */
    case 2261:  /* *pred_sminvnx8di_extended_scalar */
    case 2262:  /* *pred_uminvnx8di_extended_scalar */
    case 2263:  /* *pred_mulvnx8di_extended_scalar */
    case 2279:  /* *pred_subvnx8di_scalar */
    case 2280:  /* *pred_divvnx8di_scalar */
    case 2281:  /* *pred_udivvnx8di_scalar */
    case 2282:  /* *pred_modvnx8di_scalar */
    case 2283:  /* *pred_umodvnx8di_scalar */
    case 2299:  /* *pred_subvnx8di_extended_scalar */
    case 2300:  /* *pred_divvnx8di_extended_scalar */
    case 2301:  /* *pred_udivvnx8di_extended_scalar */
    case 2302:  /* *pred_modvnx8di_extended_scalar */
    case 2303:  /* *pred_umodvnx8di_extended_scalar */
    case 2307:  /* *pred_subvnx8di_reverse_scalar */
    case 2311:  /* *pred_subvnx8di_extended_reverse_scalar */
    case 2375:  /* pred_mulhvnx8di */
    case 2376:  /* pred_mulhuvnx8di */
    case 2377:  /* pred_mulhsuvnx8di */
    case 2441:  /* *pred_mulhvnx8di_scalar */
    case 2442:  /* *pred_mulhuvnx8di_scalar */
    case 2443:  /* *pred_mulhsuvnx8di_scalar */
    case 2453:  /* *pred_mulhvnx8di_extended_scalar */
    case 2454:  /* *pred_mulhuvnx8di_extended_scalar */
    case 2455:  /* *pred_mulhsuvnx8di_extended_scalar */
    case 2477:  /* pred_adcvnx8di */
    case 2499:  /* pred_sbcvnx8di */
    case 2539:  /* *pred_adcvnx8di_scalar */
    case 2543:  /* *pred_adcvnx8di_extended_scalar */
    case 2547:  /* *pred_sbcvnx8di_scalar */
    case 2551:  /* *pred_sbcvnx8di_extended_scalar */
    case 2573:  /* pred_madcvnx8di */
    case 2595:  /* pred_msbcvnx8di */
    case 2635:  /* *pred_madcvnx8di_scalar */
    case 2639:  /* *pred_madcvnx8di_extended_scalar */
    case 2643:  /* *pred_msbcvnx8di_scalar */
    case 2647:  /* *pred_msbcvnx8di_extended_scalar */
    case 2669:  /* pred_madcvnx8di_overflow */
    case 2691:  /* pred_msbcvnx8di_overflow */
    case 2731:  /* *pred_madcvnx8di_overflow_scalar */
    case 2735:  /* *pred_madcvnx8di_overflow_extended_scalar */
    case 2739:  /* *pred_msbcvnx8di_overflow_scalar */
    case 2743:  /* *pred_msbcvnx8di_overflow_extended_scalar */
    case 2786:  /* pred_negvnx8di */
    case 2787:  /* pred_one_cmplvnx8di */
    case 2816:  /* pred_extendvnx8di_vf2 */
    case 2817:  /* pred_zero_extendvnx8di_vf2 */
    case 2834:  /* pred_extendvnx8di_vf4 */
    case 2835:  /* pred_zero_extendvnx8di_vf4 */
    case 2842:  /* pred_extendvnx8di_vf8 */
    case 2843:  /* pred_zero_extendvnx8di_vf8 */
    case 3363:  /* pred_ssaddvnx8di */
    case 3364:  /* pred_sssubvnx8di */
    case 3365:  /* pred_usaddvnx8di */
    case 3366:  /* pred_ussubvnx8di */
    case 3445:  /* *pred_ssaddvnx8di_scalar */
    case 3446:  /* *pred_usaddvnx8di_scalar */
    case 3453:  /* *pred_ssaddvnx8di_extended_scalar */
    case 3454:  /* *pred_usaddvnx8di_extended_scalar */
    case 3461:  /* *pred_sssubvnx8di_scalar */
    case 3462:  /* *pred_ussubvnx8di_scalar */
    case 3469:  /* *pred_sssubvnx8di_extended_scalar */
    case 3470:  /* *pred_ussubvnx8di_extended_scalar */
    case 3618:  /* pred_aadduvnx8di */
    case 3619:  /* pred_aaddvnx8di */
    case 3620:  /* pred_asubuvnx8di */
    case 3621:  /* pred_asubvnx8di */
    case 3622:  /* pred_smulvnx8di */
    case 3623:  /* pred_ssrlvnx8di */
    case 3624:  /* pred_ssravnx8di */
    case 3757:  /* pred_ssrlvnx8di_scalar */
    case 3758:  /* pred_ssravnx8di_scalar */
    case 3774:  /* *pred_aadduvnx8di_scalar */
    case 3775:  /* *pred_aaddvnx8di_scalar */
    case 3776:  /* *pred_asubuvnx8di_scalar */
    case 3777:  /* *pred_asubvnx8di_scalar */
    case 3778:  /* *pred_smulvnx8di_scalar */
    case 3794:  /* *pred_aadduvnx8di_extended_scalar */
    case 3795:  /* *pred_aaddvnx8di_extended_scalar */
    case 3796:  /* *pred_asubuvnx8di_extended_scalar */
    case 3797:  /* *pred_asubvnx8di_extended_scalar */
    case 3798:  /* *pred_smulvnx8di_extended_scalar */
    case 3880:  /* *pred_cmpvnx8di */
    case 3902:  /* *pred_cmpvnx8di_narrow */
    case 3924:  /* *pred_ltgevnx8di */
    case 3946:  /* *pred_ltgevnx8di_narrow */
    case 4022:  /* *pred_cmpvnx8di_scalar */
    case 4026:  /* *pred_cmpvnx8di_scalar_narrow */
    case 4030:  /* *pred_eqnevnx8di_scalar */
    case 4034:  /* *pred_eqnevnx8di_scalar_narrow */
    case 4038:  /* *pred_cmpvnx8di_extended_scalar */
    case 4042:  /* *pred_cmpvnx8di_extended_scalar_narrow */
    case 4046:  /* *pred_eqnevnx8di_extended_scalar */
    case 4050:  /* *pred_eqnevnx8di_extended_scalar_narrow */
    case 4072:  /* *pred_maddvnx8di */
    case 4094:  /* *pred_maccvnx8di */
    case 4116:  /* *pred_mul_plusvnx8di */
    case 4138:  /* *pred_maddvnx8di_scalar */
    case 4160:  /* *pred_maccvnx8di_scalar */
    case 4182:  /* *pred_mul_plusvnx8di_scalar */
    case 4186:  /* *pred_maddvnx8di_extended_scalar */
    case 4190:  /* *pred_maccvnx8di_extended_scalar */
    case 4194:  /* *pred_mul_plusvnx8di_extended_scalar */
    case 4216:  /* *pred_nmsubvnx8di */
    case 4238:  /* *pred_nmsacvnx8di */
    case 4260:  /* *pred_minus_mulvnx8di */
    case 4282:  /* *pred_nmsubvnx8di_scalar */
    case 4304:  /* *pred_nmsacvnx8di_scalar */
    case 4326:  /* *pred_minus_mulvnx8di_scalar */
    case 4330:  /* *pred_nmsubvnx8di_extended_scalar */
    case 4334:  /* *pred_nmsacvnx8di_extended_scalar */
    case 4338:  /* *pred_minus_mulvnx8di_extended_scalar */
    case 4577:  /* pred_iotavnx8di */
    case 4599:  /* pred_seriesvnx8di */
    case 5497:  /* pred_reduc_sumvnx8divnx1DI */
    case 5498:  /* pred_reduc_maxuvnx8divnx1DI */
    case 5499:  /* pred_reduc_maxvnx8divnx1DI */
    case 5500:  /* pred_reduc_minuvnx8divnx1DI */
    case 5501:  /* pred_reduc_minvnx8divnx1DI */
    case 5502:  /* pred_reduc_andvnx8divnx1DI */
    case 5503:  /* pred_reduc_orvnx8divnx1DI */
    case 5504:  /* pred_reduc_xorvnx8divnx1DI */
    case 5766:  /* *pred_extract_firstvnx8di */
    case 5770:  /* pred_extract_first_truncvnx8di */
    case 5822:  /* pred_slideupvnx8di */
    case 5823:  /* pred_slidedownvnx8di */
    case 5884:  /* *pred_slide1upvnx8di */
    case 5885:  /* *pred_slide1downvnx8di */
    case 5892:  /* *pred_slide1upvnx8di_extended */
    case 5893:  /* *pred_slide1downvnx8di_extended */
    case 5933:  /* pred_gathervnx8di */
    case 5964:  /* pred_gathervnx8di_scalar */
    case 5994:  /* pred_gatherei16vnx8di */
    case 6025:  /* pred_compressvnx8di */
    case 6058:  /* pred_fault_loadvnx8di */
      return MODE_VNX8DI;

    case 740:  /* *movvnx4di_whole */
    case 820:  /* pred_movvnx4di */
    case 851:  /* pred_storevnx4di */
    case 896:  /* pred_mergevnx4di */
    case 927:  /* *pred_mergevnx4di_scalar */
    case 931:  /* *pred_mergevnx4di_extended_scalar */
    case 953:  /* *pred_broadcastvnx4di */
    case 966:  /* *pred_broadcastvnx4di_extended_scalar */
    case 988:  /* pred_strided_loadvnx4di */
    case 1019:  /* pred_strided_storevnx4di */
    case 1070:  /* pred_indexed_oloadvnx4di_same_eew */
    case 1071:  /* pred_indexed_uloadvnx4di_same_eew */
    case 1118:  /* pred_indexed_oloadvnx4di_x2_greater_eew */
    case 1119:  /* pred_indexed_uloadvnx4di_x2_greater_eew */
    case 1154:  /* pred_indexed_oloadvnx4di_x4_greater_eew */
    case 1155:  /* pred_indexed_uloadvnx4di_x4_greater_eew */
    case 1180:  /* pred_indexed_oloadvnx4di_x8_greater_eew */
    case 1181:  /* pred_indexed_uloadvnx4di_x8_greater_eew */
    case 1358:  /* pred_indexed_ostorevnx4divnx4qi */
    case 1359:  /* pred_indexed_ustorevnx4divnx4qi */
    case 1370:  /* pred_indexed_ostorevnx4divnx4hi */
    case 1371:  /* pred_indexed_ustorevnx4divnx4hi */
    case 1382:  /* pred_indexed_ostorevnx4divnx4si */
    case 1383:  /* pred_indexed_ustorevnx4divnx4si */
    case 1394:  /* pred_indexed_ostorevnx4divnx4di */
    case 1395:  /* pred_indexed_ustorevnx4divnx4di */
    case 1822:  /* pred_addvnx4di */
    case 1823:  /* pred_subvnx4di */
    case 1824:  /* pred_andvnx4di */
    case 1825:  /* pred_iorvnx4di */
    case 1826:  /* pred_xorvnx4di */
    case 1827:  /* pred_ashlvnx4di */
    case 1828:  /* pred_ashrvnx4di */
    case 1829:  /* pred_lshrvnx4di */
    case 1830:  /* pred_smaxvnx4di */
    case 1831:  /* pred_umaxvnx4di */
    case 1832:  /* pred_sminvnx4di */
    case 1833:  /* pred_uminvnx4di */
    case 1834:  /* pred_mulvnx4di */
    case 1835:  /* pred_divvnx4di */
    case 1836:  /* pred_udivvnx4di */
    case 1837:  /* pred_modvnx4di */
    case 1838:  /* pred_umodvnx4di */
    case 1916:  /* pred_ashlvnx4di_scalar */
    case 1917:  /* pred_ashrvnx4di_scalar */
    case 1918:  /* pred_lshrvnx4di_scalar */
    case 2210:  /* *pred_addvnx4di_scalar */
    case 2211:  /* *pred_andvnx4di_scalar */
    case 2212:  /* *pred_iorvnx4di_scalar */
    case 2213:  /* *pred_xorvnx4di_scalar */
    case 2214:  /* *pred_smaxvnx4di_scalar */
    case 2215:  /* *pred_umaxvnx4di_scalar */
    case 2216:  /* *pred_sminvnx4di_scalar */
    case 2217:  /* *pred_uminvnx4di_scalar */
    case 2218:  /* *pred_mulvnx4di_scalar */
    case 2246:  /* *pred_addvnx4di_extended_scalar */
    case 2247:  /* *pred_andvnx4di_extended_scalar */
    case 2248:  /* *pred_iorvnx4di_extended_scalar */
    case 2249:  /* *pred_xorvnx4di_extended_scalar */
    case 2250:  /* *pred_smaxvnx4di_extended_scalar */
    case 2251:  /* *pred_umaxvnx4di_extended_scalar */
    case 2252:  /* *pred_sminvnx4di_extended_scalar */
    case 2253:  /* *pred_uminvnx4di_extended_scalar */
    case 2254:  /* *pred_mulvnx4di_extended_scalar */
    case 2274:  /* *pred_subvnx4di_scalar */
    case 2275:  /* *pred_divvnx4di_scalar */
    case 2276:  /* *pred_udivvnx4di_scalar */
    case 2277:  /* *pred_modvnx4di_scalar */
    case 2278:  /* *pred_umodvnx4di_scalar */
    case 2294:  /* *pred_subvnx4di_extended_scalar */
    case 2295:  /* *pred_divvnx4di_extended_scalar */
    case 2296:  /* *pred_udivvnx4di_extended_scalar */
    case 2297:  /* *pred_modvnx4di_extended_scalar */
    case 2298:  /* *pred_umodvnx4di_extended_scalar */
    case 2306:  /* *pred_subvnx4di_reverse_scalar */
    case 2310:  /* *pred_subvnx4di_extended_reverse_scalar */
    case 2372:  /* pred_mulhvnx4di */
    case 2373:  /* pred_mulhuvnx4di */
    case 2374:  /* pred_mulhsuvnx4di */
    case 2438:  /* *pred_mulhvnx4di_scalar */
    case 2439:  /* *pred_mulhuvnx4di_scalar */
    case 2440:  /* *pred_mulhsuvnx4di_scalar */
    case 2450:  /* *pred_mulhvnx4di_extended_scalar */
    case 2451:  /* *pred_mulhuvnx4di_extended_scalar */
    case 2452:  /* *pred_mulhsuvnx4di_extended_scalar */
    case 2476:  /* pred_adcvnx4di */
    case 2498:  /* pred_sbcvnx4di */
    case 2538:  /* *pred_adcvnx4di_scalar */
    case 2542:  /* *pred_adcvnx4di_extended_scalar */
    case 2546:  /* *pred_sbcvnx4di_scalar */
    case 2550:  /* *pred_sbcvnx4di_extended_scalar */
    case 2572:  /* pred_madcvnx4di */
    case 2594:  /* pred_msbcvnx4di */
    case 2634:  /* *pred_madcvnx4di_scalar */
    case 2638:  /* *pred_madcvnx4di_extended_scalar */
    case 2642:  /* *pred_msbcvnx4di_scalar */
    case 2646:  /* *pred_msbcvnx4di_extended_scalar */
    case 2668:  /* pred_madcvnx4di_overflow */
    case 2690:  /* pred_msbcvnx4di_overflow */
    case 2730:  /* *pred_madcvnx4di_overflow_scalar */
    case 2734:  /* *pred_madcvnx4di_overflow_extended_scalar */
    case 2738:  /* *pred_msbcvnx4di_overflow_scalar */
    case 2742:  /* *pred_msbcvnx4di_overflow_extended_scalar */
    case 2784:  /* pred_negvnx4di */
    case 2785:  /* pred_one_cmplvnx4di */
    case 2814:  /* pred_extendvnx4di_vf2 */
    case 2815:  /* pred_zero_extendvnx4di_vf2 */
    case 2832:  /* pred_extendvnx4di_vf4 */
    case 2833:  /* pred_zero_extendvnx4di_vf4 */
    case 2840:  /* pred_extendvnx4di_vf8 */
    case 2841:  /* pred_zero_extendvnx4di_vf8 */
    case 3359:  /* pred_ssaddvnx4di */
    case 3360:  /* pred_sssubvnx4di */
    case 3361:  /* pred_usaddvnx4di */
    case 3362:  /* pred_ussubvnx4di */
    case 3443:  /* *pred_ssaddvnx4di_scalar */
    case 3444:  /* *pred_usaddvnx4di_scalar */
    case 3451:  /* *pred_ssaddvnx4di_extended_scalar */
    case 3452:  /* *pred_usaddvnx4di_extended_scalar */
    case 3459:  /* *pred_sssubvnx4di_scalar */
    case 3460:  /* *pred_ussubvnx4di_scalar */
    case 3467:  /* *pred_sssubvnx4di_extended_scalar */
    case 3468:  /* *pred_ussubvnx4di_extended_scalar */
    case 3611:  /* pred_aadduvnx4di */
    case 3612:  /* pred_aaddvnx4di */
    case 3613:  /* pred_asubuvnx4di */
    case 3614:  /* pred_asubvnx4di */
    case 3615:  /* pred_smulvnx4di */
    case 3616:  /* pred_ssrlvnx4di */
    case 3617:  /* pred_ssravnx4di */
    case 3755:  /* pred_ssrlvnx4di_scalar */
    case 3756:  /* pred_ssravnx4di_scalar */
    case 3769:  /* *pred_aadduvnx4di_scalar */
    case 3770:  /* *pred_aaddvnx4di_scalar */
    case 3771:  /* *pred_asubuvnx4di_scalar */
    case 3772:  /* *pred_asubvnx4di_scalar */
    case 3773:  /* *pred_smulvnx4di_scalar */
    case 3789:  /* *pred_aadduvnx4di_extended_scalar */
    case 3790:  /* *pred_aaddvnx4di_extended_scalar */
    case 3791:  /* *pred_asubuvnx4di_extended_scalar */
    case 3792:  /* *pred_asubvnx4di_extended_scalar */
    case 3793:  /* *pred_smulvnx4di_extended_scalar */
    case 3879:  /* *pred_cmpvnx4di */
    case 3901:  /* *pred_cmpvnx4di_narrow */
    case 3923:  /* *pred_ltgevnx4di */
    case 3945:  /* *pred_ltgevnx4di_narrow */
    case 4021:  /* *pred_cmpvnx4di_scalar */
    case 4025:  /* *pred_cmpvnx4di_scalar_narrow */
    case 4029:  /* *pred_eqnevnx4di_scalar */
    case 4033:  /* *pred_eqnevnx4di_scalar_narrow */
    case 4037:  /* *pred_cmpvnx4di_extended_scalar */
    case 4041:  /* *pred_cmpvnx4di_extended_scalar_narrow */
    case 4045:  /* *pred_eqnevnx4di_extended_scalar */
    case 4049:  /* *pred_eqnevnx4di_extended_scalar_narrow */
    case 4071:  /* *pred_maddvnx4di */
    case 4093:  /* *pred_maccvnx4di */
    case 4115:  /* *pred_mul_plusvnx4di */
    case 4137:  /* *pred_maddvnx4di_scalar */
    case 4159:  /* *pred_maccvnx4di_scalar */
    case 4181:  /* *pred_mul_plusvnx4di_scalar */
    case 4185:  /* *pred_maddvnx4di_extended_scalar */
    case 4189:  /* *pred_maccvnx4di_extended_scalar */
    case 4193:  /* *pred_mul_plusvnx4di_extended_scalar */
    case 4215:  /* *pred_nmsubvnx4di */
    case 4237:  /* *pred_nmsacvnx4di */
    case 4259:  /* *pred_minus_mulvnx4di */
    case 4281:  /* *pred_nmsubvnx4di_scalar */
    case 4303:  /* *pred_nmsacvnx4di_scalar */
    case 4325:  /* *pred_minus_mulvnx4di_scalar */
    case 4329:  /* *pred_nmsubvnx4di_extended_scalar */
    case 4333:  /* *pred_nmsacvnx4di_extended_scalar */
    case 4337:  /* *pred_minus_mulvnx4di_extended_scalar */
    case 4576:  /* pred_iotavnx4di */
    case 4598:  /* pred_seriesvnx4di */
    case 5489:  /* pred_reduc_sumvnx4divnx1DI */
    case 5490:  /* pred_reduc_maxuvnx4divnx1DI */
    case 5491:  /* pred_reduc_maxvnx4divnx1DI */
    case 5492:  /* pred_reduc_minuvnx4divnx1DI */
    case 5493:  /* pred_reduc_minvnx4divnx1DI */
    case 5494:  /* pred_reduc_andvnx4divnx1DI */
    case 5495:  /* pred_reduc_orvnx4divnx1DI */
    case 5496:  /* pred_reduc_xorvnx4divnx1DI */
    case 5765:  /* *pred_extract_firstvnx4di */
    case 5769:  /* pred_extract_first_truncvnx4di */
    case 5820:  /* pred_slideupvnx4di */
    case 5821:  /* pred_slidedownvnx4di */
    case 5882:  /* *pred_slide1upvnx4di */
    case 5883:  /* *pred_slide1downvnx4di */
    case 5890:  /* *pred_slide1upvnx4di_extended */
    case 5891:  /* *pred_slide1downvnx4di_extended */
    case 5932:  /* pred_gathervnx4di */
    case 5963:  /* pred_gathervnx4di_scalar */
    case 5993:  /* pred_gatherei16vnx4di */
    case 6024:  /* pred_compressvnx4di */
    case 6057:  /* pred_fault_loadvnx4di */
      return MODE_VNX4DI;

    case 739:  /* *movvnx2di_whole */
    case 819:  /* pred_movvnx2di */
    case 850:  /* pred_storevnx2di */
    case 895:  /* pred_mergevnx2di */
    case 926:  /* *pred_mergevnx2di_scalar */
    case 930:  /* *pred_mergevnx2di_extended_scalar */
    case 952:  /* *pred_broadcastvnx2di */
    case 965:  /* *pred_broadcastvnx2di_extended_scalar */
    case 987:  /* pred_strided_loadvnx2di */
    case 1018:  /* pred_strided_storevnx2di */
    case 1068:  /* pred_indexed_oloadvnx2di_same_eew */
    case 1069:  /* pred_indexed_uloadvnx2di_same_eew */
    case 1116:  /* pred_indexed_oloadvnx2di_x2_greater_eew */
    case 1117:  /* pred_indexed_uloadvnx2di_x2_greater_eew */
    case 1152:  /* pred_indexed_oloadvnx2di_x4_greater_eew */
    case 1153:  /* pred_indexed_uloadvnx2di_x4_greater_eew */
    case 1178:  /* pred_indexed_oloadvnx2di_x8_greater_eew */
    case 1179:  /* pred_indexed_uloadvnx2di_x8_greater_eew */
    case 1310:  /* pred_indexed_ostorevnx2divnx2qi */
    case 1311:  /* pred_indexed_ustorevnx2divnx2qi */
    case 1322:  /* pred_indexed_ostorevnx2divnx2hi */
    case 1323:  /* pred_indexed_ustorevnx2divnx2hi */
    case 1334:  /* pred_indexed_ostorevnx2divnx2si */
    case 1335:  /* pred_indexed_ustorevnx2divnx2si */
    case 1346:  /* pred_indexed_ostorevnx2divnx2di */
    case 1347:  /* pred_indexed_ustorevnx2divnx2di */
    case 1805:  /* pred_addvnx2di */
    case 1806:  /* pred_subvnx2di */
    case 1807:  /* pred_andvnx2di */
    case 1808:  /* pred_iorvnx2di */
    case 1809:  /* pred_xorvnx2di */
    case 1810:  /* pred_ashlvnx2di */
    case 1811:  /* pred_ashrvnx2di */
    case 1812:  /* pred_lshrvnx2di */
    case 1813:  /* pred_smaxvnx2di */
    case 1814:  /* pred_umaxvnx2di */
    case 1815:  /* pred_sminvnx2di */
    case 1816:  /* pred_uminvnx2di */
    case 1817:  /* pred_mulvnx2di */
    case 1818:  /* pred_divvnx2di */
    case 1819:  /* pred_udivvnx2di */
    case 1820:  /* pred_modvnx2di */
    case 1821:  /* pred_umodvnx2di */
    case 1913:  /* pred_ashlvnx2di_scalar */
    case 1914:  /* pred_ashrvnx2di_scalar */
    case 1915:  /* pred_lshrvnx2di_scalar */
    case 2201:  /* *pred_addvnx2di_scalar */
    case 2202:  /* *pred_andvnx2di_scalar */
    case 2203:  /* *pred_iorvnx2di_scalar */
    case 2204:  /* *pred_xorvnx2di_scalar */
    case 2205:  /* *pred_smaxvnx2di_scalar */
    case 2206:  /* *pred_umaxvnx2di_scalar */
    case 2207:  /* *pred_sminvnx2di_scalar */
    case 2208:  /* *pred_uminvnx2di_scalar */
    case 2209:  /* *pred_mulvnx2di_scalar */
    case 2237:  /* *pred_addvnx2di_extended_scalar */
    case 2238:  /* *pred_andvnx2di_extended_scalar */
    case 2239:  /* *pred_iorvnx2di_extended_scalar */
    case 2240:  /* *pred_xorvnx2di_extended_scalar */
    case 2241:  /* *pred_smaxvnx2di_extended_scalar */
    case 2242:  /* *pred_umaxvnx2di_extended_scalar */
    case 2243:  /* *pred_sminvnx2di_extended_scalar */
    case 2244:  /* *pred_uminvnx2di_extended_scalar */
    case 2245:  /* *pred_mulvnx2di_extended_scalar */
    case 2269:  /* *pred_subvnx2di_scalar */
    case 2270:  /* *pred_divvnx2di_scalar */
    case 2271:  /* *pred_udivvnx2di_scalar */
    case 2272:  /* *pred_modvnx2di_scalar */
    case 2273:  /* *pred_umodvnx2di_scalar */
    case 2289:  /* *pred_subvnx2di_extended_scalar */
    case 2290:  /* *pred_divvnx2di_extended_scalar */
    case 2291:  /* *pred_udivvnx2di_extended_scalar */
    case 2292:  /* *pred_modvnx2di_extended_scalar */
    case 2293:  /* *pred_umodvnx2di_extended_scalar */
    case 2305:  /* *pred_subvnx2di_reverse_scalar */
    case 2309:  /* *pred_subvnx2di_extended_reverse_scalar */
    case 2369:  /* pred_mulhvnx2di */
    case 2370:  /* pred_mulhuvnx2di */
    case 2371:  /* pred_mulhsuvnx2di */
    case 2435:  /* *pred_mulhvnx2di_scalar */
    case 2436:  /* *pred_mulhuvnx2di_scalar */
    case 2437:  /* *pred_mulhsuvnx2di_scalar */
    case 2447:  /* *pred_mulhvnx2di_extended_scalar */
    case 2448:  /* *pred_mulhuvnx2di_extended_scalar */
    case 2449:  /* *pred_mulhsuvnx2di_extended_scalar */
    case 2475:  /* pred_adcvnx2di */
    case 2497:  /* pred_sbcvnx2di */
    case 2537:  /* *pred_adcvnx2di_scalar */
    case 2541:  /* *pred_adcvnx2di_extended_scalar */
    case 2545:  /* *pred_sbcvnx2di_scalar */
    case 2549:  /* *pred_sbcvnx2di_extended_scalar */
    case 2571:  /* pred_madcvnx2di */
    case 2593:  /* pred_msbcvnx2di */
    case 2633:  /* *pred_madcvnx2di_scalar */
    case 2637:  /* *pred_madcvnx2di_extended_scalar */
    case 2641:  /* *pred_msbcvnx2di_scalar */
    case 2645:  /* *pred_msbcvnx2di_extended_scalar */
    case 2667:  /* pred_madcvnx2di_overflow */
    case 2689:  /* pred_msbcvnx2di_overflow */
    case 2729:  /* *pred_madcvnx2di_overflow_scalar */
    case 2733:  /* *pred_madcvnx2di_overflow_extended_scalar */
    case 2737:  /* *pred_msbcvnx2di_overflow_scalar */
    case 2741:  /* *pred_msbcvnx2di_overflow_extended_scalar */
    case 2782:  /* pred_negvnx2di */
    case 2783:  /* pred_one_cmplvnx2di */
    case 2812:  /* pred_extendvnx2di_vf2 */
    case 2813:  /* pred_zero_extendvnx2di_vf2 */
    case 2830:  /* pred_extendvnx2di_vf4 */
    case 2831:  /* pred_zero_extendvnx2di_vf4 */
    case 2838:  /* pred_extendvnx2di_vf8 */
    case 2839:  /* pred_zero_extendvnx2di_vf8 */
    case 3355:  /* pred_ssaddvnx2di */
    case 3356:  /* pred_sssubvnx2di */
    case 3357:  /* pred_usaddvnx2di */
    case 3358:  /* pred_ussubvnx2di */
    case 3441:  /* *pred_ssaddvnx2di_scalar */
    case 3442:  /* *pred_usaddvnx2di_scalar */
    case 3449:  /* *pred_ssaddvnx2di_extended_scalar */
    case 3450:  /* *pred_usaddvnx2di_extended_scalar */
    case 3457:  /* *pred_sssubvnx2di_scalar */
    case 3458:  /* *pred_ussubvnx2di_scalar */
    case 3465:  /* *pred_sssubvnx2di_extended_scalar */
    case 3466:  /* *pred_ussubvnx2di_extended_scalar */
    case 3604:  /* pred_aadduvnx2di */
    case 3605:  /* pred_aaddvnx2di */
    case 3606:  /* pred_asubuvnx2di */
    case 3607:  /* pred_asubvnx2di */
    case 3608:  /* pred_smulvnx2di */
    case 3609:  /* pred_ssrlvnx2di */
    case 3610:  /* pred_ssravnx2di */
    case 3753:  /* pred_ssrlvnx2di_scalar */
    case 3754:  /* pred_ssravnx2di_scalar */
    case 3764:  /* *pred_aadduvnx2di_scalar */
    case 3765:  /* *pred_aaddvnx2di_scalar */
    case 3766:  /* *pred_asubuvnx2di_scalar */
    case 3767:  /* *pred_asubvnx2di_scalar */
    case 3768:  /* *pred_smulvnx2di_scalar */
    case 3784:  /* *pred_aadduvnx2di_extended_scalar */
    case 3785:  /* *pred_aaddvnx2di_extended_scalar */
    case 3786:  /* *pred_asubuvnx2di_extended_scalar */
    case 3787:  /* *pred_asubvnx2di_extended_scalar */
    case 3788:  /* *pred_smulvnx2di_extended_scalar */
    case 3878:  /* *pred_cmpvnx2di */
    case 3900:  /* *pred_cmpvnx2di_narrow */
    case 3922:  /* *pred_ltgevnx2di */
    case 3944:  /* *pred_ltgevnx2di_narrow */
    case 4020:  /* *pred_cmpvnx2di_scalar */
    case 4024:  /* *pred_cmpvnx2di_scalar_narrow */
    case 4028:  /* *pred_eqnevnx2di_scalar */
    case 4032:  /* *pred_eqnevnx2di_scalar_narrow */
    case 4036:  /* *pred_cmpvnx2di_extended_scalar */
    case 4040:  /* *pred_cmpvnx2di_extended_scalar_narrow */
    case 4044:  /* *pred_eqnevnx2di_extended_scalar */
    case 4048:  /* *pred_eqnevnx2di_extended_scalar_narrow */
    case 4070:  /* *pred_maddvnx2di */
    case 4092:  /* *pred_maccvnx2di */
    case 4114:  /* *pred_mul_plusvnx2di */
    case 4136:  /* *pred_maddvnx2di_scalar */
    case 4158:  /* *pred_maccvnx2di_scalar */
    case 4180:  /* *pred_mul_plusvnx2di_scalar */
    case 4184:  /* *pred_maddvnx2di_extended_scalar */
    case 4188:  /* *pred_maccvnx2di_extended_scalar */
    case 4192:  /* *pred_mul_plusvnx2di_extended_scalar */
    case 4214:  /* *pred_nmsubvnx2di */
    case 4236:  /* *pred_nmsacvnx2di */
    case 4258:  /* *pred_minus_mulvnx2di */
    case 4280:  /* *pred_nmsubvnx2di_scalar */
    case 4302:  /* *pred_nmsacvnx2di_scalar */
    case 4324:  /* *pred_minus_mulvnx2di_scalar */
    case 4328:  /* *pred_nmsubvnx2di_extended_scalar */
    case 4332:  /* *pred_nmsacvnx2di_extended_scalar */
    case 4336:  /* *pred_minus_mulvnx2di_extended_scalar */
    case 4575:  /* pred_iotavnx2di */
    case 4597:  /* pred_seriesvnx2di */
    case 5481:  /* pred_reduc_sumvnx2divnx1DI */
    case 5482:  /* pred_reduc_maxuvnx2divnx1DI */
    case 5483:  /* pred_reduc_maxvnx2divnx1DI */
    case 5484:  /* pred_reduc_minuvnx2divnx1DI */
    case 5485:  /* pred_reduc_minvnx2divnx1DI */
    case 5486:  /* pred_reduc_andvnx2divnx1DI */
    case 5487:  /* pred_reduc_orvnx2divnx1DI */
    case 5488:  /* pred_reduc_xorvnx2divnx1DI */
    case 5764:  /* *pred_extract_firstvnx2di */
    case 5768:  /* pred_extract_first_truncvnx2di */
    case 5818:  /* pred_slideupvnx2di */
    case 5819:  /* pred_slidedownvnx2di */
    case 5880:  /* *pred_slide1upvnx2di */
    case 5881:  /* *pred_slide1downvnx2di */
    case 5888:  /* *pred_slide1upvnx2di_extended */
    case 5889:  /* *pred_slide1downvnx2di_extended */
    case 5931:  /* pred_gathervnx2di */
    case 5962:  /* pred_gathervnx2di_scalar */
    case 5992:  /* pred_gatherei16vnx2di */
    case 6023:  /* pred_compressvnx2di */
    case 6056:  /* pred_fault_loadvnx2di */
      return MODE_VNX2DI;

    case 738:  /* *movvnx1di_whole */
    case 818:  /* pred_movvnx1di */
    case 849:  /* pred_storevnx1di */
    case 894:  /* pred_mergevnx1di */
    case 925:  /* *pred_mergevnx1di_scalar */
    case 929:  /* *pred_mergevnx1di_extended_scalar */
    case 951:  /* *pred_broadcastvnx1di */
    case 964:  /* *pred_broadcastvnx1di_extended_scalar */
    case 986:  /* pred_strided_loadvnx1di */
    case 1017:  /* pred_strided_storevnx1di */
    case 1066:  /* pred_indexed_oloadvnx1di_same_eew */
    case 1067:  /* pred_indexed_uloadvnx1di_same_eew */
    case 1114:  /* pred_indexed_oloadvnx1di_x2_greater_eew */
    case 1115:  /* pred_indexed_uloadvnx1di_x2_greater_eew */
    case 1150:  /* pred_indexed_oloadvnx1di_x4_greater_eew */
    case 1151:  /* pred_indexed_uloadvnx1di_x4_greater_eew */
    case 1176:  /* pred_indexed_oloadvnx1di_x8_greater_eew */
    case 1177:  /* pred_indexed_uloadvnx1di_x8_greater_eew */
    case 1280:  /* pred_indexed_ostorevnx1divnx1qi */
    case 1281:  /* pred_indexed_ustorevnx1divnx1qi */
    case 1282:  /* pred_indexed_ostorevnx1divnx1hi */
    case 1283:  /* pred_indexed_ustorevnx1divnx1hi */
    case 1284:  /* pred_indexed_ostorevnx1divnx1si */
    case 1285:  /* pred_indexed_ustorevnx1divnx1si */
    case 1286:  /* pred_indexed_ostorevnx1divnx1di */
    case 1287:  /* pred_indexed_ustorevnx1divnx1di */
    case 1788:  /* pred_addvnx1di */
    case 1789:  /* pred_subvnx1di */
    case 1790:  /* pred_andvnx1di */
    case 1791:  /* pred_iorvnx1di */
    case 1792:  /* pred_xorvnx1di */
    case 1793:  /* pred_ashlvnx1di */
    case 1794:  /* pred_ashrvnx1di */
    case 1795:  /* pred_lshrvnx1di */
    case 1796:  /* pred_smaxvnx1di */
    case 1797:  /* pred_umaxvnx1di */
    case 1798:  /* pred_sminvnx1di */
    case 1799:  /* pred_uminvnx1di */
    case 1800:  /* pred_mulvnx1di */
    case 1801:  /* pred_divvnx1di */
    case 1802:  /* pred_udivvnx1di */
    case 1803:  /* pred_modvnx1di */
    case 1804:  /* pred_umodvnx1di */
    case 1910:  /* pred_ashlvnx1di_scalar */
    case 1911:  /* pred_ashrvnx1di_scalar */
    case 1912:  /* pred_lshrvnx1di_scalar */
    case 2192:  /* *pred_addvnx1di_scalar */
    case 2193:  /* *pred_andvnx1di_scalar */
    case 2194:  /* *pred_iorvnx1di_scalar */
    case 2195:  /* *pred_xorvnx1di_scalar */
    case 2196:  /* *pred_smaxvnx1di_scalar */
    case 2197:  /* *pred_umaxvnx1di_scalar */
    case 2198:  /* *pred_sminvnx1di_scalar */
    case 2199:  /* *pred_uminvnx1di_scalar */
    case 2200:  /* *pred_mulvnx1di_scalar */
    case 2228:  /* *pred_addvnx1di_extended_scalar */
    case 2229:  /* *pred_andvnx1di_extended_scalar */
    case 2230:  /* *pred_iorvnx1di_extended_scalar */
    case 2231:  /* *pred_xorvnx1di_extended_scalar */
    case 2232:  /* *pred_smaxvnx1di_extended_scalar */
    case 2233:  /* *pred_umaxvnx1di_extended_scalar */
    case 2234:  /* *pred_sminvnx1di_extended_scalar */
    case 2235:  /* *pred_uminvnx1di_extended_scalar */
    case 2236:  /* *pred_mulvnx1di_extended_scalar */
    case 2264:  /* *pred_subvnx1di_scalar */
    case 2265:  /* *pred_divvnx1di_scalar */
    case 2266:  /* *pred_udivvnx1di_scalar */
    case 2267:  /* *pred_modvnx1di_scalar */
    case 2268:  /* *pred_umodvnx1di_scalar */
    case 2284:  /* *pred_subvnx1di_extended_scalar */
    case 2285:  /* *pred_divvnx1di_extended_scalar */
    case 2286:  /* *pred_udivvnx1di_extended_scalar */
    case 2287:  /* *pred_modvnx1di_extended_scalar */
    case 2288:  /* *pred_umodvnx1di_extended_scalar */
    case 2304:  /* *pred_subvnx1di_reverse_scalar */
    case 2308:  /* *pred_subvnx1di_extended_reverse_scalar */
    case 2366:  /* pred_mulhvnx1di */
    case 2367:  /* pred_mulhuvnx1di */
    case 2368:  /* pred_mulhsuvnx1di */
    case 2432:  /* *pred_mulhvnx1di_scalar */
    case 2433:  /* *pred_mulhuvnx1di_scalar */
    case 2434:  /* *pred_mulhsuvnx1di_scalar */
    case 2444:  /* *pred_mulhvnx1di_extended_scalar */
    case 2445:  /* *pred_mulhuvnx1di_extended_scalar */
    case 2446:  /* *pred_mulhsuvnx1di_extended_scalar */
    case 2474:  /* pred_adcvnx1di */
    case 2496:  /* pred_sbcvnx1di */
    case 2536:  /* *pred_adcvnx1di_scalar */
    case 2540:  /* *pred_adcvnx1di_extended_scalar */
    case 2544:  /* *pred_sbcvnx1di_scalar */
    case 2548:  /* *pred_sbcvnx1di_extended_scalar */
    case 2570:  /* pred_madcvnx1di */
    case 2592:  /* pred_msbcvnx1di */
    case 2632:  /* *pred_madcvnx1di_scalar */
    case 2636:  /* *pred_madcvnx1di_extended_scalar */
    case 2640:  /* *pred_msbcvnx1di_scalar */
    case 2644:  /* *pred_msbcvnx1di_extended_scalar */
    case 2666:  /* pred_madcvnx1di_overflow */
    case 2688:  /* pred_msbcvnx1di_overflow */
    case 2728:  /* *pred_madcvnx1di_overflow_scalar */
    case 2732:  /* *pred_madcvnx1di_overflow_extended_scalar */
    case 2736:  /* *pred_msbcvnx1di_overflow_scalar */
    case 2740:  /* *pred_msbcvnx1di_overflow_extended_scalar */
    case 2780:  /* pred_negvnx1di */
    case 2781:  /* pred_one_cmplvnx1di */
    case 2810:  /* pred_extendvnx1di_vf2 */
    case 2811:  /* pred_zero_extendvnx1di_vf2 */
    case 2828:  /* pred_extendvnx1di_vf4 */
    case 2829:  /* pred_zero_extendvnx1di_vf4 */
    case 2836:  /* pred_extendvnx1di_vf8 */
    case 2837:  /* pred_zero_extendvnx1di_vf8 */
    case 3351:  /* pred_ssaddvnx1di */
    case 3352:  /* pred_sssubvnx1di */
    case 3353:  /* pred_usaddvnx1di */
    case 3354:  /* pred_ussubvnx1di */
    case 3439:  /* *pred_ssaddvnx1di_scalar */
    case 3440:  /* *pred_usaddvnx1di_scalar */
    case 3447:  /* *pred_ssaddvnx1di_extended_scalar */
    case 3448:  /* *pred_usaddvnx1di_extended_scalar */
    case 3455:  /* *pred_sssubvnx1di_scalar */
    case 3456:  /* *pred_ussubvnx1di_scalar */
    case 3463:  /* *pred_sssubvnx1di_extended_scalar */
    case 3464:  /* *pred_ussubvnx1di_extended_scalar */
    case 3597:  /* pred_aadduvnx1di */
    case 3598:  /* pred_aaddvnx1di */
    case 3599:  /* pred_asubuvnx1di */
    case 3600:  /* pred_asubvnx1di */
    case 3601:  /* pred_smulvnx1di */
    case 3602:  /* pred_ssrlvnx1di */
    case 3603:  /* pred_ssravnx1di */
    case 3751:  /* pred_ssrlvnx1di_scalar */
    case 3752:  /* pred_ssravnx1di_scalar */
    case 3759:  /* *pred_aadduvnx1di_scalar */
    case 3760:  /* *pred_aaddvnx1di_scalar */
    case 3761:  /* *pred_asubuvnx1di_scalar */
    case 3762:  /* *pred_asubvnx1di_scalar */
    case 3763:  /* *pred_smulvnx1di_scalar */
    case 3779:  /* *pred_aadduvnx1di_extended_scalar */
    case 3780:  /* *pred_aaddvnx1di_extended_scalar */
    case 3781:  /* *pred_asubuvnx1di_extended_scalar */
    case 3782:  /* *pred_asubvnx1di_extended_scalar */
    case 3783:  /* *pred_smulvnx1di_extended_scalar */
    case 3877:  /* *pred_cmpvnx1di */
    case 3899:  /* *pred_cmpvnx1di_narrow */
    case 3921:  /* *pred_ltgevnx1di */
    case 3943:  /* *pred_ltgevnx1di_narrow */
    case 4019:  /* *pred_cmpvnx1di_scalar */
    case 4023:  /* *pred_cmpvnx1di_scalar_narrow */
    case 4027:  /* *pred_eqnevnx1di_scalar */
    case 4031:  /* *pred_eqnevnx1di_scalar_narrow */
    case 4035:  /* *pred_cmpvnx1di_extended_scalar */
    case 4039:  /* *pred_cmpvnx1di_extended_scalar_narrow */
    case 4043:  /* *pred_eqnevnx1di_extended_scalar */
    case 4047:  /* *pred_eqnevnx1di_extended_scalar_narrow */
    case 4069:  /* *pred_maddvnx1di */
    case 4091:  /* *pred_maccvnx1di */
    case 4113:  /* *pred_mul_plusvnx1di */
    case 4135:  /* *pred_maddvnx1di_scalar */
    case 4157:  /* *pred_maccvnx1di_scalar */
    case 4179:  /* *pred_mul_plusvnx1di_scalar */
    case 4183:  /* *pred_maddvnx1di_extended_scalar */
    case 4187:  /* *pred_maccvnx1di_extended_scalar */
    case 4191:  /* *pred_mul_plusvnx1di_extended_scalar */
    case 4213:  /* *pred_nmsubvnx1di */
    case 4235:  /* *pred_nmsacvnx1di */
    case 4257:  /* *pred_minus_mulvnx1di */
    case 4279:  /* *pred_nmsubvnx1di_scalar */
    case 4301:  /* *pred_nmsacvnx1di_scalar */
    case 4323:  /* *pred_minus_mulvnx1di_scalar */
    case 4327:  /* *pred_nmsubvnx1di_extended_scalar */
    case 4331:  /* *pred_nmsacvnx1di_extended_scalar */
    case 4335:  /* *pred_minus_mulvnx1di_extended_scalar */
    case 4574:  /* pred_iotavnx1di */
    case 4596:  /* pred_seriesvnx1di */
    case 5473:  /* pred_reduc_sumvnx1divnx1DI */
    case 5474:  /* pred_reduc_maxuvnx1divnx1DI */
    case 5475:  /* pred_reduc_maxvnx1divnx1DI */
    case 5476:  /* pred_reduc_minuvnx1divnx1DI */
    case 5477:  /* pred_reduc_minvnx1divnx1DI */
    case 5478:  /* pred_reduc_andvnx1divnx1DI */
    case 5479:  /* pred_reduc_orvnx1divnx1DI */
    case 5480:  /* pred_reduc_xorvnx1divnx1DI */
    case 5763:  /* *pred_extract_firstvnx1di */
    case 5767:  /* pred_extract_first_truncvnx1di */
    case 5816:  /* pred_slideupvnx1di */
    case 5817:  /* pred_slidedownvnx1di */
    case 5878:  /* *pred_slide1upvnx1di */
    case 5879:  /* *pred_slide1downvnx1di */
    case 5886:  /* *pred_slide1upvnx1di_extended */
    case 5887:  /* *pred_slide1downvnx1di_extended */
    case 5930:  /* pred_gathervnx1di */
    case 5961:  /* pred_gathervnx1di_scalar */
    case 5991:  /* pred_gatherei16vnx1di */
    case 6022:  /* pred_compressvnx1di */
    case 6055:  /* pred_fault_loadvnx1di */
      return MODE_VNX1DI;

    case 737:  /* *movvnx16si_whole */
    case 817:  /* pred_movvnx16si */
    case 848:  /* pred_storevnx16si */
    case 893:  /* pred_mergevnx16si */
    case 924:  /* pred_mergevnx16si_scalar */
    case 950:  /* *pred_broadcastvnx16si */
    case 985:  /* pred_strided_loadvnx16si */
    case 1016:  /* pred_strided_storevnx16si */
    case 1064:  /* pred_indexed_oloadvnx16si_same_eew */
    case 1065:  /* pred_indexed_uloadvnx16si_same_eew */
    case 1112:  /* pred_indexed_oloadvnx16si_x2_greater_eew */
    case 1113:  /* pred_indexed_uloadvnx16si_x2_greater_eew */
    case 1148:  /* pred_indexed_oloadvnx16si_x4_greater_eew */
    case 1149:  /* pred_indexed_uloadvnx16si_x4_greater_eew */
    case 1452:  /* pred_indexed_ostorevnx16sivnx16qi */
    case 1453:  /* pred_indexed_ustorevnx16sivnx16qi */
    case 1460:  /* pred_indexed_ostorevnx16sivnx16hi */
    case 1461:  /* pred_indexed_ustorevnx16sivnx16hi */
    case 1468:  /* pred_indexed_ostorevnx16sivnx16si */
    case 1469:  /* pred_indexed_ustorevnx16sivnx16si */
    case 1771:  /* pred_addvnx16si */
    case 1772:  /* pred_subvnx16si */
    case 1773:  /* pred_andvnx16si */
    case 1774:  /* pred_iorvnx16si */
    case 1775:  /* pred_xorvnx16si */
    case 1776:  /* pred_ashlvnx16si */
    case 1777:  /* pred_ashrvnx16si */
    case 1778:  /* pred_lshrvnx16si */
    case 1779:  /* pred_smaxvnx16si */
    case 1780:  /* pred_umaxvnx16si */
    case 1781:  /* pred_sminvnx16si */
    case 1782:  /* pred_uminvnx16si */
    case 1783:  /* pred_mulvnx16si */
    case 1784:  /* pred_divvnx16si */
    case 1785:  /* pred_udivvnx16si */
    case 1786:  /* pred_modvnx16si */
    case 1787:  /* pred_umodvnx16si */
    case 1907:  /* pred_ashlvnx16si_scalar */
    case 1908:  /* pred_ashrvnx16si_scalar */
    case 1909:  /* pred_lshrvnx16si_scalar */
    case 2075:  /* pred_addvnx16si_scalar */
    case 2076:  /* pred_andvnx16si_scalar */
    case 2077:  /* pred_iorvnx16si_scalar */
    case 2078:  /* pred_xorvnx16si_scalar */
    case 2079:  /* pred_smaxvnx16si_scalar */
    case 2080:  /* pred_umaxvnx16si_scalar */
    case 2081:  /* pred_sminvnx16si_scalar */
    case 2082:  /* pred_uminvnx16si_scalar */
    case 2083:  /* pred_mulvnx16si_scalar */
    case 2169:  /* pred_subvnx16si_scalar */
    case 2170:  /* pred_divvnx16si_scalar */
    case 2171:  /* pred_udivvnx16si_scalar */
    case 2172:  /* pred_modvnx16si_scalar */
    case 2173:  /* pred_umodvnx16si_scalar */
    case 2191:  /* pred_subvnx16si_reverse_scalar */
    case 2363:  /* pred_mulhvnx16si */
    case 2364:  /* pred_mulhuvnx16si */
    case 2365:  /* pred_mulhsuvnx16si */
    case 2429:  /* pred_mulhvnx16si_scalar */
    case 2430:  /* pred_mulhuvnx16si_scalar */
    case 2431:  /* pred_mulhsuvnx16si_scalar */
    case 2473:  /* pred_adcvnx16si */
    case 2495:  /* pred_sbcvnx16si */
    case 2517:  /* pred_adcvnx16si_scalar */
    case 2535:  /* pred_sbcvnx16si_scalar */
    case 2569:  /* pred_madcvnx16si */
    case 2591:  /* pred_msbcvnx16si */
    case 2613:  /* pred_madcvnx16si_scalar */
    case 2631:  /* pred_msbcvnx16si_scalar */
    case 2665:  /* pred_madcvnx16si_overflow */
    case 2687:  /* pred_msbcvnx16si_overflow */
    case 2709:  /* pred_madcvnx16si_overflow_scalar */
    case 2727:  /* pred_msbcvnx16si_overflow_scalar */
    case 2778:  /* pred_negvnx16si */
    case 2779:  /* pred_one_cmplvnx16si */
    case 2808:  /* pred_extendvnx16si_vf2 */
    case 2809:  /* pred_zero_extendvnx16si_vf2 */
    case 2826:  /* pred_extendvnx16si_vf4 */
    case 2827:  /* pred_zero_extendvnx16si_vf4 */
    case 3347:  /* pred_ssaddvnx16si */
    case 3348:  /* pred_sssubvnx16si */
    case 3349:  /* pred_usaddvnx16si */
    case 3350:  /* pred_ussubvnx16si */
    case 3401:  /* pred_ssaddvnx16si_scalar */
    case 3402:  /* pred_usaddvnx16si_scalar */
    case 3437:  /* pred_sssubvnx16si_scalar */
    case 3438:  /* pred_ussubvnx16si_scalar */
    case 3590:  /* pred_aadduvnx16si */
    case 3591:  /* pred_aaddvnx16si */
    case 3592:  /* pred_asubuvnx16si */
    case 3593:  /* pred_asubvnx16si */
    case 3594:  /* pred_smulvnx16si */
    case 3595:  /* pred_ssrlvnx16si */
    case 3596:  /* pred_ssravnx16si */
    case 3710:  /* pred_aadduvnx16si_scalar */
    case 3711:  /* pred_aaddvnx16si_scalar */
    case 3712:  /* pred_asubuvnx16si_scalar */
    case 3713:  /* pred_asubvnx16si_scalar */
    case 3714:  /* pred_smulvnx16si_scalar */
    case 3749:  /* pred_ssrlvnx16si_scalar */
    case 3750:  /* pred_ssravnx16si_scalar */
    case 3876:  /* *pred_cmpvnx16si */
    case 3898:  /* *pred_cmpvnx16si_narrow */
    case 3920:  /* *pred_ltgevnx16si */
    case 3942:  /* *pred_ltgevnx16si_narrow */
    case 3964:  /* *pred_cmpvnx16si_scalar */
    case 3982:  /* *pred_cmpvnx16si_scalar_narrow */
    case 4000:  /* *pred_eqnevnx16si_scalar */
    case 4018:  /* *pred_eqnevnx16si_scalar_narrow */
    case 4068:  /* *pred_maddvnx16si */
    case 4090:  /* *pred_maccvnx16si */
    case 4112:  /* *pred_mul_plusvnx16si */
    case 4134:  /* *pred_maddvnx16si_scalar */
    case 4156:  /* *pred_maccvnx16si_scalar */
    case 4178:  /* *pred_mul_plusvnx16si_scalar */
    case 4212:  /* *pred_nmsubvnx16si */
    case 4234:  /* *pred_nmsacvnx16si */
    case 4256:  /* *pred_minus_mulvnx16si */
    case 4278:  /* *pred_nmsubvnx16si_scalar */
    case 4300:  /* *pred_nmsacvnx16si_scalar */
    case 4322:  /* *pred_minus_mulvnx16si_scalar */
    case 4573:  /* pred_iotavnx16si */
    case 4595:  /* pred_seriesvnx16si */
    case 5465:  /* pred_reduc_sumvnx16sivnx2si */
    case 5466:  /* pred_reduc_maxuvnx16sivnx2si */
    case 5467:  /* pred_reduc_maxvnx16sivnx2si */
    case 5468:  /* pred_reduc_minuvnx16sivnx2si */
    case 5469:  /* pred_reduc_minvnx16sivnx2si */
    case 5470:  /* pred_reduc_andvnx16sivnx2si */
    case 5471:  /* pred_reduc_orvnx16sivnx2si */
    case 5472:  /* pred_reduc_xorvnx16sivnx2si */
    case 5659:  /* pred_widen_reduc_plusvnx16sivnx2di */
    case 5660:  /* pred_widen_reduc_plusuvnx16sivnx2di */
    case 5762:  /* *pred_extract_firstvnx16si */
    case 5814:  /* pred_slideupvnx16si */
    case 5815:  /* pred_slidedownvnx16si */
    case 5876:  /* pred_slide1upvnx16si */
    case 5877:  /* pred_slide1downvnx16si */
    case 5929:  /* pred_gathervnx16si */
    case 5960:  /* pred_gathervnx16si_scalar */
    case 5990:  /* pred_gatherei16vnx16si */
    case 6021:  /* pred_compressvnx16si */
    case 6054:  /* pred_fault_loadvnx16si */
      return MODE_VNX16SI;

    case 736:  /* *movvnx8si_whole */
    case 816:  /* pred_movvnx8si */
    case 847:  /* pred_storevnx8si */
    case 892:  /* pred_mergevnx8si */
    case 923:  /* pred_mergevnx8si_scalar */
    case 949:  /* *pred_broadcastvnx8si */
    case 984:  /* pred_strided_loadvnx8si */
    case 1015:  /* pred_strided_storevnx8si */
    case 1062:  /* pred_indexed_oloadvnx8si_same_eew */
    case 1063:  /* pred_indexed_uloadvnx8si_same_eew */
    case 1110:  /* pred_indexed_oloadvnx8si_x2_greater_eew */
    case 1111:  /* pred_indexed_uloadvnx8si_x2_greater_eew */
    case 1146:  /* pred_indexed_oloadvnx8si_x4_greater_eew */
    case 1147:  /* pred_indexed_uloadvnx8si_x4_greater_eew */
    case 1220:  /* pred_indexed_oloadvnx8si_x2_smaller_eew */
    case 1221:  /* pred_indexed_uloadvnx8si_x2_smaller_eew */
    case 1404:  /* pred_indexed_ostorevnx8sivnx8qi */
    case 1405:  /* pred_indexed_ustorevnx8sivnx8qi */
    case 1416:  /* pred_indexed_ostorevnx8sivnx8hi */
    case 1417:  /* pred_indexed_ustorevnx8sivnx8hi */
    case 1428:  /* pred_indexed_ostorevnx8sivnx8si */
    case 1429:  /* pred_indexed_ustorevnx8sivnx8si */
    case 1440:  /* pred_indexed_ostorevnx8sivnx8di */
    case 1441:  /* pred_indexed_ustorevnx8sivnx8di */
    case 1754:  /* pred_addvnx8si */
    case 1755:  /* pred_subvnx8si */
    case 1756:  /* pred_andvnx8si */
    case 1757:  /* pred_iorvnx8si */
    case 1758:  /* pred_xorvnx8si */
    case 1759:  /* pred_ashlvnx8si */
    case 1760:  /* pred_ashrvnx8si */
    case 1761:  /* pred_lshrvnx8si */
    case 1762:  /* pred_smaxvnx8si */
    case 1763:  /* pred_umaxvnx8si */
    case 1764:  /* pred_sminvnx8si */
    case 1765:  /* pred_uminvnx8si */
    case 1766:  /* pred_mulvnx8si */
    case 1767:  /* pred_divvnx8si */
    case 1768:  /* pred_udivvnx8si */
    case 1769:  /* pred_modvnx8si */
    case 1770:  /* pred_umodvnx8si */
    case 1904:  /* pred_ashlvnx8si_scalar */
    case 1905:  /* pred_ashrvnx8si_scalar */
    case 1906:  /* pred_lshrvnx8si_scalar */
    case 2066:  /* pred_addvnx8si_scalar */
    case 2067:  /* pred_andvnx8si_scalar */
    case 2068:  /* pred_iorvnx8si_scalar */
    case 2069:  /* pred_xorvnx8si_scalar */
    case 2070:  /* pred_smaxvnx8si_scalar */
    case 2071:  /* pred_umaxvnx8si_scalar */
    case 2072:  /* pred_sminvnx8si_scalar */
    case 2073:  /* pred_uminvnx8si_scalar */
    case 2074:  /* pred_mulvnx8si_scalar */
    case 2164:  /* pred_subvnx8si_scalar */
    case 2165:  /* pred_divvnx8si_scalar */
    case 2166:  /* pred_udivvnx8si_scalar */
    case 2167:  /* pred_modvnx8si_scalar */
    case 2168:  /* pred_umodvnx8si_scalar */
    case 2190:  /* pred_subvnx8si_reverse_scalar */
    case 2360:  /* pred_mulhvnx8si */
    case 2361:  /* pred_mulhuvnx8si */
    case 2362:  /* pred_mulhsuvnx8si */
    case 2426:  /* pred_mulhvnx8si_scalar */
    case 2427:  /* pred_mulhuvnx8si_scalar */
    case 2428:  /* pred_mulhsuvnx8si_scalar */
    case 2472:  /* pred_adcvnx8si */
    case 2494:  /* pred_sbcvnx8si */
    case 2516:  /* pred_adcvnx8si_scalar */
    case 2534:  /* pred_sbcvnx8si_scalar */
    case 2568:  /* pred_madcvnx8si */
    case 2590:  /* pred_msbcvnx8si */
    case 2612:  /* pred_madcvnx8si_scalar */
    case 2630:  /* pred_msbcvnx8si_scalar */
    case 2664:  /* pred_madcvnx8si_overflow */
    case 2686:  /* pred_msbcvnx8si_overflow */
    case 2708:  /* pred_madcvnx8si_overflow_scalar */
    case 2726:  /* pred_msbcvnx8si_overflow_scalar */
    case 2776:  /* pred_negvnx8si */
    case 2777:  /* pred_one_cmplvnx8si */
    case 2806:  /* pred_extendvnx8si_vf2 */
    case 2807:  /* pred_zero_extendvnx8si_vf2 */
    case 2824:  /* pred_extendvnx8si_vf4 */
    case 2825:  /* pred_zero_extendvnx8si_vf4 */
    case 2928:  /* pred_dual_widen_addsvnx8di */
    case 2929:  /* pred_dual_widen_subsvnx8di */
    case 2930:  /* pred_dual_widen_mulsvnx8di */
    case 2931:  /* pred_dual_widen_adduvnx8di */
    case 2932:  /* pred_dual_widen_subuvnx8di */
    case 2933:  /* pred_dual_widen_muluvnx8di */
    case 3018:  /* pred_dual_widen_addsvnx8di_scalar */
    case 3019:  /* pred_dual_widen_subsvnx8di_scalar */
    case 3020:  /* pred_dual_widen_mulsvnx8di_scalar */
    case 3021:  /* pred_dual_widen_adduvnx8di_scalar */
    case 3022:  /* pred_dual_widen_subuvnx8di_scalar */
    case 3023:  /* pred_dual_widen_muluvnx8di_scalar */
    case 3080:  /* pred_single_widen_addsvnx8di */
    case 3081:  /* pred_single_widen_subsvnx8di */
    case 3082:  /* pred_single_widen_adduvnx8di */
    case 3083:  /* pred_single_widen_subuvnx8di */
    case 3140:  /* pred_single_widen_addsvnx8di_scalar */
    case 3141:  /* pred_single_widen_subsvnx8di_scalar */
    case 3142:  /* pred_single_widen_adduvnx8di_scalar */
    case 3143:  /* pred_single_widen_subuvnx8di_scalar */
    case 3158:  /* pred_widen_mulsuvnx8di */
    case 3173:  /* pred_widen_mulsuvnx8di_scalar */
    case 3202:  /* pred_extendvnx8di */
    case 3203:  /* pred_zero_extendvnx8di */
    case 3232:  /* pred_narrow_ashrvnx8di */
    case 3233:  /* pred_narrow_lshrvnx8di */
    case 3262:  /* pred_narrow_ashrvnx8di_scalar */
    case 3263:  /* pred_narrow_lshrvnx8di_scalar */
    case 3278:  /* pred_truncvnx8di */
    case 3343:  /* pred_ssaddvnx8si */
    case 3344:  /* pred_sssubvnx8si */
    case 3345:  /* pred_usaddvnx8si */
    case 3346:  /* pred_ussubvnx8si */
    case 3399:  /* pred_ssaddvnx8si_scalar */
    case 3400:  /* pred_usaddvnx8si_scalar */
    case 3435:  /* pred_sssubvnx8si_scalar */
    case 3436:  /* pred_ussubvnx8si_scalar */
    case 3583:  /* pred_aadduvnx8si */
    case 3584:  /* pred_aaddvnx8si */
    case 3585:  /* pred_asubuvnx8si */
    case 3586:  /* pred_asubvnx8si */
    case 3587:  /* pred_smulvnx8si */
    case 3588:  /* pred_ssrlvnx8si */
    case 3589:  /* pred_ssravnx8si */
    case 3705:  /* pred_aadduvnx8si_scalar */
    case 3706:  /* pred_aaddvnx8si_scalar */
    case 3707:  /* pred_asubuvnx8si_scalar */
    case 3708:  /* pred_asubvnx8si_scalar */
    case 3709:  /* pred_smulvnx8si_scalar */
    case 3747:  /* pred_ssrlvnx8si_scalar */
    case 3748:  /* pred_ssravnx8si_scalar */
    case 3827:  /* pred_narrow_clipvnx8di */
    case 3828:  /* pred_narrow_clipuvnx8di */
    case 3857:  /* pred_narrow_clipvnx8di_scalar */
    case 3858:  /* pred_narrow_clipuvnx8di_scalar */
    case 3875:  /* *pred_cmpvnx8si */
    case 3897:  /* *pred_cmpvnx8si_narrow */
    case 3919:  /* *pred_ltgevnx8si */
    case 3941:  /* *pred_ltgevnx8si_narrow */
    case 3963:  /* *pred_cmpvnx8si_scalar */
    case 3981:  /* *pred_cmpvnx8si_scalar_narrow */
    case 3999:  /* *pred_eqnevnx8si_scalar */
    case 4017:  /* *pred_eqnevnx8si_scalar_narrow */
    case 4067:  /* *pred_maddvnx8si */
    case 4089:  /* *pred_maccvnx8si */
    case 4111:  /* *pred_mul_plusvnx8si */
    case 4133:  /* *pred_maddvnx8si_scalar */
    case 4155:  /* *pred_maccvnx8si_scalar */
    case 4177:  /* *pred_mul_plusvnx8si_scalar */
    case 4211:  /* *pred_nmsubvnx8si */
    case 4233:  /* *pred_nmsacvnx8si */
    case 4255:  /* *pred_minus_mulvnx8si */
    case 4277:  /* *pred_nmsubvnx8si_scalar */
    case 4299:  /* *pred_nmsacvnx8si_scalar */
    case 4321:  /* *pred_minus_mulvnx8si_scalar */
    case 4367:  /* pred_widen_mul_plussvnx8di */
    case 4368:  /* pred_widen_mul_plusuvnx8di */
    case 4397:  /* pred_widen_mul_plussvnx8di_scalar */
    case 4398:  /* pred_widen_mul_plusuvnx8di_scalar */
    case 4413:  /* pred_widen_mul_plussuvnx8di */
    case 4428:  /* pred_widen_mul_plussuvnx8di_scalar */
    case 4443:  /* pred_widen_mul_plususvnx8di_scalar */
    case 4572:  /* pred_iotavnx8si */
    case 4594:  /* pred_seriesvnx8si */
    case 5271:  /* pred_widen_floatvnx8df */
    case 5272:  /* pred_widen_floatunsvnx8df */
    case 5293:  /* pred_narrow_fcvt_x_fvnx8df */
    case 5294:  /* pred_narrow_fcvt_xu_fvnx8df */
    case 5311:  /* pred_narrow_fix_truncvnx8df */
    case 5312:  /* pred_narrow_fixuns_truncvnx8df */
    case 5457:  /* pred_reduc_sumvnx8sivnx2si */
    case 5458:  /* pred_reduc_maxuvnx8sivnx2si */
    case 5459:  /* pred_reduc_maxvnx8sivnx2si */
    case 5460:  /* pred_reduc_minuvnx8sivnx2si */
    case 5461:  /* pred_reduc_minvnx8sivnx2si */
    case 5462:  /* pred_reduc_andvnx8sivnx2si */
    case 5463:  /* pred_reduc_orvnx8sivnx2si */
    case 5464:  /* pred_reduc_xorvnx8sivnx2si */
    case 5617:  /* pred_reduc_sumvnx8sivnx1si */
    case 5618:  /* pred_reduc_maxuvnx8sivnx1si */
    case 5619:  /* pred_reduc_maxvnx8sivnx1si */
    case 5620:  /* pred_reduc_minuvnx8sivnx1si */
    case 5621:  /* pred_reduc_minvnx8sivnx1si */
    case 5622:  /* pred_reduc_andvnx8sivnx1si */
    case 5623:  /* pred_reduc_orvnx8sivnx1si */
    case 5624:  /* pred_reduc_xorvnx8sivnx1si */
    case 5657:  /* pred_widen_reduc_plusvnx8sivnx2di */
    case 5658:  /* pred_widen_reduc_plusuvnx8sivnx2di */
    case 5761:  /* *pred_extract_firstvnx8si */
    case 5812:  /* pred_slideupvnx8si */
    case 5813:  /* pred_slidedownvnx8si */
    case 5874:  /* pred_slide1upvnx8si */
    case 5875:  /* pred_slide1downvnx8si */
    case 5928:  /* pred_gathervnx8si */
    case 5959:  /* pred_gathervnx8si_scalar */
    case 5989:  /* pred_gatherei16vnx8si */
    case 6020:  /* pred_compressvnx8si */
    case 6053:  /* pred_fault_loadvnx8si */
      return MODE_VNX8SI;

    case 735:  /* *movvnx4si_whole */
    case 815:  /* pred_movvnx4si */
    case 846:  /* pred_storevnx4si */
    case 891:  /* pred_mergevnx4si */
    case 922:  /* pred_mergevnx4si_scalar */
    case 948:  /* *pred_broadcastvnx4si */
    case 983:  /* pred_strided_loadvnx4si */
    case 1014:  /* pred_strided_storevnx4si */
    case 1060:  /* pred_indexed_oloadvnx4si_same_eew */
    case 1061:  /* pred_indexed_uloadvnx4si_same_eew */
    case 1108:  /* pred_indexed_oloadvnx4si_x2_greater_eew */
    case 1109:  /* pred_indexed_uloadvnx4si_x2_greater_eew */
    case 1144:  /* pred_indexed_oloadvnx4si_x4_greater_eew */
    case 1145:  /* pred_indexed_uloadvnx4si_x4_greater_eew */
    case 1218:  /* pred_indexed_oloadvnx4si_x2_smaller_eew */
    case 1219:  /* pred_indexed_uloadvnx4si_x2_smaller_eew */
    case 1356:  /* pred_indexed_ostorevnx4sivnx4qi */
    case 1357:  /* pred_indexed_ustorevnx4sivnx4qi */
    case 1368:  /* pred_indexed_ostorevnx4sivnx4hi */
    case 1369:  /* pred_indexed_ustorevnx4sivnx4hi */
    case 1380:  /* pred_indexed_ostorevnx4sivnx4si */
    case 1381:  /* pred_indexed_ustorevnx4sivnx4si */
    case 1392:  /* pred_indexed_ostorevnx4sivnx4di */
    case 1393:  /* pred_indexed_ustorevnx4sivnx4di */
    case 1737:  /* pred_addvnx4si */
    case 1738:  /* pred_subvnx4si */
    case 1739:  /* pred_andvnx4si */
    case 1740:  /* pred_iorvnx4si */
    case 1741:  /* pred_xorvnx4si */
    case 1742:  /* pred_ashlvnx4si */
    case 1743:  /* pred_ashrvnx4si */
    case 1744:  /* pred_lshrvnx4si */
    case 1745:  /* pred_smaxvnx4si */
    case 1746:  /* pred_umaxvnx4si */
    case 1747:  /* pred_sminvnx4si */
    case 1748:  /* pred_uminvnx4si */
    case 1749:  /* pred_mulvnx4si */
    case 1750:  /* pred_divvnx4si */
    case 1751:  /* pred_udivvnx4si */
    case 1752:  /* pred_modvnx4si */
    case 1753:  /* pred_umodvnx4si */
    case 1901:  /* pred_ashlvnx4si_scalar */
    case 1902:  /* pred_ashrvnx4si_scalar */
    case 1903:  /* pred_lshrvnx4si_scalar */
    case 2057:  /* pred_addvnx4si_scalar */
    case 2058:  /* pred_andvnx4si_scalar */
    case 2059:  /* pred_iorvnx4si_scalar */
    case 2060:  /* pred_xorvnx4si_scalar */
    case 2061:  /* pred_smaxvnx4si_scalar */
    case 2062:  /* pred_umaxvnx4si_scalar */
    case 2063:  /* pred_sminvnx4si_scalar */
    case 2064:  /* pred_uminvnx4si_scalar */
    case 2065:  /* pred_mulvnx4si_scalar */
    case 2159:  /* pred_subvnx4si_scalar */
    case 2160:  /* pred_divvnx4si_scalar */
    case 2161:  /* pred_udivvnx4si_scalar */
    case 2162:  /* pred_modvnx4si_scalar */
    case 2163:  /* pred_umodvnx4si_scalar */
    case 2189:  /* pred_subvnx4si_reverse_scalar */
    case 2357:  /* pred_mulhvnx4si */
    case 2358:  /* pred_mulhuvnx4si */
    case 2359:  /* pred_mulhsuvnx4si */
    case 2423:  /* pred_mulhvnx4si_scalar */
    case 2424:  /* pred_mulhuvnx4si_scalar */
    case 2425:  /* pred_mulhsuvnx4si_scalar */
    case 2471:  /* pred_adcvnx4si */
    case 2493:  /* pred_sbcvnx4si */
    case 2515:  /* pred_adcvnx4si_scalar */
    case 2533:  /* pred_sbcvnx4si_scalar */
    case 2567:  /* pred_madcvnx4si */
    case 2589:  /* pred_msbcvnx4si */
    case 2611:  /* pred_madcvnx4si_scalar */
    case 2629:  /* pred_msbcvnx4si_scalar */
    case 2663:  /* pred_madcvnx4si_overflow */
    case 2685:  /* pred_msbcvnx4si_overflow */
    case 2707:  /* pred_madcvnx4si_overflow_scalar */
    case 2725:  /* pred_msbcvnx4si_overflow_scalar */
    case 2774:  /* pred_negvnx4si */
    case 2775:  /* pred_one_cmplvnx4si */
    case 2804:  /* pred_extendvnx4si_vf2 */
    case 2805:  /* pred_zero_extendvnx4si_vf2 */
    case 2822:  /* pred_extendvnx4si_vf4 */
    case 2823:  /* pred_zero_extendvnx4si_vf4 */
    case 2922:  /* pred_dual_widen_addsvnx4di */
    case 2923:  /* pred_dual_widen_subsvnx4di */
    case 2924:  /* pred_dual_widen_mulsvnx4di */
    case 2925:  /* pred_dual_widen_adduvnx4di */
    case 2926:  /* pred_dual_widen_subuvnx4di */
    case 2927:  /* pred_dual_widen_muluvnx4di */
    case 3012:  /* pred_dual_widen_addsvnx4di_scalar */
    case 3013:  /* pred_dual_widen_subsvnx4di_scalar */
    case 3014:  /* pred_dual_widen_mulsvnx4di_scalar */
    case 3015:  /* pred_dual_widen_adduvnx4di_scalar */
    case 3016:  /* pred_dual_widen_subuvnx4di_scalar */
    case 3017:  /* pred_dual_widen_muluvnx4di_scalar */
    case 3076:  /* pred_single_widen_addsvnx4di */
    case 3077:  /* pred_single_widen_subsvnx4di */
    case 3078:  /* pred_single_widen_adduvnx4di */
    case 3079:  /* pred_single_widen_subuvnx4di */
    case 3136:  /* pred_single_widen_addsvnx4di_scalar */
    case 3137:  /* pred_single_widen_subsvnx4di_scalar */
    case 3138:  /* pred_single_widen_adduvnx4di_scalar */
    case 3139:  /* pred_single_widen_subuvnx4di_scalar */
    case 3157:  /* pred_widen_mulsuvnx4di */
    case 3172:  /* pred_widen_mulsuvnx4di_scalar */
    case 3200:  /* pred_extendvnx4di */
    case 3201:  /* pred_zero_extendvnx4di */
    case 3230:  /* pred_narrow_ashrvnx4di */
    case 3231:  /* pred_narrow_lshrvnx4di */
    case 3260:  /* pred_narrow_ashrvnx4di_scalar */
    case 3261:  /* pred_narrow_lshrvnx4di_scalar */
    case 3277:  /* pred_truncvnx4di */
    case 3339:  /* pred_ssaddvnx4si */
    case 3340:  /* pred_sssubvnx4si */
    case 3341:  /* pred_usaddvnx4si */
    case 3342:  /* pred_ussubvnx4si */
    case 3397:  /* pred_ssaddvnx4si_scalar */
    case 3398:  /* pred_usaddvnx4si_scalar */
    case 3433:  /* pred_sssubvnx4si_scalar */
    case 3434:  /* pred_ussubvnx4si_scalar */
    case 3576:  /* pred_aadduvnx4si */
    case 3577:  /* pred_aaddvnx4si */
    case 3578:  /* pred_asubuvnx4si */
    case 3579:  /* pred_asubvnx4si */
    case 3580:  /* pred_smulvnx4si */
    case 3581:  /* pred_ssrlvnx4si */
    case 3582:  /* pred_ssravnx4si */
    case 3700:  /* pred_aadduvnx4si_scalar */
    case 3701:  /* pred_aaddvnx4si_scalar */
    case 3702:  /* pred_asubuvnx4si_scalar */
    case 3703:  /* pred_asubvnx4si_scalar */
    case 3704:  /* pred_smulvnx4si_scalar */
    case 3745:  /* pred_ssrlvnx4si_scalar */
    case 3746:  /* pred_ssravnx4si_scalar */
    case 3825:  /* pred_narrow_clipvnx4di */
    case 3826:  /* pred_narrow_clipuvnx4di */
    case 3855:  /* pred_narrow_clipvnx4di_scalar */
    case 3856:  /* pred_narrow_clipuvnx4di_scalar */
    case 3874:  /* *pred_cmpvnx4si */
    case 3896:  /* *pred_cmpvnx4si_narrow */
    case 3918:  /* *pred_ltgevnx4si */
    case 3940:  /* *pred_ltgevnx4si_narrow */
    case 3962:  /* *pred_cmpvnx4si_scalar */
    case 3980:  /* *pred_cmpvnx4si_scalar_narrow */
    case 3998:  /* *pred_eqnevnx4si_scalar */
    case 4016:  /* *pred_eqnevnx4si_scalar_narrow */
    case 4066:  /* *pred_maddvnx4si */
    case 4088:  /* *pred_maccvnx4si */
    case 4110:  /* *pred_mul_plusvnx4si */
    case 4132:  /* *pred_maddvnx4si_scalar */
    case 4154:  /* *pred_maccvnx4si_scalar */
    case 4176:  /* *pred_mul_plusvnx4si_scalar */
    case 4210:  /* *pred_nmsubvnx4si */
    case 4232:  /* *pred_nmsacvnx4si */
    case 4254:  /* *pred_minus_mulvnx4si */
    case 4276:  /* *pred_nmsubvnx4si_scalar */
    case 4298:  /* *pred_nmsacvnx4si_scalar */
    case 4320:  /* *pred_minus_mulvnx4si_scalar */
    case 4365:  /* pred_widen_mul_plussvnx4di */
    case 4366:  /* pred_widen_mul_plusuvnx4di */
    case 4395:  /* pred_widen_mul_plussvnx4di_scalar */
    case 4396:  /* pred_widen_mul_plusuvnx4di_scalar */
    case 4412:  /* pred_widen_mul_plussuvnx4di */
    case 4427:  /* pred_widen_mul_plussuvnx4di_scalar */
    case 4442:  /* pred_widen_mul_plususvnx4di_scalar */
    case 4571:  /* pred_iotavnx4si */
    case 4593:  /* pred_seriesvnx4si */
    case 5269:  /* pred_widen_floatvnx4df */
    case 5270:  /* pred_widen_floatunsvnx4df */
    case 5291:  /* pred_narrow_fcvt_x_fvnx4df */
    case 5292:  /* pred_narrow_fcvt_xu_fvnx4df */
    case 5309:  /* pred_narrow_fix_truncvnx4df */
    case 5310:  /* pred_narrow_fixuns_truncvnx4df */
    case 5449:  /* pred_reduc_sumvnx4sivnx2si */
    case 5450:  /* pred_reduc_maxuvnx4sivnx2si */
    case 5451:  /* pred_reduc_maxvnx4sivnx2si */
    case 5452:  /* pred_reduc_minuvnx4sivnx2si */
    case 5453:  /* pred_reduc_minvnx4sivnx2si */
    case 5454:  /* pred_reduc_andvnx4sivnx2si */
    case 5455:  /* pred_reduc_orvnx4sivnx2si */
    case 5456:  /* pred_reduc_xorvnx4sivnx2si */
    case 5609:  /* pred_reduc_sumvnx4sivnx1si */
    case 5610:  /* pred_reduc_maxuvnx4sivnx1si */
    case 5611:  /* pred_reduc_maxvnx4sivnx1si */
    case 5612:  /* pred_reduc_minuvnx4sivnx1si */
    case 5613:  /* pred_reduc_minvnx4sivnx1si */
    case 5614:  /* pred_reduc_andvnx4sivnx1si */
    case 5615:  /* pred_reduc_orvnx4sivnx1si */
    case 5616:  /* pred_reduc_xorvnx4sivnx1si */
    case 5655:  /* pred_widen_reduc_plusvnx4sivnx2di */
    case 5656:  /* pred_widen_reduc_plusuvnx4sivnx2di */
    case 5760:  /* *pred_extract_firstvnx4si */
    case 5810:  /* pred_slideupvnx4si */
    case 5811:  /* pred_slidedownvnx4si */
    case 5872:  /* pred_slide1upvnx4si */
    case 5873:  /* pred_slide1downvnx4si */
    case 5927:  /* pred_gathervnx4si */
    case 5958:  /* pred_gathervnx4si_scalar */
    case 5988:  /* pred_gatherei16vnx4si */
    case 6019:  /* pred_compressvnx4si */
    case 6052:  /* pred_fault_loadvnx4si */
      return MODE_VNX4SI;

    case 734:  /* *movvnx2si_whole */
    case 814:  /* pred_movvnx2si */
    case 845:  /* pred_storevnx2si */
    case 890:  /* pred_mergevnx2si */
    case 921:  /* pred_mergevnx2si_scalar */
    case 947:  /* *pred_broadcastvnx2si */
    case 982:  /* pred_strided_loadvnx2si */
    case 1013:  /* pred_strided_storevnx2si */
    case 1058:  /* pred_indexed_oloadvnx2si_same_eew */
    case 1059:  /* pred_indexed_uloadvnx2si_same_eew */
    case 1106:  /* pred_indexed_oloadvnx2si_x2_greater_eew */
    case 1107:  /* pred_indexed_uloadvnx2si_x2_greater_eew */
    case 1142:  /* pred_indexed_oloadvnx2si_x4_greater_eew */
    case 1143:  /* pred_indexed_uloadvnx2si_x4_greater_eew */
    case 1216:  /* pred_indexed_oloadvnx2si_x2_smaller_eew */
    case 1217:  /* pred_indexed_uloadvnx2si_x2_smaller_eew */
    case 1308:  /* pred_indexed_ostorevnx2sivnx2qi */
    case 1309:  /* pred_indexed_ustorevnx2sivnx2qi */
    case 1320:  /* pred_indexed_ostorevnx2sivnx2hi */
    case 1321:  /* pred_indexed_ustorevnx2sivnx2hi */
    case 1332:  /* pred_indexed_ostorevnx2sivnx2si */
    case 1333:  /* pred_indexed_ustorevnx2sivnx2si */
    case 1344:  /* pred_indexed_ostorevnx2sivnx2di */
    case 1345:  /* pred_indexed_ustorevnx2sivnx2di */
    case 1720:  /* pred_addvnx2si */
    case 1721:  /* pred_subvnx2si */
    case 1722:  /* pred_andvnx2si */
    case 1723:  /* pred_iorvnx2si */
    case 1724:  /* pred_xorvnx2si */
    case 1725:  /* pred_ashlvnx2si */
    case 1726:  /* pred_ashrvnx2si */
    case 1727:  /* pred_lshrvnx2si */
    case 1728:  /* pred_smaxvnx2si */
    case 1729:  /* pred_umaxvnx2si */
    case 1730:  /* pred_sminvnx2si */
    case 1731:  /* pred_uminvnx2si */
    case 1732:  /* pred_mulvnx2si */
    case 1733:  /* pred_divvnx2si */
    case 1734:  /* pred_udivvnx2si */
    case 1735:  /* pred_modvnx2si */
    case 1736:  /* pred_umodvnx2si */
    case 1898:  /* pred_ashlvnx2si_scalar */
    case 1899:  /* pred_ashrvnx2si_scalar */
    case 1900:  /* pred_lshrvnx2si_scalar */
    case 2048:  /* pred_addvnx2si_scalar */
    case 2049:  /* pred_andvnx2si_scalar */
    case 2050:  /* pred_iorvnx2si_scalar */
    case 2051:  /* pred_xorvnx2si_scalar */
    case 2052:  /* pred_smaxvnx2si_scalar */
    case 2053:  /* pred_umaxvnx2si_scalar */
    case 2054:  /* pred_sminvnx2si_scalar */
    case 2055:  /* pred_uminvnx2si_scalar */
    case 2056:  /* pred_mulvnx2si_scalar */
    case 2154:  /* pred_subvnx2si_scalar */
    case 2155:  /* pred_divvnx2si_scalar */
    case 2156:  /* pred_udivvnx2si_scalar */
    case 2157:  /* pred_modvnx2si_scalar */
    case 2158:  /* pred_umodvnx2si_scalar */
    case 2188:  /* pred_subvnx2si_reverse_scalar */
    case 2354:  /* pred_mulhvnx2si */
    case 2355:  /* pred_mulhuvnx2si */
    case 2356:  /* pred_mulhsuvnx2si */
    case 2420:  /* pred_mulhvnx2si_scalar */
    case 2421:  /* pred_mulhuvnx2si_scalar */
    case 2422:  /* pred_mulhsuvnx2si_scalar */
    case 2470:  /* pred_adcvnx2si */
    case 2492:  /* pred_sbcvnx2si */
    case 2514:  /* pred_adcvnx2si_scalar */
    case 2532:  /* pred_sbcvnx2si_scalar */
    case 2566:  /* pred_madcvnx2si */
    case 2588:  /* pred_msbcvnx2si */
    case 2610:  /* pred_madcvnx2si_scalar */
    case 2628:  /* pred_msbcvnx2si_scalar */
    case 2662:  /* pred_madcvnx2si_overflow */
    case 2684:  /* pred_msbcvnx2si_overflow */
    case 2706:  /* pred_madcvnx2si_overflow_scalar */
    case 2724:  /* pred_msbcvnx2si_overflow_scalar */
    case 2772:  /* pred_negvnx2si */
    case 2773:  /* pred_one_cmplvnx2si */
    case 2802:  /* pred_extendvnx2si_vf2 */
    case 2803:  /* pred_zero_extendvnx2si_vf2 */
    case 2820:  /* pred_extendvnx2si_vf4 */
    case 2821:  /* pred_zero_extendvnx2si_vf4 */
    case 2916:  /* pred_dual_widen_addsvnx2di */
    case 2917:  /* pred_dual_widen_subsvnx2di */
    case 2918:  /* pred_dual_widen_mulsvnx2di */
    case 2919:  /* pred_dual_widen_adduvnx2di */
    case 2920:  /* pred_dual_widen_subuvnx2di */
    case 2921:  /* pred_dual_widen_muluvnx2di */
    case 3006:  /* pred_dual_widen_addsvnx2di_scalar */
    case 3007:  /* pred_dual_widen_subsvnx2di_scalar */
    case 3008:  /* pred_dual_widen_mulsvnx2di_scalar */
    case 3009:  /* pred_dual_widen_adduvnx2di_scalar */
    case 3010:  /* pred_dual_widen_subuvnx2di_scalar */
    case 3011:  /* pred_dual_widen_muluvnx2di_scalar */
    case 3072:  /* pred_single_widen_addsvnx2di */
    case 3073:  /* pred_single_widen_subsvnx2di */
    case 3074:  /* pred_single_widen_adduvnx2di */
    case 3075:  /* pred_single_widen_subuvnx2di */
    case 3132:  /* pred_single_widen_addsvnx2di_scalar */
    case 3133:  /* pred_single_widen_subsvnx2di_scalar */
    case 3134:  /* pred_single_widen_adduvnx2di_scalar */
    case 3135:  /* pred_single_widen_subuvnx2di_scalar */
    case 3156:  /* pred_widen_mulsuvnx2di */
    case 3171:  /* pred_widen_mulsuvnx2di_scalar */
    case 3198:  /* pred_extendvnx2di */
    case 3199:  /* pred_zero_extendvnx2di */
    case 3228:  /* pred_narrow_ashrvnx2di */
    case 3229:  /* pred_narrow_lshrvnx2di */
    case 3258:  /* pred_narrow_ashrvnx2di_scalar */
    case 3259:  /* pred_narrow_lshrvnx2di_scalar */
    case 3276:  /* pred_truncvnx2di */
    case 3335:  /* pred_ssaddvnx2si */
    case 3336:  /* pred_sssubvnx2si */
    case 3337:  /* pred_usaddvnx2si */
    case 3338:  /* pred_ussubvnx2si */
    case 3395:  /* pred_ssaddvnx2si_scalar */
    case 3396:  /* pred_usaddvnx2si_scalar */
    case 3431:  /* pred_sssubvnx2si_scalar */
    case 3432:  /* pred_ussubvnx2si_scalar */
    case 3569:  /* pred_aadduvnx2si */
    case 3570:  /* pred_aaddvnx2si */
    case 3571:  /* pred_asubuvnx2si */
    case 3572:  /* pred_asubvnx2si */
    case 3573:  /* pred_smulvnx2si */
    case 3574:  /* pred_ssrlvnx2si */
    case 3575:  /* pred_ssravnx2si */
    case 3695:  /* pred_aadduvnx2si_scalar */
    case 3696:  /* pred_aaddvnx2si_scalar */
    case 3697:  /* pred_asubuvnx2si_scalar */
    case 3698:  /* pred_asubvnx2si_scalar */
    case 3699:  /* pred_smulvnx2si_scalar */
    case 3743:  /* pred_ssrlvnx2si_scalar */
    case 3744:  /* pred_ssravnx2si_scalar */
    case 3823:  /* pred_narrow_clipvnx2di */
    case 3824:  /* pred_narrow_clipuvnx2di */
    case 3853:  /* pred_narrow_clipvnx2di_scalar */
    case 3854:  /* pred_narrow_clipuvnx2di_scalar */
    case 3873:  /* *pred_cmpvnx2si */
    case 3895:  /* *pred_cmpvnx2si_narrow */
    case 3917:  /* *pred_ltgevnx2si */
    case 3939:  /* *pred_ltgevnx2si_narrow */
    case 3961:  /* *pred_cmpvnx2si_scalar */
    case 3979:  /* *pred_cmpvnx2si_scalar_narrow */
    case 3997:  /* *pred_eqnevnx2si_scalar */
    case 4015:  /* *pred_eqnevnx2si_scalar_narrow */
    case 4065:  /* *pred_maddvnx2si */
    case 4087:  /* *pred_maccvnx2si */
    case 4109:  /* *pred_mul_plusvnx2si */
    case 4131:  /* *pred_maddvnx2si_scalar */
    case 4153:  /* *pred_maccvnx2si_scalar */
    case 4175:  /* *pred_mul_plusvnx2si_scalar */
    case 4209:  /* *pred_nmsubvnx2si */
    case 4231:  /* *pred_nmsacvnx2si */
    case 4253:  /* *pred_minus_mulvnx2si */
    case 4275:  /* *pred_nmsubvnx2si_scalar */
    case 4297:  /* *pred_nmsacvnx2si_scalar */
    case 4319:  /* *pred_minus_mulvnx2si_scalar */
    case 4363:  /* pred_widen_mul_plussvnx2di */
    case 4364:  /* pred_widen_mul_plusuvnx2di */
    case 4393:  /* pred_widen_mul_plussvnx2di_scalar */
    case 4394:  /* pred_widen_mul_plusuvnx2di_scalar */
    case 4411:  /* pred_widen_mul_plussuvnx2di */
    case 4426:  /* pred_widen_mul_plussuvnx2di_scalar */
    case 4441:  /* pred_widen_mul_plususvnx2di_scalar */
    case 4570:  /* pred_iotavnx2si */
    case 4592:  /* pred_seriesvnx2si */
    case 5267:  /* pred_widen_floatvnx2df */
    case 5268:  /* pred_widen_floatunsvnx2df */
    case 5289:  /* pred_narrow_fcvt_x_fvnx2df */
    case 5290:  /* pred_narrow_fcvt_xu_fvnx2df */
    case 5307:  /* pred_narrow_fix_truncvnx2df */
    case 5308:  /* pred_narrow_fixuns_truncvnx2df */
    case 5441:  /* pred_reduc_sumvnx2sivnx2si */
    case 5442:  /* pred_reduc_maxuvnx2sivnx2si */
    case 5443:  /* pred_reduc_maxvnx2sivnx2si */
    case 5444:  /* pred_reduc_minuvnx2sivnx2si */
    case 5445:  /* pred_reduc_minvnx2sivnx2si */
    case 5446:  /* pred_reduc_andvnx2sivnx2si */
    case 5447:  /* pred_reduc_orvnx2sivnx2si */
    case 5448:  /* pred_reduc_xorvnx2sivnx2si */
    case 5601:  /* pred_reduc_sumvnx2sivnx1si */
    case 5602:  /* pred_reduc_maxuvnx2sivnx1si */
    case 5603:  /* pred_reduc_maxvnx2sivnx1si */
    case 5604:  /* pred_reduc_minuvnx2sivnx1si */
    case 5605:  /* pred_reduc_minvnx2sivnx1si */
    case 5606:  /* pred_reduc_andvnx2sivnx1si */
    case 5607:  /* pred_reduc_orvnx2sivnx1si */
    case 5608:  /* pred_reduc_xorvnx2sivnx1si */
    case 5653:  /* pred_widen_reduc_plusvnx2sivnx2di */
    case 5654:  /* pred_widen_reduc_plusuvnx2sivnx2di */
    case 5759:  /* *pred_extract_firstvnx2si */
    case 5808:  /* pred_slideupvnx2si */
    case 5809:  /* pred_slidedownvnx2si */
    case 5870:  /* pred_slide1upvnx2si */
    case 5871:  /* pred_slide1downvnx2si */
    case 5926:  /* pred_gathervnx2si */
    case 5957:  /* pred_gathervnx2si_scalar */
    case 5987:  /* pred_gatherei16vnx2si */
    case 6018:  /* pred_compressvnx2si */
    case 6051:  /* pred_fault_loadvnx2si */
      return MODE_VNX2SI;

    case 733:  /* *movvnx1si_whole */
    case 756:  /* *movvnx1si_fract */
    case 813:  /* pred_movvnx1si */
    case 844:  /* pred_storevnx1si */
    case 889:  /* pred_mergevnx1si */
    case 920:  /* pred_mergevnx1si_scalar */
    case 946:  /* *pred_broadcastvnx1si */
    case 981:  /* pred_strided_loadvnx1si */
    case 1012:  /* pred_strided_storevnx1si */
    case 1056:  /* pred_indexed_oloadvnx1si_same_eew */
    case 1057:  /* pred_indexed_uloadvnx1si_same_eew */
    case 1104:  /* pred_indexed_oloadvnx1si_x2_greater_eew */
    case 1105:  /* pred_indexed_uloadvnx1si_x2_greater_eew */
    case 1140:  /* pred_indexed_oloadvnx1si_x4_greater_eew */
    case 1141:  /* pred_indexed_uloadvnx1si_x4_greater_eew */
    case 1214:  /* pred_indexed_oloadvnx1si_x2_smaller_eew */
    case 1215:  /* pred_indexed_uloadvnx1si_x2_smaller_eew */
    case 1272:  /* pred_indexed_ostorevnx1sivnx1qi */
    case 1273:  /* pred_indexed_ustorevnx1sivnx1qi */
    case 1274:  /* pred_indexed_ostorevnx1sivnx1hi */
    case 1275:  /* pred_indexed_ustorevnx1sivnx1hi */
    case 1276:  /* pred_indexed_ostorevnx1sivnx1si */
    case 1277:  /* pred_indexed_ustorevnx1sivnx1si */
    case 1278:  /* pred_indexed_ostorevnx1sivnx1di */
    case 1279:  /* pred_indexed_ustorevnx1sivnx1di */
    case 1703:  /* pred_addvnx1si */
    case 1704:  /* pred_subvnx1si */
    case 1705:  /* pred_andvnx1si */
    case 1706:  /* pred_iorvnx1si */
    case 1707:  /* pred_xorvnx1si */
    case 1708:  /* pred_ashlvnx1si */
    case 1709:  /* pred_ashrvnx1si */
    case 1710:  /* pred_lshrvnx1si */
    case 1711:  /* pred_smaxvnx1si */
    case 1712:  /* pred_umaxvnx1si */
    case 1713:  /* pred_sminvnx1si */
    case 1714:  /* pred_uminvnx1si */
    case 1715:  /* pred_mulvnx1si */
    case 1716:  /* pred_divvnx1si */
    case 1717:  /* pred_udivvnx1si */
    case 1718:  /* pred_modvnx1si */
    case 1719:  /* pred_umodvnx1si */
    case 1895:  /* pred_ashlvnx1si_scalar */
    case 1896:  /* pred_ashrvnx1si_scalar */
    case 1897:  /* pred_lshrvnx1si_scalar */
    case 2039:  /* pred_addvnx1si_scalar */
    case 2040:  /* pred_andvnx1si_scalar */
    case 2041:  /* pred_iorvnx1si_scalar */
    case 2042:  /* pred_xorvnx1si_scalar */
    case 2043:  /* pred_smaxvnx1si_scalar */
    case 2044:  /* pred_umaxvnx1si_scalar */
    case 2045:  /* pred_sminvnx1si_scalar */
    case 2046:  /* pred_uminvnx1si_scalar */
    case 2047:  /* pred_mulvnx1si_scalar */
    case 2149:  /* pred_subvnx1si_scalar */
    case 2150:  /* pred_divvnx1si_scalar */
    case 2151:  /* pred_udivvnx1si_scalar */
    case 2152:  /* pred_modvnx1si_scalar */
    case 2153:  /* pred_umodvnx1si_scalar */
    case 2187:  /* pred_subvnx1si_reverse_scalar */
    case 2351:  /* pred_mulhvnx1si */
    case 2352:  /* pred_mulhuvnx1si */
    case 2353:  /* pred_mulhsuvnx1si */
    case 2417:  /* pred_mulhvnx1si_scalar */
    case 2418:  /* pred_mulhuvnx1si_scalar */
    case 2419:  /* pred_mulhsuvnx1si_scalar */
    case 2469:  /* pred_adcvnx1si */
    case 2491:  /* pred_sbcvnx1si */
    case 2513:  /* pred_adcvnx1si_scalar */
    case 2531:  /* pred_sbcvnx1si_scalar */
    case 2565:  /* pred_madcvnx1si */
    case 2587:  /* pred_msbcvnx1si */
    case 2609:  /* pred_madcvnx1si_scalar */
    case 2627:  /* pred_msbcvnx1si_scalar */
    case 2661:  /* pred_madcvnx1si_overflow */
    case 2683:  /* pred_msbcvnx1si_overflow */
    case 2705:  /* pred_madcvnx1si_overflow_scalar */
    case 2723:  /* pred_msbcvnx1si_overflow_scalar */
    case 2770:  /* pred_negvnx1si */
    case 2771:  /* pred_one_cmplvnx1si */
    case 2800:  /* pred_extendvnx1si_vf2 */
    case 2801:  /* pred_zero_extendvnx1si_vf2 */
    case 2818:  /* pred_extendvnx1si_vf4 */
    case 2819:  /* pred_zero_extendvnx1si_vf4 */
    case 2910:  /* pred_dual_widen_addsvnx1di */
    case 2911:  /* pred_dual_widen_subsvnx1di */
    case 2912:  /* pred_dual_widen_mulsvnx1di */
    case 2913:  /* pred_dual_widen_adduvnx1di */
    case 2914:  /* pred_dual_widen_subuvnx1di */
    case 2915:  /* pred_dual_widen_muluvnx1di */
    case 3000:  /* pred_dual_widen_addsvnx1di_scalar */
    case 3001:  /* pred_dual_widen_subsvnx1di_scalar */
    case 3002:  /* pred_dual_widen_mulsvnx1di_scalar */
    case 3003:  /* pred_dual_widen_adduvnx1di_scalar */
    case 3004:  /* pred_dual_widen_subuvnx1di_scalar */
    case 3005:  /* pred_dual_widen_muluvnx1di_scalar */
    case 3068:  /* pred_single_widen_addsvnx1di */
    case 3069:  /* pred_single_widen_subsvnx1di */
    case 3070:  /* pred_single_widen_adduvnx1di */
    case 3071:  /* pred_single_widen_subuvnx1di */
    case 3128:  /* pred_single_widen_addsvnx1di_scalar */
    case 3129:  /* pred_single_widen_subsvnx1di_scalar */
    case 3130:  /* pred_single_widen_adduvnx1di_scalar */
    case 3131:  /* pred_single_widen_subuvnx1di_scalar */
    case 3155:  /* pred_widen_mulsuvnx1di */
    case 3170:  /* pred_widen_mulsuvnx1di_scalar */
    case 3196:  /* pred_extendvnx1di */
    case 3197:  /* pred_zero_extendvnx1di */
    case 3226:  /* pred_narrow_ashrvnx1di */
    case 3227:  /* pred_narrow_lshrvnx1di */
    case 3256:  /* pred_narrow_ashrvnx1di_scalar */
    case 3257:  /* pred_narrow_lshrvnx1di_scalar */
    case 3275:  /* pred_truncvnx1di */
    case 3331:  /* pred_ssaddvnx1si */
    case 3332:  /* pred_sssubvnx1si */
    case 3333:  /* pred_usaddvnx1si */
    case 3334:  /* pred_ussubvnx1si */
    case 3393:  /* pred_ssaddvnx1si_scalar */
    case 3394:  /* pred_usaddvnx1si_scalar */
    case 3429:  /* pred_sssubvnx1si_scalar */
    case 3430:  /* pred_ussubvnx1si_scalar */
    case 3562:  /* pred_aadduvnx1si */
    case 3563:  /* pred_aaddvnx1si */
    case 3564:  /* pred_asubuvnx1si */
    case 3565:  /* pred_asubvnx1si */
    case 3566:  /* pred_smulvnx1si */
    case 3567:  /* pred_ssrlvnx1si */
    case 3568:  /* pred_ssravnx1si */
    case 3690:  /* pred_aadduvnx1si_scalar */
    case 3691:  /* pred_aaddvnx1si_scalar */
    case 3692:  /* pred_asubuvnx1si_scalar */
    case 3693:  /* pred_asubvnx1si_scalar */
    case 3694:  /* pred_smulvnx1si_scalar */
    case 3741:  /* pred_ssrlvnx1si_scalar */
    case 3742:  /* pred_ssravnx1si_scalar */
    case 3821:  /* pred_narrow_clipvnx1di */
    case 3822:  /* pred_narrow_clipuvnx1di */
    case 3851:  /* pred_narrow_clipvnx1di_scalar */
    case 3852:  /* pred_narrow_clipuvnx1di_scalar */
    case 3872:  /* *pred_cmpvnx1si */
    case 3894:  /* *pred_cmpvnx1si_narrow */
    case 3916:  /* *pred_ltgevnx1si */
    case 3938:  /* *pred_ltgevnx1si_narrow */
    case 3960:  /* *pred_cmpvnx1si_scalar */
    case 3978:  /* *pred_cmpvnx1si_scalar_narrow */
    case 3996:  /* *pred_eqnevnx1si_scalar */
    case 4014:  /* *pred_eqnevnx1si_scalar_narrow */
    case 4064:  /* *pred_maddvnx1si */
    case 4086:  /* *pred_maccvnx1si */
    case 4108:  /* *pred_mul_plusvnx1si */
    case 4130:  /* *pred_maddvnx1si_scalar */
    case 4152:  /* *pred_maccvnx1si_scalar */
    case 4174:  /* *pred_mul_plusvnx1si_scalar */
    case 4208:  /* *pred_nmsubvnx1si */
    case 4230:  /* *pred_nmsacvnx1si */
    case 4252:  /* *pred_minus_mulvnx1si */
    case 4274:  /* *pred_nmsubvnx1si_scalar */
    case 4296:  /* *pred_nmsacvnx1si_scalar */
    case 4318:  /* *pred_minus_mulvnx1si_scalar */
    case 4361:  /* pred_widen_mul_plussvnx1di */
    case 4362:  /* pred_widen_mul_plusuvnx1di */
    case 4391:  /* pred_widen_mul_plussvnx1di_scalar */
    case 4392:  /* pred_widen_mul_plusuvnx1di_scalar */
    case 4410:  /* pred_widen_mul_plussuvnx1di */
    case 4425:  /* pred_widen_mul_plussuvnx1di_scalar */
    case 4440:  /* pred_widen_mul_plususvnx1di_scalar */
    case 4569:  /* pred_iotavnx1si */
    case 4591:  /* pred_seriesvnx1si */
    case 5265:  /* pred_widen_floatvnx1df */
    case 5266:  /* pred_widen_floatunsvnx1df */
    case 5287:  /* pred_narrow_fcvt_x_fvnx1df */
    case 5288:  /* pred_narrow_fcvt_xu_fvnx1df */
    case 5305:  /* pred_narrow_fix_truncvnx1df */
    case 5306:  /* pred_narrow_fixuns_truncvnx1df */
    case 5433:  /* pred_reduc_sumvnx1sivnx2si */
    case 5434:  /* pred_reduc_maxuvnx1sivnx2si */
    case 5435:  /* pred_reduc_maxvnx1sivnx2si */
    case 5436:  /* pred_reduc_minuvnx1sivnx2si */
    case 5437:  /* pred_reduc_minvnx1sivnx2si */
    case 5438:  /* pred_reduc_andvnx1sivnx2si */
    case 5439:  /* pred_reduc_orvnx1sivnx2si */
    case 5440:  /* pred_reduc_xorvnx1sivnx2si */
    case 5593:  /* pred_reduc_sumvnx1sivnx1si */
    case 5594:  /* pred_reduc_maxuvnx1sivnx1si */
    case 5595:  /* pred_reduc_maxvnx1sivnx1si */
    case 5596:  /* pred_reduc_minuvnx1sivnx1si */
    case 5597:  /* pred_reduc_minvnx1sivnx1si */
    case 5598:  /* pred_reduc_andvnx1sivnx1si */
    case 5599:  /* pred_reduc_orvnx1sivnx1si */
    case 5600:  /* pred_reduc_xorvnx1sivnx1si */
    case 5651:  /* pred_widen_reduc_plusvnx1sivnx2di */
    case 5652:  /* pred_widen_reduc_plusuvnx1sivnx2di */
    case 5758:  /* *pred_extract_firstvnx1si */
    case 5806:  /* pred_slideupvnx1si */
    case 5807:  /* pred_slidedownvnx1si */
    case 5868:  /* pred_slide1upvnx1si */
    case 5869:  /* pred_slide1downvnx1si */
    case 5925:  /* pred_gathervnx1si */
    case 5956:  /* pred_gathervnx1si_scalar */
    case 5986:  /* pred_gatherei16vnx1si */
    case 6017:  /* pred_compressvnx1si */
    case 6050:  /* pred_fault_loadvnx1si */
      return MODE_VNX1SI;

    case 732:  /* *movvnx32hi_whole */
    case 812:  /* pred_movvnx32hi */
    case 843:  /* pred_storevnx32hi */
    case 888:  /* pred_mergevnx32hi */
    case 919:  /* pred_mergevnx32hi_scalar */
    case 945:  /* *pred_broadcastvnx32hi */
    case 980:  /* pred_strided_loadvnx32hi */
    case 1011:  /* pred_strided_storevnx32hi */
    case 1054:  /* pred_indexed_oloadvnx32hi_same_eew */
    case 1055:  /* pred_indexed_uloadvnx32hi_same_eew */
    case 1102:  /* pred_indexed_oloadvnx32hi_x2_greater_eew */
    case 1103:  /* pred_indexed_uloadvnx32hi_x2_greater_eew */
    case 1476:  /* pred_indexed_ostorevnx32hivnx32qi */
    case 1477:  /* pred_indexed_ustorevnx32hivnx32qi */
    case 1478:  /* pred_indexed_ostorevnx32hivnx32hi */
    case 1479:  /* pred_indexed_ustorevnx32hivnx32hi */
    case 1686:  /* pred_addvnx32hi */
    case 1687:  /* pred_subvnx32hi */
    case 1688:  /* pred_andvnx32hi */
    case 1689:  /* pred_iorvnx32hi */
    case 1690:  /* pred_xorvnx32hi */
    case 1691:  /* pred_ashlvnx32hi */
    case 1692:  /* pred_ashrvnx32hi */
    case 1693:  /* pred_lshrvnx32hi */
    case 1694:  /* pred_smaxvnx32hi */
    case 1695:  /* pred_umaxvnx32hi */
    case 1696:  /* pred_sminvnx32hi */
    case 1697:  /* pred_uminvnx32hi */
    case 1698:  /* pred_mulvnx32hi */
    case 1699:  /* pred_divvnx32hi */
    case 1700:  /* pred_udivvnx32hi */
    case 1701:  /* pred_modvnx32hi */
    case 1702:  /* pred_umodvnx32hi */
    case 1892:  /* pred_ashlvnx32hi_scalar */
    case 1893:  /* pred_ashrvnx32hi_scalar */
    case 1894:  /* pred_lshrvnx32hi_scalar */
    case 2030:  /* pred_addvnx32hi_scalar */
    case 2031:  /* pred_andvnx32hi_scalar */
    case 2032:  /* pred_iorvnx32hi_scalar */
    case 2033:  /* pred_xorvnx32hi_scalar */
    case 2034:  /* pred_smaxvnx32hi_scalar */
    case 2035:  /* pred_umaxvnx32hi_scalar */
    case 2036:  /* pred_sminvnx32hi_scalar */
    case 2037:  /* pred_uminvnx32hi_scalar */
    case 2038:  /* pred_mulvnx32hi_scalar */
    case 2144:  /* pred_subvnx32hi_scalar */
    case 2145:  /* pred_divvnx32hi_scalar */
    case 2146:  /* pred_udivvnx32hi_scalar */
    case 2147:  /* pred_modvnx32hi_scalar */
    case 2148:  /* pred_umodvnx32hi_scalar */
    case 2186:  /* pred_subvnx32hi_reverse_scalar */
    case 2348:  /* pred_mulhvnx32hi */
    case 2349:  /* pred_mulhuvnx32hi */
    case 2350:  /* pred_mulhsuvnx32hi */
    case 2414:  /* pred_mulhvnx32hi_scalar */
    case 2415:  /* pred_mulhuvnx32hi_scalar */
    case 2416:  /* pred_mulhsuvnx32hi_scalar */
    case 2468:  /* pred_adcvnx32hi */
    case 2490:  /* pred_sbcvnx32hi */
    case 2512:  /* pred_adcvnx32hi_scalar */
    case 2530:  /* pred_sbcvnx32hi_scalar */
    case 2564:  /* pred_madcvnx32hi */
    case 2586:  /* pred_msbcvnx32hi */
    case 2608:  /* pred_madcvnx32hi_scalar */
    case 2626:  /* pred_msbcvnx32hi_scalar */
    case 2660:  /* pred_madcvnx32hi_overflow */
    case 2682:  /* pred_msbcvnx32hi_overflow */
    case 2704:  /* pred_madcvnx32hi_overflow_scalar */
    case 2722:  /* pred_msbcvnx32hi_overflow_scalar */
    case 2768:  /* pred_negvnx32hi */
    case 2769:  /* pred_one_cmplvnx32hi */
    case 2798:  /* pred_extendvnx32hi_vf2 */
    case 2799:  /* pred_zero_extendvnx32hi_vf2 */
    case 3327:  /* pred_ssaddvnx32hi */
    case 3328:  /* pred_sssubvnx32hi */
    case 3329:  /* pred_usaddvnx32hi */
    case 3330:  /* pred_ussubvnx32hi */
    case 3391:  /* pred_ssaddvnx32hi_scalar */
    case 3392:  /* pred_usaddvnx32hi_scalar */
    case 3427:  /* pred_sssubvnx32hi_scalar */
    case 3428:  /* pred_ussubvnx32hi_scalar */
    case 3555:  /* pred_aadduvnx32hi */
    case 3556:  /* pred_aaddvnx32hi */
    case 3557:  /* pred_asubuvnx32hi */
    case 3558:  /* pred_asubvnx32hi */
    case 3559:  /* pred_smulvnx32hi */
    case 3560:  /* pred_ssrlvnx32hi */
    case 3561:  /* pred_ssravnx32hi */
    case 3685:  /* pred_aadduvnx32hi_scalar */
    case 3686:  /* pred_aaddvnx32hi_scalar */
    case 3687:  /* pred_asubuvnx32hi_scalar */
    case 3688:  /* pred_asubvnx32hi_scalar */
    case 3689:  /* pred_smulvnx32hi_scalar */
    case 3739:  /* pred_ssrlvnx32hi_scalar */
    case 3740:  /* pred_ssravnx32hi_scalar */
    case 3871:  /* *pred_cmpvnx32hi */
    case 3893:  /* *pred_cmpvnx32hi_narrow */
    case 3915:  /* *pred_ltgevnx32hi */
    case 3937:  /* *pred_ltgevnx32hi_narrow */
    case 3959:  /* *pred_cmpvnx32hi_scalar */
    case 3977:  /* *pred_cmpvnx32hi_scalar_narrow */
    case 3995:  /* *pred_eqnevnx32hi_scalar */
    case 4013:  /* *pred_eqnevnx32hi_scalar_narrow */
    case 4063:  /* *pred_maddvnx32hi */
    case 4085:  /* *pred_maccvnx32hi */
    case 4107:  /* *pred_mul_plusvnx32hi */
    case 4129:  /* *pred_maddvnx32hi_scalar */
    case 4151:  /* *pred_maccvnx32hi_scalar */
    case 4173:  /* *pred_mul_plusvnx32hi_scalar */
    case 4207:  /* *pred_nmsubvnx32hi */
    case 4229:  /* *pred_nmsacvnx32hi */
    case 4251:  /* *pred_minus_mulvnx32hi */
    case 4273:  /* *pred_nmsubvnx32hi_scalar */
    case 4295:  /* *pred_nmsacvnx32hi_scalar */
    case 4317:  /* *pred_minus_mulvnx32hi_scalar */
    case 4568:  /* pred_iotavnx32hi */
    case 4590:  /* pred_seriesvnx32hi */
    case 5425:  /* pred_reduc_sumvnx32hivnx4hi */
    case 5426:  /* pred_reduc_maxuvnx32hivnx4hi */
    case 5427:  /* pred_reduc_maxvnx32hivnx4hi */
    case 5428:  /* pred_reduc_minuvnx32hivnx4hi */
    case 5429:  /* pred_reduc_minvnx32hivnx4hi */
    case 5430:  /* pred_reduc_andvnx32hivnx4hi */
    case 5431:  /* pred_reduc_orvnx32hivnx4hi */
    case 5432:  /* pred_reduc_xorvnx32hivnx4hi */
    case 5649:  /* pred_widen_reduc_plusvnx32hivnx2si */
    case 5650:  /* pred_widen_reduc_plusuvnx32hivnx2si */
    case 5757:  /* *pred_extract_firstvnx32hi */
    case 5804:  /* pred_slideupvnx32hi */
    case 5805:  /* pred_slidedownvnx32hi */
    case 5866:  /* pred_slide1upvnx32hi */
    case 5867:  /* pred_slide1downvnx32hi */
    case 5924:  /* pred_gathervnx32hi */
    case 5955:  /* pred_gathervnx32hi_scalar */
    case 5985:  /* pred_gatherei16vnx32hi */
    case 6016:  /* pred_compressvnx32hi */
    case 6049:  /* pred_fault_loadvnx32hi */
      return MODE_VNX32HI;

    case 731:  /* *movvnx16hi_whole */
    case 811:  /* pred_movvnx16hi */
    case 842:  /* pred_storevnx16hi */
    case 887:  /* pred_mergevnx16hi */
    case 918:  /* pred_mergevnx16hi_scalar */
    case 944:  /* *pred_broadcastvnx16hi */
    case 979:  /* pred_strided_loadvnx16hi */
    case 1010:  /* pred_strided_storevnx16hi */
    case 1052:  /* pred_indexed_oloadvnx16hi_same_eew */
    case 1053:  /* pred_indexed_uloadvnx16hi_same_eew */
    case 1100:  /* pred_indexed_oloadvnx16hi_x2_greater_eew */
    case 1101:  /* pred_indexed_uloadvnx16hi_x2_greater_eew */
    case 1212:  /* pred_indexed_oloadvnx16hi_x2_smaller_eew */
    case 1213:  /* pred_indexed_uloadvnx16hi_x2_smaller_eew */
    case 1450:  /* pred_indexed_ostorevnx16hivnx16qi */
    case 1451:  /* pred_indexed_ustorevnx16hivnx16qi */
    case 1458:  /* pred_indexed_ostorevnx16hivnx16hi */
    case 1459:  /* pred_indexed_ustorevnx16hivnx16hi */
    case 1466:  /* pred_indexed_ostorevnx16hivnx16si */
    case 1467:  /* pred_indexed_ustorevnx16hivnx16si */
    case 1669:  /* pred_addvnx16hi */
    case 1670:  /* pred_subvnx16hi */
    case 1671:  /* pred_andvnx16hi */
    case 1672:  /* pred_iorvnx16hi */
    case 1673:  /* pred_xorvnx16hi */
    case 1674:  /* pred_ashlvnx16hi */
    case 1675:  /* pred_ashrvnx16hi */
    case 1676:  /* pred_lshrvnx16hi */
    case 1677:  /* pred_smaxvnx16hi */
    case 1678:  /* pred_umaxvnx16hi */
    case 1679:  /* pred_sminvnx16hi */
    case 1680:  /* pred_uminvnx16hi */
    case 1681:  /* pred_mulvnx16hi */
    case 1682:  /* pred_divvnx16hi */
    case 1683:  /* pred_udivvnx16hi */
    case 1684:  /* pred_modvnx16hi */
    case 1685:  /* pred_umodvnx16hi */
    case 1889:  /* pred_ashlvnx16hi_scalar */
    case 1890:  /* pred_ashrvnx16hi_scalar */
    case 1891:  /* pred_lshrvnx16hi_scalar */
    case 2021:  /* pred_addvnx16hi_scalar */
    case 2022:  /* pred_andvnx16hi_scalar */
    case 2023:  /* pred_iorvnx16hi_scalar */
    case 2024:  /* pred_xorvnx16hi_scalar */
    case 2025:  /* pred_smaxvnx16hi_scalar */
    case 2026:  /* pred_umaxvnx16hi_scalar */
    case 2027:  /* pred_sminvnx16hi_scalar */
    case 2028:  /* pred_uminvnx16hi_scalar */
    case 2029:  /* pred_mulvnx16hi_scalar */
    case 2139:  /* pred_subvnx16hi_scalar */
    case 2140:  /* pred_divvnx16hi_scalar */
    case 2141:  /* pred_udivvnx16hi_scalar */
    case 2142:  /* pred_modvnx16hi_scalar */
    case 2143:  /* pred_umodvnx16hi_scalar */
    case 2185:  /* pred_subvnx16hi_reverse_scalar */
    case 2345:  /* pred_mulhvnx16hi */
    case 2346:  /* pred_mulhuvnx16hi */
    case 2347:  /* pred_mulhsuvnx16hi */
    case 2411:  /* pred_mulhvnx16hi_scalar */
    case 2412:  /* pred_mulhuvnx16hi_scalar */
    case 2413:  /* pred_mulhsuvnx16hi_scalar */
    case 2467:  /* pred_adcvnx16hi */
    case 2489:  /* pred_sbcvnx16hi */
    case 2511:  /* pred_adcvnx16hi_scalar */
    case 2529:  /* pred_sbcvnx16hi_scalar */
    case 2563:  /* pred_madcvnx16hi */
    case 2585:  /* pred_msbcvnx16hi */
    case 2607:  /* pred_madcvnx16hi_scalar */
    case 2625:  /* pred_msbcvnx16hi_scalar */
    case 2659:  /* pred_madcvnx16hi_overflow */
    case 2681:  /* pred_msbcvnx16hi_overflow */
    case 2703:  /* pred_madcvnx16hi_overflow_scalar */
    case 2721:  /* pred_msbcvnx16hi_overflow_scalar */
    case 2766:  /* pred_negvnx16hi */
    case 2767:  /* pred_one_cmplvnx16hi */
    case 2796:  /* pred_extendvnx16hi_vf2 */
    case 2797:  /* pred_zero_extendvnx16hi_vf2 */
    case 2904:  /* pred_dual_widen_addsvnx16si */
    case 2905:  /* pred_dual_widen_subsvnx16si */
    case 2906:  /* pred_dual_widen_mulsvnx16si */
    case 2907:  /* pred_dual_widen_adduvnx16si */
    case 2908:  /* pred_dual_widen_subuvnx16si */
    case 2909:  /* pred_dual_widen_muluvnx16si */
    case 2994:  /* pred_dual_widen_addsvnx16si_scalar */
    case 2995:  /* pred_dual_widen_subsvnx16si_scalar */
    case 2996:  /* pred_dual_widen_mulsvnx16si_scalar */
    case 2997:  /* pred_dual_widen_adduvnx16si_scalar */
    case 2998:  /* pred_dual_widen_subuvnx16si_scalar */
    case 2999:  /* pred_dual_widen_muluvnx16si_scalar */
    case 3064:  /* pred_single_widen_addsvnx16si */
    case 3065:  /* pred_single_widen_subsvnx16si */
    case 3066:  /* pred_single_widen_adduvnx16si */
    case 3067:  /* pred_single_widen_subuvnx16si */
    case 3124:  /* pred_single_widen_addsvnx16si_scalar */
    case 3125:  /* pred_single_widen_subsvnx16si_scalar */
    case 3126:  /* pred_single_widen_adduvnx16si_scalar */
    case 3127:  /* pred_single_widen_subuvnx16si_scalar */
    case 3154:  /* pred_widen_mulsuvnx16si */
    case 3169:  /* pred_widen_mulsuvnx16si_scalar */
    case 3194:  /* pred_extendvnx16si */
    case 3195:  /* pred_zero_extendvnx16si */
    case 3224:  /* pred_narrow_ashrvnx16si */
    case 3225:  /* pred_narrow_lshrvnx16si */
    case 3254:  /* pred_narrow_ashrvnx16si_scalar */
    case 3255:  /* pred_narrow_lshrvnx16si_scalar */
    case 3274:  /* pred_truncvnx16si */
    case 3323:  /* pred_ssaddvnx16hi */
    case 3324:  /* pred_sssubvnx16hi */
    case 3325:  /* pred_usaddvnx16hi */
    case 3326:  /* pred_ussubvnx16hi */
    case 3389:  /* pred_ssaddvnx16hi_scalar */
    case 3390:  /* pred_usaddvnx16hi_scalar */
    case 3425:  /* pred_sssubvnx16hi_scalar */
    case 3426:  /* pred_ussubvnx16hi_scalar */
    case 3548:  /* pred_aadduvnx16hi */
    case 3549:  /* pred_aaddvnx16hi */
    case 3550:  /* pred_asubuvnx16hi */
    case 3551:  /* pred_asubvnx16hi */
    case 3552:  /* pred_smulvnx16hi */
    case 3553:  /* pred_ssrlvnx16hi */
    case 3554:  /* pred_ssravnx16hi */
    case 3680:  /* pred_aadduvnx16hi_scalar */
    case 3681:  /* pred_aaddvnx16hi_scalar */
    case 3682:  /* pred_asubuvnx16hi_scalar */
    case 3683:  /* pred_asubvnx16hi_scalar */
    case 3684:  /* pred_smulvnx16hi_scalar */
    case 3737:  /* pred_ssrlvnx16hi_scalar */
    case 3738:  /* pred_ssravnx16hi_scalar */
    case 3819:  /* pred_narrow_clipvnx16si */
    case 3820:  /* pred_narrow_clipuvnx16si */
    case 3849:  /* pred_narrow_clipvnx16si_scalar */
    case 3850:  /* pred_narrow_clipuvnx16si_scalar */
    case 3870:  /* *pred_cmpvnx16hi */
    case 3892:  /* *pred_cmpvnx16hi_narrow */
    case 3914:  /* *pred_ltgevnx16hi */
    case 3936:  /* *pred_ltgevnx16hi_narrow */
    case 3958:  /* *pred_cmpvnx16hi_scalar */
    case 3976:  /* *pred_cmpvnx16hi_scalar_narrow */
    case 3994:  /* *pred_eqnevnx16hi_scalar */
    case 4012:  /* *pred_eqnevnx16hi_scalar_narrow */
    case 4062:  /* *pred_maddvnx16hi */
    case 4084:  /* *pred_maccvnx16hi */
    case 4106:  /* *pred_mul_plusvnx16hi */
    case 4128:  /* *pred_maddvnx16hi_scalar */
    case 4150:  /* *pred_maccvnx16hi_scalar */
    case 4172:  /* *pred_mul_plusvnx16hi_scalar */
    case 4206:  /* *pred_nmsubvnx16hi */
    case 4228:  /* *pred_nmsacvnx16hi */
    case 4250:  /* *pred_minus_mulvnx16hi */
    case 4272:  /* *pred_nmsubvnx16hi_scalar */
    case 4294:  /* *pred_nmsacvnx16hi_scalar */
    case 4316:  /* *pred_minus_mulvnx16hi_scalar */
    case 4359:  /* pred_widen_mul_plussvnx16si */
    case 4360:  /* pred_widen_mul_plusuvnx16si */
    case 4389:  /* pred_widen_mul_plussvnx16si_scalar */
    case 4390:  /* pred_widen_mul_plusuvnx16si_scalar */
    case 4409:  /* pred_widen_mul_plussuvnx16si */
    case 4424:  /* pred_widen_mul_plussuvnx16si_scalar */
    case 4439:  /* pred_widen_mul_plususvnx16si_scalar */
    case 4567:  /* pred_iotavnx16hi */
    case 4589:  /* pred_seriesvnx16hi */
    case 5263:  /* pred_widen_floatvnx16sf */
    case 5264:  /* pred_widen_floatunsvnx16sf */
    case 5285:  /* pred_narrow_fcvt_x_fvnx16sf */
    case 5286:  /* pred_narrow_fcvt_xu_fvnx16sf */
    case 5303:  /* pred_narrow_fix_truncvnx16sf */
    case 5304:  /* pred_narrow_fixuns_truncvnx16sf */
    case 5417:  /* pred_reduc_sumvnx16hivnx4hi */
    case 5418:  /* pred_reduc_maxuvnx16hivnx4hi */
    case 5419:  /* pred_reduc_maxvnx16hivnx4hi */
    case 5420:  /* pred_reduc_minuvnx16hivnx4hi */
    case 5421:  /* pred_reduc_minvnx16hivnx4hi */
    case 5422:  /* pred_reduc_andvnx16hivnx4hi */
    case 5423:  /* pred_reduc_orvnx16hivnx4hi */
    case 5424:  /* pred_reduc_xorvnx16hivnx4hi */
    case 5585:  /* pred_reduc_sumvnx16hivnx2hi */
    case 5586:  /* pred_reduc_maxuvnx16hivnx2hi */
    case 5587:  /* pred_reduc_maxvnx16hivnx2hi */
    case 5588:  /* pred_reduc_minuvnx16hivnx2hi */
    case 5589:  /* pred_reduc_minvnx16hivnx2hi */
    case 5590:  /* pred_reduc_andvnx16hivnx2hi */
    case 5591:  /* pred_reduc_orvnx16hivnx2hi */
    case 5592:  /* pred_reduc_xorvnx16hivnx2hi */
    case 5647:  /* pred_widen_reduc_plusvnx16hivnx2si */
    case 5648:  /* pred_widen_reduc_plusuvnx16hivnx2si */
    case 5681:  /* pred_widen_reduc_plusvnx16hivnx1si */
    case 5682:  /* pred_widen_reduc_plusuvnx16hivnx1si */
    case 5756:  /* *pred_extract_firstvnx16hi */
    case 5802:  /* pred_slideupvnx16hi */
    case 5803:  /* pred_slidedownvnx16hi */
    case 5864:  /* pred_slide1upvnx16hi */
    case 5865:  /* pred_slide1downvnx16hi */
    case 5923:  /* pred_gathervnx16hi */
    case 5954:  /* pred_gathervnx16hi_scalar */
    case 5984:  /* pred_gatherei16vnx16hi */
    case 6015:  /* pred_compressvnx16hi */
    case 6048:  /* pred_fault_loadvnx16hi */
      return MODE_VNX16HI;

    case 730:  /* *movvnx8hi_whole */
    case 810:  /* pred_movvnx8hi */
    case 841:  /* pred_storevnx8hi */
    case 886:  /* pred_mergevnx8hi */
    case 917:  /* pred_mergevnx8hi_scalar */
    case 943:  /* *pred_broadcastvnx8hi */
    case 978:  /* pred_strided_loadvnx8hi */
    case 1009:  /* pred_strided_storevnx8hi */
    case 1050:  /* pred_indexed_oloadvnx8hi_same_eew */
    case 1051:  /* pred_indexed_uloadvnx8hi_same_eew */
    case 1098:  /* pred_indexed_oloadvnx8hi_x2_greater_eew */
    case 1099:  /* pred_indexed_uloadvnx8hi_x2_greater_eew */
    case 1210:  /* pred_indexed_oloadvnx8hi_x2_smaller_eew */
    case 1211:  /* pred_indexed_uloadvnx8hi_x2_smaller_eew */
    case 1246:  /* pred_indexed_oloadvnx8hi_x4_smaller_eew */
    case 1247:  /* pred_indexed_uloadvnx8hi_x4_smaller_eew */
    case 1402:  /* pred_indexed_ostorevnx8hivnx8qi */
    case 1403:  /* pred_indexed_ustorevnx8hivnx8qi */
    case 1414:  /* pred_indexed_ostorevnx8hivnx8hi */
    case 1415:  /* pred_indexed_ustorevnx8hivnx8hi */
    case 1426:  /* pred_indexed_ostorevnx8hivnx8si */
    case 1427:  /* pred_indexed_ustorevnx8hivnx8si */
    case 1438:  /* pred_indexed_ostorevnx8hivnx8di */
    case 1439:  /* pred_indexed_ustorevnx8hivnx8di */
    case 1652:  /* pred_addvnx8hi */
    case 1653:  /* pred_subvnx8hi */
    case 1654:  /* pred_andvnx8hi */
    case 1655:  /* pred_iorvnx8hi */
    case 1656:  /* pred_xorvnx8hi */
    case 1657:  /* pred_ashlvnx8hi */
    case 1658:  /* pred_ashrvnx8hi */
    case 1659:  /* pred_lshrvnx8hi */
    case 1660:  /* pred_smaxvnx8hi */
    case 1661:  /* pred_umaxvnx8hi */
    case 1662:  /* pred_sminvnx8hi */
    case 1663:  /* pred_uminvnx8hi */
    case 1664:  /* pred_mulvnx8hi */
    case 1665:  /* pred_divvnx8hi */
    case 1666:  /* pred_udivvnx8hi */
    case 1667:  /* pred_modvnx8hi */
    case 1668:  /* pred_umodvnx8hi */
    case 1886:  /* pred_ashlvnx8hi_scalar */
    case 1887:  /* pred_ashrvnx8hi_scalar */
    case 1888:  /* pred_lshrvnx8hi_scalar */
    case 2012:  /* pred_addvnx8hi_scalar */
    case 2013:  /* pred_andvnx8hi_scalar */
    case 2014:  /* pred_iorvnx8hi_scalar */
    case 2015:  /* pred_xorvnx8hi_scalar */
    case 2016:  /* pred_smaxvnx8hi_scalar */
    case 2017:  /* pred_umaxvnx8hi_scalar */
    case 2018:  /* pred_sminvnx8hi_scalar */
    case 2019:  /* pred_uminvnx8hi_scalar */
    case 2020:  /* pred_mulvnx8hi_scalar */
    case 2134:  /* pred_subvnx8hi_scalar */
    case 2135:  /* pred_divvnx8hi_scalar */
    case 2136:  /* pred_udivvnx8hi_scalar */
    case 2137:  /* pred_modvnx8hi_scalar */
    case 2138:  /* pred_umodvnx8hi_scalar */
    case 2184:  /* pred_subvnx8hi_reverse_scalar */
    case 2342:  /* pred_mulhvnx8hi */
    case 2343:  /* pred_mulhuvnx8hi */
    case 2344:  /* pred_mulhsuvnx8hi */
    case 2408:  /* pred_mulhvnx8hi_scalar */
    case 2409:  /* pred_mulhuvnx8hi_scalar */
    case 2410:  /* pred_mulhsuvnx8hi_scalar */
    case 2466:  /* pred_adcvnx8hi */
    case 2488:  /* pred_sbcvnx8hi */
    case 2510:  /* pred_adcvnx8hi_scalar */
    case 2528:  /* pred_sbcvnx8hi_scalar */
    case 2562:  /* pred_madcvnx8hi */
    case 2584:  /* pred_msbcvnx8hi */
    case 2606:  /* pred_madcvnx8hi_scalar */
    case 2624:  /* pred_msbcvnx8hi_scalar */
    case 2658:  /* pred_madcvnx8hi_overflow */
    case 2680:  /* pred_msbcvnx8hi_overflow */
    case 2702:  /* pred_madcvnx8hi_overflow_scalar */
    case 2720:  /* pred_msbcvnx8hi_overflow_scalar */
    case 2764:  /* pred_negvnx8hi */
    case 2765:  /* pred_one_cmplvnx8hi */
    case 2794:  /* pred_extendvnx8hi_vf2 */
    case 2795:  /* pred_zero_extendvnx8hi_vf2 */
    case 2898:  /* pred_dual_widen_addsvnx8si */
    case 2899:  /* pred_dual_widen_subsvnx8si */
    case 2900:  /* pred_dual_widen_mulsvnx8si */
    case 2901:  /* pred_dual_widen_adduvnx8si */
    case 2902:  /* pred_dual_widen_subuvnx8si */
    case 2903:  /* pred_dual_widen_muluvnx8si */
    case 2988:  /* pred_dual_widen_addsvnx8si_scalar */
    case 2989:  /* pred_dual_widen_subsvnx8si_scalar */
    case 2990:  /* pred_dual_widen_mulsvnx8si_scalar */
    case 2991:  /* pred_dual_widen_adduvnx8si_scalar */
    case 2992:  /* pred_dual_widen_subuvnx8si_scalar */
    case 2993:  /* pred_dual_widen_muluvnx8si_scalar */
    case 3060:  /* pred_single_widen_addsvnx8si */
    case 3061:  /* pred_single_widen_subsvnx8si */
    case 3062:  /* pred_single_widen_adduvnx8si */
    case 3063:  /* pred_single_widen_subuvnx8si */
    case 3120:  /* pred_single_widen_addsvnx8si_scalar */
    case 3121:  /* pred_single_widen_subsvnx8si_scalar */
    case 3122:  /* pred_single_widen_adduvnx8si_scalar */
    case 3123:  /* pred_single_widen_subuvnx8si_scalar */
    case 3153:  /* pred_widen_mulsuvnx8si */
    case 3168:  /* pred_widen_mulsuvnx8si_scalar */
    case 3192:  /* pred_extendvnx8si */
    case 3193:  /* pred_zero_extendvnx8si */
    case 3222:  /* pred_narrow_ashrvnx8si */
    case 3223:  /* pred_narrow_lshrvnx8si */
    case 3252:  /* pred_narrow_ashrvnx8si_scalar */
    case 3253:  /* pred_narrow_lshrvnx8si_scalar */
    case 3273:  /* pred_truncvnx8si */
    case 3319:  /* pred_ssaddvnx8hi */
    case 3320:  /* pred_sssubvnx8hi */
    case 3321:  /* pred_usaddvnx8hi */
    case 3322:  /* pred_ussubvnx8hi */
    case 3387:  /* pred_ssaddvnx8hi_scalar */
    case 3388:  /* pred_usaddvnx8hi_scalar */
    case 3423:  /* pred_sssubvnx8hi_scalar */
    case 3424:  /* pred_ussubvnx8hi_scalar */
    case 3541:  /* pred_aadduvnx8hi */
    case 3542:  /* pred_aaddvnx8hi */
    case 3543:  /* pred_asubuvnx8hi */
    case 3544:  /* pred_asubvnx8hi */
    case 3545:  /* pred_smulvnx8hi */
    case 3546:  /* pred_ssrlvnx8hi */
    case 3547:  /* pred_ssravnx8hi */
    case 3675:  /* pred_aadduvnx8hi_scalar */
    case 3676:  /* pred_aaddvnx8hi_scalar */
    case 3677:  /* pred_asubuvnx8hi_scalar */
    case 3678:  /* pred_asubvnx8hi_scalar */
    case 3679:  /* pred_smulvnx8hi_scalar */
    case 3735:  /* pred_ssrlvnx8hi_scalar */
    case 3736:  /* pred_ssravnx8hi_scalar */
    case 3817:  /* pred_narrow_clipvnx8si */
    case 3818:  /* pred_narrow_clipuvnx8si */
    case 3847:  /* pred_narrow_clipvnx8si_scalar */
    case 3848:  /* pred_narrow_clipuvnx8si_scalar */
    case 3869:  /* *pred_cmpvnx8hi */
    case 3891:  /* *pred_cmpvnx8hi_narrow */
    case 3913:  /* *pred_ltgevnx8hi */
    case 3935:  /* *pred_ltgevnx8hi_narrow */
    case 3957:  /* *pred_cmpvnx8hi_scalar */
    case 3975:  /* *pred_cmpvnx8hi_scalar_narrow */
    case 3993:  /* *pred_eqnevnx8hi_scalar */
    case 4011:  /* *pred_eqnevnx8hi_scalar_narrow */
    case 4061:  /* *pred_maddvnx8hi */
    case 4083:  /* *pred_maccvnx8hi */
    case 4105:  /* *pred_mul_plusvnx8hi */
    case 4127:  /* *pred_maddvnx8hi_scalar */
    case 4149:  /* *pred_maccvnx8hi_scalar */
    case 4171:  /* *pred_mul_plusvnx8hi_scalar */
    case 4205:  /* *pred_nmsubvnx8hi */
    case 4227:  /* *pred_nmsacvnx8hi */
    case 4249:  /* *pred_minus_mulvnx8hi */
    case 4271:  /* *pred_nmsubvnx8hi_scalar */
    case 4293:  /* *pred_nmsacvnx8hi_scalar */
    case 4315:  /* *pred_minus_mulvnx8hi_scalar */
    case 4357:  /* pred_widen_mul_plussvnx8si */
    case 4358:  /* pred_widen_mul_plusuvnx8si */
    case 4387:  /* pred_widen_mul_plussvnx8si_scalar */
    case 4388:  /* pred_widen_mul_plusuvnx8si_scalar */
    case 4408:  /* pred_widen_mul_plussuvnx8si */
    case 4423:  /* pred_widen_mul_plussuvnx8si_scalar */
    case 4438:  /* pred_widen_mul_plususvnx8si_scalar */
    case 4566:  /* pred_iotavnx8hi */
    case 4588:  /* pred_seriesvnx8hi */
    case 5261:  /* pred_widen_floatvnx8sf */
    case 5262:  /* pred_widen_floatunsvnx8sf */
    case 5283:  /* pred_narrow_fcvt_x_fvnx8sf */
    case 5284:  /* pred_narrow_fcvt_xu_fvnx8sf */
    case 5301:  /* pred_narrow_fix_truncvnx8sf */
    case 5302:  /* pred_narrow_fixuns_truncvnx8sf */
    case 5409:  /* pred_reduc_sumvnx8hivnx4hi */
    case 5410:  /* pred_reduc_maxuvnx8hivnx4hi */
    case 5411:  /* pred_reduc_maxvnx8hivnx4hi */
    case 5412:  /* pred_reduc_minuvnx8hivnx4hi */
    case 5413:  /* pred_reduc_minvnx8hivnx4hi */
    case 5414:  /* pred_reduc_andvnx8hivnx4hi */
    case 5415:  /* pred_reduc_orvnx8hivnx4hi */
    case 5416:  /* pred_reduc_xorvnx8hivnx4hi */
    case 5577:  /* pred_reduc_sumvnx8hivnx2hi */
    case 5578:  /* pred_reduc_maxuvnx8hivnx2hi */
    case 5579:  /* pred_reduc_maxvnx8hivnx2hi */
    case 5580:  /* pred_reduc_minuvnx8hivnx2hi */
    case 5581:  /* pred_reduc_minvnx8hivnx2hi */
    case 5582:  /* pred_reduc_andvnx8hivnx2hi */
    case 5583:  /* pred_reduc_orvnx8hivnx2hi */
    case 5584:  /* pred_reduc_xorvnx8hivnx2hi */
    case 5645:  /* pred_widen_reduc_plusvnx8hivnx2si */
    case 5646:  /* pred_widen_reduc_plusuvnx8hivnx2si */
    case 5679:  /* pred_widen_reduc_plusvnx8hivnx1si */
    case 5680:  /* pred_widen_reduc_plusuvnx8hivnx1si */
    case 5755:  /* *pred_extract_firstvnx8hi */
    case 5800:  /* pred_slideupvnx8hi */
    case 5801:  /* pred_slidedownvnx8hi */
    case 5862:  /* pred_slide1upvnx8hi */
    case 5863:  /* pred_slide1downvnx8hi */
    case 5922:  /* pred_gathervnx8hi */
    case 5953:  /* pred_gathervnx8hi_scalar */
    case 5983:  /* pred_gatherei16vnx8hi */
    case 6014:  /* pred_compressvnx8hi */
    case 6047:  /* pred_fault_loadvnx8hi */
      return MODE_VNX8HI;

    case 729:  /* *movvnx4hi_whole */
    case 809:  /* pred_movvnx4hi */
    case 840:  /* pred_storevnx4hi */
    case 885:  /* pred_mergevnx4hi */
    case 916:  /* pred_mergevnx4hi_scalar */
    case 942:  /* *pred_broadcastvnx4hi */
    case 977:  /* pred_strided_loadvnx4hi */
    case 1008:  /* pred_strided_storevnx4hi */
    case 1048:  /* pred_indexed_oloadvnx4hi_same_eew */
    case 1049:  /* pred_indexed_uloadvnx4hi_same_eew */
    case 1096:  /* pred_indexed_oloadvnx4hi_x2_greater_eew */
    case 1097:  /* pred_indexed_uloadvnx4hi_x2_greater_eew */
    case 1208:  /* pred_indexed_oloadvnx4hi_x2_smaller_eew */
    case 1209:  /* pred_indexed_uloadvnx4hi_x2_smaller_eew */
    case 1244:  /* pred_indexed_oloadvnx4hi_x4_smaller_eew */
    case 1245:  /* pred_indexed_uloadvnx4hi_x4_smaller_eew */
    case 1354:  /* pred_indexed_ostorevnx4hivnx4qi */
    case 1355:  /* pred_indexed_ustorevnx4hivnx4qi */
    case 1366:  /* pred_indexed_ostorevnx4hivnx4hi */
    case 1367:  /* pred_indexed_ustorevnx4hivnx4hi */
    case 1378:  /* pred_indexed_ostorevnx4hivnx4si */
    case 1379:  /* pred_indexed_ustorevnx4hivnx4si */
    case 1390:  /* pred_indexed_ostorevnx4hivnx4di */
    case 1391:  /* pred_indexed_ustorevnx4hivnx4di */
    case 1635:  /* pred_addvnx4hi */
    case 1636:  /* pred_subvnx4hi */
    case 1637:  /* pred_andvnx4hi */
    case 1638:  /* pred_iorvnx4hi */
    case 1639:  /* pred_xorvnx4hi */
    case 1640:  /* pred_ashlvnx4hi */
    case 1641:  /* pred_ashrvnx4hi */
    case 1642:  /* pred_lshrvnx4hi */
    case 1643:  /* pred_smaxvnx4hi */
    case 1644:  /* pred_umaxvnx4hi */
    case 1645:  /* pred_sminvnx4hi */
    case 1646:  /* pred_uminvnx4hi */
    case 1647:  /* pred_mulvnx4hi */
    case 1648:  /* pred_divvnx4hi */
    case 1649:  /* pred_udivvnx4hi */
    case 1650:  /* pred_modvnx4hi */
    case 1651:  /* pred_umodvnx4hi */
    case 1883:  /* pred_ashlvnx4hi_scalar */
    case 1884:  /* pred_ashrvnx4hi_scalar */
    case 1885:  /* pred_lshrvnx4hi_scalar */
    case 2003:  /* pred_addvnx4hi_scalar */
    case 2004:  /* pred_andvnx4hi_scalar */
    case 2005:  /* pred_iorvnx4hi_scalar */
    case 2006:  /* pred_xorvnx4hi_scalar */
    case 2007:  /* pred_smaxvnx4hi_scalar */
    case 2008:  /* pred_umaxvnx4hi_scalar */
    case 2009:  /* pred_sminvnx4hi_scalar */
    case 2010:  /* pred_uminvnx4hi_scalar */
    case 2011:  /* pred_mulvnx4hi_scalar */
    case 2129:  /* pred_subvnx4hi_scalar */
    case 2130:  /* pred_divvnx4hi_scalar */
    case 2131:  /* pred_udivvnx4hi_scalar */
    case 2132:  /* pred_modvnx4hi_scalar */
    case 2133:  /* pred_umodvnx4hi_scalar */
    case 2183:  /* pred_subvnx4hi_reverse_scalar */
    case 2339:  /* pred_mulhvnx4hi */
    case 2340:  /* pred_mulhuvnx4hi */
    case 2341:  /* pred_mulhsuvnx4hi */
    case 2405:  /* pred_mulhvnx4hi_scalar */
    case 2406:  /* pred_mulhuvnx4hi_scalar */
    case 2407:  /* pred_mulhsuvnx4hi_scalar */
    case 2465:  /* pred_adcvnx4hi */
    case 2487:  /* pred_sbcvnx4hi */
    case 2509:  /* pred_adcvnx4hi_scalar */
    case 2527:  /* pred_sbcvnx4hi_scalar */
    case 2561:  /* pred_madcvnx4hi */
    case 2583:  /* pred_msbcvnx4hi */
    case 2605:  /* pred_madcvnx4hi_scalar */
    case 2623:  /* pred_msbcvnx4hi_scalar */
    case 2657:  /* pred_madcvnx4hi_overflow */
    case 2679:  /* pred_msbcvnx4hi_overflow */
    case 2701:  /* pred_madcvnx4hi_overflow_scalar */
    case 2719:  /* pred_msbcvnx4hi_overflow_scalar */
    case 2762:  /* pred_negvnx4hi */
    case 2763:  /* pred_one_cmplvnx4hi */
    case 2792:  /* pred_extendvnx4hi_vf2 */
    case 2793:  /* pred_zero_extendvnx4hi_vf2 */
    case 2892:  /* pred_dual_widen_addsvnx4si */
    case 2893:  /* pred_dual_widen_subsvnx4si */
    case 2894:  /* pred_dual_widen_mulsvnx4si */
    case 2895:  /* pred_dual_widen_adduvnx4si */
    case 2896:  /* pred_dual_widen_subuvnx4si */
    case 2897:  /* pred_dual_widen_muluvnx4si */
    case 2982:  /* pred_dual_widen_addsvnx4si_scalar */
    case 2983:  /* pred_dual_widen_subsvnx4si_scalar */
    case 2984:  /* pred_dual_widen_mulsvnx4si_scalar */
    case 2985:  /* pred_dual_widen_adduvnx4si_scalar */
    case 2986:  /* pred_dual_widen_subuvnx4si_scalar */
    case 2987:  /* pred_dual_widen_muluvnx4si_scalar */
    case 3056:  /* pred_single_widen_addsvnx4si */
    case 3057:  /* pred_single_widen_subsvnx4si */
    case 3058:  /* pred_single_widen_adduvnx4si */
    case 3059:  /* pred_single_widen_subuvnx4si */
    case 3116:  /* pred_single_widen_addsvnx4si_scalar */
    case 3117:  /* pred_single_widen_subsvnx4si_scalar */
    case 3118:  /* pred_single_widen_adduvnx4si_scalar */
    case 3119:  /* pred_single_widen_subuvnx4si_scalar */
    case 3152:  /* pred_widen_mulsuvnx4si */
    case 3167:  /* pred_widen_mulsuvnx4si_scalar */
    case 3190:  /* pred_extendvnx4si */
    case 3191:  /* pred_zero_extendvnx4si */
    case 3220:  /* pred_narrow_ashrvnx4si */
    case 3221:  /* pred_narrow_lshrvnx4si */
    case 3250:  /* pred_narrow_ashrvnx4si_scalar */
    case 3251:  /* pred_narrow_lshrvnx4si_scalar */
    case 3272:  /* pred_truncvnx4si */
    case 3315:  /* pred_ssaddvnx4hi */
    case 3316:  /* pred_sssubvnx4hi */
    case 3317:  /* pred_usaddvnx4hi */
    case 3318:  /* pred_ussubvnx4hi */
    case 3385:  /* pred_ssaddvnx4hi_scalar */
    case 3386:  /* pred_usaddvnx4hi_scalar */
    case 3421:  /* pred_sssubvnx4hi_scalar */
    case 3422:  /* pred_ussubvnx4hi_scalar */
    case 3534:  /* pred_aadduvnx4hi */
    case 3535:  /* pred_aaddvnx4hi */
    case 3536:  /* pred_asubuvnx4hi */
    case 3537:  /* pred_asubvnx4hi */
    case 3538:  /* pred_smulvnx4hi */
    case 3539:  /* pred_ssrlvnx4hi */
    case 3540:  /* pred_ssravnx4hi */
    case 3670:  /* pred_aadduvnx4hi_scalar */
    case 3671:  /* pred_aaddvnx4hi_scalar */
    case 3672:  /* pred_asubuvnx4hi_scalar */
    case 3673:  /* pred_asubvnx4hi_scalar */
    case 3674:  /* pred_smulvnx4hi_scalar */
    case 3733:  /* pred_ssrlvnx4hi_scalar */
    case 3734:  /* pred_ssravnx4hi_scalar */
    case 3815:  /* pred_narrow_clipvnx4si */
    case 3816:  /* pred_narrow_clipuvnx4si */
    case 3845:  /* pred_narrow_clipvnx4si_scalar */
    case 3846:  /* pred_narrow_clipuvnx4si_scalar */
    case 3868:  /* *pred_cmpvnx4hi */
    case 3890:  /* *pred_cmpvnx4hi_narrow */
    case 3912:  /* *pred_ltgevnx4hi */
    case 3934:  /* *pred_ltgevnx4hi_narrow */
    case 3956:  /* *pred_cmpvnx4hi_scalar */
    case 3974:  /* *pred_cmpvnx4hi_scalar_narrow */
    case 3992:  /* *pred_eqnevnx4hi_scalar */
    case 4010:  /* *pred_eqnevnx4hi_scalar_narrow */
    case 4060:  /* *pred_maddvnx4hi */
    case 4082:  /* *pred_maccvnx4hi */
    case 4104:  /* *pred_mul_plusvnx4hi */
    case 4126:  /* *pred_maddvnx4hi_scalar */
    case 4148:  /* *pred_maccvnx4hi_scalar */
    case 4170:  /* *pred_mul_plusvnx4hi_scalar */
    case 4204:  /* *pred_nmsubvnx4hi */
    case 4226:  /* *pred_nmsacvnx4hi */
    case 4248:  /* *pred_minus_mulvnx4hi */
    case 4270:  /* *pred_nmsubvnx4hi_scalar */
    case 4292:  /* *pred_nmsacvnx4hi_scalar */
    case 4314:  /* *pred_minus_mulvnx4hi_scalar */
    case 4355:  /* pred_widen_mul_plussvnx4si */
    case 4356:  /* pred_widen_mul_plusuvnx4si */
    case 4385:  /* pred_widen_mul_plussvnx4si_scalar */
    case 4386:  /* pred_widen_mul_plusuvnx4si_scalar */
    case 4407:  /* pred_widen_mul_plussuvnx4si */
    case 4422:  /* pred_widen_mul_plussuvnx4si_scalar */
    case 4437:  /* pred_widen_mul_plususvnx4si_scalar */
    case 4565:  /* pred_iotavnx4hi */
    case 4587:  /* pred_seriesvnx4hi */
    case 5259:  /* pred_widen_floatvnx4sf */
    case 5260:  /* pred_widen_floatunsvnx4sf */
    case 5281:  /* pred_narrow_fcvt_x_fvnx4sf */
    case 5282:  /* pred_narrow_fcvt_xu_fvnx4sf */
    case 5299:  /* pred_narrow_fix_truncvnx4sf */
    case 5300:  /* pred_narrow_fixuns_truncvnx4sf */
    case 5401:  /* pred_reduc_sumvnx4hivnx4hi */
    case 5402:  /* pred_reduc_maxuvnx4hivnx4hi */
    case 5403:  /* pred_reduc_maxvnx4hivnx4hi */
    case 5404:  /* pred_reduc_minuvnx4hivnx4hi */
    case 5405:  /* pred_reduc_minvnx4hivnx4hi */
    case 5406:  /* pred_reduc_andvnx4hivnx4hi */
    case 5407:  /* pred_reduc_orvnx4hivnx4hi */
    case 5408:  /* pred_reduc_xorvnx4hivnx4hi */
    case 5569:  /* pred_reduc_sumvnx4hivnx2hi */
    case 5570:  /* pred_reduc_maxuvnx4hivnx2hi */
    case 5571:  /* pred_reduc_maxvnx4hivnx2hi */
    case 5572:  /* pred_reduc_minuvnx4hivnx2hi */
    case 5573:  /* pred_reduc_minvnx4hivnx2hi */
    case 5574:  /* pred_reduc_andvnx4hivnx2hi */
    case 5575:  /* pred_reduc_orvnx4hivnx2hi */
    case 5576:  /* pred_reduc_xorvnx4hivnx2hi */
    case 5643:  /* pred_widen_reduc_plusvnx4hivnx2si */
    case 5644:  /* pred_widen_reduc_plusuvnx4hivnx2si */
    case 5677:  /* pred_widen_reduc_plusvnx4hivnx1si */
    case 5678:  /* pred_widen_reduc_plusuvnx4hivnx1si */
    case 5754:  /* *pred_extract_firstvnx4hi */
    case 5798:  /* pred_slideupvnx4hi */
    case 5799:  /* pred_slidedownvnx4hi */
    case 5860:  /* pred_slide1upvnx4hi */
    case 5861:  /* pred_slide1downvnx4hi */
    case 5921:  /* pred_gathervnx4hi */
    case 5952:  /* pred_gathervnx4hi_scalar */
    case 5982:  /* pred_gatherei16vnx4hi */
    case 6013:  /* pred_compressvnx4hi */
    case 6046:  /* pred_fault_loadvnx4hi */
      return MODE_VNX4HI;

    case 728:  /* *movvnx2hi_whole */
    case 755:  /* *movvnx2hi_fract */
    case 808:  /* pred_movvnx2hi */
    case 839:  /* pred_storevnx2hi */
    case 884:  /* pred_mergevnx2hi */
    case 915:  /* pred_mergevnx2hi_scalar */
    case 941:  /* *pred_broadcastvnx2hi */
    case 976:  /* pred_strided_loadvnx2hi */
    case 1007:  /* pred_strided_storevnx2hi */
    case 1046:  /* pred_indexed_oloadvnx2hi_same_eew */
    case 1047:  /* pred_indexed_uloadvnx2hi_same_eew */
    case 1094:  /* pred_indexed_oloadvnx2hi_x2_greater_eew */
    case 1095:  /* pred_indexed_uloadvnx2hi_x2_greater_eew */
    case 1206:  /* pred_indexed_oloadvnx2hi_x2_smaller_eew */
    case 1207:  /* pred_indexed_uloadvnx2hi_x2_smaller_eew */
    case 1242:  /* pred_indexed_oloadvnx2hi_x4_smaller_eew */
    case 1243:  /* pred_indexed_uloadvnx2hi_x4_smaller_eew */
    case 1306:  /* pred_indexed_ostorevnx2hivnx2qi */
    case 1307:  /* pred_indexed_ustorevnx2hivnx2qi */
    case 1318:  /* pred_indexed_ostorevnx2hivnx2hi */
    case 1319:  /* pred_indexed_ustorevnx2hivnx2hi */
    case 1330:  /* pred_indexed_ostorevnx2hivnx2si */
    case 1331:  /* pred_indexed_ustorevnx2hivnx2si */
    case 1342:  /* pred_indexed_ostorevnx2hivnx2di */
    case 1343:  /* pred_indexed_ustorevnx2hivnx2di */
    case 1618:  /* pred_addvnx2hi */
    case 1619:  /* pred_subvnx2hi */
    case 1620:  /* pred_andvnx2hi */
    case 1621:  /* pred_iorvnx2hi */
    case 1622:  /* pred_xorvnx2hi */
    case 1623:  /* pred_ashlvnx2hi */
    case 1624:  /* pred_ashrvnx2hi */
    case 1625:  /* pred_lshrvnx2hi */
    case 1626:  /* pred_smaxvnx2hi */
    case 1627:  /* pred_umaxvnx2hi */
    case 1628:  /* pred_sminvnx2hi */
    case 1629:  /* pred_uminvnx2hi */
    case 1630:  /* pred_mulvnx2hi */
    case 1631:  /* pred_divvnx2hi */
    case 1632:  /* pred_udivvnx2hi */
    case 1633:  /* pred_modvnx2hi */
    case 1634:  /* pred_umodvnx2hi */
    case 1880:  /* pred_ashlvnx2hi_scalar */
    case 1881:  /* pred_ashrvnx2hi_scalar */
    case 1882:  /* pred_lshrvnx2hi_scalar */
    case 1994:  /* pred_addvnx2hi_scalar */
    case 1995:  /* pred_andvnx2hi_scalar */
    case 1996:  /* pred_iorvnx2hi_scalar */
    case 1997:  /* pred_xorvnx2hi_scalar */
    case 1998:  /* pred_smaxvnx2hi_scalar */
    case 1999:  /* pred_umaxvnx2hi_scalar */
    case 2000:  /* pred_sminvnx2hi_scalar */
    case 2001:  /* pred_uminvnx2hi_scalar */
    case 2002:  /* pred_mulvnx2hi_scalar */
    case 2124:  /* pred_subvnx2hi_scalar */
    case 2125:  /* pred_divvnx2hi_scalar */
    case 2126:  /* pred_udivvnx2hi_scalar */
    case 2127:  /* pred_modvnx2hi_scalar */
    case 2128:  /* pred_umodvnx2hi_scalar */
    case 2182:  /* pred_subvnx2hi_reverse_scalar */
    case 2336:  /* pred_mulhvnx2hi */
    case 2337:  /* pred_mulhuvnx2hi */
    case 2338:  /* pred_mulhsuvnx2hi */
    case 2402:  /* pred_mulhvnx2hi_scalar */
    case 2403:  /* pred_mulhuvnx2hi_scalar */
    case 2404:  /* pred_mulhsuvnx2hi_scalar */
    case 2464:  /* pred_adcvnx2hi */
    case 2486:  /* pred_sbcvnx2hi */
    case 2508:  /* pred_adcvnx2hi_scalar */
    case 2526:  /* pred_sbcvnx2hi_scalar */
    case 2560:  /* pred_madcvnx2hi */
    case 2582:  /* pred_msbcvnx2hi */
    case 2604:  /* pred_madcvnx2hi_scalar */
    case 2622:  /* pred_msbcvnx2hi_scalar */
    case 2656:  /* pred_madcvnx2hi_overflow */
    case 2678:  /* pred_msbcvnx2hi_overflow */
    case 2700:  /* pred_madcvnx2hi_overflow_scalar */
    case 2718:  /* pred_msbcvnx2hi_overflow_scalar */
    case 2760:  /* pred_negvnx2hi */
    case 2761:  /* pred_one_cmplvnx2hi */
    case 2790:  /* pred_extendvnx2hi_vf2 */
    case 2791:  /* pred_zero_extendvnx2hi_vf2 */
    case 2886:  /* pred_dual_widen_addsvnx2si */
    case 2887:  /* pred_dual_widen_subsvnx2si */
    case 2888:  /* pred_dual_widen_mulsvnx2si */
    case 2889:  /* pred_dual_widen_adduvnx2si */
    case 2890:  /* pred_dual_widen_subuvnx2si */
    case 2891:  /* pred_dual_widen_muluvnx2si */
    case 2976:  /* pred_dual_widen_addsvnx2si_scalar */
    case 2977:  /* pred_dual_widen_subsvnx2si_scalar */
    case 2978:  /* pred_dual_widen_mulsvnx2si_scalar */
    case 2979:  /* pred_dual_widen_adduvnx2si_scalar */
    case 2980:  /* pred_dual_widen_subuvnx2si_scalar */
    case 2981:  /* pred_dual_widen_muluvnx2si_scalar */
    case 3052:  /* pred_single_widen_addsvnx2si */
    case 3053:  /* pred_single_widen_subsvnx2si */
    case 3054:  /* pred_single_widen_adduvnx2si */
    case 3055:  /* pred_single_widen_subuvnx2si */
    case 3112:  /* pred_single_widen_addsvnx2si_scalar */
    case 3113:  /* pred_single_widen_subsvnx2si_scalar */
    case 3114:  /* pred_single_widen_adduvnx2si_scalar */
    case 3115:  /* pred_single_widen_subuvnx2si_scalar */
    case 3151:  /* pred_widen_mulsuvnx2si */
    case 3166:  /* pred_widen_mulsuvnx2si_scalar */
    case 3188:  /* pred_extendvnx2si */
    case 3189:  /* pred_zero_extendvnx2si */
    case 3218:  /* pred_narrow_ashrvnx2si */
    case 3219:  /* pred_narrow_lshrvnx2si */
    case 3248:  /* pred_narrow_ashrvnx2si_scalar */
    case 3249:  /* pred_narrow_lshrvnx2si_scalar */
    case 3271:  /* pred_truncvnx2si */
    case 3311:  /* pred_ssaddvnx2hi */
    case 3312:  /* pred_sssubvnx2hi */
    case 3313:  /* pred_usaddvnx2hi */
    case 3314:  /* pred_ussubvnx2hi */
    case 3383:  /* pred_ssaddvnx2hi_scalar */
    case 3384:  /* pred_usaddvnx2hi_scalar */
    case 3419:  /* pred_sssubvnx2hi_scalar */
    case 3420:  /* pred_ussubvnx2hi_scalar */
    case 3527:  /* pred_aadduvnx2hi */
    case 3528:  /* pred_aaddvnx2hi */
    case 3529:  /* pred_asubuvnx2hi */
    case 3530:  /* pred_asubvnx2hi */
    case 3531:  /* pred_smulvnx2hi */
    case 3532:  /* pred_ssrlvnx2hi */
    case 3533:  /* pred_ssravnx2hi */
    case 3665:  /* pred_aadduvnx2hi_scalar */
    case 3666:  /* pred_aaddvnx2hi_scalar */
    case 3667:  /* pred_asubuvnx2hi_scalar */
    case 3668:  /* pred_asubvnx2hi_scalar */
    case 3669:  /* pred_smulvnx2hi_scalar */
    case 3731:  /* pred_ssrlvnx2hi_scalar */
    case 3732:  /* pred_ssravnx2hi_scalar */
    case 3813:  /* pred_narrow_clipvnx2si */
    case 3814:  /* pred_narrow_clipuvnx2si */
    case 3843:  /* pred_narrow_clipvnx2si_scalar */
    case 3844:  /* pred_narrow_clipuvnx2si_scalar */
    case 3867:  /* *pred_cmpvnx2hi */
    case 3889:  /* *pred_cmpvnx2hi_narrow */
    case 3911:  /* *pred_ltgevnx2hi */
    case 3933:  /* *pred_ltgevnx2hi_narrow */
    case 3955:  /* *pred_cmpvnx2hi_scalar */
    case 3973:  /* *pred_cmpvnx2hi_scalar_narrow */
    case 3991:  /* *pred_eqnevnx2hi_scalar */
    case 4009:  /* *pred_eqnevnx2hi_scalar_narrow */
    case 4059:  /* *pred_maddvnx2hi */
    case 4081:  /* *pred_maccvnx2hi */
    case 4103:  /* *pred_mul_plusvnx2hi */
    case 4125:  /* *pred_maddvnx2hi_scalar */
    case 4147:  /* *pred_maccvnx2hi_scalar */
    case 4169:  /* *pred_mul_plusvnx2hi_scalar */
    case 4203:  /* *pred_nmsubvnx2hi */
    case 4225:  /* *pred_nmsacvnx2hi */
    case 4247:  /* *pred_minus_mulvnx2hi */
    case 4269:  /* *pred_nmsubvnx2hi_scalar */
    case 4291:  /* *pred_nmsacvnx2hi_scalar */
    case 4313:  /* *pred_minus_mulvnx2hi_scalar */
    case 4353:  /* pred_widen_mul_plussvnx2si */
    case 4354:  /* pred_widen_mul_plusuvnx2si */
    case 4383:  /* pred_widen_mul_plussvnx2si_scalar */
    case 4384:  /* pred_widen_mul_plusuvnx2si_scalar */
    case 4406:  /* pred_widen_mul_plussuvnx2si */
    case 4421:  /* pred_widen_mul_plussuvnx2si_scalar */
    case 4436:  /* pred_widen_mul_plususvnx2si_scalar */
    case 4564:  /* pred_iotavnx2hi */
    case 4586:  /* pred_seriesvnx2hi */
    case 5257:  /* pred_widen_floatvnx2sf */
    case 5258:  /* pred_widen_floatunsvnx2sf */
    case 5279:  /* pred_narrow_fcvt_x_fvnx2sf */
    case 5280:  /* pred_narrow_fcvt_xu_fvnx2sf */
    case 5297:  /* pred_narrow_fix_truncvnx2sf */
    case 5298:  /* pred_narrow_fixuns_truncvnx2sf */
    case 5393:  /* pred_reduc_sumvnx2hivnx4hi */
    case 5394:  /* pred_reduc_maxuvnx2hivnx4hi */
    case 5395:  /* pred_reduc_maxvnx2hivnx4hi */
    case 5396:  /* pred_reduc_minuvnx2hivnx4hi */
    case 5397:  /* pred_reduc_minvnx2hivnx4hi */
    case 5398:  /* pred_reduc_andvnx2hivnx4hi */
    case 5399:  /* pred_reduc_orvnx2hivnx4hi */
    case 5400:  /* pred_reduc_xorvnx2hivnx4hi */
    case 5561:  /* pred_reduc_sumvnx2hivnx2hi */
    case 5562:  /* pred_reduc_maxuvnx2hivnx2hi */
    case 5563:  /* pred_reduc_maxvnx2hivnx2hi */
    case 5564:  /* pred_reduc_minuvnx2hivnx2hi */
    case 5565:  /* pred_reduc_minvnx2hivnx2hi */
    case 5566:  /* pred_reduc_andvnx2hivnx2hi */
    case 5567:  /* pred_reduc_orvnx2hivnx2hi */
    case 5568:  /* pred_reduc_xorvnx2hivnx2hi */
    case 5641:  /* pred_widen_reduc_plusvnx2hivnx2si */
    case 5642:  /* pred_widen_reduc_plusuvnx2hivnx2si */
    case 5675:  /* pred_widen_reduc_plusvnx2hivnx1si */
    case 5676:  /* pred_widen_reduc_plusuvnx2hivnx1si */
    case 5753:  /* *pred_extract_firstvnx2hi */
    case 5796:  /* pred_slideupvnx2hi */
    case 5797:  /* pred_slidedownvnx2hi */
    case 5858:  /* pred_slide1upvnx2hi */
    case 5859:  /* pred_slide1downvnx2hi */
    case 5920:  /* pred_gathervnx2hi */
    case 5951:  /* pred_gathervnx2hi_scalar */
    case 5981:  /* pred_gatherei16vnx2hi */
    case 6012:  /* pred_compressvnx2hi */
    case 6045:  /* pred_fault_loadvnx2hi */
      return MODE_VNX2HI;

    case 754:  /* *movvnx1hi_fract */
    case 807:  /* pred_movvnx1hi */
    case 838:  /* pred_storevnx1hi */
    case 883:  /* pred_mergevnx1hi */
    case 914:  /* pred_mergevnx1hi_scalar */
    case 940:  /* *pred_broadcastvnx1hi */
    case 975:  /* pred_strided_loadvnx1hi */
    case 1006:  /* pred_strided_storevnx1hi */
    case 1044:  /* pred_indexed_oloadvnx1hi_same_eew */
    case 1045:  /* pred_indexed_uloadvnx1hi_same_eew */
    case 1092:  /* pred_indexed_oloadvnx1hi_x2_greater_eew */
    case 1093:  /* pred_indexed_uloadvnx1hi_x2_greater_eew */
    case 1204:  /* pred_indexed_oloadvnx1hi_x2_smaller_eew */
    case 1205:  /* pred_indexed_uloadvnx1hi_x2_smaller_eew */
    case 1240:  /* pred_indexed_oloadvnx1hi_x4_smaller_eew */
    case 1241:  /* pred_indexed_uloadvnx1hi_x4_smaller_eew */
    case 1264:  /* pred_indexed_ostorevnx1hivnx1qi */
    case 1265:  /* pred_indexed_ustorevnx1hivnx1qi */
    case 1266:  /* pred_indexed_ostorevnx1hivnx1hi */
    case 1267:  /* pred_indexed_ustorevnx1hivnx1hi */
    case 1268:  /* pred_indexed_ostorevnx1hivnx1si */
    case 1269:  /* pred_indexed_ustorevnx1hivnx1si */
    case 1270:  /* pred_indexed_ostorevnx1hivnx1di */
    case 1271:  /* pred_indexed_ustorevnx1hivnx1di */
    case 1601:  /* pred_addvnx1hi */
    case 1602:  /* pred_subvnx1hi */
    case 1603:  /* pred_andvnx1hi */
    case 1604:  /* pred_iorvnx1hi */
    case 1605:  /* pred_xorvnx1hi */
    case 1606:  /* pred_ashlvnx1hi */
    case 1607:  /* pred_ashrvnx1hi */
    case 1608:  /* pred_lshrvnx1hi */
    case 1609:  /* pred_smaxvnx1hi */
    case 1610:  /* pred_umaxvnx1hi */
    case 1611:  /* pred_sminvnx1hi */
    case 1612:  /* pred_uminvnx1hi */
    case 1613:  /* pred_mulvnx1hi */
    case 1614:  /* pred_divvnx1hi */
    case 1615:  /* pred_udivvnx1hi */
    case 1616:  /* pred_modvnx1hi */
    case 1617:  /* pred_umodvnx1hi */
    case 1877:  /* pred_ashlvnx1hi_scalar */
    case 1878:  /* pred_ashrvnx1hi_scalar */
    case 1879:  /* pred_lshrvnx1hi_scalar */
    case 1985:  /* pred_addvnx1hi_scalar */
    case 1986:  /* pred_andvnx1hi_scalar */
    case 1987:  /* pred_iorvnx1hi_scalar */
    case 1988:  /* pred_xorvnx1hi_scalar */
    case 1989:  /* pred_smaxvnx1hi_scalar */
    case 1990:  /* pred_umaxvnx1hi_scalar */
    case 1991:  /* pred_sminvnx1hi_scalar */
    case 1992:  /* pred_uminvnx1hi_scalar */
    case 1993:  /* pred_mulvnx1hi_scalar */
    case 2119:  /* pred_subvnx1hi_scalar */
    case 2120:  /* pred_divvnx1hi_scalar */
    case 2121:  /* pred_udivvnx1hi_scalar */
    case 2122:  /* pred_modvnx1hi_scalar */
    case 2123:  /* pred_umodvnx1hi_scalar */
    case 2181:  /* pred_subvnx1hi_reverse_scalar */
    case 2333:  /* pred_mulhvnx1hi */
    case 2334:  /* pred_mulhuvnx1hi */
    case 2335:  /* pred_mulhsuvnx1hi */
    case 2399:  /* pred_mulhvnx1hi_scalar */
    case 2400:  /* pred_mulhuvnx1hi_scalar */
    case 2401:  /* pred_mulhsuvnx1hi_scalar */
    case 2463:  /* pred_adcvnx1hi */
    case 2485:  /* pred_sbcvnx1hi */
    case 2507:  /* pred_adcvnx1hi_scalar */
    case 2525:  /* pred_sbcvnx1hi_scalar */
    case 2559:  /* pred_madcvnx1hi */
    case 2581:  /* pred_msbcvnx1hi */
    case 2603:  /* pred_madcvnx1hi_scalar */
    case 2621:  /* pred_msbcvnx1hi_scalar */
    case 2655:  /* pred_madcvnx1hi_overflow */
    case 2677:  /* pred_msbcvnx1hi_overflow */
    case 2699:  /* pred_madcvnx1hi_overflow_scalar */
    case 2717:  /* pred_msbcvnx1hi_overflow_scalar */
    case 2758:  /* pred_negvnx1hi */
    case 2759:  /* pred_one_cmplvnx1hi */
    case 2788:  /* pred_extendvnx1hi_vf2 */
    case 2789:  /* pred_zero_extendvnx1hi_vf2 */
    case 2880:  /* pred_dual_widen_addsvnx1si */
    case 2881:  /* pred_dual_widen_subsvnx1si */
    case 2882:  /* pred_dual_widen_mulsvnx1si */
    case 2883:  /* pred_dual_widen_adduvnx1si */
    case 2884:  /* pred_dual_widen_subuvnx1si */
    case 2885:  /* pred_dual_widen_muluvnx1si */
    case 2970:  /* pred_dual_widen_addsvnx1si_scalar */
    case 2971:  /* pred_dual_widen_subsvnx1si_scalar */
    case 2972:  /* pred_dual_widen_mulsvnx1si_scalar */
    case 2973:  /* pred_dual_widen_adduvnx1si_scalar */
    case 2974:  /* pred_dual_widen_subuvnx1si_scalar */
    case 2975:  /* pred_dual_widen_muluvnx1si_scalar */
    case 3048:  /* pred_single_widen_addsvnx1si */
    case 3049:  /* pred_single_widen_subsvnx1si */
    case 3050:  /* pred_single_widen_adduvnx1si */
    case 3051:  /* pred_single_widen_subuvnx1si */
    case 3108:  /* pred_single_widen_addsvnx1si_scalar */
    case 3109:  /* pred_single_widen_subsvnx1si_scalar */
    case 3110:  /* pred_single_widen_adduvnx1si_scalar */
    case 3111:  /* pred_single_widen_subuvnx1si_scalar */
    case 3150:  /* pred_widen_mulsuvnx1si */
    case 3165:  /* pred_widen_mulsuvnx1si_scalar */
    case 3186:  /* pred_extendvnx1si */
    case 3187:  /* pred_zero_extendvnx1si */
    case 3216:  /* pred_narrow_ashrvnx1si */
    case 3217:  /* pred_narrow_lshrvnx1si */
    case 3246:  /* pred_narrow_ashrvnx1si_scalar */
    case 3247:  /* pred_narrow_lshrvnx1si_scalar */
    case 3270:  /* pred_truncvnx1si */
    case 3307:  /* pred_ssaddvnx1hi */
    case 3308:  /* pred_sssubvnx1hi */
    case 3309:  /* pred_usaddvnx1hi */
    case 3310:  /* pred_ussubvnx1hi */
    case 3381:  /* pred_ssaddvnx1hi_scalar */
    case 3382:  /* pred_usaddvnx1hi_scalar */
    case 3417:  /* pred_sssubvnx1hi_scalar */
    case 3418:  /* pred_ussubvnx1hi_scalar */
    case 3520:  /* pred_aadduvnx1hi */
    case 3521:  /* pred_aaddvnx1hi */
    case 3522:  /* pred_asubuvnx1hi */
    case 3523:  /* pred_asubvnx1hi */
    case 3524:  /* pred_smulvnx1hi */
    case 3525:  /* pred_ssrlvnx1hi */
    case 3526:  /* pred_ssravnx1hi */
    case 3660:  /* pred_aadduvnx1hi_scalar */
    case 3661:  /* pred_aaddvnx1hi_scalar */
    case 3662:  /* pred_asubuvnx1hi_scalar */
    case 3663:  /* pred_asubvnx1hi_scalar */
    case 3664:  /* pred_smulvnx1hi_scalar */
    case 3729:  /* pred_ssrlvnx1hi_scalar */
    case 3730:  /* pred_ssravnx1hi_scalar */
    case 3811:  /* pred_narrow_clipvnx1si */
    case 3812:  /* pred_narrow_clipuvnx1si */
    case 3841:  /* pred_narrow_clipvnx1si_scalar */
    case 3842:  /* pred_narrow_clipuvnx1si_scalar */
    case 3866:  /* *pred_cmpvnx1hi */
    case 3888:  /* *pred_cmpvnx1hi_narrow */
    case 3910:  /* *pred_ltgevnx1hi */
    case 3932:  /* *pred_ltgevnx1hi_narrow */
    case 3954:  /* *pred_cmpvnx1hi_scalar */
    case 3972:  /* *pred_cmpvnx1hi_scalar_narrow */
    case 3990:  /* *pred_eqnevnx1hi_scalar */
    case 4008:  /* *pred_eqnevnx1hi_scalar_narrow */
    case 4058:  /* *pred_maddvnx1hi */
    case 4080:  /* *pred_maccvnx1hi */
    case 4102:  /* *pred_mul_plusvnx1hi */
    case 4124:  /* *pred_maddvnx1hi_scalar */
    case 4146:  /* *pred_maccvnx1hi_scalar */
    case 4168:  /* *pred_mul_plusvnx1hi_scalar */
    case 4202:  /* *pred_nmsubvnx1hi */
    case 4224:  /* *pred_nmsacvnx1hi */
    case 4246:  /* *pred_minus_mulvnx1hi */
    case 4268:  /* *pred_nmsubvnx1hi_scalar */
    case 4290:  /* *pred_nmsacvnx1hi_scalar */
    case 4312:  /* *pred_minus_mulvnx1hi_scalar */
    case 4351:  /* pred_widen_mul_plussvnx1si */
    case 4352:  /* pred_widen_mul_plusuvnx1si */
    case 4381:  /* pred_widen_mul_plussvnx1si_scalar */
    case 4382:  /* pred_widen_mul_plusuvnx1si_scalar */
    case 4405:  /* pred_widen_mul_plussuvnx1si */
    case 4420:  /* pred_widen_mul_plussuvnx1si_scalar */
    case 4435:  /* pred_widen_mul_plususvnx1si_scalar */
    case 4563:  /* pred_iotavnx1hi */
    case 4585:  /* pred_seriesvnx1hi */
    case 5255:  /* pred_widen_floatvnx1sf */
    case 5256:  /* pred_widen_floatunsvnx1sf */
    case 5277:  /* pred_narrow_fcvt_x_fvnx1sf */
    case 5278:  /* pred_narrow_fcvt_xu_fvnx1sf */
    case 5295:  /* pred_narrow_fix_truncvnx1sf */
    case 5296:  /* pred_narrow_fixuns_truncvnx1sf */
    case 5385:  /* pred_reduc_sumvnx1hivnx4hi */
    case 5386:  /* pred_reduc_maxuvnx1hivnx4hi */
    case 5387:  /* pred_reduc_maxvnx1hivnx4hi */
    case 5388:  /* pred_reduc_minuvnx1hivnx4hi */
    case 5389:  /* pred_reduc_minvnx1hivnx4hi */
    case 5390:  /* pred_reduc_andvnx1hivnx4hi */
    case 5391:  /* pred_reduc_orvnx1hivnx4hi */
    case 5392:  /* pred_reduc_xorvnx1hivnx4hi */
    case 5553:  /* pred_reduc_sumvnx1hivnx2hi */
    case 5554:  /* pred_reduc_maxuvnx1hivnx2hi */
    case 5555:  /* pred_reduc_maxvnx1hivnx2hi */
    case 5556:  /* pred_reduc_minuvnx1hivnx2hi */
    case 5557:  /* pred_reduc_minvnx1hivnx2hi */
    case 5558:  /* pred_reduc_andvnx1hivnx2hi */
    case 5559:  /* pred_reduc_orvnx1hivnx2hi */
    case 5560:  /* pred_reduc_xorvnx1hivnx2hi */
    case 5639:  /* pred_widen_reduc_plusvnx1hivnx2si */
    case 5640:  /* pred_widen_reduc_plusuvnx1hivnx2si */
    case 5673:  /* pred_widen_reduc_plusvnx1hivnx1si */
    case 5674:  /* pred_widen_reduc_plusuvnx1hivnx1si */
    case 5752:  /* *pred_extract_firstvnx1hi */
    case 5794:  /* pred_slideupvnx1hi */
    case 5795:  /* pred_slidedownvnx1hi */
    case 5856:  /* pred_slide1upvnx1hi */
    case 5857:  /* pred_slide1downvnx1hi */
    case 5919:  /* pred_gathervnx1hi */
    case 5950:  /* pred_gathervnx1hi_scalar */
    case 5980:  /* pred_gatherei16vnx1hi */
    case 6011:  /* pred_compressvnx1hi */
    case 6044:  /* pred_fault_loadvnx1hi */
      return MODE_VNX1HI;

    case 727:  /* *movvnx64qi_whole */
    case 806:  /* pred_movvnx64qi */
    case 837:  /* pred_storevnx64qi */
    case 882:  /* pred_mergevnx64qi */
    case 913:  /* pred_mergevnx64qi_scalar */
    case 939:  /* *pred_broadcastvnx64qi */
    case 974:  /* pred_strided_loadvnx64qi */
    case 1005:  /* pred_strided_storevnx64qi */
    case 1042:  /* pred_indexed_oloadvnx64qi_same_eew */
    case 1043:  /* pred_indexed_uloadvnx64qi_same_eew */
    case 1480:  /* pred_indexed_ostorevnx64qivnx64qi */
    case 1481:  /* pred_indexed_ustorevnx64qivnx64qi */
    case 1584:  /* pred_addvnx64qi */
    case 1585:  /* pred_subvnx64qi */
    case 1586:  /* pred_andvnx64qi */
    case 1587:  /* pred_iorvnx64qi */
    case 1588:  /* pred_xorvnx64qi */
    case 1589:  /* pred_ashlvnx64qi */
    case 1590:  /* pred_ashrvnx64qi */
    case 1591:  /* pred_lshrvnx64qi */
    case 1592:  /* pred_smaxvnx64qi */
    case 1593:  /* pred_umaxvnx64qi */
    case 1594:  /* pred_sminvnx64qi */
    case 1595:  /* pred_uminvnx64qi */
    case 1596:  /* pred_mulvnx64qi */
    case 1597:  /* pred_divvnx64qi */
    case 1598:  /* pred_udivvnx64qi */
    case 1599:  /* pred_modvnx64qi */
    case 1600:  /* pred_umodvnx64qi */
    case 1874:  /* pred_ashlvnx64qi_scalar */
    case 1875:  /* pred_ashrvnx64qi_scalar */
    case 1876:  /* pred_lshrvnx64qi_scalar */
    case 1976:  /* pred_addvnx64qi_scalar */
    case 1977:  /* pred_andvnx64qi_scalar */
    case 1978:  /* pred_iorvnx64qi_scalar */
    case 1979:  /* pred_xorvnx64qi_scalar */
    case 1980:  /* pred_smaxvnx64qi_scalar */
    case 1981:  /* pred_umaxvnx64qi_scalar */
    case 1982:  /* pred_sminvnx64qi_scalar */
    case 1983:  /* pred_uminvnx64qi_scalar */
    case 1984:  /* pred_mulvnx64qi_scalar */
    case 2114:  /* pred_subvnx64qi_scalar */
    case 2115:  /* pred_divvnx64qi_scalar */
    case 2116:  /* pred_udivvnx64qi_scalar */
    case 2117:  /* pred_modvnx64qi_scalar */
    case 2118:  /* pred_umodvnx64qi_scalar */
    case 2180:  /* pred_subvnx64qi_reverse_scalar */
    case 2330:  /* pred_mulhvnx64qi */
    case 2331:  /* pred_mulhuvnx64qi */
    case 2332:  /* pred_mulhsuvnx64qi */
    case 2396:  /* pred_mulhvnx64qi_scalar */
    case 2397:  /* pred_mulhuvnx64qi_scalar */
    case 2398:  /* pred_mulhsuvnx64qi_scalar */
    case 2462:  /* pred_adcvnx64qi */
    case 2484:  /* pred_sbcvnx64qi */
    case 2506:  /* pred_adcvnx64qi_scalar */
    case 2524:  /* pred_sbcvnx64qi_scalar */
    case 2558:  /* pred_madcvnx64qi */
    case 2580:  /* pred_msbcvnx64qi */
    case 2602:  /* pred_madcvnx64qi_scalar */
    case 2620:  /* pred_msbcvnx64qi_scalar */
    case 2654:  /* pred_madcvnx64qi_overflow */
    case 2676:  /* pred_msbcvnx64qi_overflow */
    case 2698:  /* pred_madcvnx64qi_overflow_scalar */
    case 2716:  /* pred_msbcvnx64qi_overflow_scalar */
    case 2756:  /* pred_negvnx64qi */
    case 2757:  /* pred_one_cmplvnx64qi */
    case 3303:  /* pred_ssaddvnx64qi */
    case 3304:  /* pred_sssubvnx64qi */
    case 3305:  /* pred_usaddvnx64qi */
    case 3306:  /* pred_ussubvnx64qi */
    case 3379:  /* pred_ssaddvnx64qi_scalar */
    case 3380:  /* pred_usaddvnx64qi_scalar */
    case 3415:  /* pred_sssubvnx64qi_scalar */
    case 3416:  /* pred_ussubvnx64qi_scalar */
    case 3513:  /* pred_aadduvnx64qi */
    case 3514:  /* pred_aaddvnx64qi */
    case 3515:  /* pred_asubuvnx64qi */
    case 3516:  /* pred_asubvnx64qi */
    case 3517:  /* pred_smulvnx64qi */
    case 3518:  /* pred_ssrlvnx64qi */
    case 3519:  /* pred_ssravnx64qi */
    case 3655:  /* pred_aadduvnx64qi_scalar */
    case 3656:  /* pred_aaddvnx64qi_scalar */
    case 3657:  /* pred_asubuvnx64qi_scalar */
    case 3658:  /* pred_asubvnx64qi_scalar */
    case 3659:  /* pred_smulvnx64qi_scalar */
    case 3727:  /* pred_ssrlvnx64qi_scalar */
    case 3728:  /* pred_ssravnx64qi_scalar */
    case 3865:  /* *pred_cmpvnx64qi */
    case 3887:  /* *pred_cmpvnx64qi_narrow */
    case 3909:  /* *pred_ltgevnx64qi */
    case 3931:  /* *pred_ltgevnx64qi_narrow */
    case 3953:  /* *pred_cmpvnx64qi_scalar */
    case 3971:  /* *pred_cmpvnx64qi_scalar_narrow */
    case 3989:  /* *pred_eqnevnx64qi_scalar */
    case 4007:  /* *pred_eqnevnx64qi_scalar_narrow */
    case 4057:  /* *pred_maddvnx64qi */
    case 4079:  /* *pred_maccvnx64qi */
    case 4101:  /* *pred_mul_plusvnx64qi */
    case 4123:  /* *pred_maddvnx64qi_scalar */
    case 4145:  /* *pred_maccvnx64qi_scalar */
    case 4167:  /* *pred_mul_plusvnx64qi_scalar */
    case 4201:  /* *pred_nmsubvnx64qi */
    case 4223:  /* *pred_nmsacvnx64qi */
    case 4245:  /* *pred_minus_mulvnx64qi */
    case 4267:  /* *pred_nmsubvnx64qi_scalar */
    case 4289:  /* *pred_nmsacvnx64qi_scalar */
    case 4311:  /* *pred_minus_mulvnx64qi_scalar */
    case 4562:  /* pred_iotavnx64qi */
    case 4584:  /* pred_seriesvnx64qi */
    case 5377:  /* pred_reduc_sumvnx64qivnx8qi */
    case 5378:  /* pred_reduc_maxuvnx64qivnx8qi */
    case 5379:  /* pred_reduc_maxvnx64qivnx8qi */
    case 5380:  /* pred_reduc_minuvnx64qivnx8qi */
    case 5381:  /* pred_reduc_minvnx64qivnx8qi */
    case 5382:  /* pred_reduc_andvnx64qivnx8qi */
    case 5383:  /* pred_reduc_orvnx64qivnx8qi */
    case 5384:  /* pred_reduc_xorvnx64qivnx8qi */
    case 5637:  /* pred_widen_reduc_plusvnx64qivnx4hi */
    case 5638:  /* pred_widen_reduc_plusuvnx64qivnx4hi */
    case 5751:  /* *pred_extract_firstvnx64qi */
    case 5792:  /* pred_slideupvnx64qi */
    case 5793:  /* pred_slidedownvnx64qi */
    case 5854:  /* pred_slide1upvnx64qi */
    case 5855:  /* pred_slide1downvnx64qi */
    case 5918:  /* pred_gathervnx64qi */
    case 5949:  /* pred_gathervnx64qi_scalar */
    case 6010:  /* pred_compressvnx64qi */
    case 6043:  /* pred_fault_loadvnx64qi */
      return MODE_VNX64QI;

    case 726:  /* *movvnx32qi_whole */
    case 805:  /* pred_movvnx32qi */
    case 836:  /* pred_storevnx32qi */
    case 881:  /* pred_mergevnx32qi */
    case 912:  /* pred_mergevnx32qi_scalar */
    case 938:  /* *pred_broadcastvnx32qi */
    case 973:  /* pred_strided_loadvnx32qi */
    case 1004:  /* pred_strided_storevnx32qi */
    case 1040:  /* pred_indexed_oloadvnx32qi_same_eew */
    case 1041:  /* pred_indexed_uloadvnx32qi_same_eew */
    case 1202:  /* pred_indexed_oloadvnx32qi_x2_smaller_eew */
    case 1203:  /* pred_indexed_uloadvnx32qi_x2_smaller_eew */
    case 1472:  /* pred_indexed_ostorevnx32qivnx32qi */
    case 1473:  /* pred_indexed_ustorevnx32qivnx32qi */
    case 1474:  /* pred_indexed_ostorevnx32qivnx32hi */
    case 1475:  /* pred_indexed_ustorevnx32qivnx32hi */
    case 1567:  /* pred_addvnx32qi */
    case 1568:  /* pred_subvnx32qi */
    case 1569:  /* pred_andvnx32qi */
    case 1570:  /* pred_iorvnx32qi */
    case 1571:  /* pred_xorvnx32qi */
    case 1572:  /* pred_ashlvnx32qi */
    case 1573:  /* pred_ashrvnx32qi */
    case 1574:  /* pred_lshrvnx32qi */
    case 1575:  /* pred_smaxvnx32qi */
    case 1576:  /* pred_umaxvnx32qi */
    case 1577:  /* pred_sminvnx32qi */
    case 1578:  /* pred_uminvnx32qi */
    case 1579:  /* pred_mulvnx32qi */
    case 1580:  /* pred_divvnx32qi */
    case 1581:  /* pred_udivvnx32qi */
    case 1582:  /* pred_modvnx32qi */
    case 1583:  /* pred_umodvnx32qi */
    case 1871:  /* pred_ashlvnx32qi_scalar */
    case 1872:  /* pred_ashrvnx32qi_scalar */
    case 1873:  /* pred_lshrvnx32qi_scalar */
    case 1967:  /* pred_addvnx32qi_scalar */
    case 1968:  /* pred_andvnx32qi_scalar */
    case 1969:  /* pred_iorvnx32qi_scalar */
    case 1970:  /* pred_xorvnx32qi_scalar */
    case 1971:  /* pred_smaxvnx32qi_scalar */
    case 1972:  /* pred_umaxvnx32qi_scalar */
    case 1973:  /* pred_sminvnx32qi_scalar */
    case 1974:  /* pred_uminvnx32qi_scalar */
    case 1975:  /* pred_mulvnx32qi_scalar */
    case 2109:  /* pred_subvnx32qi_scalar */
    case 2110:  /* pred_divvnx32qi_scalar */
    case 2111:  /* pred_udivvnx32qi_scalar */
    case 2112:  /* pred_modvnx32qi_scalar */
    case 2113:  /* pred_umodvnx32qi_scalar */
    case 2179:  /* pred_subvnx32qi_reverse_scalar */
    case 2327:  /* pred_mulhvnx32qi */
    case 2328:  /* pred_mulhuvnx32qi */
    case 2329:  /* pred_mulhsuvnx32qi */
    case 2393:  /* pred_mulhvnx32qi_scalar */
    case 2394:  /* pred_mulhuvnx32qi_scalar */
    case 2395:  /* pred_mulhsuvnx32qi_scalar */
    case 2461:  /* pred_adcvnx32qi */
    case 2483:  /* pred_sbcvnx32qi */
    case 2505:  /* pred_adcvnx32qi_scalar */
    case 2523:  /* pred_sbcvnx32qi_scalar */
    case 2557:  /* pred_madcvnx32qi */
    case 2579:  /* pred_msbcvnx32qi */
    case 2601:  /* pred_madcvnx32qi_scalar */
    case 2619:  /* pred_msbcvnx32qi_scalar */
    case 2653:  /* pred_madcvnx32qi_overflow */
    case 2675:  /* pred_msbcvnx32qi_overflow */
    case 2697:  /* pred_madcvnx32qi_overflow_scalar */
    case 2715:  /* pred_msbcvnx32qi_overflow_scalar */
    case 2754:  /* pred_negvnx32qi */
    case 2755:  /* pred_one_cmplvnx32qi */
    case 2874:  /* pred_dual_widen_addsvnx32hi */
    case 2875:  /* pred_dual_widen_subsvnx32hi */
    case 2876:  /* pred_dual_widen_mulsvnx32hi */
    case 2877:  /* pred_dual_widen_adduvnx32hi */
    case 2878:  /* pred_dual_widen_subuvnx32hi */
    case 2879:  /* pred_dual_widen_muluvnx32hi */
    case 2964:  /* pred_dual_widen_addsvnx32hi_scalar */
    case 2965:  /* pred_dual_widen_subsvnx32hi_scalar */
    case 2966:  /* pred_dual_widen_mulsvnx32hi_scalar */
    case 2967:  /* pred_dual_widen_adduvnx32hi_scalar */
    case 2968:  /* pred_dual_widen_subuvnx32hi_scalar */
    case 2969:  /* pred_dual_widen_muluvnx32hi_scalar */
    case 3044:  /* pred_single_widen_addsvnx32hi */
    case 3045:  /* pred_single_widen_subsvnx32hi */
    case 3046:  /* pred_single_widen_adduvnx32hi */
    case 3047:  /* pred_single_widen_subuvnx32hi */
    case 3104:  /* pred_single_widen_addsvnx32hi_scalar */
    case 3105:  /* pred_single_widen_subsvnx32hi_scalar */
    case 3106:  /* pred_single_widen_adduvnx32hi_scalar */
    case 3107:  /* pred_single_widen_subuvnx32hi_scalar */
    case 3149:  /* pred_widen_mulsuvnx32hi */
    case 3164:  /* pred_widen_mulsuvnx32hi_scalar */
    case 3184:  /* pred_extendvnx32hi */
    case 3185:  /* pred_zero_extendvnx32hi */
    case 3214:  /* pred_narrow_ashrvnx32hi */
    case 3215:  /* pred_narrow_lshrvnx32hi */
    case 3244:  /* pred_narrow_ashrvnx32hi_scalar */
    case 3245:  /* pred_narrow_lshrvnx32hi_scalar */
    case 3269:  /* pred_truncvnx32hi */
    case 3299:  /* pred_ssaddvnx32qi */
    case 3300:  /* pred_sssubvnx32qi */
    case 3301:  /* pred_usaddvnx32qi */
    case 3302:  /* pred_ussubvnx32qi */
    case 3377:  /* pred_ssaddvnx32qi_scalar */
    case 3378:  /* pred_usaddvnx32qi_scalar */
    case 3413:  /* pred_sssubvnx32qi_scalar */
    case 3414:  /* pred_ussubvnx32qi_scalar */
    case 3506:  /* pred_aadduvnx32qi */
    case 3507:  /* pred_aaddvnx32qi */
    case 3508:  /* pred_asubuvnx32qi */
    case 3509:  /* pred_asubvnx32qi */
    case 3510:  /* pred_smulvnx32qi */
    case 3511:  /* pred_ssrlvnx32qi */
    case 3512:  /* pred_ssravnx32qi */
    case 3650:  /* pred_aadduvnx32qi_scalar */
    case 3651:  /* pred_aaddvnx32qi_scalar */
    case 3652:  /* pred_asubuvnx32qi_scalar */
    case 3653:  /* pred_asubvnx32qi_scalar */
    case 3654:  /* pred_smulvnx32qi_scalar */
    case 3725:  /* pred_ssrlvnx32qi_scalar */
    case 3726:  /* pred_ssravnx32qi_scalar */
    case 3809:  /* pred_narrow_clipvnx32hi */
    case 3810:  /* pred_narrow_clipuvnx32hi */
    case 3839:  /* pred_narrow_clipvnx32hi_scalar */
    case 3840:  /* pred_narrow_clipuvnx32hi_scalar */
    case 3864:  /* *pred_cmpvnx32qi */
    case 3886:  /* *pred_cmpvnx32qi_narrow */
    case 3908:  /* *pred_ltgevnx32qi */
    case 3930:  /* *pred_ltgevnx32qi_narrow */
    case 3952:  /* *pred_cmpvnx32qi_scalar */
    case 3970:  /* *pred_cmpvnx32qi_scalar_narrow */
    case 3988:  /* *pred_eqnevnx32qi_scalar */
    case 4006:  /* *pred_eqnevnx32qi_scalar_narrow */
    case 4056:  /* *pred_maddvnx32qi */
    case 4078:  /* *pred_maccvnx32qi */
    case 4100:  /* *pred_mul_plusvnx32qi */
    case 4122:  /* *pred_maddvnx32qi_scalar */
    case 4144:  /* *pred_maccvnx32qi_scalar */
    case 4166:  /* *pred_mul_plusvnx32qi_scalar */
    case 4200:  /* *pred_nmsubvnx32qi */
    case 4222:  /* *pred_nmsacvnx32qi */
    case 4244:  /* *pred_minus_mulvnx32qi */
    case 4266:  /* *pred_nmsubvnx32qi_scalar */
    case 4288:  /* *pred_nmsacvnx32qi_scalar */
    case 4310:  /* *pred_minus_mulvnx32qi_scalar */
    case 4349:  /* pred_widen_mul_plussvnx32hi */
    case 4350:  /* pred_widen_mul_plusuvnx32hi */
    case 4379:  /* pred_widen_mul_plussvnx32hi_scalar */
    case 4380:  /* pred_widen_mul_plusuvnx32hi_scalar */
    case 4404:  /* pred_widen_mul_plussuvnx32hi */
    case 4419:  /* pred_widen_mul_plussuvnx32hi_scalar */
    case 4434:  /* pred_widen_mul_plususvnx32hi_scalar */
    case 4561:  /* pred_iotavnx32qi */
    case 4583:  /* pred_seriesvnx32qi */
    case 5369:  /* pred_reduc_sumvnx32qivnx8qi */
    case 5370:  /* pred_reduc_maxuvnx32qivnx8qi */
    case 5371:  /* pred_reduc_maxvnx32qivnx8qi */
    case 5372:  /* pred_reduc_minuvnx32qivnx8qi */
    case 5373:  /* pred_reduc_minvnx32qivnx8qi */
    case 5374:  /* pred_reduc_andvnx32qivnx8qi */
    case 5375:  /* pred_reduc_orvnx32qivnx8qi */
    case 5376:  /* pred_reduc_xorvnx32qivnx8qi */
    case 5545:  /* pred_reduc_sumvnx32qivnx4qi */
    case 5546:  /* pred_reduc_maxuvnx32qivnx4qi */
    case 5547:  /* pred_reduc_maxvnx32qivnx4qi */
    case 5548:  /* pred_reduc_minuvnx32qivnx4qi */
    case 5549:  /* pred_reduc_minvnx32qivnx4qi */
    case 5550:  /* pred_reduc_andvnx32qivnx4qi */
    case 5551:  /* pred_reduc_orvnx32qivnx4qi */
    case 5552:  /* pred_reduc_xorvnx32qivnx4qi */
    case 5635:  /* pred_widen_reduc_plusvnx32qivnx4hi */
    case 5636:  /* pred_widen_reduc_plusuvnx32qivnx4hi */
    case 5671:  /* pred_widen_reduc_plusvnx32qivnx2hi */
    case 5672:  /* pred_widen_reduc_plusuvnx32qivnx2hi */
    case 5750:  /* *pred_extract_firstvnx32qi */
    case 5790:  /* pred_slideupvnx32qi */
    case 5791:  /* pred_slidedownvnx32qi */
    case 5852:  /* pred_slide1upvnx32qi */
    case 5853:  /* pred_slide1downvnx32qi */
    case 5917:  /* pred_gathervnx32qi */
    case 5948:  /* pred_gathervnx32qi_scalar */
    case 5979:  /* pred_gatherei16vnx32qi */
    case 6009:  /* pred_compressvnx32qi */
    case 6042:  /* pred_fault_loadvnx32qi */
      return MODE_VNX32QI;

    case 725:  /* *movvnx16qi_whole */
    case 804:  /* pred_movvnx16qi */
    case 835:  /* pred_storevnx16qi */
    case 880:  /* pred_mergevnx16qi */
    case 911:  /* pred_mergevnx16qi_scalar */
    case 937:  /* *pred_broadcastvnx16qi */
    case 972:  /* pred_strided_loadvnx16qi */
    case 1003:  /* pred_strided_storevnx16qi */
    case 1038:  /* pred_indexed_oloadvnx16qi_same_eew */
    case 1039:  /* pred_indexed_uloadvnx16qi_same_eew */
    case 1200:  /* pred_indexed_oloadvnx16qi_x2_smaller_eew */
    case 1201:  /* pred_indexed_uloadvnx16qi_x2_smaller_eew */
    case 1238:  /* pred_indexed_oloadvnx16qi_x4_smaller_eew */
    case 1239:  /* pred_indexed_uloadvnx16qi_x4_smaller_eew */
    case 1448:  /* pred_indexed_ostorevnx16qivnx16qi */
    case 1449:  /* pred_indexed_ustorevnx16qivnx16qi */
    case 1456:  /* pred_indexed_ostorevnx16qivnx16hi */
    case 1457:  /* pred_indexed_ustorevnx16qivnx16hi */
    case 1464:  /* pred_indexed_ostorevnx16qivnx16si */
    case 1465:  /* pred_indexed_ustorevnx16qivnx16si */
    case 1550:  /* pred_addvnx16qi */
    case 1551:  /* pred_subvnx16qi */
    case 1552:  /* pred_andvnx16qi */
    case 1553:  /* pred_iorvnx16qi */
    case 1554:  /* pred_xorvnx16qi */
    case 1555:  /* pred_ashlvnx16qi */
    case 1556:  /* pred_ashrvnx16qi */
    case 1557:  /* pred_lshrvnx16qi */
    case 1558:  /* pred_smaxvnx16qi */
    case 1559:  /* pred_umaxvnx16qi */
    case 1560:  /* pred_sminvnx16qi */
    case 1561:  /* pred_uminvnx16qi */
    case 1562:  /* pred_mulvnx16qi */
    case 1563:  /* pred_divvnx16qi */
    case 1564:  /* pred_udivvnx16qi */
    case 1565:  /* pred_modvnx16qi */
    case 1566:  /* pred_umodvnx16qi */
    case 1868:  /* pred_ashlvnx16qi_scalar */
    case 1869:  /* pred_ashrvnx16qi_scalar */
    case 1870:  /* pred_lshrvnx16qi_scalar */
    case 1958:  /* pred_addvnx16qi_scalar */
    case 1959:  /* pred_andvnx16qi_scalar */
    case 1960:  /* pred_iorvnx16qi_scalar */
    case 1961:  /* pred_xorvnx16qi_scalar */
    case 1962:  /* pred_smaxvnx16qi_scalar */
    case 1963:  /* pred_umaxvnx16qi_scalar */
    case 1964:  /* pred_sminvnx16qi_scalar */
    case 1965:  /* pred_uminvnx16qi_scalar */
    case 1966:  /* pred_mulvnx16qi_scalar */
    case 2104:  /* pred_subvnx16qi_scalar */
    case 2105:  /* pred_divvnx16qi_scalar */
    case 2106:  /* pred_udivvnx16qi_scalar */
    case 2107:  /* pred_modvnx16qi_scalar */
    case 2108:  /* pred_umodvnx16qi_scalar */
    case 2178:  /* pred_subvnx16qi_reverse_scalar */
    case 2324:  /* pred_mulhvnx16qi */
    case 2325:  /* pred_mulhuvnx16qi */
    case 2326:  /* pred_mulhsuvnx16qi */
    case 2390:  /* pred_mulhvnx16qi_scalar */
    case 2391:  /* pred_mulhuvnx16qi_scalar */
    case 2392:  /* pred_mulhsuvnx16qi_scalar */
    case 2460:  /* pred_adcvnx16qi */
    case 2482:  /* pred_sbcvnx16qi */
    case 2504:  /* pred_adcvnx16qi_scalar */
    case 2522:  /* pred_sbcvnx16qi_scalar */
    case 2556:  /* pred_madcvnx16qi */
    case 2578:  /* pred_msbcvnx16qi */
    case 2600:  /* pred_madcvnx16qi_scalar */
    case 2618:  /* pred_msbcvnx16qi_scalar */
    case 2652:  /* pred_madcvnx16qi_overflow */
    case 2674:  /* pred_msbcvnx16qi_overflow */
    case 2696:  /* pred_madcvnx16qi_overflow_scalar */
    case 2714:  /* pred_msbcvnx16qi_overflow_scalar */
    case 2752:  /* pred_negvnx16qi */
    case 2753:  /* pred_one_cmplvnx16qi */
    case 2868:  /* pred_dual_widen_addsvnx16hi */
    case 2869:  /* pred_dual_widen_subsvnx16hi */
    case 2870:  /* pred_dual_widen_mulsvnx16hi */
    case 2871:  /* pred_dual_widen_adduvnx16hi */
    case 2872:  /* pred_dual_widen_subuvnx16hi */
    case 2873:  /* pred_dual_widen_muluvnx16hi */
    case 2958:  /* pred_dual_widen_addsvnx16hi_scalar */
    case 2959:  /* pred_dual_widen_subsvnx16hi_scalar */
    case 2960:  /* pred_dual_widen_mulsvnx16hi_scalar */
    case 2961:  /* pred_dual_widen_adduvnx16hi_scalar */
    case 2962:  /* pred_dual_widen_subuvnx16hi_scalar */
    case 2963:  /* pred_dual_widen_muluvnx16hi_scalar */
    case 3040:  /* pred_single_widen_addsvnx16hi */
    case 3041:  /* pred_single_widen_subsvnx16hi */
    case 3042:  /* pred_single_widen_adduvnx16hi */
    case 3043:  /* pred_single_widen_subuvnx16hi */
    case 3100:  /* pred_single_widen_addsvnx16hi_scalar */
    case 3101:  /* pred_single_widen_subsvnx16hi_scalar */
    case 3102:  /* pred_single_widen_adduvnx16hi_scalar */
    case 3103:  /* pred_single_widen_subuvnx16hi_scalar */
    case 3148:  /* pred_widen_mulsuvnx16hi */
    case 3163:  /* pred_widen_mulsuvnx16hi_scalar */
    case 3182:  /* pred_extendvnx16hi */
    case 3183:  /* pred_zero_extendvnx16hi */
    case 3212:  /* pred_narrow_ashrvnx16hi */
    case 3213:  /* pred_narrow_lshrvnx16hi */
    case 3242:  /* pred_narrow_ashrvnx16hi_scalar */
    case 3243:  /* pred_narrow_lshrvnx16hi_scalar */
    case 3268:  /* pred_truncvnx16hi */
    case 3295:  /* pred_ssaddvnx16qi */
    case 3296:  /* pred_sssubvnx16qi */
    case 3297:  /* pred_usaddvnx16qi */
    case 3298:  /* pred_ussubvnx16qi */
    case 3375:  /* pred_ssaddvnx16qi_scalar */
    case 3376:  /* pred_usaddvnx16qi_scalar */
    case 3411:  /* pred_sssubvnx16qi_scalar */
    case 3412:  /* pred_ussubvnx16qi_scalar */
    case 3499:  /* pred_aadduvnx16qi */
    case 3500:  /* pred_aaddvnx16qi */
    case 3501:  /* pred_asubuvnx16qi */
    case 3502:  /* pred_asubvnx16qi */
    case 3503:  /* pred_smulvnx16qi */
    case 3504:  /* pred_ssrlvnx16qi */
    case 3505:  /* pred_ssravnx16qi */
    case 3645:  /* pred_aadduvnx16qi_scalar */
    case 3646:  /* pred_aaddvnx16qi_scalar */
    case 3647:  /* pred_asubuvnx16qi_scalar */
    case 3648:  /* pred_asubvnx16qi_scalar */
    case 3649:  /* pred_smulvnx16qi_scalar */
    case 3723:  /* pred_ssrlvnx16qi_scalar */
    case 3724:  /* pred_ssravnx16qi_scalar */
    case 3807:  /* pred_narrow_clipvnx16hi */
    case 3808:  /* pred_narrow_clipuvnx16hi */
    case 3837:  /* pred_narrow_clipvnx16hi_scalar */
    case 3838:  /* pred_narrow_clipuvnx16hi_scalar */
    case 3863:  /* *pred_cmpvnx16qi */
    case 3885:  /* *pred_cmpvnx16qi_narrow */
    case 3907:  /* *pred_ltgevnx16qi */
    case 3929:  /* *pred_ltgevnx16qi_narrow */
    case 3951:  /* *pred_cmpvnx16qi_scalar */
    case 3969:  /* *pred_cmpvnx16qi_scalar_narrow */
    case 3987:  /* *pred_eqnevnx16qi_scalar */
    case 4005:  /* *pred_eqnevnx16qi_scalar_narrow */
    case 4055:  /* *pred_maddvnx16qi */
    case 4077:  /* *pred_maccvnx16qi */
    case 4099:  /* *pred_mul_plusvnx16qi */
    case 4121:  /* *pred_maddvnx16qi_scalar */
    case 4143:  /* *pred_maccvnx16qi_scalar */
    case 4165:  /* *pred_mul_plusvnx16qi_scalar */
    case 4199:  /* *pred_nmsubvnx16qi */
    case 4221:  /* *pred_nmsacvnx16qi */
    case 4243:  /* *pred_minus_mulvnx16qi */
    case 4265:  /* *pred_nmsubvnx16qi_scalar */
    case 4287:  /* *pred_nmsacvnx16qi_scalar */
    case 4309:  /* *pred_minus_mulvnx16qi_scalar */
    case 4347:  /* pred_widen_mul_plussvnx16hi */
    case 4348:  /* pred_widen_mul_plusuvnx16hi */
    case 4377:  /* pred_widen_mul_plussvnx16hi_scalar */
    case 4378:  /* pred_widen_mul_plusuvnx16hi_scalar */
    case 4403:  /* pred_widen_mul_plussuvnx16hi */
    case 4418:  /* pred_widen_mul_plussuvnx16hi_scalar */
    case 4433:  /* pred_widen_mul_plususvnx16hi_scalar */
    case 4560:  /* pred_iotavnx16qi */
    case 4582:  /* pred_seriesvnx16qi */
    case 5361:  /* pred_reduc_sumvnx16qivnx8qi */
    case 5362:  /* pred_reduc_maxuvnx16qivnx8qi */
    case 5363:  /* pred_reduc_maxvnx16qivnx8qi */
    case 5364:  /* pred_reduc_minuvnx16qivnx8qi */
    case 5365:  /* pred_reduc_minvnx16qivnx8qi */
    case 5366:  /* pred_reduc_andvnx16qivnx8qi */
    case 5367:  /* pred_reduc_orvnx16qivnx8qi */
    case 5368:  /* pred_reduc_xorvnx16qivnx8qi */
    case 5537:  /* pred_reduc_sumvnx16qivnx4qi */
    case 5538:  /* pred_reduc_maxuvnx16qivnx4qi */
    case 5539:  /* pred_reduc_maxvnx16qivnx4qi */
    case 5540:  /* pred_reduc_minuvnx16qivnx4qi */
    case 5541:  /* pred_reduc_minvnx16qivnx4qi */
    case 5542:  /* pred_reduc_andvnx16qivnx4qi */
    case 5543:  /* pred_reduc_orvnx16qivnx4qi */
    case 5544:  /* pred_reduc_xorvnx16qivnx4qi */
    case 5633:  /* pred_widen_reduc_plusvnx16qivnx4hi */
    case 5634:  /* pred_widen_reduc_plusuvnx16qivnx4hi */
    case 5669:  /* pred_widen_reduc_plusvnx16qivnx2hi */
    case 5670:  /* pred_widen_reduc_plusuvnx16qivnx2hi */
    case 5749:  /* *pred_extract_firstvnx16qi */
    case 5788:  /* pred_slideupvnx16qi */
    case 5789:  /* pred_slidedownvnx16qi */
    case 5850:  /* pred_slide1upvnx16qi */
    case 5851:  /* pred_slide1downvnx16qi */
    case 5916:  /* pred_gathervnx16qi */
    case 5947:  /* pred_gathervnx16qi_scalar */
    case 5978:  /* pred_gatherei16vnx16qi */
    case 6008:  /* pred_compressvnx16qi */
    case 6041:  /* pred_fault_loadvnx16qi */
      return MODE_VNX16QI;

    case 724:  /* *movvnx8qi_whole */
    case 803:  /* pred_movvnx8qi */
    case 834:  /* pred_storevnx8qi */
    case 879:  /* pred_mergevnx8qi */
    case 910:  /* pred_mergevnx8qi_scalar */
    case 936:  /* *pred_broadcastvnx8qi */
    case 971:  /* pred_strided_loadvnx8qi */
    case 1002:  /* pred_strided_storevnx8qi */
    case 1036:  /* pred_indexed_oloadvnx8qi_same_eew */
    case 1037:  /* pred_indexed_uloadvnx8qi_same_eew */
    case 1198:  /* pred_indexed_oloadvnx8qi_x2_smaller_eew */
    case 1199:  /* pred_indexed_uloadvnx8qi_x2_smaller_eew */
    case 1236:  /* pred_indexed_oloadvnx8qi_x4_smaller_eew */
    case 1237:  /* pred_indexed_uloadvnx8qi_x4_smaller_eew */
    case 1254:  /* pred_indexed_oloadvnx8qi_x8_smaller_eew */
    case 1255:  /* pred_indexed_uloadvnx8qi_x8_smaller_eew */
    case 1400:  /* pred_indexed_ostorevnx8qivnx8qi */
    case 1401:  /* pred_indexed_ustorevnx8qivnx8qi */
    case 1412:  /* pred_indexed_ostorevnx8qivnx8hi */
    case 1413:  /* pred_indexed_ustorevnx8qivnx8hi */
    case 1424:  /* pred_indexed_ostorevnx8qivnx8si */
    case 1425:  /* pred_indexed_ustorevnx8qivnx8si */
    case 1436:  /* pred_indexed_ostorevnx8qivnx8di */
    case 1437:  /* pred_indexed_ustorevnx8qivnx8di */
    case 1533:  /* pred_addvnx8qi */
    case 1534:  /* pred_subvnx8qi */
    case 1535:  /* pred_andvnx8qi */
    case 1536:  /* pred_iorvnx8qi */
    case 1537:  /* pred_xorvnx8qi */
    case 1538:  /* pred_ashlvnx8qi */
    case 1539:  /* pred_ashrvnx8qi */
    case 1540:  /* pred_lshrvnx8qi */
    case 1541:  /* pred_smaxvnx8qi */
    case 1542:  /* pred_umaxvnx8qi */
    case 1543:  /* pred_sminvnx8qi */
    case 1544:  /* pred_uminvnx8qi */
    case 1545:  /* pred_mulvnx8qi */
    case 1546:  /* pred_divvnx8qi */
    case 1547:  /* pred_udivvnx8qi */
    case 1548:  /* pred_modvnx8qi */
    case 1549:  /* pred_umodvnx8qi */
    case 1865:  /* pred_ashlvnx8qi_scalar */
    case 1866:  /* pred_ashrvnx8qi_scalar */
    case 1867:  /* pred_lshrvnx8qi_scalar */
    case 1949:  /* pred_addvnx8qi_scalar */
    case 1950:  /* pred_andvnx8qi_scalar */
    case 1951:  /* pred_iorvnx8qi_scalar */
    case 1952:  /* pred_xorvnx8qi_scalar */
    case 1953:  /* pred_smaxvnx8qi_scalar */
    case 1954:  /* pred_umaxvnx8qi_scalar */
    case 1955:  /* pred_sminvnx8qi_scalar */
    case 1956:  /* pred_uminvnx8qi_scalar */
    case 1957:  /* pred_mulvnx8qi_scalar */
    case 2099:  /* pred_subvnx8qi_scalar */
    case 2100:  /* pred_divvnx8qi_scalar */
    case 2101:  /* pred_udivvnx8qi_scalar */
    case 2102:  /* pred_modvnx8qi_scalar */
    case 2103:  /* pred_umodvnx8qi_scalar */
    case 2177:  /* pred_subvnx8qi_reverse_scalar */
    case 2321:  /* pred_mulhvnx8qi */
    case 2322:  /* pred_mulhuvnx8qi */
    case 2323:  /* pred_mulhsuvnx8qi */
    case 2387:  /* pred_mulhvnx8qi_scalar */
    case 2388:  /* pred_mulhuvnx8qi_scalar */
    case 2389:  /* pred_mulhsuvnx8qi_scalar */
    case 2459:  /* pred_adcvnx8qi */
    case 2481:  /* pred_sbcvnx8qi */
    case 2503:  /* pred_adcvnx8qi_scalar */
    case 2521:  /* pred_sbcvnx8qi_scalar */
    case 2555:  /* pred_madcvnx8qi */
    case 2577:  /* pred_msbcvnx8qi */
    case 2599:  /* pred_madcvnx8qi_scalar */
    case 2617:  /* pred_msbcvnx8qi_scalar */
    case 2651:  /* pred_madcvnx8qi_overflow */
    case 2673:  /* pred_msbcvnx8qi_overflow */
    case 2695:  /* pred_madcvnx8qi_overflow_scalar */
    case 2713:  /* pred_msbcvnx8qi_overflow_scalar */
    case 2750:  /* pred_negvnx8qi */
    case 2751:  /* pred_one_cmplvnx8qi */
    case 2862:  /* pred_dual_widen_addsvnx8hi */
    case 2863:  /* pred_dual_widen_subsvnx8hi */
    case 2864:  /* pred_dual_widen_mulsvnx8hi */
    case 2865:  /* pred_dual_widen_adduvnx8hi */
    case 2866:  /* pred_dual_widen_subuvnx8hi */
    case 2867:  /* pred_dual_widen_muluvnx8hi */
    case 2952:  /* pred_dual_widen_addsvnx8hi_scalar */
    case 2953:  /* pred_dual_widen_subsvnx8hi_scalar */
    case 2954:  /* pred_dual_widen_mulsvnx8hi_scalar */
    case 2955:  /* pred_dual_widen_adduvnx8hi_scalar */
    case 2956:  /* pred_dual_widen_subuvnx8hi_scalar */
    case 2957:  /* pred_dual_widen_muluvnx8hi_scalar */
    case 3036:  /* pred_single_widen_addsvnx8hi */
    case 3037:  /* pred_single_widen_subsvnx8hi */
    case 3038:  /* pred_single_widen_adduvnx8hi */
    case 3039:  /* pred_single_widen_subuvnx8hi */
    case 3096:  /* pred_single_widen_addsvnx8hi_scalar */
    case 3097:  /* pred_single_widen_subsvnx8hi_scalar */
    case 3098:  /* pred_single_widen_adduvnx8hi_scalar */
    case 3099:  /* pred_single_widen_subuvnx8hi_scalar */
    case 3147:  /* pred_widen_mulsuvnx8hi */
    case 3162:  /* pred_widen_mulsuvnx8hi_scalar */
    case 3180:  /* pred_extendvnx8hi */
    case 3181:  /* pred_zero_extendvnx8hi */
    case 3210:  /* pred_narrow_ashrvnx8hi */
    case 3211:  /* pred_narrow_lshrvnx8hi */
    case 3240:  /* pred_narrow_ashrvnx8hi_scalar */
    case 3241:  /* pred_narrow_lshrvnx8hi_scalar */
    case 3267:  /* pred_truncvnx8hi */
    case 3291:  /* pred_ssaddvnx8qi */
    case 3292:  /* pred_sssubvnx8qi */
    case 3293:  /* pred_usaddvnx8qi */
    case 3294:  /* pred_ussubvnx8qi */
    case 3373:  /* pred_ssaddvnx8qi_scalar */
    case 3374:  /* pred_usaddvnx8qi_scalar */
    case 3409:  /* pred_sssubvnx8qi_scalar */
    case 3410:  /* pred_ussubvnx8qi_scalar */
    case 3492:  /* pred_aadduvnx8qi */
    case 3493:  /* pred_aaddvnx8qi */
    case 3494:  /* pred_asubuvnx8qi */
    case 3495:  /* pred_asubvnx8qi */
    case 3496:  /* pred_smulvnx8qi */
    case 3497:  /* pred_ssrlvnx8qi */
    case 3498:  /* pred_ssravnx8qi */
    case 3640:  /* pred_aadduvnx8qi_scalar */
    case 3641:  /* pred_aaddvnx8qi_scalar */
    case 3642:  /* pred_asubuvnx8qi_scalar */
    case 3643:  /* pred_asubvnx8qi_scalar */
    case 3644:  /* pred_smulvnx8qi_scalar */
    case 3721:  /* pred_ssrlvnx8qi_scalar */
    case 3722:  /* pred_ssravnx8qi_scalar */
    case 3805:  /* pred_narrow_clipvnx8hi */
    case 3806:  /* pred_narrow_clipuvnx8hi */
    case 3835:  /* pred_narrow_clipvnx8hi_scalar */
    case 3836:  /* pred_narrow_clipuvnx8hi_scalar */
    case 3862:  /* *pred_cmpvnx8qi */
    case 3884:  /* *pred_cmpvnx8qi_narrow */
    case 3906:  /* *pred_ltgevnx8qi */
    case 3928:  /* *pred_ltgevnx8qi_narrow */
    case 3950:  /* *pred_cmpvnx8qi_scalar */
    case 3968:  /* *pred_cmpvnx8qi_scalar_narrow */
    case 3986:  /* *pred_eqnevnx8qi_scalar */
    case 4004:  /* *pred_eqnevnx8qi_scalar_narrow */
    case 4054:  /* *pred_maddvnx8qi */
    case 4076:  /* *pred_maccvnx8qi */
    case 4098:  /* *pred_mul_plusvnx8qi */
    case 4120:  /* *pred_maddvnx8qi_scalar */
    case 4142:  /* *pred_maccvnx8qi_scalar */
    case 4164:  /* *pred_mul_plusvnx8qi_scalar */
    case 4198:  /* *pred_nmsubvnx8qi */
    case 4220:  /* *pred_nmsacvnx8qi */
    case 4242:  /* *pred_minus_mulvnx8qi */
    case 4264:  /* *pred_nmsubvnx8qi_scalar */
    case 4286:  /* *pred_nmsacvnx8qi_scalar */
    case 4308:  /* *pred_minus_mulvnx8qi_scalar */
    case 4345:  /* pred_widen_mul_plussvnx8hi */
    case 4346:  /* pred_widen_mul_plusuvnx8hi */
    case 4375:  /* pred_widen_mul_plussvnx8hi_scalar */
    case 4376:  /* pred_widen_mul_plusuvnx8hi_scalar */
    case 4402:  /* pred_widen_mul_plussuvnx8hi */
    case 4417:  /* pred_widen_mul_plussuvnx8hi_scalar */
    case 4432:  /* pred_widen_mul_plususvnx8hi_scalar */
    case 4559:  /* pred_iotavnx8qi */
    case 4581:  /* pred_seriesvnx8qi */
    case 5353:  /* pred_reduc_sumvnx8qivnx8qi */
    case 5354:  /* pred_reduc_maxuvnx8qivnx8qi */
    case 5355:  /* pred_reduc_maxvnx8qivnx8qi */
    case 5356:  /* pred_reduc_minuvnx8qivnx8qi */
    case 5357:  /* pred_reduc_minvnx8qivnx8qi */
    case 5358:  /* pred_reduc_andvnx8qivnx8qi */
    case 5359:  /* pred_reduc_orvnx8qivnx8qi */
    case 5360:  /* pred_reduc_xorvnx8qivnx8qi */
    case 5529:  /* pred_reduc_sumvnx8qivnx4qi */
    case 5530:  /* pred_reduc_maxuvnx8qivnx4qi */
    case 5531:  /* pred_reduc_maxvnx8qivnx4qi */
    case 5532:  /* pred_reduc_minuvnx8qivnx4qi */
    case 5533:  /* pred_reduc_minvnx8qivnx4qi */
    case 5534:  /* pred_reduc_andvnx8qivnx4qi */
    case 5535:  /* pred_reduc_orvnx8qivnx4qi */
    case 5536:  /* pred_reduc_xorvnx8qivnx4qi */
    case 5631:  /* pred_widen_reduc_plusvnx8qivnx4hi */
    case 5632:  /* pred_widen_reduc_plusuvnx8qivnx4hi */
    case 5667:  /* pred_widen_reduc_plusvnx8qivnx2hi */
    case 5668:  /* pred_widen_reduc_plusuvnx8qivnx2hi */
    case 5748:  /* *pred_extract_firstvnx8qi */
    case 5786:  /* pred_slideupvnx8qi */
    case 5787:  /* pred_slidedownvnx8qi */
    case 5848:  /* pred_slide1upvnx8qi */
    case 5849:  /* pred_slide1downvnx8qi */
    case 5915:  /* pred_gathervnx8qi */
    case 5946:  /* pred_gathervnx8qi_scalar */
    case 5977:  /* pred_gatherei16vnx8qi */
    case 6007:  /* pred_compressvnx8qi */
    case 6040:  /* pred_fault_loadvnx8qi */
      return MODE_VNX8QI;

    case 723:  /* *movvnx4qi_whole */
    case 753:  /* *movvnx4qi_fract */
    case 802:  /* pred_movvnx4qi */
    case 833:  /* pred_storevnx4qi */
    case 878:  /* pred_mergevnx4qi */
    case 909:  /* pred_mergevnx4qi_scalar */
    case 935:  /* *pred_broadcastvnx4qi */
    case 970:  /* pred_strided_loadvnx4qi */
    case 1001:  /* pred_strided_storevnx4qi */
    case 1034:  /* pred_indexed_oloadvnx4qi_same_eew */
    case 1035:  /* pred_indexed_uloadvnx4qi_same_eew */
    case 1196:  /* pred_indexed_oloadvnx4qi_x2_smaller_eew */
    case 1197:  /* pred_indexed_uloadvnx4qi_x2_smaller_eew */
    case 1234:  /* pred_indexed_oloadvnx4qi_x4_smaller_eew */
    case 1235:  /* pred_indexed_uloadvnx4qi_x4_smaller_eew */
    case 1252:  /* pred_indexed_oloadvnx4qi_x8_smaller_eew */
    case 1253:  /* pred_indexed_uloadvnx4qi_x8_smaller_eew */
    case 1352:  /* pred_indexed_ostorevnx4qivnx4qi */
    case 1353:  /* pred_indexed_ustorevnx4qivnx4qi */
    case 1364:  /* pred_indexed_ostorevnx4qivnx4hi */
    case 1365:  /* pred_indexed_ustorevnx4qivnx4hi */
    case 1376:  /* pred_indexed_ostorevnx4qivnx4si */
    case 1377:  /* pred_indexed_ustorevnx4qivnx4si */
    case 1388:  /* pred_indexed_ostorevnx4qivnx4di */
    case 1389:  /* pred_indexed_ustorevnx4qivnx4di */
    case 1516:  /* pred_addvnx4qi */
    case 1517:  /* pred_subvnx4qi */
    case 1518:  /* pred_andvnx4qi */
    case 1519:  /* pred_iorvnx4qi */
    case 1520:  /* pred_xorvnx4qi */
    case 1521:  /* pred_ashlvnx4qi */
    case 1522:  /* pred_ashrvnx4qi */
    case 1523:  /* pred_lshrvnx4qi */
    case 1524:  /* pred_smaxvnx4qi */
    case 1525:  /* pred_umaxvnx4qi */
    case 1526:  /* pred_sminvnx4qi */
    case 1527:  /* pred_uminvnx4qi */
    case 1528:  /* pred_mulvnx4qi */
    case 1529:  /* pred_divvnx4qi */
    case 1530:  /* pred_udivvnx4qi */
    case 1531:  /* pred_modvnx4qi */
    case 1532:  /* pred_umodvnx4qi */
    case 1862:  /* pred_ashlvnx4qi_scalar */
    case 1863:  /* pred_ashrvnx4qi_scalar */
    case 1864:  /* pred_lshrvnx4qi_scalar */
    case 1940:  /* pred_addvnx4qi_scalar */
    case 1941:  /* pred_andvnx4qi_scalar */
    case 1942:  /* pred_iorvnx4qi_scalar */
    case 1943:  /* pred_xorvnx4qi_scalar */
    case 1944:  /* pred_smaxvnx4qi_scalar */
    case 1945:  /* pred_umaxvnx4qi_scalar */
    case 1946:  /* pred_sminvnx4qi_scalar */
    case 1947:  /* pred_uminvnx4qi_scalar */
    case 1948:  /* pred_mulvnx4qi_scalar */
    case 2094:  /* pred_subvnx4qi_scalar */
    case 2095:  /* pred_divvnx4qi_scalar */
    case 2096:  /* pred_udivvnx4qi_scalar */
    case 2097:  /* pred_modvnx4qi_scalar */
    case 2098:  /* pred_umodvnx4qi_scalar */
    case 2176:  /* pred_subvnx4qi_reverse_scalar */
    case 2318:  /* pred_mulhvnx4qi */
    case 2319:  /* pred_mulhuvnx4qi */
    case 2320:  /* pred_mulhsuvnx4qi */
    case 2384:  /* pred_mulhvnx4qi_scalar */
    case 2385:  /* pred_mulhuvnx4qi_scalar */
    case 2386:  /* pred_mulhsuvnx4qi_scalar */
    case 2458:  /* pred_adcvnx4qi */
    case 2480:  /* pred_sbcvnx4qi */
    case 2502:  /* pred_adcvnx4qi_scalar */
    case 2520:  /* pred_sbcvnx4qi_scalar */
    case 2554:  /* pred_madcvnx4qi */
    case 2576:  /* pred_msbcvnx4qi */
    case 2598:  /* pred_madcvnx4qi_scalar */
    case 2616:  /* pred_msbcvnx4qi_scalar */
    case 2650:  /* pred_madcvnx4qi_overflow */
    case 2672:  /* pred_msbcvnx4qi_overflow */
    case 2694:  /* pred_madcvnx4qi_overflow_scalar */
    case 2712:  /* pred_msbcvnx4qi_overflow_scalar */
    case 2748:  /* pred_negvnx4qi */
    case 2749:  /* pred_one_cmplvnx4qi */
    case 2856:  /* pred_dual_widen_addsvnx4hi */
    case 2857:  /* pred_dual_widen_subsvnx4hi */
    case 2858:  /* pred_dual_widen_mulsvnx4hi */
    case 2859:  /* pred_dual_widen_adduvnx4hi */
    case 2860:  /* pred_dual_widen_subuvnx4hi */
    case 2861:  /* pred_dual_widen_muluvnx4hi */
    case 2946:  /* pred_dual_widen_addsvnx4hi_scalar */
    case 2947:  /* pred_dual_widen_subsvnx4hi_scalar */
    case 2948:  /* pred_dual_widen_mulsvnx4hi_scalar */
    case 2949:  /* pred_dual_widen_adduvnx4hi_scalar */
    case 2950:  /* pred_dual_widen_subuvnx4hi_scalar */
    case 2951:  /* pred_dual_widen_muluvnx4hi_scalar */
    case 3032:  /* pred_single_widen_addsvnx4hi */
    case 3033:  /* pred_single_widen_subsvnx4hi */
    case 3034:  /* pred_single_widen_adduvnx4hi */
    case 3035:  /* pred_single_widen_subuvnx4hi */
    case 3092:  /* pred_single_widen_addsvnx4hi_scalar */
    case 3093:  /* pred_single_widen_subsvnx4hi_scalar */
    case 3094:  /* pred_single_widen_adduvnx4hi_scalar */
    case 3095:  /* pred_single_widen_subuvnx4hi_scalar */
    case 3146:  /* pred_widen_mulsuvnx4hi */
    case 3161:  /* pred_widen_mulsuvnx4hi_scalar */
    case 3178:  /* pred_extendvnx4hi */
    case 3179:  /* pred_zero_extendvnx4hi */
    case 3208:  /* pred_narrow_ashrvnx4hi */
    case 3209:  /* pred_narrow_lshrvnx4hi */
    case 3238:  /* pred_narrow_ashrvnx4hi_scalar */
    case 3239:  /* pred_narrow_lshrvnx4hi_scalar */
    case 3266:  /* pred_truncvnx4hi */
    case 3287:  /* pred_ssaddvnx4qi */
    case 3288:  /* pred_sssubvnx4qi */
    case 3289:  /* pred_usaddvnx4qi */
    case 3290:  /* pred_ussubvnx4qi */
    case 3371:  /* pred_ssaddvnx4qi_scalar */
    case 3372:  /* pred_usaddvnx4qi_scalar */
    case 3407:  /* pred_sssubvnx4qi_scalar */
    case 3408:  /* pred_ussubvnx4qi_scalar */
    case 3485:  /* pred_aadduvnx4qi */
    case 3486:  /* pred_aaddvnx4qi */
    case 3487:  /* pred_asubuvnx4qi */
    case 3488:  /* pred_asubvnx4qi */
    case 3489:  /* pred_smulvnx4qi */
    case 3490:  /* pred_ssrlvnx4qi */
    case 3491:  /* pred_ssravnx4qi */
    case 3635:  /* pred_aadduvnx4qi_scalar */
    case 3636:  /* pred_aaddvnx4qi_scalar */
    case 3637:  /* pred_asubuvnx4qi_scalar */
    case 3638:  /* pred_asubvnx4qi_scalar */
    case 3639:  /* pred_smulvnx4qi_scalar */
    case 3719:  /* pred_ssrlvnx4qi_scalar */
    case 3720:  /* pred_ssravnx4qi_scalar */
    case 3803:  /* pred_narrow_clipvnx4hi */
    case 3804:  /* pred_narrow_clipuvnx4hi */
    case 3833:  /* pred_narrow_clipvnx4hi_scalar */
    case 3834:  /* pred_narrow_clipuvnx4hi_scalar */
    case 3861:  /* *pred_cmpvnx4qi */
    case 3883:  /* *pred_cmpvnx4qi_narrow */
    case 3905:  /* *pred_ltgevnx4qi */
    case 3927:  /* *pred_ltgevnx4qi_narrow */
    case 3949:  /* *pred_cmpvnx4qi_scalar */
    case 3967:  /* *pred_cmpvnx4qi_scalar_narrow */
    case 3985:  /* *pred_eqnevnx4qi_scalar */
    case 4003:  /* *pred_eqnevnx4qi_scalar_narrow */
    case 4053:  /* *pred_maddvnx4qi */
    case 4075:  /* *pred_maccvnx4qi */
    case 4097:  /* *pred_mul_plusvnx4qi */
    case 4119:  /* *pred_maddvnx4qi_scalar */
    case 4141:  /* *pred_maccvnx4qi_scalar */
    case 4163:  /* *pred_mul_plusvnx4qi_scalar */
    case 4197:  /* *pred_nmsubvnx4qi */
    case 4219:  /* *pred_nmsacvnx4qi */
    case 4241:  /* *pred_minus_mulvnx4qi */
    case 4263:  /* *pred_nmsubvnx4qi_scalar */
    case 4285:  /* *pred_nmsacvnx4qi_scalar */
    case 4307:  /* *pred_minus_mulvnx4qi_scalar */
    case 4343:  /* pred_widen_mul_plussvnx4hi */
    case 4344:  /* pred_widen_mul_plusuvnx4hi */
    case 4373:  /* pred_widen_mul_plussvnx4hi_scalar */
    case 4374:  /* pred_widen_mul_plusuvnx4hi_scalar */
    case 4401:  /* pred_widen_mul_plussuvnx4hi */
    case 4416:  /* pred_widen_mul_plussuvnx4hi_scalar */
    case 4431:  /* pred_widen_mul_plususvnx4hi_scalar */
    case 4558:  /* pred_iotavnx4qi */
    case 4580:  /* pred_seriesvnx4qi */
    case 5345:  /* pred_reduc_sumvnx4qivnx8qi */
    case 5346:  /* pred_reduc_maxuvnx4qivnx8qi */
    case 5347:  /* pred_reduc_maxvnx4qivnx8qi */
    case 5348:  /* pred_reduc_minuvnx4qivnx8qi */
    case 5349:  /* pred_reduc_minvnx4qivnx8qi */
    case 5350:  /* pred_reduc_andvnx4qivnx8qi */
    case 5351:  /* pred_reduc_orvnx4qivnx8qi */
    case 5352:  /* pred_reduc_xorvnx4qivnx8qi */
    case 5521:  /* pred_reduc_sumvnx4qivnx4qi */
    case 5522:  /* pred_reduc_maxuvnx4qivnx4qi */
    case 5523:  /* pred_reduc_maxvnx4qivnx4qi */
    case 5524:  /* pred_reduc_minuvnx4qivnx4qi */
    case 5525:  /* pred_reduc_minvnx4qivnx4qi */
    case 5526:  /* pred_reduc_andvnx4qivnx4qi */
    case 5527:  /* pred_reduc_orvnx4qivnx4qi */
    case 5528:  /* pred_reduc_xorvnx4qivnx4qi */
    case 5629:  /* pred_widen_reduc_plusvnx4qivnx4hi */
    case 5630:  /* pred_widen_reduc_plusuvnx4qivnx4hi */
    case 5665:  /* pred_widen_reduc_plusvnx4qivnx2hi */
    case 5666:  /* pred_widen_reduc_plusuvnx4qivnx2hi */
    case 5747:  /* *pred_extract_firstvnx4qi */
    case 5784:  /* pred_slideupvnx4qi */
    case 5785:  /* pred_slidedownvnx4qi */
    case 5846:  /* pred_slide1upvnx4qi */
    case 5847:  /* pred_slide1downvnx4qi */
    case 5914:  /* pred_gathervnx4qi */
    case 5945:  /* pred_gathervnx4qi_scalar */
    case 5976:  /* pred_gatherei16vnx4qi */
    case 6006:  /* pred_compressvnx4qi */
    case 6039:  /* pred_fault_loadvnx4qi */
      return MODE_VNX4QI;

    case 752:  /* *movvnx2qi_fract */
    case 801:  /* pred_movvnx2qi */
    case 832:  /* pred_storevnx2qi */
    case 877:  /* pred_mergevnx2qi */
    case 908:  /* pred_mergevnx2qi_scalar */
    case 934:  /* *pred_broadcastvnx2qi */
    case 969:  /* pred_strided_loadvnx2qi */
    case 1000:  /* pred_strided_storevnx2qi */
    case 1032:  /* pred_indexed_oloadvnx2qi_same_eew */
    case 1033:  /* pred_indexed_uloadvnx2qi_same_eew */
    case 1194:  /* pred_indexed_oloadvnx2qi_x2_smaller_eew */
    case 1195:  /* pred_indexed_uloadvnx2qi_x2_smaller_eew */
    case 1232:  /* pred_indexed_oloadvnx2qi_x4_smaller_eew */
    case 1233:  /* pred_indexed_uloadvnx2qi_x4_smaller_eew */
    case 1250:  /* pred_indexed_oloadvnx2qi_x8_smaller_eew */
    case 1251:  /* pred_indexed_uloadvnx2qi_x8_smaller_eew */
    case 1304:  /* pred_indexed_ostorevnx2qivnx2qi */
    case 1305:  /* pred_indexed_ustorevnx2qivnx2qi */
    case 1316:  /* pred_indexed_ostorevnx2qivnx2hi */
    case 1317:  /* pred_indexed_ustorevnx2qivnx2hi */
    case 1328:  /* pred_indexed_ostorevnx2qivnx2si */
    case 1329:  /* pred_indexed_ustorevnx2qivnx2si */
    case 1340:  /* pred_indexed_ostorevnx2qivnx2di */
    case 1341:  /* pred_indexed_ustorevnx2qivnx2di */
    case 1499:  /* pred_addvnx2qi */
    case 1500:  /* pred_subvnx2qi */
    case 1501:  /* pred_andvnx2qi */
    case 1502:  /* pred_iorvnx2qi */
    case 1503:  /* pred_xorvnx2qi */
    case 1504:  /* pred_ashlvnx2qi */
    case 1505:  /* pred_ashrvnx2qi */
    case 1506:  /* pred_lshrvnx2qi */
    case 1507:  /* pred_smaxvnx2qi */
    case 1508:  /* pred_umaxvnx2qi */
    case 1509:  /* pred_sminvnx2qi */
    case 1510:  /* pred_uminvnx2qi */
    case 1511:  /* pred_mulvnx2qi */
    case 1512:  /* pred_divvnx2qi */
    case 1513:  /* pred_udivvnx2qi */
    case 1514:  /* pred_modvnx2qi */
    case 1515:  /* pred_umodvnx2qi */
    case 1859:  /* pred_ashlvnx2qi_scalar */
    case 1860:  /* pred_ashrvnx2qi_scalar */
    case 1861:  /* pred_lshrvnx2qi_scalar */
    case 1931:  /* pred_addvnx2qi_scalar */
    case 1932:  /* pred_andvnx2qi_scalar */
    case 1933:  /* pred_iorvnx2qi_scalar */
    case 1934:  /* pred_xorvnx2qi_scalar */
    case 1935:  /* pred_smaxvnx2qi_scalar */
    case 1936:  /* pred_umaxvnx2qi_scalar */
    case 1937:  /* pred_sminvnx2qi_scalar */
    case 1938:  /* pred_uminvnx2qi_scalar */
    case 1939:  /* pred_mulvnx2qi_scalar */
    case 2089:  /* pred_subvnx2qi_scalar */
    case 2090:  /* pred_divvnx2qi_scalar */
    case 2091:  /* pred_udivvnx2qi_scalar */
    case 2092:  /* pred_modvnx2qi_scalar */
    case 2093:  /* pred_umodvnx2qi_scalar */
    case 2175:  /* pred_subvnx2qi_reverse_scalar */
    case 2315:  /* pred_mulhvnx2qi */
    case 2316:  /* pred_mulhuvnx2qi */
    case 2317:  /* pred_mulhsuvnx2qi */
    case 2381:  /* pred_mulhvnx2qi_scalar */
    case 2382:  /* pred_mulhuvnx2qi_scalar */
    case 2383:  /* pred_mulhsuvnx2qi_scalar */
    case 2457:  /* pred_adcvnx2qi */
    case 2479:  /* pred_sbcvnx2qi */
    case 2501:  /* pred_adcvnx2qi_scalar */
    case 2519:  /* pred_sbcvnx2qi_scalar */
    case 2553:  /* pred_madcvnx2qi */
    case 2575:  /* pred_msbcvnx2qi */
    case 2597:  /* pred_madcvnx2qi_scalar */
    case 2615:  /* pred_msbcvnx2qi_scalar */
    case 2649:  /* pred_madcvnx2qi_overflow */
    case 2671:  /* pred_msbcvnx2qi_overflow */
    case 2693:  /* pred_madcvnx2qi_overflow_scalar */
    case 2711:  /* pred_msbcvnx2qi_overflow_scalar */
    case 2746:  /* pred_negvnx2qi */
    case 2747:  /* pred_one_cmplvnx2qi */
    case 2850:  /* pred_dual_widen_addsvnx2hi */
    case 2851:  /* pred_dual_widen_subsvnx2hi */
    case 2852:  /* pred_dual_widen_mulsvnx2hi */
    case 2853:  /* pred_dual_widen_adduvnx2hi */
    case 2854:  /* pred_dual_widen_subuvnx2hi */
    case 2855:  /* pred_dual_widen_muluvnx2hi */
    case 2940:  /* pred_dual_widen_addsvnx2hi_scalar */
    case 2941:  /* pred_dual_widen_subsvnx2hi_scalar */
    case 2942:  /* pred_dual_widen_mulsvnx2hi_scalar */
    case 2943:  /* pred_dual_widen_adduvnx2hi_scalar */
    case 2944:  /* pred_dual_widen_subuvnx2hi_scalar */
    case 2945:  /* pred_dual_widen_muluvnx2hi_scalar */
    case 3028:  /* pred_single_widen_addsvnx2hi */
    case 3029:  /* pred_single_widen_subsvnx2hi */
    case 3030:  /* pred_single_widen_adduvnx2hi */
    case 3031:  /* pred_single_widen_subuvnx2hi */
    case 3088:  /* pred_single_widen_addsvnx2hi_scalar */
    case 3089:  /* pred_single_widen_subsvnx2hi_scalar */
    case 3090:  /* pred_single_widen_adduvnx2hi_scalar */
    case 3091:  /* pred_single_widen_subuvnx2hi_scalar */
    case 3145:  /* pred_widen_mulsuvnx2hi */
    case 3160:  /* pred_widen_mulsuvnx2hi_scalar */
    case 3176:  /* pred_extendvnx2hi */
    case 3177:  /* pred_zero_extendvnx2hi */
    case 3206:  /* pred_narrow_ashrvnx2hi */
    case 3207:  /* pred_narrow_lshrvnx2hi */
    case 3236:  /* pred_narrow_ashrvnx2hi_scalar */
    case 3237:  /* pred_narrow_lshrvnx2hi_scalar */
    case 3265:  /* pred_truncvnx2hi */
    case 3283:  /* pred_ssaddvnx2qi */
    case 3284:  /* pred_sssubvnx2qi */
    case 3285:  /* pred_usaddvnx2qi */
    case 3286:  /* pred_ussubvnx2qi */
    case 3369:  /* pred_ssaddvnx2qi_scalar */
    case 3370:  /* pred_usaddvnx2qi_scalar */
    case 3405:  /* pred_sssubvnx2qi_scalar */
    case 3406:  /* pred_ussubvnx2qi_scalar */
    case 3478:  /* pred_aadduvnx2qi */
    case 3479:  /* pred_aaddvnx2qi */
    case 3480:  /* pred_asubuvnx2qi */
    case 3481:  /* pred_asubvnx2qi */
    case 3482:  /* pred_smulvnx2qi */
    case 3483:  /* pred_ssrlvnx2qi */
    case 3484:  /* pred_ssravnx2qi */
    case 3630:  /* pred_aadduvnx2qi_scalar */
    case 3631:  /* pred_aaddvnx2qi_scalar */
    case 3632:  /* pred_asubuvnx2qi_scalar */
    case 3633:  /* pred_asubvnx2qi_scalar */
    case 3634:  /* pred_smulvnx2qi_scalar */
    case 3717:  /* pred_ssrlvnx2qi_scalar */
    case 3718:  /* pred_ssravnx2qi_scalar */
    case 3801:  /* pred_narrow_clipvnx2hi */
    case 3802:  /* pred_narrow_clipuvnx2hi */
    case 3831:  /* pred_narrow_clipvnx2hi_scalar */
    case 3832:  /* pred_narrow_clipuvnx2hi_scalar */
    case 3860:  /* *pred_cmpvnx2qi */
    case 3882:  /* *pred_cmpvnx2qi_narrow */
    case 3904:  /* *pred_ltgevnx2qi */
    case 3926:  /* *pred_ltgevnx2qi_narrow */
    case 3948:  /* *pred_cmpvnx2qi_scalar */
    case 3966:  /* *pred_cmpvnx2qi_scalar_narrow */
    case 3984:  /* *pred_eqnevnx2qi_scalar */
    case 4002:  /* *pred_eqnevnx2qi_scalar_narrow */
    case 4052:  /* *pred_maddvnx2qi */
    case 4074:  /* *pred_maccvnx2qi */
    case 4096:  /* *pred_mul_plusvnx2qi */
    case 4118:  /* *pred_maddvnx2qi_scalar */
    case 4140:  /* *pred_maccvnx2qi_scalar */
    case 4162:  /* *pred_mul_plusvnx2qi_scalar */
    case 4196:  /* *pred_nmsubvnx2qi */
    case 4218:  /* *pred_nmsacvnx2qi */
    case 4240:  /* *pred_minus_mulvnx2qi */
    case 4262:  /* *pred_nmsubvnx2qi_scalar */
    case 4284:  /* *pred_nmsacvnx2qi_scalar */
    case 4306:  /* *pred_minus_mulvnx2qi_scalar */
    case 4341:  /* pred_widen_mul_plussvnx2hi */
    case 4342:  /* pred_widen_mul_plusuvnx2hi */
    case 4371:  /* pred_widen_mul_plussvnx2hi_scalar */
    case 4372:  /* pred_widen_mul_plusuvnx2hi_scalar */
    case 4400:  /* pred_widen_mul_plussuvnx2hi */
    case 4415:  /* pred_widen_mul_plussuvnx2hi_scalar */
    case 4430:  /* pred_widen_mul_plususvnx2hi_scalar */
    case 4557:  /* pred_iotavnx2qi */
    case 4579:  /* pred_seriesvnx2qi */
    case 5337:  /* pred_reduc_sumvnx2qivnx8qi */
    case 5338:  /* pred_reduc_maxuvnx2qivnx8qi */
    case 5339:  /* pred_reduc_maxvnx2qivnx8qi */
    case 5340:  /* pred_reduc_minuvnx2qivnx8qi */
    case 5341:  /* pred_reduc_minvnx2qivnx8qi */
    case 5342:  /* pred_reduc_andvnx2qivnx8qi */
    case 5343:  /* pred_reduc_orvnx2qivnx8qi */
    case 5344:  /* pred_reduc_xorvnx2qivnx8qi */
    case 5513:  /* pred_reduc_sumvnx2qivnx4qi */
    case 5514:  /* pred_reduc_maxuvnx2qivnx4qi */
    case 5515:  /* pred_reduc_maxvnx2qivnx4qi */
    case 5516:  /* pred_reduc_minuvnx2qivnx4qi */
    case 5517:  /* pred_reduc_minvnx2qivnx4qi */
    case 5518:  /* pred_reduc_andvnx2qivnx4qi */
    case 5519:  /* pred_reduc_orvnx2qivnx4qi */
    case 5520:  /* pred_reduc_xorvnx2qivnx4qi */
    case 5627:  /* pred_widen_reduc_plusvnx2qivnx4hi */
    case 5628:  /* pred_widen_reduc_plusuvnx2qivnx4hi */
    case 5663:  /* pred_widen_reduc_plusvnx2qivnx2hi */
    case 5664:  /* pred_widen_reduc_plusuvnx2qivnx2hi */
    case 5746:  /* *pred_extract_firstvnx2qi */
    case 5782:  /* pred_slideupvnx2qi */
    case 5783:  /* pred_slidedownvnx2qi */
    case 5844:  /* pred_slide1upvnx2qi */
    case 5845:  /* pred_slide1downvnx2qi */
    case 5913:  /* pred_gathervnx2qi */
    case 5944:  /* pred_gathervnx2qi_scalar */
    case 5975:  /* pred_gatherei16vnx2qi */
    case 6005:  /* pred_compressvnx2qi */
    case 6038:  /* pred_fault_loadvnx2qi */
      return MODE_VNX2QI;

    case 751:  /* *movvnx1qi_fract */
    case 800:  /* pred_movvnx1qi */
    case 831:  /* pred_storevnx1qi */
    case 876:  /* pred_mergevnx1qi */
    case 907:  /* pred_mergevnx1qi_scalar */
    case 933:  /* *pred_broadcastvnx1qi */
    case 968:  /* pred_strided_loadvnx1qi */
    case 999:  /* pred_strided_storevnx1qi */
    case 1030:  /* pred_indexed_oloadvnx1qi_same_eew */
    case 1031:  /* pred_indexed_uloadvnx1qi_same_eew */
    case 1192:  /* pred_indexed_oloadvnx1qi_x2_smaller_eew */
    case 1193:  /* pred_indexed_uloadvnx1qi_x2_smaller_eew */
    case 1230:  /* pred_indexed_oloadvnx1qi_x4_smaller_eew */
    case 1231:  /* pred_indexed_uloadvnx1qi_x4_smaller_eew */
    case 1248:  /* pred_indexed_oloadvnx1qi_x8_smaller_eew */
    case 1249:  /* pred_indexed_uloadvnx1qi_x8_smaller_eew */
    case 1256:  /* pred_indexed_ostorevnx1qivnx1qi */
    case 1257:  /* pred_indexed_ustorevnx1qivnx1qi */
    case 1258:  /* pred_indexed_ostorevnx1qivnx1hi */
    case 1259:  /* pred_indexed_ustorevnx1qivnx1hi */
    case 1260:  /* pred_indexed_ostorevnx1qivnx1si */
    case 1261:  /* pred_indexed_ustorevnx1qivnx1si */
    case 1262:  /* pred_indexed_ostorevnx1qivnx1di */
    case 1263:  /* pred_indexed_ustorevnx1qivnx1di */
    case 1482:  /* pred_addvnx1qi */
    case 1483:  /* pred_subvnx1qi */
    case 1484:  /* pred_andvnx1qi */
    case 1485:  /* pred_iorvnx1qi */
    case 1486:  /* pred_xorvnx1qi */
    case 1487:  /* pred_ashlvnx1qi */
    case 1488:  /* pred_ashrvnx1qi */
    case 1489:  /* pred_lshrvnx1qi */
    case 1490:  /* pred_smaxvnx1qi */
    case 1491:  /* pred_umaxvnx1qi */
    case 1492:  /* pred_sminvnx1qi */
    case 1493:  /* pred_uminvnx1qi */
    case 1494:  /* pred_mulvnx1qi */
    case 1495:  /* pred_divvnx1qi */
    case 1496:  /* pred_udivvnx1qi */
    case 1497:  /* pred_modvnx1qi */
    case 1498:  /* pred_umodvnx1qi */
    case 1856:  /* pred_ashlvnx1qi_scalar */
    case 1857:  /* pred_ashrvnx1qi_scalar */
    case 1858:  /* pred_lshrvnx1qi_scalar */
    case 1922:  /* pred_addvnx1qi_scalar */
    case 1923:  /* pred_andvnx1qi_scalar */
    case 1924:  /* pred_iorvnx1qi_scalar */
    case 1925:  /* pred_xorvnx1qi_scalar */
    case 1926:  /* pred_smaxvnx1qi_scalar */
    case 1927:  /* pred_umaxvnx1qi_scalar */
    case 1928:  /* pred_sminvnx1qi_scalar */
    case 1929:  /* pred_uminvnx1qi_scalar */
    case 1930:  /* pred_mulvnx1qi_scalar */
    case 2084:  /* pred_subvnx1qi_scalar */
    case 2085:  /* pred_divvnx1qi_scalar */
    case 2086:  /* pred_udivvnx1qi_scalar */
    case 2087:  /* pred_modvnx1qi_scalar */
    case 2088:  /* pred_umodvnx1qi_scalar */
    case 2174:  /* pred_subvnx1qi_reverse_scalar */
    case 2312:  /* pred_mulhvnx1qi */
    case 2313:  /* pred_mulhuvnx1qi */
    case 2314:  /* pred_mulhsuvnx1qi */
    case 2378:  /* pred_mulhvnx1qi_scalar */
    case 2379:  /* pred_mulhuvnx1qi_scalar */
    case 2380:  /* pred_mulhsuvnx1qi_scalar */
    case 2456:  /* pred_adcvnx1qi */
    case 2478:  /* pred_sbcvnx1qi */
    case 2500:  /* pred_adcvnx1qi_scalar */
    case 2518:  /* pred_sbcvnx1qi_scalar */
    case 2552:  /* pred_madcvnx1qi */
    case 2574:  /* pred_msbcvnx1qi */
    case 2596:  /* pred_madcvnx1qi_scalar */
    case 2614:  /* pred_msbcvnx1qi_scalar */
    case 2648:  /* pred_madcvnx1qi_overflow */
    case 2670:  /* pred_msbcvnx1qi_overflow */
    case 2692:  /* pred_madcvnx1qi_overflow_scalar */
    case 2710:  /* pred_msbcvnx1qi_overflow_scalar */
    case 2744:  /* pred_negvnx1qi */
    case 2745:  /* pred_one_cmplvnx1qi */
    case 2844:  /* pred_dual_widen_addsvnx1hi */
    case 2845:  /* pred_dual_widen_subsvnx1hi */
    case 2846:  /* pred_dual_widen_mulsvnx1hi */
    case 2847:  /* pred_dual_widen_adduvnx1hi */
    case 2848:  /* pred_dual_widen_subuvnx1hi */
    case 2849:  /* pred_dual_widen_muluvnx1hi */
    case 2934:  /* pred_dual_widen_addsvnx1hi_scalar */
    case 2935:  /* pred_dual_widen_subsvnx1hi_scalar */
    case 2936:  /* pred_dual_widen_mulsvnx1hi_scalar */
    case 2937:  /* pred_dual_widen_adduvnx1hi_scalar */
    case 2938:  /* pred_dual_widen_subuvnx1hi_scalar */
    case 2939:  /* pred_dual_widen_muluvnx1hi_scalar */
    case 3024:  /* pred_single_widen_addsvnx1hi */
    case 3025:  /* pred_single_widen_subsvnx1hi */
    case 3026:  /* pred_single_widen_adduvnx1hi */
    case 3027:  /* pred_single_widen_subuvnx1hi */
    case 3084:  /* pred_single_widen_addsvnx1hi_scalar */
    case 3085:  /* pred_single_widen_subsvnx1hi_scalar */
    case 3086:  /* pred_single_widen_adduvnx1hi_scalar */
    case 3087:  /* pred_single_widen_subuvnx1hi_scalar */
    case 3144:  /* pred_widen_mulsuvnx1hi */
    case 3159:  /* pred_widen_mulsuvnx1hi_scalar */
    case 3174:  /* pred_extendvnx1hi */
    case 3175:  /* pred_zero_extendvnx1hi */
    case 3204:  /* pred_narrow_ashrvnx1hi */
    case 3205:  /* pred_narrow_lshrvnx1hi */
    case 3234:  /* pred_narrow_ashrvnx1hi_scalar */
    case 3235:  /* pred_narrow_lshrvnx1hi_scalar */
    case 3264:  /* pred_truncvnx1hi */
    case 3279:  /* pred_ssaddvnx1qi */
    case 3280:  /* pred_sssubvnx1qi */
    case 3281:  /* pred_usaddvnx1qi */
    case 3282:  /* pred_ussubvnx1qi */
    case 3367:  /* pred_ssaddvnx1qi_scalar */
    case 3368:  /* pred_usaddvnx1qi_scalar */
    case 3403:  /* pred_sssubvnx1qi_scalar */
    case 3404:  /* pred_ussubvnx1qi_scalar */
    case 3471:  /* pred_aadduvnx1qi */
    case 3472:  /* pred_aaddvnx1qi */
    case 3473:  /* pred_asubuvnx1qi */
    case 3474:  /* pred_asubvnx1qi */
    case 3475:  /* pred_smulvnx1qi */
    case 3476:  /* pred_ssrlvnx1qi */
    case 3477:  /* pred_ssravnx1qi */
    case 3625:  /* pred_aadduvnx1qi_scalar */
    case 3626:  /* pred_aaddvnx1qi_scalar */
    case 3627:  /* pred_asubuvnx1qi_scalar */
    case 3628:  /* pred_asubvnx1qi_scalar */
    case 3629:  /* pred_smulvnx1qi_scalar */
    case 3715:  /* pred_ssrlvnx1qi_scalar */
    case 3716:  /* pred_ssravnx1qi_scalar */
    case 3799:  /* pred_narrow_clipvnx1hi */
    case 3800:  /* pred_narrow_clipuvnx1hi */
    case 3829:  /* pred_narrow_clipvnx1hi_scalar */
    case 3830:  /* pred_narrow_clipuvnx1hi_scalar */
    case 3859:  /* *pred_cmpvnx1qi */
    case 3881:  /* *pred_cmpvnx1qi_narrow */
    case 3903:  /* *pred_ltgevnx1qi */
    case 3925:  /* *pred_ltgevnx1qi_narrow */
    case 3947:  /* *pred_cmpvnx1qi_scalar */
    case 3965:  /* *pred_cmpvnx1qi_scalar_narrow */
    case 3983:  /* *pred_eqnevnx1qi_scalar */
    case 4001:  /* *pred_eqnevnx1qi_scalar_narrow */
    case 4051:  /* *pred_maddvnx1qi */
    case 4073:  /* *pred_maccvnx1qi */
    case 4095:  /* *pred_mul_plusvnx1qi */
    case 4117:  /* *pred_maddvnx1qi_scalar */
    case 4139:  /* *pred_maccvnx1qi_scalar */
    case 4161:  /* *pred_mul_plusvnx1qi_scalar */
    case 4195:  /* *pred_nmsubvnx1qi */
    case 4217:  /* *pred_nmsacvnx1qi */
    case 4239:  /* *pred_minus_mulvnx1qi */
    case 4261:  /* *pred_nmsubvnx1qi_scalar */
    case 4283:  /* *pred_nmsacvnx1qi_scalar */
    case 4305:  /* *pred_minus_mulvnx1qi_scalar */
    case 4339:  /* pred_widen_mul_plussvnx1hi */
    case 4340:  /* pred_widen_mul_plusuvnx1hi */
    case 4369:  /* pred_widen_mul_plussvnx1hi_scalar */
    case 4370:  /* pred_widen_mul_plusuvnx1hi_scalar */
    case 4399:  /* pred_widen_mul_plussuvnx1hi */
    case 4414:  /* pred_widen_mul_plussuvnx1hi_scalar */
    case 4429:  /* pred_widen_mul_plususvnx1hi_scalar */
    case 4556:  /* pred_iotavnx1qi */
    case 4578:  /* pred_seriesvnx1qi */
    case 5329:  /* pred_reduc_sumvnx1qivnx8qi */
    case 5330:  /* pred_reduc_maxuvnx1qivnx8qi */
    case 5331:  /* pred_reduc_maxvnx1qivnx8qi */
    case 5332:  /* pred_reduc_minuvnx1qivnx8qi */
    case 5333:  /* pred_reduc_minvnx1qivnx8qi */
    case 5334:  /* pred_reduc_andvnx1qivnx8qi */
    case 5335:  /* pred_reduc_orvnx1qivnx8qi */
    case 5336:  /* pred_reduc_xorvnx1qivnx8qi */
    case 5505:  /* pred_reduc_sumvnx1qivnx4qi */
    case 5506:  /* pred_reduc_maxuvnx1qivnx4qi */
    case 5507:  /* pred_reduc_maxvnx1qivnx4qi */
    case 5508:  /* pred_reduc_minuvnx1qivnx4qi */
    case 5509:  /* pred_reduc_minvnx1qivnx4qi */
    case 5510:  /* pred_reduc_andvnx1qivnx4qi */
    case 5511:  /* pred_reduc_orvnx1qivnx4qi */
    case 5512:  /* pred_reduc_xorvnx1qivnx4qi */
    case 5625:  /* pred_widen_reduc_plusvnx1qivnx4hi */
    case 5626:  /* pred_widen_reduc_plusuvnx1qivnx4hi */
    case 5661:  /* pred_widen_reduc_plusvnx1qivnx2hi */
    case 5662:  /* pred_widen_reduc_plusuvnx1qivnx2hi */
    case 5745:  /* *pred_extract_firstvnx1qi */
    case 5780:  /* pred_slideupvnx1qi */
    case 5781:  /* pred_slidedownvnx1qi */
    case 5842:  /* pred_slide1upvnx1qi */
    case 5843:  /* pred_slide1downvnx1qi */
    case 5912:  /* pred_gathervnx1qi */
    case 5943:  /* pred_gathervnx1qi_scalar */
    case 5974:  /* pred_gatherei16vnx1qi */
    case 6004:  /* pred_compressvnx1qi */
    case 6037:  /* pred_fault_loadvnx1qi */
      return MODE_VNX1QI;

    case 764:  /* *movvnx64bi */
    case 868:  /* pred_movvnx64bi */
    case 875:  /* pred_storevnx64bi */
    case 4462:  /* pred_andvnx64bi */
    case 4463:  /* pred_iorvnx64bi */
    case 4464:  /* pred_xorvnx64bi */
    case 4483:  /* pred_nandvnx64bi */
    case 4484:  /* pred_niorvnx64bi */
    case 4485:  /* pred_nxorvnx64bi */
    case 4498:  /* pred_andnotvnx64bi */
    case 4499:  /* pred_iornotvnx64bi */
    case 4506:  /* pred_notvnx64bi */
    case 4513:  /* pred_popcountvnx64bisi */
    case 4520:  /* pred_popcountvnx64bidi */
    case 4527:  /* pred_ffsvnx64bisi */
    case 4534:  /* pred_ffsvnx64bidi */
    case 4553:  /* pred_sbfvnx64bi */
    case 4554:  /* pred_sifvnx64bi */
    case 4555:  /* pred_sofvnx64bi */
      return MODE_VNX64BI;

    case 763:  /* *movvnx32bi */
    case 867:  /* pred_movvnx32bi */
    case 874:  /* pred_storevnx32bi */
    case 4459:  /* pred_andvnx32bi */
    case 4460:  /* pred_iorvnx32bi */
    case 4461:  /* pred_xorvnx32bi */
    case 4480:  /* pred_nandvnx32bi */
    case 4481:  /* pred_niorvnx32bi */
    case 4482:  /* pred_nxorvnx32bi */
    case 4496:  /* pred_andnotvnx32bi */
    case 4497:  /* pred_iornotvnx32bi */
    case 4505:  /* pred_notvnx32bi */
    case 4512:  /* pred_popcountvnx32bisi */
    case 4519:  /* pred_popcountvnx32bidi */
    case 4526:  /* pred_ffsvnx32bisi */
    case 4533:  /* pred_ffsvnx32bidi */
    case 4550:  /* pred_sbfvnx32bi */
    case 4551:  /* pred_sifvnx32bi */
    case 4552:  /* pred_sofvnx32bi */
      return MODE_VNX32BI;

    case 762:  /* *movvnx16bi */
    case 866:  /* pred_movvnx16bi */
    case 873:  /* pred_storevnx16bi */
    case 4456:  /* pred_andvnx16bi */
    case 4457:  /* pred_iorvnx16bi */
    case 4458:  /* pred_xorvnx16bi */
    case 4477:  /* pred_nandvnx16bi */
    case 4478:  /* pred_niorvnx16bi */
    case 4479:  /* pred_nxorvnx16bi */
    case 4494:  /* pred_andnotvnx16bi */
    case 4495:  /* pred_iornotvnx16bi */
    case 4504:  /* pred_notvnx16bi */
    case 4511:  /* pred_popcountvnx16bisi */
    case 4518:  /* pred_popcountvnx16bidi */
    case 4525:  /* pred_ffsvnx16bisi */
    case 4532:  /* pred_ffsvnx16bidi */
    case 4547:  /* pred_sbfvnx16bi */
    case 4548:  /* pred_sifvnx16bi */
    case 4549:  /* pred_sofvnx16bi */
      return MODE_VNX16BI;

    case 761:  /* *movvnx8bi */
    case 865:  /* pred_movvnx8bi */
    case 872:  /* pred_storevnx8bi */
    case 4453:  /* pred_andvnx8bi */
    case 4454:  /* pred_iorvnx8bi */
    case 4455:  /* pred_xorvnx8bi */
    case 4474:  /* pred_nandvnx8bi */
    case 4475:  /* pred_niorvnx8bi */
    case 4476:  /* pred_nxorvnx8bi */
    case 4492:  /* pred_andnotvnx8bi */
    case 4493:  /* pred_iornotvnx8bi */
    case 4503:  /* pred_notvnx8bi */
    case 4510:  /* pred_popcountvnx8bisi */
    case 4517:  /* pred_popcountvnx8bidi */
    case 4524:  /* pred_ffsvnx8bisi */
    case 4531:  /* pred_ffsvnx8bidi */
    case 4544:  /* pred_sbfvnx8bi */
    case 4545:  /* pred_sifvnx8bi */
    case 4546:  /* pred_sofvnx8bi */
      return MODE_VNX8BI;

    case 760:  /* *movvnx4bi */
    case 864:  /* pred_movvnx4bi */
    case 871:  /* pred_storevnx4bi */
    case 4450:  /* pred_andvnx4bi */
    case 4451:  /* pred_iorvnx4bi */
    case 4452:  /* pred_xorvnx4bi */
    case 4471:  /* pred_nandvnx4bi */
    case 4472:  /* pred_niorvnx4bi */
    case 4473:  /* pred_nxorvnx4bi */
    case 4490:  /* pred_andnotvnx4bi */
    case 4491:  /* pred_iornotvnx4bi */
    case 4502:  /* pred_notvnx4bi */
    case 4509:  /* pred_popcountvnx4bisi */
    case 4516:  /* pred_popcountvnx4bidi */
    case 4523:  /* pred_ffsvnx4bisi */
    case 4530:  /* pred_ffsvnx4bidi */
    case 4541:  /* pred_sbfvnx4bi */
    case 4542:  /* pred_sifvnx4bi */
    case 4543:  /* pred_sofvnx4bi */
      return MODE_VNX4BI;

    case 759:  /* *movvnx2bi */
    case 863:  /* pred_movvnx2bi */
    case 870:  /* pred_storevnx2bi */
    case 4447:  /* pred_andvnx2bi */
    case 4448:  /* pred_iorvnx2bi */
    case 4449:  /* pred_xorvnx2bi */
    case 4468:  /* pred_nandvnx2bi */
    case 4469:  /* pred_niorvnx2bi */
    case 4470:  /* pred_nxorvnx2bi */
    case 4488:  /* pred_andnotvnx2bi */
    case 4489:  /* pred_iornotvnx2bi */
    case 4501:  /* pred_notvnx2bi */
    case 4508:  /* pred_popcountvnx2bisi */
    case 4515:  /* pred_popcountvnx2bidi */
    case 4522:  /* pred_ffsvnx2bisi */
    case 4529:  /* pred_ffsvnx2bidi */
    case 4538:  /* pred_sbfvnx2bi */
    case 4539:  /* pred_sifvnx2bi */
    case 4540:  /* pred_sofvnx2bi */
      return MODE_VNX2BI;

    case 758:  /* *movvnx1bi */
    case 862:  /* pred_movvnx1bi */
    case 869:  /* pred_storevnx1bi */
    case 4444:  /* pred_andvnx1bi */
    case 4445:  /* pred_iorvnx1bi */
    case 4446:  /* pred_xorvnx1bi */
    case 4465:  /* pred_nandvnx1bi */
    case 4466:  /* pred_niorvnx1bi */
    case 4467:  /* pred_nxorvnx1bi */
    case 4486:  /* pred_andnotvnx1bi */
    case 4487:  /* pred_iornotvnx1bi */
    case 4500:  /* pred_notvnx1bi */
    case 4507:  /* pred_popcountvnx1bisi */
    case 4514:  /* pred_popcountvnx1bidi */
    case 4521:  /* pred_ffsvnx1bisi */
    case 4528:  /* pred_ffsvnx1bidi */
    case 4535:  /* pred_sbfvnx1bi */
    case 4536:  /* pred_sifvnx1bi */
    case 4537:  /* pred_sofvnx1bi */
      return MODE_VNX1BI;

    case 2:  /* adddf3 */
    case 9:  /* subdf3 */
    case 20:  /* muldf3 */
    case 45:  /* divdf3 */
    case 48:  /* sqrtdf2 */
    case 51:  /* fmadf4 */
    case 54:  /* fmsdf4 */
    case 57:  /* fnmsdf4 */
    case 60:  /* fnmadf4 */
    case 63:  /* *fmadf4 */
    case 66:  /* *fmsdf4 */
    case 69:  /* *fnmsdf4 */
    case 72:  /* *fnmadf4 */
    case 75:  /* absdf2 */
    case 78:  /* copysigndf3 */
    case 81:  /* negdf2 */
    case 84:  /* fmindf3 */
    case 87:  /* fmaxdf3 */
    case 90:  /* smindf3 */
    case 93:  /* smaxdf3 */
    case 124:  /* extendsfdf2 */
    case 125:  /* extendhfdf2 */
    case 130:  /* fix_truncdfsi2 */
    case 131:  /* fix_truncdfdi2 */
    case 136:  /* fixuns_truncdfsi2 */
    case 137:  /* fixuns_truncdfdi2 */
    case 142:  /* floatsidf2 */
    case 143:  /* floatdidf2 */
    case 148:  /* floatunssidf2 */
    case 149:  /* floatunsdidf2 */
    case 156:  /* lrintdfsi2 */
    case 157:  /* lrounddfsi2 */
    case 158:  /* lrintdfdi2 */
    case 159:  /* lrounddfdi2 */
    case 189:  /* *movdf_hardfloat_rv32 */
    case 190:  /* *movdf_hardfloat_rv64 */
    case 191:  /* *movdf_softfloat */
    case 252:  /* *cstoredfsi4 */
    case 253:  /* *cstoredfdi4 */
    case 309:  /* *riscv_fsnvsnandf2 */
    case 594:  /* th_fmv_hw_w_x */
    case 595:  /* th_fmv_x_w */
    case 596:  /* th_fmv_x_hw */
      return MODE_DF;

    case 1:  /* addsf3 */
    case 8:  /* subsf3 */
    case 19:  /* mulsf3 */
    case 44:  /* divsf3 */
    case 47:  /* sqrtsf2 */
    case 50:  /* fmasf4 */
    case 53:  /* fmssf4 */
    case 56:  /* fnmssf4 */
    case 59:  /* fnmasf4 */
    case 62:  /* *fmasf4 */
    case 65:  /* *fmssf4 */
    case 68:  /* *fnmssf4 */
    case 71:  /* *fnmasf4 */
    case 74:  /* abssf2 */
    case 77:  /* copysignsf3 */
    case 80:  /* negsf2 */
    case 83:  /* fminsf3 */
    case 86:  /* fmaxsf3 */
    case 89:  /* sminsf3 */
    case 92:  /* smaxsf3 */
    case 107:  /* truncdfsf2 */
    case 123:  /* extendhfsf2 */
    case 128:  /* fix_truncsfsi2 */
    case 129:  /* fix_truncsfdi2 */
    case 134:  /* fixuns_truncsfsi2 */
    case 135:  /* fixuns_truncsfdi2 */
    case 140:  /* floatsisf2 */
    case 141:  /* floatdisf2 */
    case 146:  /* floatunssisf2 */
    case 147:  /* floatunsdisf2 */
    case 152:  /* lrintsfsi2 */
    case 153:  /* lroundsfsi2 */
    case 154:  /* lrintsfdi2 */
    case 155:  /* lroundsfdi2 */
    case 187:  /* *movsf_hardfloat */
    case 188:  /* *movsf_softfloat */
    case 250:  /* *cstoresfsi4 */
    case 251:  /* *cstoresfdi4 */
    case 308:  /* *riscv_fsnvsnansf2 */
      return MODE_SF;

    case 3:  /* addhf3 */
    case 10:  /* subhf3 */
    case 21:  /* mulhf3 */
    case 46:  /* divhf3 */
    case 49:  /* sqrthf2 */
    case 52:  /* fmahf4 */
    case 55:  /* fmshf4 */
    case 58:  /* fnmshf4 */
    case 61:  /* fnmahf4 */
    case 64:  /* *fmahf4 */
    case 67:  /* *fmshf4 */
    case 70:  /* *fnmshf4 */
    case 73:  /* *fnmahf4 */
    case 76:  /* abshf2 */
    case 79:  /* copysignhf3 */
    case 82:  /* neghf2 */
    case 85:  /* fminhf3 */
    case 88:  /* fmaxhf3 */
    case 91:  /* sminhf3 */
    case 94:  /* smaxhf3 */
    case 108:  /* truncsfhf2 */
    case 109:  /* truncdfhf2 */
    case 126:  /* *movhf_hardfloat */
    case 127:  /* *movhf_softfloat */
    case 132:  /* fix_trunchfsi2 */
    case 133:  /* fix_trunchfdi2 */
    case 138:  /* fixuns_trunchfsi2 */
    case 139:  /* fixuns_trunchfdi2 */
    case 144:  /* floatsihf2 */
    case 145:  /* floatdihf2 */
    case 150:  /* floatunssihf2 */
    case 151:  /* floatunsdihf2 */
    case 160:  /* lrinthfsi2 */
    case 161:  /* lroundhfsi2 */
    case 162:  /* lrinthfdi2 */
    case 163:  /* lroundhfdi2 */
    case 254:  /* *cstorehfsi4 */
    case 255:  /* *cstorehfdi4 */
    case 310:  /* *riscv_fsnvsnanhf2 */
      return MODE_HF;

    case 5:  /* adddi3 */
    case 11:  /* subdi3 */
    case 15:  /* negdi2 */
    case 23:  /* muldi3 */
    case 26:  /* smuldi3_highpart */
    case 27:  /* umuldi3_highpart */
    case 28:  /* usmuldi3_highpart */
    case 36:  /* divdi3 */
    case 37:  /* udivdi3 */
    case 38:  /* moddi3 */
    case 39:  /* umoddi3 */
    case 40:  /* *divsi3_extended */
    case 41:  /* *udivsi3_extended */
    case 42:  /* *modsi3_extended */
    case 43:  /* *umodsi3_extended */
    case 98:  /* anddi3 */
    case 99:  /* iordi3 */
    case 100:  /* xordi3 */
    case 105:  /* one_cmpldi2 */
    case 110:  /* *zero_extendsidi2_internal */
    case 112:  /* *zero_extendhidi2 */
    case 115:  /* zero_extendqidi2 */
    case 116:  /* extendsidi2 */
    case 165:  /* got_loaddi */
    case 167:  /* tls_add_tp_ledi */
    case 169:  /* got_load_tls_gddi */
    case 171:  /* got_load_tls_iedi */
    case 175:  /* *lowdi */
    case 178:  /* *movdi_32bit */
    case 179:  /* *movdi_64bit */
    case 204:  /* ashldi3 */
    case 205:  /* ashrdi3 */
    case 206:  /* lshrdi3 */
    case 207:  /* *ashldi3_mask */
    case 208:  /* *ashrdi3_mask */
    case 209:  /* *lshrdi3_mask */
    case 210:  /* *ashldi3_mask_1 */
    case 211:  /* *ashrdi3_mask_1 */
    case 212:  /* *lshrdi3_mask_1 */
    case 225:  /* zero_extendsidi2_shifted */
    case 245:  /* *movdidicc */
    case 257:  /* *seq_zero_disi */
    case 258:  /* *seq_zero_didi */
    case 260:  /* *sne_zero_disi */
    case 261:  /* *sne_zero_didi */
    case 264:  /* *sgt_disi */
    case 265:  /* *sgtu_disi */
    case 266:  /* *sgt_didi */
    case 267:  /* *sgtu_didi */
    case 270:  /* *sge_disi */
    case 271:  /* *sgeu_disi */
    case 272:  /* *sge_didi */
    case 273:  /* *sgeu_didi */
    case 276:  /* *slt_disi */
    case 277:  /* *sltu_disi */
    case 278:  /* *slt_didi */
    case 279:  /* *sltu_didi */
    case 282:  /* *sle_disi */
    case 283:  /* *sleu_disi */
    case 284:  /* *sle_didi */
    case 285:  /* *sleu_didi */
    case 331:  /* *zero_extendsidi2_bitmanip */
    case 333:  /* *shNadd */
    case 335:  /* *shNadduw */
    case 336:  /* *add.uw */
    case 337:  /* *slliuw */
    case 340:  /* *and_notdi */
    case 341:  /* *ior_notdi */
    case 343:  /* *xor_notdi */
    case 350:  /* *clzdi2 */
    case 351:  /* *ctzdi2 */
    case 352:  /* *popcountdi2 */
    case 354:  /* *zero_extendhidi2_bitmanip */
    case 357:  /* *extendqidi2_zbb */
    case 360:  /* *extendhidi2_zbb */
    case 573:  /* *th_addsldi4 */
    case 575:  /* *th_srridi3 */
    case 577:  /* *th_extdi4 */
    case 579:  /* *th_extudi4 */
    case 581:  /* *th_clzdi2 */
    case 583:  /* *th_revdi2 */
    case 587:  /* *th_cond_movdisi */
    case 589:  /* *th_cond_movdidi */
    case 591:  /* *th_cond_gpr_movdisi */
    case 593:  /* *th_cond_gpr_movdidi */
    case 598:  /* *th_muladi */
    case 604:  /* *th_mulsdi */
    case 610:  /* *th_mempair_load_di2 */
    case 612:  /* *th_mempair_store_di2 */
    case 613:  /* *th_mempair_load_extendsidi2 */
    case 614:  /* *th_mempair_load_zero_extendsidi2 */
    case 794:  /* vsetvldi */
    case 797:  /* vsetvl_discard_resultdi */
    case 6036:  /* read_vldi_zero_extend */
      return MODE_DI;

    case 4:  /* addsi3 */
    case 6:  /* *addsi3_extended */
    case 7:  /* *addsi3_extended2 */
    case 12:  /* subsi3 */
    case 13:  /* *subsi3_extended */
    case 14:  /* *subsi3_extended2 */
    case 16:  /* negsi2 */
    case 17:  /* *negsi2_extended */
    case 18:  /* *negsi2_extended2 */
    case 22:  /* mulsi3 */
    case 24:  /* *mulsi3_extended */
    case 25:  /* *mulsi3_extended2 */
    case 29:  /* smulsi3_highpart */
    case 30:  /* umulsi3_highpart */
    case 31:  /* usmulsi3_highpart */
    case 32:  /* divsi3 */
    case 33:  /* udivsi3 */
    case 34:  /* modsi3 */
    case 35:  /* umodsi3 */
    case 95:  /* andsi3 */
    case 96:  /* iorsi3 */
    case 97:  /* xorsi3 */
    case 101:  /* *andsi3_internal */
    case 102:  /* *iorsi3_internal */
    case 103:  /* *xorsi3_internal */
    case 104:  /* one_cmplsi2 */
    case 106:  /* *one_cmplsi2_internal */
    case 111:  /* *zero_extendhisi2 */
    case 114:  /* zero_extendqisi2 */
    case 117:  /* *extendqihi2 */
    case 118:  /* *extendqisi2 */
    case 119:  /* *extendqidi2 */
    case 120:  /* *extendhihi2 */
    case 121:  /* *extendhisi2 */
    case 122:  /* *extendhidi2 */
    case 164:  /* got_loadsi */
    case 166:  /* tls_add_tp_lesi */
    case 168:  /* got_load_tls_gdsi */
    case 170:  /* got_load_tls_iesi */
    case 174:  /* *lowsi */
    case 180:  /* *movsi_internal */
    case 195:  /* ashlsi3 */
    case 196:  /* ashrsi3 */
    case 197:  /* lshrsi3 */
    case 198:  /* *ashlsi3_mask */
    case 199:  /* *ashrsi3_mask */
    case 200:  /* *lshrsi3_mask */
    case 201:  /* *ashlsi3_mask_1 */
    case 202:  /* *ashrsi3_mask_1 */
    case 203:  /* *lshrsi3_mask_1 */
    case 213:  /* *ashlsi3_extend */
    case 214:  /* *ashrsi3_extend */
    case 215:  /* *lshrsi3_extend */
    case 216:  /* *ashlsi3_extend_mask */
    case 217:  /* *ashrsi3_extend_mask */
    case 218:  /* *lshrsi3_extend_mask */
    case 219:  /* *ashlsi3_extend_mask_1 */
    case 220:  /* *ashrsi3_extend_mask_1 */
    case 221:  /* *lshrsi3_extend_mask_1 */
    case 222:  /* *lshrsi3_zero_extend_1 */
    case 223:  /* *lshrsi3_zero_extend_2 */
    case 224:  /* *lshrsi3_zero_extend_3 */
    case 243:  /* *movsisicc */
    case 244:  /* *movsidicc */
    case 256:  /* *seq_zero_sisi */
    case 259:  /* *sne_zero_sisi */
    case 262:  /* *sgt_sisi */
    case 263:  /* *sgtu_sisi */
    case 268:  /* *sge_sisi */
    case 269:  /* *sgeu_sisi */
    case 274:  /* *slt_sisi */
    case 275:  /* *sltu_sisi */
    case 280:  /* *sle_sisi */
    case 281:  /* *sleu_sisi */
    case 332:  /* *shNadd */
    case 338:  /* *and_notsi */
    case 339:  /* *ior_notsi */
    case 342:  /* *xor_notsi */
    case 344:  /* *clzsi2 */
    case 345:  /* *ctzsi2 */
    case 346:  /* *popcountsi2 */
    case 347:  /* *clzdisi2 */
    case 348:  /* *ctzdisi2 */
    case 349:  /* *popcountdisi2 */
    case 353:  /* *zero_extendhisi2_bitmanip */
    case 356:  /* *extendqisi2_zbb */
    case 359:  /* *extendhisi2_zbb */
    case 572:  /* *th_addslsi4 */
    case 574:  /* *th_srrisi3 */
    case 576:  /* *th_extsi4 */
    case 578:  /* *th_extusi4 */
    case 580:  /* *th_clzsi2 */
    case 582:  /* *th_revsi2 */
    case 586:  /* *th_cond_movsisi */
    case 588:  /* *th_cond_movsidi */
    case 590:  /* *th_cond_gpr_movsisi */
    case 592:  /* *th_cond_gpr_movsidi */
    case 597:  /* *th_mulasi */
    case 599:  /* *th_mulawsi */
    case 600:  /* *th_mulawsi2 */
    case 601:  /* *th_maddhisi4 */
    case 602:  /* *th_sextw_maddhisi4 */
    case 603:  /* *th_mulssi */
    case 605:  /* *th_mulswsi */
    case 606:  /* *th_mulswsi2 */
    case 607:  /* *th_msubhisi4 */
    case 608:  /* *th_sextw_msubhisi4 */
    case 609:  /* *th_mempair_load_si2 */
    case 611:  /* *th_mempair_store_si2 */
    case 793:  /* vsetvlsi */
    case 795:  /* vsetvl_vtype_change_only */
    case 796:  /* vsetvl_discard_resultsi */
    case 798:  /* vsetvlsi_no_side_effects */
    case 799:  /* vsetvldi_no_side_effects */
    case 6035:  /* read_vlsi */
      return MODE_SI;

    case 113:  /* zero_extendqihi2 */
    case 181:  /* *movhi_internal */
    case 182:  /* *addhihi3 */
    case 183:  /* *addsihi3 */
    case 184:  /* *xorhihi3 */
    case 185:  /* *xorsihi3 */
    case 355:  /* *extendqihi2_zbb */
    case 358:  /* *extendhihi2_zbb */
    case 361:  /* *zero_extendhisi2_zbb */
    case 362:  /* *zero_extendhidi2_zbb */
      return MODE_HI;

    case 186:  /* *movqi_internal */
      return MODE_QI;

    case 241:  /* *branchsi */
    case 242:  /* *branchdi */
    case 286:  /* jump */
    case 287:  /* indirect_jumpsi */
    case 288:  /* indirect_jumpdi */
    case 289:  /* tablejumpsi */
    case 290:  /* tablejumpdi */
    case 291:  /* blockage */
    case 292:  /* simple_return */
    case 293:  /* simple_return_internal */
    case 301:  /* nop */
      return MODE_NONE;

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return MODE_UNKNOWN;

    }
}

enum attr_move_type
get_attr_move_type (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 113:  /* zero_extendqihi2 */
    case 114:  /* zero_extendqisi2 */
    case 115:  /* zero_extendqidi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return MOVE_TYPE_ANDI;
        }
      else
        {
	  return MOVE_TYPE_LOAD;
        }

    case 116:  /* extendsidi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return MOVE_TYPE_MOVE;
        }
      else
        {
	  return MOVE_TYPE_LOAD;
        }

    case 110:  /* *zero_extendsidi2_internal */
    case 111:  /* *zero_extendhisi2 */
    case 112:  /* *zero_extendhidi2 */
    case 117:  /* *extendqihi2 */
    case 118:  /* *extendqisi2 */
    case 119:  /* *extendqidi2 */
    case 120:  /* *extendhihi2 */
    case 121:  /* *extendhisi2 */
    case 122:  /* *extendhidi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return MOVE_TYPE_SHIFT_SHIFT;
        }
      else
        {
	  return MOVE_TYPE_LOAD;
        }

    case 127:  /* *movhf_softfloat */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return MOVE_TYPE_FMOVE;
        }
      else if (which_alternative == 1)
        {
	  return MOVE_TYPE_MOVE;
        }
      else if (which_alternative == 2)
        {
	  return MOVE_TYPE_LOAD;
        }
      else if (which_alternative == 3)
        {
	  return MOVE_TYPE_STORE;
        }
      else if (which_alternative == 4)
        {
	  return MOVE_TYPE_MTC;
        }
      else
        {
	  return MOVE_TYPE_MFC;
        }

    case 178:  /* *movdi_32bit */
    case 179:  /* *movdi_64bit */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return MOVE_TYPE_MOVE;
        }
      else if (which_alternative == 1)
        {
	  return MOVE_TYPE_CONST;
        }
      else if (which_alternative == 2)
        {
	  return MOVE_TYPE_LOAD;
        }
      else if (which_alternative == 3)
        {
	  return MOVE_TYPE_STORE;
        }
      else if (which_alternative == 4)
        {
	  return MOVE_TYPE_MTC;
        }
      else if (which_alternative == 5)
        {
	  return MOVE_TYPE_FPLOAD;
        }
      else if (which_alternative == 6)
        {
	  return MOVE_TYPE_MFC;
        }
      else if (which_alternative == 7)
        {
	  return MOVE_TYPE_FMOVE;
        }
      else if (which_alternative == 8)
        {
	  return MOVE_TYPE_FPSTORE;
        }
      else
        {
	  return MOVE_TYPE_RDVLENB;
        }

    case 180:  /* *movsi_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return MOVE_TYPE_MOVE;
        }
      else if (which_alternative == 1)
        {
	  return MOVE_TYPE_CONST;
        }
      else if (which_alternative == 2)
        {
	  return MOVE_TYPE_LOAD;
        }
      else if (which_alternative == 3)
        {
	  return MOVE_TYPE_STORE;
        }
      else if (which_alternative == 4)
        {
	  return MOVE_TYPE_MTC;
        }
      else if (which_alternative == 5)
        {
	  return MOVE_TYPE_FPLOAD;
        }
      else if (which_alternative == 6)
        {
	  return MOVE_TYPE_MFC;
        }
      else if (which_alternative == 7)
        {
	  return MOVE_TYPE_FPSTORE;
        }
      else
        {
	  return MOVE_TYPE_RDVLENB;
        }

    case 181:  /* *movhi_internal */
    case 186:  /* *movqi_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return MOVE_TYPE_MOVE;
        }
      else if (which_alternative == 1)
        {
	  return MOVE_TYPE_CONST;
        }
      else if (which_alternative == 2)
        {
	  return MOVE_TYPE_LOAD;
        }
      else if (which_alternative == 3)
        {
	  return MOVE_TYPE_STORE;
        }
      else if (which_alternative == 4)
        {
	  return MOVE_TYPE_MTC;
        }
      else if (which_alternative == 5)
        {
	  return MOVE_TYPE_MFC;
        }
      else
        {
	  return MOVE_TYPE_RDVLENB;
        }

    case 126:  /* *movhf_hardfloat */
    case 187:  /* *movsf_hardfloat */
    case 189:  /* *movdf_hardfloat_rv32 */
    case 190:  /* *movdf_hardfloat_rv64 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return MOVE_TYPE_FMOVE;
        }
      else if (which_alternative == 1)
        {
	  return MOVE_TYPE_MTC;
        }
      else if (which_alternative == 2)
        {
	  return MOVE_TYPE_FPLOAD;
        }
      else if (which_alternative == 3)
        {
	  return MOVE_TYPE_FPSTORE;
        }
      else if (which_alternative == 4)
        {
	  return MOVE_TYPE_STORE;
        }
      else if (which_alternative == 5)
        {
	  return MOVE_TYPE_MTC;
        }
      else if (which_alternative == 6)
        {
	  return MOVE_TYPE_MFC;
        }
      else if (which_alternative == 7)
        {
	  return MOVE_TYPE_MOVE;
        }
      else if (which_alternative == 8)
        {
	  return MOVE_TYPE_LOAD;
        }
      else
        {
	  return MOVE_TYPE_STORE;
        }

    case 188:  /* *movsf_softfloat */
    case 191:  /* *movdf_softfloat */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return MOVE_TYPE_MOVE;
        }
      else if (which_alternative == 1)
        {
	  return MOVE_TYPE_LOAD;
        }
      else
        {
	  return MOVE_TYPE_STORE;
        }

    case 594:  /* th_fmv_hw_w_x */
    case 595:  /* th_fmv_x_w */
    case 596:  /* th_fmv_x_hw */
      return MOVE_TYPE_MOVE;

    case 611:  /* *th_mempair_store_si2 */
    case 612:  /* *th_mempair_store_di2 */
      return MOVE_TYPE_STORE;

    case 609:  /* *th_mempair_load_si2 */
    case 610:  /* *th_mempair_load_di2 */
    case 613:  /* *th_mempair_load_extendsidi2 */
    case 614:  /* *th_mempair_load_zero_extendsidi2 */
      return MOVE_TYPE_LOAD;

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return MOVE_TYPE_UNKNOWN;

    }
}

int
get_attr_ratio (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;
  enum attr_mode cached_mode ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 963:  /* *pred_broadcastvnx8df */
    case 954:  /* *pred_broadcastvnx8di */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 205 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx8DImode));
        }

    case 962:  /* *pred_broadcastvnx4df */
    case 953:  /* *pred_broadcastvnx4di */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 203 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx4DImode));
        }

    case 961:  /* *pred_broadcastvnx2df */
    case 952:  /* *pred_broadcastvnx2di */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 201 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx2DImode));
        }

    case 960:  /* *pred_broadcastvnx1df */
    case 951:  /* *pred_broadcastvnx1di */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 199 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx1DImode));
        }

    case 959:  /* *pred_broadcastvnx16sf */
    case 950:  /* *pred_broadcastvnx16si */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 197 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx16SImode));
        }

    case 958:  /* *pred_broadcastvnx8sf */
    case 949:  /* *pred_broadcastvnx8si */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 195 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx8SImode));
        }

    case 957:  /* *pred_broadcastvnx4sf */
    case 948:  /* *pred_broadcastvnx4si */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 193 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx4SImode));
        }

    case 956:  /* *pred_broadcastvnx2sf */
    case 947:  /* *pred_broadcastvnx2si */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 191 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx2SImode));
        }

    case 955:  /* *pred_broadcastvnx1sf */
    case 946:  /* *pred_broadcastvnx1si */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 189 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx1SImode));
        }

    case 945:  /* *pred_broadcastvnx32hi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 187 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx32HImode));
        }

    case 944:  /* *pred_broadcastvnx16hi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 185 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx16HImode));
        }

    case 943:  /* *pred_broadcastvnx8hi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 183 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx8HImode));
        }

    case 942:  /* *pred_broadcastvnx4hi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 181 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx4HImode));
        }

    case 941:  /* *pred_broadcastvnx2hi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 179 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx2HImode));
        }

    case 940:  /* *pred_broadcastvnx1hi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 177 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx1HImode));
        }

    case 939:  /* *pred_broadcastvnx64qi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 175 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx64QImode));
        }

    case 938:  /* *pred_broadcastvnx32qi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 173 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx32QImode));
        }

    case 937:  /* *pred_broadcastvnx16qi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 171 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx16QImode));
        }

    case 936:  /* *pred_broadcastvnx8qi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 169 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx8QImode));
        }

    case 935:  /* *pred_broadcastvnx4qi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 167 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx4QImode));
        }

    case 934:  /* *pred_broadcastvnx2qi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 165 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx2QImode));
        }

    case 933:  /* *pred_broadcastvnx1qi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 163 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx1QImode));
        }

    case 830:  /* pred_movvnx8df */
    case 821:  /* pred_movvnx8di */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 205 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx8DImode));
        }

    case 829:  /* pred_movvnx4df */
    case 820:  /* pred_movvnx4di */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 203 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx4DImode));
        }

    case 828:  /* pred_movvnx2df */
    case 819:  /* pred_movvnx2di */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 201 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx2DImode));
        }

    case 827:  /* pred_movvnx1df */
    case 818:  /* pred_movvnx1di */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 199 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx1DImode));
        }

    case 826:  /* pred_movvnx16sf */
    case 817:  /* pred_movvnx16si */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 197 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx16SImode));
        }

    case 825:  /* pred_movvnx8sf */
    case 816:  /* pred_movvnx8si */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 195 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx8SImode));
        }

    case 824:  /* pred_movvnx4sf */
    case 815:  /* pred_movvnx4si */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 193 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx4SImode));
        }

    case 823:  /* pred_movvnx2sf */
    case 814:  /* pred_movvnx2si */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 191 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx2SImode));
        }

    case 822:  /* pred_movvnx1sf */
    case 813:  /* pred_movvnx1si */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 189 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx1SImode));
        }

    case 812:  /* pred_movvnx32hi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 187 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx32HImode));
        }

    case 811:  /* pred_movvnx16hi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 185 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx16HImode));
        }

    case 810:  /* pred_movvnx8hi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 183 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx8HImode));
        }

    case 809:  /* pred_movvnx4hi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 181 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx4HImode));
        }

    case 808:  /* pred_movvnx2hi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 179 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx2HImode));
        }

    case 807:  /* pred_movvnx1hi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 177 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx1HImode));
        }

    case 806:  /* pred_movvnx64qi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 175 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx64QImode));
        }

    case 805:  /* pred_movvnx32qi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 173 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx32QImode));
        }

    case 804:  /* pred_movvnx16qi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 171 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx16QImode));
        }

    case 803:  /* pred_movvnx8qi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 169 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx8QImode));
        }

    case 802:  /* pred_movvnx4qi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 167 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx4QImode));
        }

    case 801:  /* pred_movvnx2qi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 165 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx2QImode));
        }

    case 800:  /* pred_movvnx1qi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return 255 /* 0xff */;
        }
      else
        {
	  return 
#line 163 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx1QImode));
        }

    case 6044:  /* pred_fault_loadvnx1hi */
    case 1006:  /* pred_strided_storevnx1hi */
    case 975:  /* pred_strided_loadvnx1hi */
    case 838:  /* pred_storevnx1hi */
    case 754:  /* *movvnx1hi_fract */
      extract_constrain_insn_cached (insn);
      return 
#line 177 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx1HImode));

    case 6038:  /* pred_fault_loadvnx2qi */
    case 4501:  /* pred_notvnx2bi */
    case 4489:  /* pred_iornotvnx2bi */
    case 4488:  /* pred_andnotvnx2bi */
    case 4470:  /* pred_nxorvnx2bi */
    case 4469:  /* pred_niorvnx2bi */
    case 4468:  /* pred_nandvnx2bi */
    case 4449:  /* pred_xorvnx2bi */
    case 4448:  /* pred_iorvnx2bi */
    case 4447:  /* pred_andvnx2bi */
    case 1000:  /* pred_strided_storevnx2qi */
    case 969:  /* pred_strided_loadvnx2qi */
    case 870:  /* pred_storevnx2bi */
    case 863:  /* pred_movvnx2bi */
    case 832:  /* pred_storevnx2qi */
    case 759:  /* *movvnx2bi */
    case 752:  /* *movvnx2qi_fract */
      extract_constrain_insn_cached (insn);
      return 
#line 165 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx2QImode));

    case 6037:  /* pred_fault_loadvnx1qi */
    case 4500:  /* pred_notvnx1bi */
    case 4487:  /* pred_iornotvnx1bi */
    case 4486:  /* pred_andnotvnx1bi */
    case 4467:  /* pred_nxorvnx1bi */
    case 4466:  /* pred_niorvnx1bi */
    case 4465:  /* pred_nandvnx1bi */
    case 4446:  /* pred_xorvnx1bi */
    case 4445:  /* pred_iorvnx1bi */
    case 4444:  /* pred_andvnx1bi */
    case 999:  /* pred_strided_storevnx1qi */
    case 968:  /* pred_strided_loadvnx1qi */
    case 869:  /* pred_storevnx1bi */
    case 862:  /* pred_movvnx1bi */
    case 831:  /* pred_storevnx1qi */
    case 758:  /* *movvnx1bi */
    case 751:  /* *movvnx1qi_fract */
      extract_constrain_insn_cached (insn);
      return 
#line 163 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx1QImode));

    case 6067:  /* pred_fault_loadvnx8df */
    case 6058:  /* pred_fault_loadvnx8di */
    case 1029:  /* pred_strided_storevnx8df */
    case 1020:  /* pred_strided_storevnx8di */
    case 998:  /* pred_strided_loadvnx8df */
    case 989:  /* pred_strided_loadvnx8di */
    case 861:  /* pred_storevnx8df */
    case 852:  /* pred_storevnx8di */
    case 750:  /* *movvnx8df_whole */
    case 741:  /* *movvnx8di_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 205 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx8DImode));

    case 6066:  /* pred_fault_loadvnx4df */
    case 6057:  /* pred_fault_loadvnx4di */
    case 1028:  /* pred_strided_storevnx4df */
    case 1019:  /* pred_strided_storevnx4di */
    case 997:  /* pred_strided_loadvnx4df */
    case 988:  /* pred_strided_loadvnx4di */
    case 860:  /* pred_storevnx4df */
    case 851:  /* pred_storevnx4di */
    case 749:  /* *movvnx4df_whole */
    case 740:  /* *movvnx4di_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 203 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx4DImode));

    case 6065:  /* pred_fault_loadvnx2df */
    case 6056:  /* pred_fault_loadvnx2di */
    case 1027:  /* pred_strided_storevnx2df */
    case 1018:  /* pred_strided_storevnx2di */
    case 996:  /* pred_strided_loadvnx2df */
    case 987:  /* pred_strided_loadvnx2di */
    case 859:  /* pred_storevnx2df */
    case 850:  /* pred_storevnx2di */
    case 748:  /* *movvnx2df_whole */
    case 739:  /* *movvnx2di_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 201 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx2DImode));

    case 6064:  /* pred_fault_loadvnx1df */
    case 6055:  /* pred_fault_loadvnx1di */
    case 1026:  /* pred_strided_storevnx1df */
    case 1017:  /* pred_strided_storevnx1di */
    case 995:  /* pred_strided_loadvnx1df */
    case 986:  /* pred_strided_loadvnx1di */
    case 858:  /* pred_storevnx1df */
    case 849:  /* pred_storevnx1di */
    case 747:  /* *movvnx1df_whole */
    case 738:  /* *movvnx1di_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 199 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx1DImode));

    case 6063:  /* pred_fault_loadvnx16sf */
    case 6054:  /* pred_fault_loadvnx16si */
    case 1025:  /* pred_strided_storevnx16sf */
    case 1016:  /* pred_strided_storevnx16si */
    case 994:  /* pred_strided_loadvnx16sf */
    case 985:  /* pred_strided_loadvnx16si */
    case 857:  /* pred_storevnx16sf */
    case 848:  /* pred_storevnx16si */
    case 746:  /* *movvnx16sf_whole */
    case 737:  /* *movvnx16si_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 197 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx16SImode));

    case 6062:  /* pred_fault_loadvnx8sf */
    case 6053:  /* pred_fault_loadvnx8si */
    case 1024:  /* pred_strided_storevnx8sf */
    case 1015:  /* pred_strided_storevnx8si */
    case 993:  /* pred_strided_loadvnx8sf */
    case 984:  /* pred_strided_loadvnx8si */
    case 856:  /* pred_storevnx8sf */
    case 847:  /* pred_storevnx8si */
    case 745:  /* *movvnx8sf_whole */
    case 736:  /* *movvnx8si_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 195 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx8SImode));

    case 6061:  /* pred_fault_loadvnx4sf */
    case 6052:  /* pred_fault_loadvnx4si */
    case 1023:  /* pred_strided_storevnx4sf */
    case 1014:  /* pred_strided_storevnx4si */
    case 992:  /* pred_strided_loadvnx4sf */
    case 983:  /* pred_strided_loadvnx4si */
    case 855:  /* pred_storevnx4sf */
    case 846:  /* pred_storevnx4si */
    case 744:  /* *movvnx4sf_whole */
    case 735:  /* *movvnx4si_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 193 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx4SImode));

    case 6060:  /* pred_fault_loadvnx2sf */
    case 6051:  /* pred_fault_loadvnx2si */
    case 1022:  /* pred_strided_storevnx2sf */
    case 1013:  /* pred_strided_storevnx2si */
    case 991:  /* pred_strided_loadvnx2sf */
    case 982:  /* pred_strided_loadvnx2si */
    case 854:  /* pred_storevnx2sf */
    case 845:  /* pred_storevnx2si */
    case 743:  /* *movvnx2sf_whole */
    case 734:  /* *movvnx2si_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 191 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx2SImode));

    case 6059:  /* pred_fault_loadvnx1sf */
    case 6050:  /* pred_fault_loadvnx1si */
    case 1021:  /* pred_strided_storevnx1sf */
    case 1012:  /* pred_strided_storevnx1si */
    case 990:  /* pred_strided_loadvnx1sf */
    case 981:  /* pred_strided_loadvnx1si */
    case 853:  /* pred_storevnx1sf */
    case 844:  /* pred_storevnx1si */
    case 757:  /* *movvnx1sf_fract */
    case 756:  /* *movvnx1si_fract */
    case 742:  /* *movvnx1sf_whole */
    case 733:  /* *movvnx1si_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 189 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx1SImode));

    case 6049:  /* pred_fault_loadvnx32hi */
    case 1011:  /* pred_strided_storevnx32hi */
    case 980:  /* pred_strided_loadvnx32hi */
    case 843:  /* pred_storevnx32hi */
    case 732:  /* *movvnx32hi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 187 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx32HImode));

    case 6048:  /* pred_fault_loadvnx16hi */
    case 1010:  /* pred_strided_storevnx16hi */
    case 979:  /* pred_strided_loadvnx16hi */
    case 842:  /* pred_storevnx16hi */
    case 731:  /* *movvnx16hi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 185 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx16HImode));

    case 6047:  /* pred_fault_loadvnx8hi */
    case 1009:  /* pred_strided_storevnx8hi */
    case 978:  /* pred_strided_loadvnx8hi */
    case 841:  /* pred_storevnx8hi */
    case 730:  /* *movvnx8hi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 183 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx8HImode));

    case 6046:  /* pred_fault_loadvnx4hi */
    case 1008:  /* pred_strided_storevnx4hi */
    case 977:  /* pred_strided_loadvnx4hi */
    case 840:  /* pred_storevnx4hi */
    case 729:  /* *movvnx4hi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 181 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx4HImode));

    case 6045:  /* pred_fault_loadvnx2hi */
    case 1007:  /* pred_strided_storevnx2hi */
    case 976:  /* pred_strided_loadvnx2hi */
    case 839:  /* pred_storevnx2hi */
    case 755:  /* *movvnx2hi_fract */
    case 728:  /* *movvnx2hi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 179 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx2HImode));

    case 6043:  /* pred_fault_loadvnx64qi */
    case 4506:  /* pred_notvnx64bi */
    case 4499:  /* pred_iornotvnx64bi */
    case 4498:  /* pred_andnotvnx64bi */
    case 4485:  /* pred_nxorvnx64bi */
    case 4484:  /* pred_niorvnx64bi */
    case 4483:  /* pred_nandvnx64bi */
    case 4464:  /* pred_xorvnx64bi */
    case 4463:  /* pred_iorvnx64bi */
    case 4462:  /* pred_andvnx64bi */
    case 1005:  /* pred_strided_storevnx64qi */
    case 974:  /* pred_strided_loadvnx64qi */
    case 875:  /* pred_storevnx64bi */
    case 868:  /* pred_movvnx64bi */
    case 837:  /* pred_storevnx64qi */
    case 764:  /* *movvnx64bi */
    case 727:  /* *movvnx64qi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 175 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx64QImode));

    case 6042:  /* pred_fault_loadvnx32qi */
    case 4505:  /* pred_notvnx32bi */
    case 4497:  /* pred_iornotvnx32bi */
    case 4496:  /* pred_andnotvnx32bi */
    case 4482:  /* pred_nxorvnx32bi */
    case 4481:  /* pred_niorvnx32bi */
    case 4480:  /* pred_nandvnx32bi */
    case 4461:  /* pred_xorvnx32bi */
    case 4460:  /* pred_iorvnx32bi */
    case 4459:  /* pred_andvnx32bi */
    case 1004:  /* pred_strided_storevnx32qi */
    case 973:  /* pred_strided_loadvnx32qi */
    case 874:  /* pred_storevnx32bi */
    case 867:  /* pred_movvnx32bi */
    case 836:  /* pred_storevnx32qi */
    case 763:  /* *movvnx32bi */
    case 726:  /* *movvnx32qi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 173 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx32QImode));

    case 6041:  /* pred_fault_loadvnx16qi */
    case 4504:  /* pred_notvnx16bi */
    case 4495:  /* pred_iornotvnx16bi */
    case 4494:  /* pred_andnotvnx16bi */
    case 4479:  /* pred_nxorvnx16bi */
    case 4478:  /* pred_niorvnx16bi */
    case 4477:  /* pred_nandvnx16bi */
    case 4458:  /* pred_xorvnx16bi */
    case 4457:  /* pred_iorvnx16bi */
    case 4456:  /* pred_andvnx16bi */
    case 1003:  /* pred_strided_storevnx16qi */
    case 972:  /* pred_strided_loadvnx16qi */
    case 873:  /* pred_storevnx16bi */
    case 866:  /* pred_movvnx16bi */
    case 835:  /* pred_storevnx16qi */
    case 762:  /* *movvnx16bi */
    case 725:  /* *movvnx16qi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 171 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx16QImode));

    case 6040:  /* pred_fault_loadvnx8qi */
    case 4503:  /* pred_notvnx8bi */
    case 4493:  /* pred_iornotvnx8bi */
    case 4492:  /* pred_andnotvnx8bi */
    case 4476:  /* pred_nxorvnx8bi */
    case 4475:  /* pred_niorvnx8bi */
    case 4474:  /* pred_nandvnx8bi */
    case 4455:  /* pred_xorvnx8bi */
    case 4454:  /* pred_iorvnx8bi */
    case 4453:  /* pred_andvnx8bi */
    case 1002:  /* pred_strided_storevnx8qi */
    case 971:  /* pred_strided_loadvnx8qi */
    case 872:  /* pred_storevnx8bi */
    case 865:  /* pred_movvnx8bi */
    case 834:  /* pred_storevnx8qi */
    case 761:  /* *movvnx8bi */
    case 724:  /* *movvnx8qi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 169 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx8QImode));

    case 6039:  /* pred_fault_loadvnx4qi */
    case 4502:  /* pred_notvnx4bi */
    case 4491:  /* pred_iornotvnx4bi */
    case 4490:  /* pred_andnotvnx4bi */
    case 4473:  /* pred_nxorvnx4bi */
    case 4472:  /* pred_niorvnx4bi */
    case 4471:  /* pred_nandvnx4bi */
    case 4452:  /* pred_xorvnx4bi */
    case 4451:  /* pred_iorvnx4bi */
    case 4450:  /* pred_andvnx4bi */
    case 1001:  /* pred_strided_storevnx4qi */
    case 970:  /* pred_strided_loadvnx4qi */
    case 871:  /* pred_storevnx4bi */
    case 864:  /* pred_movvnx4bi */
    case 833:  /* pred_storevnx4qi */
    case 760:  /* *movvnx4bi */
    case 753:  /* *movvnx4qi_fract */
    case 723:  /* *movvnx4qi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 167 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx4QImode));

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      extract_constrain_insn_cached (insn);
      if (((cached_type = get_attr_type (insn)) == TYPE_VIMOV) || (cached_type == TYPE_VFMOV) || (cached_type == TYPE_VLDUX) || (cached_type == TYPE_VLDOX) || (cached_type == TYPE_VSTUX) || (cached_type == TYPE_VSTOX) || (cached_type == TYPE_VIALU) || (cached_type == TYPE_VSHIFT) || (cached_type == TYPE_VICMP) || (cached_type == TYPE_VIMUL) || (cached_type == TYPE_VIDIV) || (cached_type == TYPE_VSALU) || (cached_type == TYPE_VEXT) || (cached_type == TYPE_VIWALU) || (cached_type == TYPE_VIWMUL) || (cached_type == TYPE_VICALU) || (cached_type == TYPE_VNSHIFT) || (cached_type == TYPE_VIMULADD) || (cached_type == TYPE_VIMERGE) || (cached_type == TYPE_VAALU) || (cached_type == TYPE_VSMUL) || (cached_type == TYPE_VSSHIFT) || (cached_type == TYPE_VNCLIP) || (cached_type == TYPE_VIMINMAX) || (cached_type == TYPE_VIWMULADD) || (cached_type == TYPE_VMPOP) || (cached_type == TYPE_VMFFS) || (cached_type == TYPE_VMSFS) || (cached_type == TYPE_VMIOTA) || (cached_type == TYPE_VMIDX) || (cached_type == TYPE_VFALU) || (cached_type == TYPE_VFMUL) || (cached_type == TYPE_VFMINMAX) || (cached_type == TYPE_VFDIV) || (cached_type == TYPE_VFWALU) || (cached_type == TYPE_VFWMUL) || (cached_type == TYPE_VFSQRT) || (cached_type == TYPE_VFRECP) || (cached_type == TYPE_VFSGNJ) || (cached_type == TYPE_VFCMP) || (cached_type == TYPE_VFMERGE) || (cached_type == TYPE_VFCVTITOF) || (cached_type == TYPE_VFCVTFTOI) || (cached_type == TYPE_VFWCVTITOF) || (cached_type == TYPE_VFWCVTFTOI) || (cached_type == TYPE_VFWCVTFTOF) || (cached_type == TYPE_VFNCVTITOF) || (cached_type == TYPE_VFNCVTFTOI) || (cached_type == TYPE_VFNCVTFTOF) || (cached_type == TYPE_VFMULADD) || (cached_type == TYPE_VFWMULADD) || (cached_type == TYPE_VFCLASS) || (cached_type == TYPE_VIRED) || (cached_type == TYPE_VIWRED) || (cached_type == TYPE_VFREDU) || (cached_type == TYPE_VFREDO) || (cached_type == TYPE_VFWREDU) || (cached_type == TYPE_VFWREDO) || (cached_type == TYPE_VIMOVVX) || (cached_type == TYPE_VIMOVXV) || (cached_type == TYPE_VFMOVVF) || (cached_type == TYPE_VFMOVFV) || (cached_type == TYPE_VSLIDEUP) || (cached_type == TYPE_VSLIDEDOWN) || (cached_type == TYPE_VISLIDE1UP) || (cached_type == TYPE_VISLIDE1DOWN) || (cached_type == TYPE_VFSLIDE1UP) || (cached_type == TYPE_VFSLIDE1DOWN) || (cached_type == TYPE_VGATHER) || (cached_type == TYPE_VCOMPRESS))
        {
	  return 255 /* 0xff */;
        }
      else if (((cached_mode = get_attr_mode (insn)) == MODE_VNX1QI) || (cached_mode == MODE_VNX1BI))
        {
	  return 
#line 163 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx1QImode));
        }
      else if ((cached_mode == MODE_VNX2QI) || (cached_mode == MODE_VNX2BI))
        {
	  return 
#line 165 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx2QImode));
        }
      else if ((cached_mode == MODE_VNX4QI) || (cached_mode == MODE_VNX4BI))
        {
	  return 
#line 167 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx4QImode));
        }
      else if ((cached_mode == MODE_VNX8QI) || (cached_mode == MODE_VNX8BI))
        {
	  return 
#line 169 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx8QImode));
        }
      else if ((cached_mode == MODE_VNX16QI) || (cached_mode == MODE_VNX16BI))
        {
	  return 
#line 171 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx16QImode));
        }
      else if ((cached_mode == MODE_VNX32QI) || (cached_mode == MODE_VNX32BI))
        {
	  return 
#line 173 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx32QImode));
        }
      else if ((cached_mode == MODE_VNX64QI) || (cached_mode == MODE_VNX64BI))
        {
	  return 
#line 175 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx64QImode));
        }
      else if (cached_mode == MODE_VNX1HI)
        {
	  return 
#line 177 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx1HImode));
        }
      else if (cached_mode == MODE_VNX2HI)
        {
	  return 
#line 179 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx2HImode));
        }
      else if (cached_mode == MODE_VNX4HI)
        {
	  return 
#line 181 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx4HImode));
        }
      else if (cached_mode == MODE_VNX8HI)
        {
	  return 
#line 183 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx8HImode));
        }
      else if (cached_mode == MODE_VNX16HI)
        {
	  return 
#line 185 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx16HImode));
        }
      else if (cached_mode == MODE_VNX32HI)
        {
	  return 
#line 187 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx32HImode));
        }
      else if ((cached_mode == MODE_VNX1SI) || (cached_mode == MODE_VNX1SF))
        {
	  return 
#line 189 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx1SImode));
        }
      else if ((cached_mode == MODE_VNX2SI) || (cached_mode == MODE_VNX2SF))
        {
	  return 
#line 191 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx2SImode));
        }
      else if ((cached_mode == MODE_VNX4SI) || (cached_mode == MODE_VNX4SF))
        {
	  return 
#line 193 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx4SImode));
        }
      else if ((cached_mode == MODE_VNX8SI) || (cached_mode == MODE_VNX8SF))
        {
	  return 
#line 195 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx8SImode));
        }
      else if ((cached_mode == MODE_VNX16SI) || (cached_mode == MODE_VNX16SF))
        {
	  return 
#line 197 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx16SImode));
        }
      else if ((cached_mode == MODE_VNX1DI) || (cached_mode == MODE_VNX1DF))
        {
	  return 
#line 199 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx1DImode));
        }
      else if ((cached_mode == MODE_VNX2DI) || (cached_mode == MODE_VNX2DF))
        {
	  return 
#line 201 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx2DImode));
        }
      else if ((cached_mode == MODE_VNX4DI) || (cached_mode == MODE_VNX4DF))
        {
	  return 
#line 203 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx4DImode));
        }
      else if ((cached_mode == MODE_VNX8DI) || (cached_mode == MODE_VNX8DF))
        {
	  return 
#line 205 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ratio(E_VNx8DImode));
        }
      else
        {
	  return 255 /* 0xff */;
        }

    default:
      return 255 /* 0xff */;

    }
}

int
get_attr_sew (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_mode cached_mode ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 6067:  /* pred_fault_loadvnx8df */
    case 6066:  /* pred_fault_loadvnx4df */
    case 6065:  /* pred_fault_loadvnx2df */
    case 6064:  /* pred_fault_loadvnx1df */
    case 6058:  /* pred_fault_loadvnx8di */
    case 6057:  /* pred_fault_loadvnx4di */
    case 6056:  /* pred_fault_loadvnx2di */
    case 6055:  /* pred_fault_loadvnx1di */
    case 6034:  /* pred_compressvnx8df */
    case 6033:  /* pred_compressvnx4df */
    case 6032:  /* pred_compressvnx2df */
    case 6031:  /* pred_compressvnx1df */
    case 6025:  /* pred_compressvnx8di */
    case 6024:  /* pred_compressvnx4di */
    case 6023:  /* pred_compressvnx2di */
    case 6022:  /* pred_compressvnx1di */
    case 6003:  /* pred_gatherei16vnx8df */
    case 6002:  /* pred_gatherei16vnx4df */
    case 6001:  /* pred_gatherei16vnx2df */
    case 6000:  /* pred_gatherei16vnx1df */
    case 5994:  /* pred_gatherei16vnx8di */
    case 5993:  /* pred_gatherei16vnx4di */
    case 5992:  /* pred_gatherei16vnx2di */
    case 5991:  /* pred_gatherei16vnx1di */
    case 5973:  /* pred_gathervnx8df_scalar */
    case 5972:  /* pred_gathervnx4df_scalar */
    case 5971:  /* pred_gathervnx2df_scalar */
    case 5970:  /* pred_gathervnx1df_scalar */
    case 5964:  /* pred_gathervnx8di_scalar */
    case 5963:  /* pred_gathervnx4di_scalar */
    case 5962:  /* pred_gathervnx2di_scalar */
    case 5961:  /* pred_gathervnx1di_scalar */
    case 5942:  /* pred_gathervnx8df */
    case 5941:  /* pred_gathervnx4df */
    case 5940:  /* pred_gathervnx2df */
    case 5939:  /* pred_gathervnx1df */
    case 5933:  /* pred_gathervnx8di */
    case 5932:  /* pred_gathervnx4di */
    case 5931:  /* pred_gathervnx2di */
    case 5930:  /* pred_gathervnx1di */
    case 5911:  /* pred_slide1downvnx8df */
    case 5910:  /* pred_slide1upvnx8df */
    case 5909:  /* pred_slide1downvnx4df */
    case 5908:  /* pred_slide1upvnx4df */
    case 5907:  /* pred_slide1downvnx2df */
    case 5906:  /* pred_slide1upvnx2df */
    case 5905:  /* pred_slide1downvnx1df */
    case 5904:  /* pred_slide1upvnx1df */
    case 5893:  /* *pred_slide1downvnx8di_extended */
    case 5892:  /* *pred_slide1upvnx8di_extended */
    case 5891:  /* *pred_slide1downvnx4di_extended */
    case 5890:  /* *pred_slide1upvnx4di_extended */
    case 5889:  /* *pred_slide1downvnx2di_extended */
    case 5888:  /* *pred_slide1upvnx2di_extended */
    case 5887:  /* *pred_slide1downvnx1di_extended */
    case 5886:  /* *pred_slide1upvnx1di_extended */
    case 5885:  /* *pred_slide1downvnx8di */
    case 5884:  /* *pred_slide1upvnx8di */
    case 5883:  /* *pred_slide1downvnx4di */
    case 5882:  /* *pred_slide1upvnx4di */
    case 5881:  /* *pred_slide1downvnx2di */
    case 5880:  /* *pred_slide1upvnx2di */
    case 5879:  /* *pred_slide1downvnx1di */
    case 5878:  /* *pred_slide1upvnx1di */
    case 5841:  /* pred_slidedownvnx8df */
    case 5840:  /* pred_slideupvnx8df */
    case 5839:  /* pred_slidedownvnx4df */
    case 5838:  /* pred_slideupvnx4df */
    case 5837:  /* pred_slidedownvnx2df */
    case 5836:  /* pred_slideupvnx2df */
    case 5835:  /* pred_slidedownvnx1df */
    case 5834:  /* pred_slideupvnx1df */
    case 5823:  /* pred_slidedownvnx8di */
    case 5822:  /* pred_slideupvnx8di */
    case 5821:  /* pred_slidedownvnx4di */
    case 5820:  /* pred_slideupvnx4di */
    case 5819:  /* pred_slidedownvnx2di */
    case 5818:  /* pred_slideupvnx2di */
    case 5817:  /* pred_slidedownvnx1di */
    case 5816:  /* pred_slideupvnx1di */
    case 5779:  /* *pred_extract_firstvnx8df */
    case 5778:  /* *pred_extract_firstvnx4df */
    case 5777:  /* *pred_extract_firstvnx2df */
    case 5776:  /* *pred_extract_firstvnx1df */
    case 5770:  /* pred_extract_first_truncvnx8di */
    case 5769:  /* pred_extract_first_truncvnx4di */
    case 5768:  /* pred_extract_first_truncvnx2di */
    case 5767:  /* pred_extract_first_truncvnx1di */
    case 5766:  /* *pred_extract_firstvnx8di */
    case 5765:  /* *pred_extract_firstvnx4di */
    case 5764:  /* *pred_extract_firstvnx2di */
    case 5763:  /* *pred_extract_firstvnx1di */
    case 5726:  /* pred_reduc_plusuvnx8dfvnx1df */
    case 5725:  /* pred_reduc_plusovnx8dfvnx1df */
    case 5724:  /* pred_reduc_plusuvnx4dfvnx1df */
    case 5723:  /* pred_reduc_plusovnx4dfvnx1df */
    case 5722:  /* pred_reduc_plusuvnx2dfvnx1df */
    case 5721:  /* pred_reduc_plusovnx2dfvnx1df */
    case 5720:  /* pred_reduc_plusuvnx1dfvnx1df */
    case 5719:  /* pred_reduc_plusovnx1dfvnx1df */
    case 5700:  /* pred_reduc_minvnx8dfvnx1df */
    case 5699:  /* pred_reduc_maxvnx8dfvnx1df */
    case 5698:  /* pred_reduc_minvnx4dfvnx1df */
    case 5697:  /* pred_reduc_maxvnx4dfvnx1df */
    case 5696:  /* pred_reduc_minvnx2dfvnx1df */
    case 5695:  /* pred_reduc_maxvnx2dfvnx1df */
    case 5694:  /* pred_reduc_minvnx1dfvnx1df */
    case 5693:  /* pred_reduc_maxvnx1dfvnx1df */
    case 5504:  /* pred_reduc_xorvnx8divnx1DI */
    case 5503:  /* pred_reduc_orvnx8divnx1DI */
    case 5502:  /* pred_reduc_andvnx8divnx1DI */
    case 5501:  /* pred_reduc_minvnx8divnx1DI */
    case 5500:  /* pred_reduc_minuvnx8divnx1DI */
    case 5499:  /* pred_reduc_maxvnx8divnx1DI */
    case 5498:  /* pred_reduc_maxuvnx8divnx1DI */
    case 5497:  /* pred_reduc_sumvnx8divnx1DI */
    case 5496:  /* pred_reduc_xorvnx4divnx1DI */
    case 5495:  /* pred_reduc_orvnx4divnx1DI */
    case 5494:  /* pred_reduc_andvnx4divnx1DI */
    case 5493:  /* pred_reduc_minvnx4divnx1DI */
    case 5492:  /* pred_reduc_minuvnx4divnx1DI */
    case 5491:  /* pred_reduc_maxvnx4divnx1DI */
    case 5490:  /* pred_reduc_maxuvnx4divnx1DI */
    case 5489:  /* pred_reduc_sumvnx4divnx1DI */
    case 5488:  /* pred_reduc_xorvnx2divnx1DI */
    case 5487:  /* pred_reduc_orvnx2divnx1DI */
    case 5486:  /* pred_reduc_andvnx2divnx1DI */
    case 5485:  /* pred_reduc_minvnx2divnx1DI */
    case 5484:  /* pred_reduc_minuvnx2divnx1DI */
    case 5483:  /* pred_reduc_maxvnx2divnx1DI */
    case 5482:  /* pred_reduc_maxuvnx2divnx1DI */
    case 5481:  /* pred_reduc_sumvnx2divnx1DI */
    case 5480:  /* pred_reduc_xorvnx1divnx1DI */
    case 5479:  /* pred_reduc_orvnx1divnx1DI */
    case 5478:  /* pred_reduc_andvnx1divnx1DI */
    case 5477:  /* pred_reduc_minvnx1divnx1DI */
    case 5476:  /* pred_reduc_minuvnx1divnx1DI */
    case 5475:  /* pred_reduc_maxvnx1divnx1DI */
    case 5474:  /* pred_reduc_maxuvnx1divnx1DI */
    case 5473:  /* pred_reduc_sumvnx1divnx1DI */
    case 5238:  /* pred_floatunsvnx8df */
    case 5237:  /* pred_floatvnx8df */
    case 5236:  /* pred_floatunsvnx4df */
    case 5235:  /* pred_floatvnx4df */
    case 5234:  /* pred_floatunsvnx2df */
    case 5233:  /* pred_floatvnx2df */
    case 5232:  /* pred_floatunsvnx1df */
    case 5231:  /* pred_floatvnx1df */
    case 5220:  /* pred_fixuns_truncvnx8df */
    case 5219:  /* pred_fix_truncvnx8df */
    case 5218:  /* pred_fixuns_truncvnx4df */
    case 5217:  /* pred_fix_truncvnx4df */
    case 5216:  /* pred_fixuns_truncvnx2df */
    case 5215:  /* pred_fix_truncvnx2df */
    case 5214:  /* pred_fixuns_truncvnx1df */
    case 5213:  /* pred_fix_truncvnx1df */
    case 5202:  /* pred_fcvt_xu_fvnx8df */
    case 5201:  /* pred_fcvt_x_fvnx8df */
    case 5200:  /* pred_fcvt_xu_fvnx4df */
    case 5199:  /* pred_fcvt_x_fvnx4df */
    case 5198:  /* pred_fcvt_xu_fvnx2df */
    case 5197:  /* pred_fcvt_x_fvnx2df */
    case 5196:  /* pred_fcvt_xu_fvnx1df */
    case 5195:  /* pred_fcvt_x_fvnx1df */
    case 5184:  /* pred_mergevnx8df_scalar */
    case 5183:  /* pred_mergevnx4df_scalar */
    case 5182:  /* pred_mergevnx2df_scalar */
    case 5181:  /* pred_mergevnx1df_scalar */
    case 5175:  /* *pred_eqnevnx8df_scalar_narrow */
    case 5174:  /* *pred_eqnevnx4df_scalar_narrow */
    case 5173:  /* *pred_eqnevnx2df_scalar_narrow */
    case 5172:  /* *pred_eqnevnx1df_scalar_narrow */
    case 5166:  /* *pred_eqnevnx8df_scalar */
    case 5165:  /* *pred_eqnevnx4df_scalar */
    case 5164:  /* *pred_eqnevnx2df_scalar */
    case 5163:  /* *pred_eqnevnx1df_scalar */
    case 5157:  /* *pred_cmpvnx8df_scalar_narrow */
    case 5156:  /* *pred_cmpvnx4df_scalar_narrow */
    case 5155:  /* *pred_cmpvnx2df_scalar_narrow */
    case 5154:  /* *pred_cmpvnx1df_scalar_narrow */
    case 5148:  /* *pred_cmpvnx8df_scalar */
    case 5147:  /* *pred_cmpvnx4df_scalar */
    case 5146:  /* *pred_cmpvnx2df_scalar */
    case 5145:  /* *pred_cmpvnx1df_scalar */
    case 5139:  /* *pred_cmpvnx8df_narrow */
    case 5138:  /* *pred_cmpvnx4df_narrow */
    case 5137:  /* *pred_cmpvnx2df_narrow */
    case 5136:  /* *pred_cmpvnx1df_narrow */
    case 5130:  /* *pred_cmpvnx8df */
    case 5129:  /* *pred_cmpvnx4df */
    case 5128:  /* *pred_cmpvnx2df */
    case 5127:  /* *pred_cmpvnx1df */
    case 5049:  /* pred_classvnx8df */
    case 5048:  /* pred_classvnx4df */
    case 5047:  /* pred_classvnx2df */
    case 5046:  /* pred_classvnx1df */
    case 5040:  /* pred_rec7vnx8df */
    case 5039:  /* pred_rsqrt7vnx8df */
    case 5038:  /* pred_rec7vnx4df */
    case 5037:  /* pred_rsqrt7vnx4df */
    case 5036:  /* pred_rec7vnx2df */
    case 5035:  /* pred_rsqrt7vnx2df */
    case 5034:  /* pred_rec7vnx1df */
    case 5033:  /* pred_rsqrt7vnx1df */
    case 5022:  /* pred_sqrtvnx8df */
    case 5021:  /* pred_absvnx8df */
    case 5020:  /* pred_negvnx8df */
    case 5019:  /* pred_sqrtvnx4df */
    case 5018:  /* pred_absvnx4df */
    case 5017:  /* pred_negvnx4df */
    case 5016:  /* pred_sqrtvnx2df */
    case 5015:  /* pred_absvnx2df */
    case 5014:  /* pred_negvnx2df */
    case 5013:  /* pred_sqrtvnx1df */
    case 5012:  /* pred_absvnx1df */
    case 5011:  /* pred_negvnx1df */
    case 4995:  /* *pred_mul_neg_subvnx8df_scalar */
    case 4994:  /* *pred_mul_neg_addvnx8df_scalar */
    case 4993:  /* *pred_mul_neg_subvnx4df_scalar */
    case 4992:  /* *pred_mul_neg_addvnx4df_scalar */
    case 4991:  /* *pred_mul_neg_subvnx2df_scalar */
    case 4990:  /* *pred_mul_neg_addvnx2df_scalar */
    case 4989:  /* *pred_mul_neg_subvnx1df_scalar */
    case 4988:  /* *pred_mul_neg_addvnx1df_scalar */
    case 4977:  /* *pred_nmaccvnx8df_scalar */
    case 4976:  /* *pred_nmsacvnx8df_scalar */
    case 4975:  /* *pred_nmaccvnx4df_scalar */
    case 4974:  /* *pred_nmsacvnx4df_scalar */
    case 4973:  /* *pred_nmaccvnx2df_scalar */
    case 4972:  /* *pred_nmsacvnx2df_scalar */
    case 4971:  /* *pred_nmaccvnx1df_scalar */
    case 4970:  /* *pred_nmsacvnx1df_scalar */
    case 4959:  /* *pred_nmaddvnx8df_scalar */
    case 4958:  /* *pred_nmsubvnx8df_scalar */
    case 4957:  /* *pred_nmaddvnx4df_scalar */
    case 4956:  /* *pred_nmsubvnx4df_scalar */
    case 4955:  /* *pred_nmaddvnx2df_scalar */
    case 4954:  /* *pred_nmsubvnx2df_scalar */
    case 4953:  /* *pred_nmaddvnx1df_scalar */
    case 4952:  /* *pred_nmsubvnx1df_scalar */
    case 4941:  /* *pred_mul_neg_subvnx8df */
    case 4940:  /* *pred_mul_neg_addvnx8df */
    case 4939:  /* *pred_mul_neg_subvnx4df */
    case 4938:  /* *pred_mul_neg_addvnx4df */
    case 4937:  /* *pred_mul_neg_subvnx2df */
    case 4936:  /* *pred_mul_neg_addvnx2df */
    case 4935:  /* *pred_mul_neg_subvnx1df */
    case 4934:  /* *pred_mul_neg_addvnx1df */
    case 4923:  /* *pred_nmaccvnx8df */
    case 4922:  /* *pred_nmsacvnx8df */
    case 4921:  /* *pred_nmaccvnx4df */
    case 4920:  /* *pred_nmsacvnx4df */
    case 4919:  /* *pred_nmaccvnx2df */
    case 4918:  /* *pred_nmsacvnx2df */
    case 4917:  /* *pred_nmaccvnx1df */
    case 4916:  /* *pred_nmsacvnx1df */
    case 4905:  /* *pred_nmaddvnx8df */
    case 4904:  /* *pred_nmsubvnx8df */
    case 4903:  /* *pred_nmaddvnx4df */
    case 4902:  /* *pred_nmsubvnx4df */
    case 4901:  /* *pred_nmaddvnx2df */
    case 4900:  /* *pred_nmsubvnx2df */
    case 4899:  /* *pred_nmaddvnx1df */
    case 4898:  /* *pred_nmsubvnx1df */
    case 4887:  /* *pred_mul_subvnx8df_scalar */
    case 4886:  /* *pred_mul_addvnx8df_scalar */
    case 4885:  /* *pred_mul_subvnx4df_scalar */
    case 4884:  /* *pred_mul_addvnx4df_scalar */
    case 4883:  /* *pred_mul_subvnx2df_scalar */
    case 4882:  /* *pred_mul_addvnx2df_scalar */
    case 4881:  /* *pred_mul_subvnx1df_scalar */
    case 4880:  /* *pred_mul_addvnx1df_scalar */
    case 4869:  /* *pred_msacvnx8df_scalar */
    case 4868:  /* *pred_maccvnx8df_scalar */
    case 4867:  /* *pred_msacvnx4df_scalar */
    case 4866:  /* *pred_maccvnx4df_scalar */
    case 4865:  /* *pred_msacvnx2df_scalar */
    case 4864:  /* *pred_maccvnx2df_scalar */
    case 4863:  /* *pred_msacvnx1df_scalar */
    case 4862:  /* *pred_maccvnx1df_scalar */
    case 4851:  /* *pred_msubvnx8df_scalar */
    case 4850:  /* *pred_maddvnx8df_scalar */
    case 4849:  /* *pred_msubvnx4df_scalar */
    case 4848:  /* *pred_maddvnx4df_scalar */
    case 4847:  /* *pred_msubvnx2df_scalar */
    case 4846:  /* *pred_maddvnx2df_scalar */
    case 4845:  /* *pred_msubvnx1df_scalar */
    case 4844:  /* *pred_maddvnx1df_scalar */
    case 4833:  /* *pred_mul_subvnx8df */
    case 4832:  /* *pred_mul_addvnx8df */
    case 4831:  /* *pred_mul_subvnx4df */
    case 4830:  /* *pred_mul_addvnx4df */
    case 4829:  /* *pred_mul_subvnx2df */
    case 4828:  /* *pred_mul_addvnx2df */
    case 4827:  /* *pred_mul_subvnx1df */
    case 4826:  /* *pred_mul_addvnx1df */
    case 4815:  /* *pred_msacvnx8df */
    case 4814:  /* *pred_maccvnx8df */
    case 4813:  /* *pred_msacvnx4df */
    case 4812:  /* *pred_maccvnx4df */
    case 4811:  /* *pred_msacvnx2df */
    case 4810:  /* *pred_maccvnx2df */
    case 4809:  /* *pred_msacvnx1df */
    case 4808:  /* *pred_maccvnx1df */
    case 4797:  /* *pred_msubvnx8df */
    case 4796:  /* *pred_maddvnx8df */
    case 4795:  /* *pred_msubvnx4df */
    case 4794:  /* *pred_maddvnx4df */
    case 4793:  /* *pred_msubvnx2df */
    case 4792:  /* *pred_maddvnx2df */
    case 4791:  /* *pred_msubvnx1df */
    case 4790:  /* *pred_maddvnx1df */
    case 4779:  /* pred_xorsignvnx8df_scalar */
    case 4778:  /* pred_ncopysignvnx8df_scalar */
    case 4777:  /* pred_copysignvnx8df_scalar */
    case 4776:  /* pred_xorsignvnx4df_scalar */
    case 4775:  /* pred_ncopysignvnx4df_scalar */
    case 4774:  /* pred_copysignvnx4df_scalar */
    case 4773:  /* pred_xorsignvnx2df_scalar */
    case 4772:  /* pred_ncopysignvnx2df_scalar */
    case 4771:  /* pred_copysignvnx2df_scalar */
    case 4770:  /* pred_xorsignvnx1df_scalar */
    case 4769:  /* pred_ncopysignvnx1df_scalar */
    case 4768:  /* pred_copysignvnx1df_scalar */
    case 4752:  /* pred_xorsignvnx8df */
    case 4751:  /* pred_ncopysignvnx8df */
    case 4750:  /* pred_copysignvnx8df */
    case 4749:  /* pred_xorsignvnx4df */
    case 4748:  /* pred_ncopysignvnx4df */
    case 4747:  /* pred_copysignvnx4df */
    case 4746:  /* pred_xorsignvnx2df */
    case 4745:  /* pred_ncopysignvnx2df */
    case 4744:  /* pred_copysignvnx2df */
    case 4743:  /* pred_xorsignvnx1df */
    case 4742:  /* pred_ncopysignvnx1df */
    case 4741:  /* pred_copysignvnx1df */
    case 4725:  /* pred_divvnx8df_reverse_scalar */
    case 4724:  /* pred_subvnx8df_reverse_scalar */
    case 4723:  /* pred_divvnx4df_reverse_scalar */
    case 4722:  /* pred_subvnx4df_reverse_scalar */
    case 4721:  /* pred_divvnx2df_reverse_scalar */
    case 4720:  /* pred_subvnx2df_reverse_scalar */
    case 4719:  /* pred_divvnx1df_reverse_scalar */
    case 4718:  /* pred_subvnx1df_reverse_scalar */
    case 4707:  /* pred_divvnx8df_scalar */
    case 4706:  /* pred_subvnx8df_scalar */
    case 4705:  /* pred_divvnx4df_scalar */
    case 4704:  /* pred_subvnx4df_scalar */
    case 4703:  /* pred_divvnx2df_scalar */
    case 4702:  /* pred_subvnx2df_scalar */
    case 4701:  /* pred_divvnx1df_scalar */
    case 4700:  /* pred_subvnx1df_scalar */
    case 4689:  /* pred_sminvnx8df_scalar */
    case 4688:  /* pred_smaxvnx8df_scalar */
    case 4687:  /* pred_mulvnx8df_scalar */
    case 4686:  /* pred_addvnx8df_scalar */
    case 4685:  /* pred_sminvnx4df_scalar */
    case 4684:  /* pred_smaxvnx4df_scalar */
    case 4683:  /* pred_mulvnx4df_scalar */
    case 4682:  /* pred_addvnx4df_scalar */
    case 4681:  /* pred_sminvnx2df_scalar */
    case 4680:  /* pred_smaxvnx2df_scalar */
    case 4679:  /* pred_mulvnx2df_scalar */
    case 4678:  /* pred_addvnx2df_scalar */
    case 4677:  /* pred_sminvnx1df_scalar */
    case 4676:  /* pred_smaxvnx1df_scalar */
    case 4675:  /* pred_mulvnx1df_scalar */
    case 4674:  /* pred_addvnx1df_scalar */
    case 4653:  /* pred_divvnx8df */
    case 4652:  /* pred_subvnx8df */
    case 4651:  /* pred_sminvnx8df */
    case 4650:  /* pred_smaxvnx8df */
    case 4649:  /* pred_mulvnx8df */
    case 4648:  /* pred_addvnx8df */
    case 4647:  /* pred_divvnx4df */
    case 4646:  /* pred_subvnx4df */
    case 4645:  /* pred_sminvnx4df */
    case 4644:  /* pred_smaxvnx4df */
    case 4643:  /* pred_mulvnx4df */
    case 4642:  /* pred_addvnx4df */
    case 4641:  /* pred_divvnx2df */
    case 4640:  /* pred_subvnx2df */
    case 4639:  /* pred_sminvnx2df */
    case 4638:  /* pred_smaxvnx2df */
    case 4637:  /* pred_mulvnx2df */
    case 4636:  /* pred_addvnx2df */
    case 4635:  /* pred_divvnx1df */
    case 4634:  /* pred_subvnx1df */
    case 4633:  /* pred_sminvnx1df */
    case 4632:  /* pred_smaxvnx1df */
    case 4631:  /* pred_mulvnx1df */
    case 4630:  /* pred_addvnx1df */
    case 4599:  /* pred_seriesvnx8di */
    case 4598:  /* pred_seriesvnx4di */
    case 4597:  /* pred_seriesvnx2di */
    case 4596:  /* pred_seriesvnx1di */
    case 4577:  /* pred_iotavnx8di */
    case 4576:  /* pred_iotavnx4di */
    case 4575:  /* pred_iotavnx2di */
    case 4574:  /* pred_iotavnx1di */
    case 4338:  /* *pred_minus_mulvnx8di_extended_scalar */
    case 4337:  /* *pred_minus_mulvnx4di_extended_scalar */
    case 4336:  /* *pred_minus_mulvnx2di_extended_scalar */
    case 4335:  /* *pred_minus_mulvnx1di_extended_scalar */
    case 4334:  /* *pred_nmsacvnx8di_extended_scalar */
    case 4333:  /* *pred_nmsacvnx4di_extended_scalar */
    case 4332:  /* *pred_nmsacvnx2di_extended_scalar */
    case 4331:  /* *pred_nmsacvnx1di_extended_scalar */
    case 4330:  /* *pred_nmsubvnx8di_extended_scalar */
    case 4329:  /* *pred_nmsubvnx4di_extended_scalar */
    case 4328:  /* *pred_nmsubvnx2di_extended_scalar */
    case 4327:  /* *pred_nmsubvnx1di_extended_scalar */
    case 4326:  /* *pred_minus_mulvnx8di_scalar */
    case 4325:  /* *pred_minus_mulvnx4di_scalar */
    case 4324:  /* *pred_minus_mulvnx2di_scalar */
    case 4323:  /* *pred_minus_mulvnx1di_scalar */
    case 4304:  /* *pred_nmsacvnx8di_scalar */
    case 4303:  /* *pred_nmsacvnx4di_scalar */
    case 4302:  /* *pred_nmsacvnx2di_scalar */
    case 4301:  /* *pred_nmsacvnx1di_scalar */
    case 4282:  /* *pred_nmsubvnx8di_scalar */
    case 4281:  /* *pred_nmsubvnx4di_scalar */
    case 4280:  /* *pred_nmsubvnx2di_scalar */
    case 4279:  /* *pred_nmsubvnx1di_scalar */
    case 4260:  /* *pred_minus_mulvnx8di */
    case 4259:  /* *pred_minus_mulvnx4di */
    case 4258:  /* *pred_minus_mulvnx2di */
    case 4257:  /* *pred_minus_mulvnx1di */
    case 4238:  /* *pred_nmsacvnx8di */
    case 4237:  /* *pred_nmsacvnx4di */
    case 4236:  /* *pred_nmsacvnx2di */
    case 4235:  /* *pred_nmsacvnx1di */
    case 4216:  /* *pred_nmsubvnx8di */
    case 4215:  /* *pred_nmsubvnx4di */
    case 4214:  /* *pred_nmsubvnx2di */
    case 4213:  /* *pred_nmsubvnx1di */
    case 4194:  /* *pred_mul_plusvnx8di_extended_scalar */
    case 4193:  /* *pred_mul_plusvnx4di_extended_scalar */
    case 4192:  /* *pred_mul_plusvnx2di_extended_scalar */
    case 4191:  /* *pred_mul_plusvnx1di_extended_scalar */
    case 4190:  /* *pred_maccvnx8di_extended_scalar */
    case 4189:  /* *pred_maccvnx4di_extended_scalar */
    case 4188:  /* *pred_maccvnx2di_extended_scalar */
    case 4187:  /* *pred_maccvnx1di_extended_scalar */
    case 4186:  /* *pred_maddvnx8di_extended_scalar */
    case 4185:  /* *pred_maddvnx4di_extended_scalar */
    case 4184:  /* *pred_maddvnx2di_extended_scalar */
    case 4183:  /* *pred_maddvnx1di_extended_scalar */
    case 4182:  /* *pred_mul_plusvnx8di_scalar */
    case 4181:  /* *pred_mul_plusvnx4di_scalar */
    case 4180:  /* *pred_mul_plusvnx2di_scalar */
    case 4179:  /* *pred_mul_plusvnx1di_scalar */
    case 4160:  /* *pred_maccvnx8di_scalar */
    case 4159:  /* *pred_maccvnx4di_scalar */
    case 4158:  /* *pred_maccvnx2di_scalar */
    case 4157:  /* *pred_maccvnx1di_scalar */
    case 4138:  /* *pred_maddvnx8di_scalar */
    case 4137:  /* *pred_maddvnx4di_scalar */
    case 4136:  /* *pred_maddvnx2di_scalar */
    case 4135:  /* *pred_maddvnx1di_scalar */
    case 4116:  /* *pred_mul_plusvnx8di */
    case 4115:  /* *pred_mul_plusvnx4di */
    case 4114:  /* *pred_mul_plusvnx2di */
    case 4113:  /* *pred_mul_plusvnx1di */
    case 4094:  /* *pred_maccvnx8di */
    case 4093:  /* *pred_maccvnx4di */
    case 4092:  /* *pred_maccvnx2di */
    case 4091:  /* *pred_maccvnx1di */
    case 4072:  /* *pred_maddvnx8di */
    case 4071:  /* *pred_maddvnx4di */
    case 4070:  /* *pred_maddvnx2di */
    case 4069:  /* *pred_maddvnx1di */
    case 4050:  /* *pred_eqnevnx8di_extended_scalar_narrow */
    case 4049:  /* *pred_eqnevnx4di_extended_scalar_narrow */
    case 4048:  /* *pred_eqnevnx2di_extended_scalar_narrow */
    case 4047:  /* *pred_eqnevnx1di_extended_scalar_narrow */
    case 4046:  /* *pred_eqnevnx8di_extended_scalar */
    case 4045:  /* *pred_eqnevnx4di_extended_scalar */
    case 4044:  /* *pred_eqnevnx2di_extended_scalar */
    case 4043:  /* *pred_eqnevnx1di_extended_scalar */
    case 4042:  /* *pred_cmpvnx8di_extended_scalar_narrow */
    case 4041:  /* *pred_cmpvnx4di_extended_scalar_narrow */
    case 4040:  /* *pred_cmpvnx2di_extended_scalar_narrow */
    case 4039:  /* *pred_cmpvnx1di_extended_scalar_narrow */
    case 4038:  /* *pred_cmpvnx8di_extended_scalar */
    case 4037:  /* *pred_cmpvnx4di_extended_scalar */
    case 4036:  /* *pred_cmpvnx2di_extended_scalar */
    case 4035:  /* *pred_cmpvnx1di_extended_scalar */
    case 4034:  /* *pred_eqnevnx8di_scalar_narrow */
    case 4033:  /* *pred_eqnevnx4di_scalar_narrow */
    case 4032:  /* *pred_eqnevnx2di_scalar_narrow */
    case 4031:  /* *pred_eqnevnx1di_scalar_narrow */
    case 4030:  /* *pred_eqnevnx8di_scalar */
    case 4029:  /* *pred_eqnevnx4di_scalar */
    case 4028:  /* *pred_eqnevnx2di_scalar */
    case 4027:  /* *pred_eqnevnx1di_scalar */
    case 4026:  /* *pred_cmpvnx8di_scalar_narrow */
    case 4025:  /* *pred_cmpvnx4di_scalar_narrow */
    case 4024:  /* *pred_cmpvnx2di_scalar_narrow */
    case 4023:  /* *pred_cmpvnx1di_scalar_narrow */
    case 4022:  /* *pred_cmpvnx8di_scalar */
    case 4021:  /* *pred_cmpvnx4di_scalar */
    case 4020:  /* *pred_cmpvnx2di_scalar */
    case 4019:  /* *pred_cmpvnx1di_scalar */
    case 3946:  /* *pred_ltgevnx8di_narrow */
    case 3945:  /* *pred_ltgevnx4di_narrow */
    case 3944:  /* *pred_ltgevnx2di_narrow */
    case 3943:  /* *pred_ltgevnx1di_narrow */
    case 3924:  /* *pred_ltgevnx8di */
    case 3923:  /* *pred_ltgevnx4di */
    case 3922:  /* *pred_ltgevnx2di */
    case 3921:  /* *pred_ltgevnx1di */
    case 3902:  /* *pred_cmpvnx8di_narrow */
    case 3901:  /* *pred_cmpvnx4di_narrow */
    case 3900:  /* *pred_cmpvnx2di_narrow */
    case 3899:  /* *pred_cmpvnx1di_narrow */
    case 3880:  /* *pred_cmpvnx8di */
    case 3879:  /* *pred_cmpvnx4di */
    case 3878:  /* *pred_cmpvnx2di */
    case 3877:  /* *pred_cmpvnx1di */
    case 3798:  /* *pred_smulvnx8di_extended_scalar */
    case 3797:  /* *pred_asubvnx8di_extended_scalar */
    case 3796:  /* *pred_asubuvnx8di_extended_scalar */
    case 3795:  /* *pred_aaddvnx8di_extended_scalar */
    case 3794:  /* *pred_aadduvnx8di_extended_scalar */
    case 3793:  /* *pred_smulvnx4di_extended_scalar */
    case 3792:  /* *pred_asubvnx4di_extended_scalar */
    case 3791:  /* *pred_asubuvnx4di_extended_scalar */
    case 3790:  /* *pred_aaddvnx4di_extended_scalar */
    case 3789:  /* *pred_aadduvnx4di_extended_scalar */
    case 3788:  /* *pred_smulvnx2di_extended_scalar */
    case 3787:  /* *pred_asubvnx2di_extended_scalar */
    case 3786:  /* *pred_asubuvnx2di_extended_scalar */
    case 3785:  /* *pred_aaddvnx2di_extended_scalar */
    case 3784:  /* *pred_aadduvnx2di_extended_scalar */
    case 3783:  /* *pred_smulvnx1di_extended_scalar */
    case 3782:  /* *pred_asubvnx1di_extended_scalar */
    case 3781:  /* *pred_asubuvnx1di_extended_scalar */
    case 3780:  /* *pred_aaddvnx1di_extended_scalar */
    case 3779:  /* *pred_aadduvnx1di_extended_scalar */
    case 3778:  /* *pred_smulvnx8di_scalar */
    case 3777:  /* *pred_asubvnx8di_scalar */
    case 3776:  /* *pred_asubuvnx8di_scalar */
    case 3775:  /* *pred_aaddvnx8di_scalar */
    case 3774:  /* *pred_aadduvnx8di_scalar */
    case 3773:  /* *pred_smulvnx4di_scalar */
    case 3772:  /* *pred_asubvnx4di_scalar */
    case 3771:  /* *pred_asubuvnx4di_scalar */
    case 3770:  /* *pred_aaddvnx4di_scalar */
    case 3769:  /* *pred_aadduvnx4di_scalar */
    case 3768:  /* *pred_smulvnx2di_scalar */
    case 3767:  /* *pred_asubvnx2di_scalar */
    case 3766:  /* *pred_asubuvnx2di_scalar */
    case 3765:  /* *pred_aaddvnx2di_scalar */
    case 3764:  /* *pred_aadduvnx2di_scalar */
    case 3763:  /* *pred_smulvnx1di_scalar */
    case 3762:  /* *pred_asubvnx1di_scalar */
    case 3761:  /* *pred_asubuvnx1di_scalar */
    case 3760:  /* *pred_aaddvnx1di_scalar */
    case 3759:  /* *pred_aadduvnx1di_scalar */
    case 3758:  /* pred_ssravnx8di_scalar */
    case 3757:  /* pred_ssrlvnx8di_scalar */
    case 3756:  /* pred_ssravnx4di_scalar */
    case 3755:  /* pred_ssrlvnx4di_scalar */
    case 3754:  /* pred_ssravnx2di_scalar */
    case 3753:  /* pred_ssrlvnx2di_scalar */
    case 3752:  /* pred_ssravnx1di_scalar */
    case 3751:  /* pred_ssrlvnx1di_scalar */
    case 3624:  /* pred_ssravnx8di */
    case 3623:  /* pred_ssrlvnx8di */
    case 3622:  /* pred_smulvnx8di */
    case 3621:  /* pred_asubvnx8di */
    case 3620:  /* pred_asubuvnx8di */
    case 3619:  /* pred_aaddvnx8di */
    case 3618:  /* pred_aadduvnx8di */
    case 3617:  /* pred_ssravnx4di */
    case 3616:  /* pred_ssrlvnx4di */
    case 3615:  /* pred_smulvnx4di */
    case 3614:  /* pred_asubvnx4di */
    case 3613:  /* pred_asubuvnx4di */
    case 3612:  /* pred_aaddvnx4di */
    case 3611:  /* pred_aadduvnx4di */
    case 3610:  /* pred_ssravnx2di */
    case 3609:  /* pred_ssrlvnx2di */
    case 3608:  /* pred_smulvnx2di */
    case 3607:  /* pred_asubvnx2di */
    case 3606:  /* pred_asubuvnx2di */
    case 3605:  /* pred_aaddvnx2di */
    case 3604:  /* pred_aadduvnx2di */
    case 3603:  /* pred_ssravnx1di */
    case 3602:  /* pred_ssrlvnx1di */
    case 3601:  /* pred_smulvnx1di */
    case 3600:  /* pred_asubvnx1di */
    case 3599:  /* pred_asubuvnx1di */
    case 3598:  /* pred_aaddvnx1di */
    case 3597:  /* pred_aadduvnx1di */
    case 3470:  /* *pred_ussubvnx8di_extended_scalar */
    case 3469:  /* *pred_sssubvnx8di_extended_scalar */
    case 3468:  /* *pred_ussubvnx4di_extended_scalar */
    case 3467:  /* *pred_sssubvnx4di_extended_scalar */
    case 3466:  /* *pred_ussubvnx2di_extended_scalar */
    case 3465:  /* *pred_sssubvnx2di_extended_scalar */
    case 3464:  /* *pred_ussubvnx1di_extended_scalar */
    case 3463:  /* *pred_sssubvnx1di_extended_scalar */
    case 3462:  /* *pred_ussubvnx8di_scalar */
    case 3461:  /* *pred_sssubvnx8di_scalar */
    case 3460:  /* *pred_ussubvnx4di_scalar */
    case 3459:  /* *pred_sssubvnx4di_scalar */
    case 3458:  /* *pred_ussubvnx2di_scalar */
    case 3457:  /* *pred_sssubvnx2di_scalar */
    case 3456:  /* *pred_ussubvnx1di_scalar */
    case 3455:  /* *pred_sssubvnx1di_scalar */
    case 3454:  /* *pred_usaddvnx8di_extended_scalar */
    case 3453:  /* *pred_ssaddvnx8di_extended_scalar */
    case 3452:  /* *pred_usaddvnx4di_extended_scalar */
    case 3451:  /* *pred_ssaddvnx4di_extended_scalar */
    case 3450:  /* *pred_usaddvnx2di_extended_scalar */
    case 3449:  /* *pred_ssaddvnx2di_extended_scalar */
    case 3448:  /* *pred_usaddvnx1di_extended_scalar */
    case 3447:  /* *pred_ssaddvnx1di_extended_scalar */
    case 3446:  /* *pred_usaddvnx8di_scalar */
    case 3445:  /* *pred_ssaddvnx8di_scalar */
    case 3444:  /* *pred_usaddvnx4di_scalar */
    case 3443:  /* *pred_ssaddvnx4di_scalar */
    case 3442:  /* *pred_usaddvnx2di_scalar */
    case 3441:  /* *pred_ssaddvnx2di_scalar */
    case 3440:  /* *pred_usaddvnx1di_scalar */
    case 3439:  /* *pred_ssaddvnx1di_scalar */
    case 3366:  /* pred_ussubvnx8di */
    case 3365:  /* pred_usaddvnx8di */
    case 3364:  /* pred_sssubvnx8di */
    case 3363:  /* pred_ssaddvnx8di */
    case 3362:  /* pred_ussubvnx4di */
    case 3361:  /* pred_usaddvnx4di */
    case 3360:  /* pred_sssubvnx4di */
    case 3359:  /* pred_ssaddvnx4di */
    case 3358:  /* pred_ussubvnx2di */
    case 3357:  /* pred_usaddvnx2di */
    case 3356:  /* pred_sssubvnx2di */
    case 3355:  /* pred_ssaddvnx2di */
    case 3354:  /* pred_ussubvnx1di */
    case 3353:  /* pred_usaddvnx1di */
    case 3352:  /* pred_sssubvnx1di */
    case 3351:  /* pred_ssaddvnx1di */
    case 2843:  /* pred_zero_extendvnx8di_vf8 */
    case 2842:  /* pred_extendvnx8di_vf8 */
    case 2841:  /* pred_zero_extendvnx4di_vf8 */
    case 2840:  /* pred_extendvnx4di_vf8 */
    case 2839:  /* pred_zero_extendvnx2di_vf8 */
    case 2838:  /* pred_extendvnx2di_vf8 */
    case 2837:  /* pred_zero_extendvnx1di_vf8 */
    case 2836:  /* pred_extendvnx1di_vf8 */
    case 2835:  /* pred_zero_extendvnx8di_vf4 */
    case 2834:  /* pred_extendvnx8di_vf4 */
    case 2833:  /* pred_zero_extendvnx4di_vf4 */
    case 2832:  /* pred_extendvnx4di_vf4 */
    case 2831:  /* pred_zero_extendvnx2di_vf4 */
    case 2830:  /* pred_extendvnx2di_vf4 */
    case 2829:  /* pred_zero_extendvnx1di_vf4 */
    case 2828:  /* pred_extendvnx1di_vf4 */
    case 2817:  /* pred_zero_extendvnx8di_vf2 */
    case 2816:  /* pred_extendvnx8di_vf2 */
    case 2815:  /* pred_zero_extendvnx4di_vf2 */
    case 2814:  /* pred_extendvnx4di_vf2 */
    case 2813:  /* pred_zero_extendvnx2di_vf2 */
    case 2812:  /* pred_extendvnx2di_vf2 */
    case 2811:  /* pred_zero_extendvnx1di_vf2 */
    case 2810:  /* pred_extendvnx1di_vf2 */
    case 2787:  /* pred_one_cmplvnx8di */
    case 2786:  /* pred_negvnx8di */
    case 2785:  /* pred_one_cmplvnx4di */
    case 2784:  /* pred_negvnx4di */
    case 2783:  /* pred_one_cmplvnx2di */
    case 2782:  /* pred_negvnx2di */
    case 2781:  /* pred_one_cmplvnx1di */
    case 2780:  /* pred_negvnx1di */
    case 2743:  /* *pred_msbcvnx8di_overflow_extended_scalar */
    case 2742:  /* *pred_msbcvnx4di_overflow_extended_scalar */
    case 2741:  /* *pred_msbcvnx2di_overflow_extended_scalar */
    case 2740:  /* *pred_msbcvnx1di_overflow_extended_scalar */
    case 2739:  /* *pred_msbcvnx8di_overflow_scalar */
    case 2738:  /* *pred_msbcvnx4di_overflow_scalar */
    case 2737:  /* *pred_msbcvnx2di_overflow_scalar */
    case 2736:  /* *pred_msbcvnx1di_overflow_scalar */
    case 2735:  /* *pred_madcvnx8di_overflow_extended_scalar */
    case 2734:  /* *pred_madcvnx4di_overflow_extended_scalar */
    case 2733:  /* *pred_madcvnx2di_overflow_extended_scalar */
    case 2732:  /* *pred_madcvnx1di_overflow_extended_scalar */
    case 2731:  /* *pred_madcvnx8di_overflow_scalar */
    case 2730:  /* *pred_madcvnx4di_overflow_scalar */
    case 2729:  /* *pred_madcvnx2di_overflow_scalar */
    case 2728:  /* *pred_madcvnx1di_overflow_scalar */
    case 2691:  /* pred_msbcvnx8di_overflow */
    case 2690:  /* pred_msbcvnx4di_overflow */
    case 2689:  /* pred_msbcvnx2di_overflow */
    case 2688:  /* pred_msbcvnx1di_overflow */
    case 2669:  /* pred_madcvnx8di_overflow */
    case 2668:  /* pred_madcvnx4di_overflow */
    case 2667:  /* pred_madcvnx2di_overflow */
    case 2666:  /* pred_madcvnx1di_overflow */
    case 2647:  /* *pred_msbcvnx8di_extended_scalar */
    case 2646:  /* *pred_msbcvnx4di_extended_scalar */
    case 2645:  /* *pred_msbcvnx2di_extended_scalar */
    case 2644:  /* *pred_msbcvnx1di_extended_scalar */
    case 2643:  /* *pred_msbcvnx8di_scalar */
    case 2642:  /* *pred_msbcvnx4di_scalar */
    case 2641:  /* *pred_msbcvnx2di_scalar */
    case 2640:  /* *pred_msbcvnx1di_scalar */
    case 2639:  /* *pred_madcvnx8di_extended_scalar */
    case 2638:  /* *pred_madcvnx4di_extended_scalar */
    case 2637:  /* *pred_madcvnx2di_extended_scalar */
    case 2636:  /* *pred_madcvnx1di_extended_scalar */
    case 2635:  /* *pred_madcvnx8di_scalar */
    case 2634:  /* *pred_madcvnx4di_scalar */
    case 2633:  /* *pred_madcvnx2di_scalar */
    case 2632:  /* *pred_madcvnx1di_scalar */
    case 2595:  /* pred_msbcvnx8di */
    case 2594:  /* pred_msbcvnx4di */
    case 2593:  /* pred_msbcvnx2di */
    case 2592:  /* pred_msbcvnx1di */
    case 2573:  /* pred_madcvnx8di */
    case 2572:  /* pred_madcvnx4di */
    case 2571:  /* pred_madcvnx2di */
    case 2570:  /* pred_madcvnx1di */
    case 2551:  /* *pred_sbcvnx8di_extended_scalar */
    case 2550:  /* *pred_sbcvnx4di_extended_scalar */
    case 2549:  /* *pred_sbcvnx2di_extended_scalar */
    case 2548:  /* *pred_sbcvnx1di_extended_scalar */
    case 2547:  /* *pred_sbcvnx8di_scalar */
    case 2546:  /* *pred_sbcvnx4di_scalar */
    case 2545:  /* *pred_sbcvnx2di_scalar */
    case 2544:  /* *pred_sbcvnx1di_scalar */
    case 2543:  /* *pred_adcvnx8di_extended_scalar */
    case 2542:  /* *pred_adcvnx4di_extended_scalar */
    case 2541:  /* *pred_adcvnx2di_extended_scalar */
    case 2540:  /* *pred_adcvnx1di_extended_scalar */
    case 2539:  /* *pred_adcvnx8di_scalar */
    case 2538:  /* *pred_adcvnx4di_scalar */
    case 2537:  /* *pred_adcvnx2di_scalar */
    case 2536:  /* *pred_adcvnx1di_scalar */
    case 2499:  /* pred_sbcvnx8di */
    case 2498:  /* pred_sbcvnx4di */
    case 2497:  /* pred_sbcvnx2di */
    case 2496:  /* pred_sbcvnx1di */
    case 2477:  /* pred_adcvnx8di */
    case 2476:  /* pred_adcvnx4di */
    case 2475:  /* pred_adcvnx2di */
    case 2474:  /* pred_adcvnx1di */
    case 2455:  /* *pred_mulhsuvnx8di_extended_scalar */
    case 2454:  /* *pred_mulhuvnx8di_extended_scalar */
    case 2453:  /* *pred_mulhvnx8di_extended_scalar */
    case 2452:  /* *pred_mulhsuvnx4di_extended_scalar */
    case 2451:  /* *pred_mulhuvnx4di_extended_scalar */
    case 2450:  /* *pred_mulhvnx4di_extended_scalar */
    case 2449:  /* *pred_mulhsuvnx2di_extended_scalar */
    case 2448:  /* *pred_mulhuvnx2di_extended_scalar */
    case 2447:  /* *pred_mulhvnx2di_extended_scalar */
    case 2446:  /* *pred_mulhsuvnx1di_extended_scalar */
    case 2445:  /* *pred_mulhuvnx1di_extended_scalar */
    case 2444:  /* *pred_mulhvnx1di_extended_scalar */
    case 2443:  /* *pred_mulhsuvnx8di_scalar */
    case 2442:  /* *pred_mulhuvnx8di_scalar */
    case 2441:  /* *pred_mulhvnx8di_scalar */
    case 2440:  /* *pred_mulhsuvnx4di_scalar */
    case 2439:  /* *pred_mulhuvnx4di_scalar */
    case 2438:  /* *pred_mulhvnx4di_scalar */
    case 2437:  /* *pred_mulhsuvnx2di_scalar */
    case 2436:  /* *pred_mulhuvnx2di_scalar */
    case 2435:  /* *pred_mulhvnx2di_scalar */
    case 2434:  /* *pred_mulhsuvnx1di_scalar */
    case 2433:  /* *pred_mulhuvnx1di_scalar */
    case 2432:  /* *pred_mulhvnx1di_scalar */
    case 2377:  /* pred_mulhsuvnx8di */
    case 2376:  /* pred_mulhuvnx8di */
    case 2375:  /* pred_mulhvnx8di */
    case 2374:  /* pred_mulhsuvnx4di */
    case 2373:  /* pred_mulhuvnx4di */
    case 2372:  /* pred_mulhvnx4di */
    case 2371:  /* pred_mulhsuvnx2di */
    case 2370:  /* pred_mulhuvnx2di */
    case 2369:  /* pred_mulhvnx2di */
    case 2368:  /* pred_mulhsuvnx1di */
    case 2367:  /* pred_mulhuvnx1di */
    case 2366:  /* pred_mulhvnx1di */
    case 2311:  /* *pred_subvnx8di_extended_reverse_scalar */
    case 2310:  /* *pred_subvnx4di_extended_reverse_scalar */
    case 2309:  /* *pred_subvnx2di_extended_reverse_scalar */
    case 2308:  /* *pred_subvnx1di_extended_reverse_scalar */
    case 2307:  /* *pred_subvnx8di_reverse_scalar */
    case 2306:  /* *pred_subvnx4di_reverse_scalar */
    case 2305:  /* *pred_subvnx2di_reverse_scalar */
    case 2304:  /* *pred_subvnx1di_reverse_scalar */
    case 2303:  /* *pred_umodvnx8di_extended_scalar */
    case 2302:  /* *pred_modvnx8di_extended_scalar */
    case 2301:  /* *pred_udivvnx8di_extended_scalar */
    case 2300:  /* *pred_divvnx8di_extended_scalar */
    case 2299:  /* *pred_subvnx8di_extended_scalar */
    case 2298:  /* *pred_umodvnx4di_extended_scalar */
    case 2297:  /* *pred_modvnx4di_extended_scalar */
    case 2296:  /* *pred_udivvnx4di_extended_scalar */
    case 2295:  /* *pred_divvnx4di_extended_scalar */
    case 2294:  /* *pred_subvnx4di_extended_scalar */
    case 2293:  /* *pred_umodvnx2di_extended_scalar */
    case 2292:  /* *pred_modvnx2di_extended_scalar */
    case 2291:  /* *pred_udivvnx2di_extended_scalar */
    case 2290:  /* *pred_divvnx2di_extended_scalar */
    case 2289:  /* *pred_subvnx2di_extended_scalar */
    case 2288:  /* *pred_umodvnx1di_extended_scalar */
    case 2287:  /* *pred_modvnx1di_extended_scalar */
    case 2286:  /* *pred_udivvnx1di_extended_scalar */
    case 2285:  /* *pred_divvnx1di_extended_scalar */
    case 2284:  /* *pred_subvnx1di_extended_scalar */
    case 2283:  /* *pred_umodvnx8di_scalar */
    case 2282:  /* *pred_modvnx8di_scalar */
    case 2281:  /* *pred_udivvnx8di_scalar */
    case 2280:  /* *pred_divvnx8di_scalar */
    case 2279:  /* *pred_subvnx8di_scalar */
    case 2278:  /* *pred_umodvnx4di_scalar */
    case 2277:  /* *pred_modvnx4di_scalar */
    case 2276:  /* *pred_udivvnx4di_scalar */
    case 2275:  /* *pred_divvnx4di_scalar */
    case 2274:  /* *pred_subvnx4di_scalar */
    case 2273:  /* *pred_umodvnx2di_scalar */
    case 2272:  /* *pred_modvnx2di_scalar */
    case 2271:  /* *pred_udivvnx2di_scalar */
    case 2270:  /* *pred_divvnx2di_scalar */
    case 2269:  /* *pred_subvnx2di_scalar */
    case 2268:  /* *pred_umodvnx1di_scalar */
    case 2267:  /* *pred_modvnx1di_scalar */
    case 2266:  /* *pred_udivvnx1di_scalar */
    case 2265:  /* *pred_divvnx1di_scalar */
    case 2264:  /* *pred_subvnx1di_scalar */
    case 2263:  /* *pred_mulvnx8di_extended_scalar */
    case 2262:  /* *pred_uminvnx8di_extended_scalar */
    case 2261:  /* *pred_sminvnx8di_extended_scalar */
    case 2260:  /* *pred_umaxvnx8di_extended_scalar */
    case 2259:  /* *pred_smaxvnx8di_extended_scalar */
    case 2258:  /* *pred_xorvnx8di_extended_scalar */
    case 2257:  /* *pred_iorvnx8di_extended_scalar */
    case 2256:  /* *pred_andvnx8di_extended_scalar */
    case 2255:  /* *pred_addvnx8di_extended_scalar */
    case 2254:  /* *pred_mulvnx4di_extended_scalar */
    case 2253:  /* *pred_uminvnx4di_extended_scalar */
    case 2252:  /* *pred_sminvnx4di_extended_scalar */
    case 2251:  /* *pred_umaxvnx4di_extended_scalar */
    case 2250:  /* *pred_smaxvnx4di_extended_scalar */
    case 2249:  /* *pred_xorvnx4di_extended_scalar */
    case 2248:  /* *pred_iorvnx4di_extended_scalar */
    case 2247:  /* *pred_andvnx4di_extended_scalar */
    case 2246:  /* *pred_addvnx4di_extended_scalar */
    case 2245:  /* *pred_mulvnx2di_extended_scalar */
    case 2244:  /* *pred_uminvnx2di_extended_scalar */
    case 2243:  /* *pred_sminvnx2di_extended_scalar */
    case 2242:  /* *pred_umaxvnx2di_extended_scalar */
    case 2241:  /* *pred_smaxvnx2di_extended_scalar */
    case 2240:  /* *pred_xorvnx2di_extended_scalar */
    case 2239:  /* *pred_iorvnx2di_extended_scalar */
    case 2238:  /* *pred_andvnx2di_extended_scalar */
    case 2237:  /* *pred_addvnx2di_extended_scalar */
    case 2236:  /* *pred_mulvnx1di_extended_scalar */
    case 2235:  /* *pred_uminvnx1di_extended_scalar */
    case 2234:  /* *pred_sminvnx1di_extended_scalar */
    case 2233:  /* *pred_umaxvnx1di_extended_scalar */
    case 2232:  /* *pred_smaxvnx1di_extended_scalar */
    case 2231:  /* *pred_xorvnx1di_extended_scalar */
    case 2230:  /* *pred_iorvnx1di_extended_scalar */
    case 2229:  /* *pred_andvnx1di_extended_scalar */
    case 2228:  /* *pred_addvnx1di_extended_scalar */
    case 2227:  /* *pred_mulvnx8di_scalar */
    case 2226:  /* *pred_uminvnx8di_scalar */
    case 2225:  /* *pred_sminvnx8di_scalar */
    case 2224:  /* *pred_umaxvnx8di_scalar */
    case 2223:  /* *pred_smaxvnx8di_scalar */
    case 2222:  /* *pred_xorvnx8di_scalar */
    case 2221:  /* *pred_iorvnx8di_scalar */
    case 2220:  /* *pred_andvnx8di_scalar */
    case 2219:  /* *pred_addvnx8di_scalar */
    case 2218:  /* *pred_mulvnx4di_scalar */
    case 2217:  /* *pred_uminvnx4di_scalar */
    case 2216:  /* *pred_sminvnx4di_scalar */
    case 2215:  /* *pred_umaxvnx4di_scalar */
    case 2214:  /* *pred_smaxvnx4di_scalar */
    case 2213:  /* *pred_xorvnx4di_scalar */
    case 2212:  /* *pred_iorvnx4di_scalar */
    case 2211:  /* *pred_andvnx4di_scalar */
    case 2210:  /* *pred_addvnx4di_scalar */
    case 2209:  /* *pred_mulvnx2di_scalar */
    case 2208:  /* *pred_uminvnx2di_scalar */
    case 2207:  /* *pred_sminvnx2di_scalar */
    case 2206:  /* *pred_umaxvnx2di_scalar */
    case 2205:  /* *pred_smaxvnx2di_scalar */
    case 2204:  /* *pred_xorvnx2di_scalar */
    case 2203:  /* *pred_iorvnx2di_scalar */
    case 2202:  /* *pred_andvnx2di_scalar */
    case 2201:  /* *pred_addvnx2di_scalar */
    case 2200:  /* *pred_mulvnx1di_scalar */
    case 2199:  /* *pred_uminvnx1di_scalar */
    case 2198:  /* *pred_sminvnx1di_scalar */
    case 2197:  /* *pred_umaxvnx1di_scalar */
    case 2196:  /* *pred_smaxvnx1di_scalar */
    case 2195:  /* *pred_xorvnx1di_scalar */
    case 2194:  /* *pred_iorvnx1di_scalar */
    case 2193:  /* *pred_andvnx1di_scalar */
    case 2192:  /* *pred_addvnx1di_scalar */
    case 1921:  /* pred_lshrvnx8di_scalar */
    case 1920:  /* pred_ashrvnx8di_scalar */
    case 1919:  /* pred_ashlvnx8di_scalar */
    case 1918:  /* pred_lshrvnx4di_scalar */
    case 1917:  /* pred_ashrvnx4di_scalar */
    case 1916:  /* pred_ashlvnx4di_scalar */
    case 1915:  /* pred_lshrvnx2di_scalar */
    case 1914:  /* pred_ashrvnx2di_scalar */
    case 1913:  /* pred_ashlvnx2di_scalar */
    case 1912:  /* pred_lshrvnx1di_scalar */
    case 1911:  /* pred_ashrvnx1di_scalar */
    case 1910:  /* pred_ashlvnx1di_scalar */
    case 1855:  /* pred_umodvnx8di */
    case 1854:  /* pred_modvnx8di */
    case 1853:  /* pred_udivvnx8di */
    case 1852:  /* pred_divvnx8di */
    case 1851:  /* pred_mulvnx8di */
    case 1850:  /* pred_uminvnx8di */
    case 1849:  /* pred_sminvnx8di */
    case 1848:  /* pred_umaxvnx8di */
    case 1847:  /* pred_smaxvnx8di */
    case 1846:  /* pred_lshrvnx8di */
    case 1845:  /* pred_ashrvnx8di */
    case 1844:  /* pred_ashlvnx8di */
    case 1843:  /* pred_xorvnx8di */
    case 1842:  /* pred_iorvnx8di */
    case 1841:  /* pred_andvnx8di */
    case 1840:  /* pred_subvnx8di */
    case 1839:  /* pred_addvnx8di */
    case 1838:  /* pred_umodvnx4di */
    case 1837:  /* pred_modvnx4di */
    case 1836:  /* pred_udivvnx4di */
    case 1835:  /* pred_divvnx4di */
    case 1834:  /* pred_mulvnx4di */
    case 1833:  /* pred_uminvnx4di */
    case 1832:  /* pred_sminvnx4di */
    case 1831:  /* pred_umaxvnx4di */
    case 1830:  /* pred_smaxvnx4di */
    case 1829:  /* pred_lshrvnx4di */
    case 1828:  /* pred_ashrvnx4di */
    case 1827:  /* pred_ashlvnx4di */
    case 1826:  /* pred_xorvnx4di */
    case 1825:  /* pred_iorvnx4di */
    case 1824:  /* pred_andvnx4di */
    case 1823:  /* pred_subvnx4di */
    case 1822:  /* pred_addvnx4di */
    case 1821:  /* pred_umodvnx2di */
    case 1820:  /* pred_modvnx2di */
    case 1819:  /* pred_udivvnx2di */
    case 1818:  /* pred_divvnx2di */
    case 1817:  /* pred_mulvnx2di */
    case 1816:  /* pred_uminvnx2di */
    case 1815:  /* pred_sminvnx2di */
    case 1814:  /* pred_umaxvnx2di */
    case 1813:  /* pred_smaxvnx2di */
    case 1812:  /* pred_lshrvnx2di */
    case 1811:  /* pred_ashrvnx2di */
    case 1810:  /* pred_ashlvnx2di */
    case 1809:  /* pred_xorvnx2di */
    case 1808:  /* pred_iorvnx2di */
    case 1807:  /* pred_andvnx2di */
    case 1806:  /* pred_subvnx2di */
    case 1805:  /* pred_addvnx2di */
    case 1804:  /* pred_umodvnx1di */
    case 1803:  /* pred_modvnx1di */
    case 1802:  /* pred_udivvnx1di */
    case 1801:  /* pred_divvnx1di */
    case 1800:  /* pred_mulvnx1di */
    case 1799:  /* pred_uminvnx1di */
    case 1798:  /* pred_sminvnx1di */
    case 1797:  /* pred_umaxvnx1di */
    case 1796:  /* pred_smaxvnx1di */
    case 1795:  /* pred_lshrvnx1di */
    case 1794:  /* pred_ashrvnx1di */
    case 1793:  /* pred_ashlvnx1di */
    case 1792:  /* pred_xorvnx1di */
    case 1791:  /* pred_iorvnx1di */
    case 1790:  /* pred_andvnx1di */
    case 1789:  /* pred_subvnx1di */
    case 1788:  /* pred_addvnx1di */
    case 1447:  /* pred_indexed_ustorevnx8dfvnx8di */
    case 1446:  /* pred_indexed_ostorevnx8dfvnx8di */
    case 1443:  /* pred_indexed_ustorevnx8divnx8di */
    case 1442:  /* pred_indexed_ostorevnx8divnx8di */
    case 1435:  /* pred_indexed_ustorevnx8dfvnx8si */
    case 1434:  /* pred_indexed_ostorevnx8dfvnx8si */
    case 1431:  /* pred_indexed_ustorevnx8divnx8si */
    case 1430:  /* pred_indexed_ostorevnx8divnx8si */
    case 1423:  /* pred_indexed_ustorevnx8dfvnx8hi */
    case 1422:  /* pred_indexed_ostorevnx8dfvnx8hi */
    case 1419:  /* pred_indexed_ustorevnx8divnx8hi */
    case 1418:  /* pred_indexed_ostorevnx8divnx8hi */
    case 1411:  /* pred_indexed_ustorevnx8dfvnx8qi */
    case 1410:  /* pred_indexed_ostorevnx8dfvnx8qi */
    case 1407:  /* pred_indexed_ustorevnx8divnx8qi */
    case 1406:  /* pred_indexed_ostorevnx8divnx8qi */
    case 1399:  /* pred_indexed_ustorevnx4dfvnx4di */
    case 1398:  /* pred_indexed_ostorevnx4dfvnx4di */
    case 1395:  /* pred_indexed_ustorevnx4divnx4di */
    case 1394:  /* pred_indexed_ostorevnx4divnx4di */
    case 1387:  /* pred_indexed_ustorevnx4dfvnx4si */
    case 1386:  /* pred_indexed_ostorevnx4dfvnx4si */
    case 1383:  /* pred_indexed_ustorevnx4divnx4si */
    case 1382:  /* pred_indexed_ostorevnx4divnx4si */
    case 1375:  /* pred_indexed_ustorevnx4dfvnx4hi */
    case 1374:  /* pred_indexed_ostorevnx4dfvnx4hi */
    case 1371:  /* pred_indexed_ustorevnx4divnx4hi */
    case 1370:  /* pred_indexed_ostorevnx4divnx4hi */
    case 1363:  /* pred_indexed_ustorevnx4dfvnx4qi */
    case 1362:  /* pred_indexed_ostorevnx4dfvnx4qi */
    case 1359:  /* pred_indexed_ustorevnx4divnx4qi */
    case 1358:  /* pred_indexed_ostorevnx4divnx4qi */
    case 1351:  /* pred_indexed_ustorevnx2dfvnx2di */
    case 1350:  /* pred_indexed_ostorevnx2dfvnx2di */
    case 1347:  /* pred_indexed_ustorevnx2divnx2di */
    case 1346:  /* pred_indexed_ostorevnx2divnx2di */
    case 1339:  /* pred_indexed_ustorevnx2dfvnx2si */
    case 1338:  /* pred_indexed_ostorevnx2dfvnx2si */
    case 1335:  /* pred_indexed_ustorevnx2divnx2si */
    case 1334:  /* pred_indexed_ostorevnx2divnx2si */
    case 1327:  /* pred_indexed_ustorevnx2dfvnx2hi */
    case 1326:  /* pred_indexed_ostorevnx2dfvnx2hi */
    case 1323:  /* pred_indexed_ustorevnx2divnx2hi */
    case 1322:  /* pred_indexed_ostorevnx2divnx2hi */
    case 1315:  /* pred_indexed_ustorevnx2dfvnx2qi */
    case 1314:  /* pred_indexed_ostorevnx2dfvnx2qi */
    case 1311:  /* pred_indexed_ustorevnx2divnx2qi */
    case 1310:  /* pred_indexed_ostorevnx2divnx2qi */
    case 1303:  /* pred_indexed_ustorevnx1dfvnx1di */
    case 1302:  /* pred_indexed_ostorevnx1dfvnx1di */
    case 1301:  /* pred_indexed_ustorevnx1dfvnx1si */
    case 1300:  /* pred_indexed_ostorevnx1dfvnx1si */
    case 1299:  /* pred_indexed_ustorevnx1dfvnx1hi */
    case 1298:  /* pred_indexed_ostorevnx1dfvnx1hi */
    case 1297:  /* pred_indexed_ustorevnx1dfvnx1qi */
    case 1296:  /* pred_indexed_ostorevnx1dfvnx1qi */
    case 1287:  /* pred_indexed_ustorevnx1divnx1di */
    case 1286:  /* pred_indexed_ostorevnx1divnx1di */
    case 1285:  /* pred_indexed_ustorevnx1divnx1si */
    case 1284:  /* pred_indexed_ostorevnx1divnx1si */
    case 1283:  /* pred_indexed_ustorevnx1divnx1hi */
    case 1282:  /* pred_indexed_ostorevnx1divnx1hi */
    case 1281:  /* pred_indexed_ustorevnx1divnx1qi */
    case 1280:  /* pred_indexed_ostorevnx1divnx1qi */
    case 1191:  /* pred_indexed_uloadvnx8df_x8_greater_eew */
    case 1190:  /* pred_indexed_oloadvnx8df_x8_greater_eew */
    case 1189:  /* pred_indexed_uloadvnx4df_x8_greater_eew */
    case 1188:  /* pred_indexed_oloadvnx4df_x8_greater_eew */
    case 1187:  /* pred_indexed_uloadvnx2df_x8_greater_eew */
    case 1186:  /* pred_indexed_oloadvnx2df_x8_greater_eew */
    case 1185:  /* pred_indexed_uloadvnx1df_x8_greater_eew */
    case 1184:  /* pred_indexed_oloadvnx1df_x8_greater_eew */
    case 1183:  /* pred_indexed_uloadvnx8di_x8_greater_eew */
    case 1182:  /* pred_indexed_oloadvnx8di_x8_greater_eew */
    case 1181:  /* pred_indexed_uloadvnx4di_x8_greater_eew */
    case 1180:  /* pred_indexed_oloadvnx4di_x8_greater_eew */
    case 1179:  /* pred_indexed_uloadvnx2di_x8_greater_eew */
    case 1178:  /* pred_indexed_oloadvnx2di_x8_greater_eew */
    case 1177:  /* pred_indexed_uloadvnx1di_x8_greater_eew */
    case 1176:  /* pred_indexed_oloadvnx1di_x8_greater_eew */
    case 1175:  /* pred_indexed_uloadvnx8df_x4_greater_eew */
    case 1174:  /* pred_indexed_oloadvnx8df_x4_greater_eew */
    case 1173:  /* pred_indexed_uloadvnx4df_x4_greater_eew */
    case 1172:  /* pred_indexed_oloadvnx4df_x4_greater_eew */
    case 1171:  /* pred_indexed_uloadvnx2df_x4_greater_eew */
    case 1170:  /* pred_indexed_oloadvnx2df_x4_greater_eew */
    case 1169:  /* pred_indexed_uloadvnx1df_x4_greater_eew */
    case 1168:  /* pred_indexed_oloadvnx1df_x4_greater_eew */
    case 1157:  /* pred_indexed_uloadvnx8di_x4_greater_eew */
    case 1156:  /* pred_indexed_oloadvnx8di_x4_greater_eew */
    case 1155:  /* pred_indexed_uloadvnx4di_x4_greater_eew */
    case 1154:  /* pred_indexed_oloadvnx4di_x4_greater_eew */
    case 1153:  /* pred_indexed_uloadvnx2di_x4_greater_eew */
    case 1152:  /* pred_indexed_oloadvnx2di_x4_greater_eew */
    case 1151:  /* pred_indexed_uloadvnx1di_x4_greater_eew */
    case 1150:  /* pred_indexed_oloadvnx1di_x4_greater_eew */
    case 1139:  /* pred_indexed_uloadvnx8df_x2_greater_eew */
    case 1138:  /* pred_indexed_oloadvnx8df_x2_greater_eew */
    case 1137:  /* pred_indexed_uloadvnx4df_x2_greater_eew */
    case 1136:  /* pred_indexed_oloadvnx4df_x2_greater_eew */
    case 1135:  /* pred_indexed_uloadvnx2df_x2_greater_eew */
    case 1134:  /* pred_indexed_oloadvnx2df_x2_greater_eew */
    case 1133:  /* pred_indexed_uloadvnx1df_x2_greater_eew */
    case 1132:  /* pred_indexed_oloadvnx1df_x2_greater_eew */
    case 1121:  /* pred_indexed_uloadvnx8di_x2_greater_eew */
    case 1120:  /* pred_indexed_oloadvnx8di_x2_greater_eew */
    case 1119:  /* pred_indexed_uloadvnx4di_x2_greater_eew */
    case 1118:  /* pred_indexed_oloadvnx4di_x2_greater_eew */
    case 1117:  /* pred_indexed_uloadvnx2di_x2_greater_eew */
    case 1116:  /* pred_indexed_oloadvnx2di_x2_greater_eew */
    case 1115:  /* pred_indexed_uloadvnx1di_x2_greater_eew */
    case 1114:  /* pred_indexed_oloadvnx1di_x2_greater_eew */
    case 1091:  /* pred_indexed_uloadvnx8df_same_eew */
    case 1090:  /* pred_indexed_oloadvnx8df_same_eew */
    case 1089:  /* pred_indexed_uloadvnx4df_same_eew */
    case 1088:  /* pred_indexed_oloadvnx4df_same_eew */
    case 1087:  /* pred_indexed_uloadvnx2df_same_eew */
    case 1086:  /* pred_indexed_oloadvnx2df_same_eew */
    case 1085:  /* pred_indexed_uloadvnx1df_same_eew */
    case 1084:  /* pred_indexed_oloadvnx1df_same_eew */
    case 1073:  /* pred_indexed_uloadvnx8di_same_eew */
    case 1072:  /* pred_indexed_oloadvnx8di_same_eew */
    case 1071:  /* pred_indexed_uloadvnx4di_same_eew */
    case 1070:  /* pred_indexed_oloadvnx4di_same_eew */
    case 1069:  /* pred_indexed_uloadvnx2di_same_eew */
    case 1068:  /* pred_indexed_oloadvnx2di_same_eew */
    case 1067:  /* pred_indexed_uloadvnx1di_same_eew */
    case 1066:  /* pred_indexed_oloadvnx1di_same_eew */
    case 1029:  /* pred_strided_storevnx8df */
    case 1028:  /* pred_strided_storevnx4df */
    case 1027:  /* pred_strided_storevnx2df */
    case 1026:  /* pred_strided_storevnx1df */
    case 1020:  /* pred_strided_storevnx8di */
    case 1019:  /* pred_strided_storevnx4di */
    case 1018:  /* pred_strided_storevnx2di */
    case 1017:  /* pred_strided_storevnx1di */
    case 998:  /* pred_strided_loadvnx8df */
    case 997:  /* pred_strided_loadvnx4df */
    case 996:  /* pred_strided_loadvnx2df */
    case 995:  /* pred_strided_loadvnx1df */
    case 989:  /* pred_strided_loadvnx8di */
    case 988:  /* pred_strided_loadvnx4di */
    case 987:  /* pred_strided_loadvnx2di */
    case 986:  /* pred_strided_loadvnx1di */
    case 967:  /* *pred_broadcastvnx8di_extended_scalar */
    case 966:  /* *pred_broadcastvnx4di_extended_scalar */
    case 965:  /* *pred_broadcastvnx2di_extended_scalar */
    case 964:  /* *pred_broadcastvnx1di_extended_scalar */
    case 963:  /* *pred_broadcastvnx8df */
    case 962:  /* *pred_broadcastvnx4df */
    case 961:  /* *pred_broadcastvnx2df */
    case 960:  /* *pred_broadcastvnx1df */
    case 954:  /* *pred_broadcastvnx8di */
    case 953:  /* *pred_broadcastvnx4di */
    case 952:  /* *pred_broadcastvnx2di */
    case 951:  /* *pred_broadcastvnx1di */
    case 932:  /* *pred_mergevnx8di_extended_scalar */
    case 931:  /* *pred_mergevnx4di_extended_scalar */
    case 930:  /* *pred_mergevnx2di_extended_scalar */
    case 929:  /* *pred_mergevnx1di_extended_scalar */
    case 928:  /* *pred_mergevnx8di_scalar */
    case 927:  /* *pred_mergevnx4di_scalar */
    case 926:  /* *pred_mergevnx2di_scalar */
    case 925:  /* *pred_mergevnx1di_scalar */
    case 906:  /* pred_mergevnx8df */
    case 905:  /* pred_mergevnx4df */
    case 904:  /* pred_mergevnx2df */
    case 903:  /* pred_mergevnx1df */
    case 897:  /* pred_mergevnx8di */
    case 896:  /* pred_mergevnx4di */
    case 895:  /* pred_mergevnx2di */
    case 894:  /* pred_mergevnx1di */
    case 861:  /* pred_storevnx8df */
    case 860:  /* pred_storevnx4df */
    case 859:  /* pred_storevnx2df */
    case 858:  /* pred_storevnx1df */
    case 852:  /* pred_storevnx8di */
    case 851:  /* pred_storevnx4di */
    case 850:  /* pred_storevnx2di */
    case 849:  /* pred_storevnx1di */
    case 830:  /* pred_movvnx8df */
    case 829:  /* pred_movvnx4df */
    case 828:  /* pred_movvnx2df */
    case 827:  /* pred_movvnx1df */
    case 821:  /* pred_movvnx8di */
    case 820:  /* pred_movvnx4di */
    case 819:  /* pred_movvnx2di */
    case 818:  /* pred_movvnx1di */
    case 750:  /* *movvnx8df_whole */
    case 749:  /* *movvnx4df_whole */
    case 748:  /* *movvnx2df_whole */
    case 747:  /* *movvnx1df_whole */
    case 741:  /* *movvnx8di_whole */
    case 740:  /* *movvnx4di_whole */
    case 739:  /* *movvnx2di_whole */
    case 738:  /* *movvnx1di_whole */
      return 64 /* 0x40 */;

    case 6049:  /* pred_fault_loadvnx32hi */
    case 6048:  /* pred_fault_loadvnx16hi */
    case 6047:  /* pred_fault_loadvnx8hi */
    case 6046:  /* pred_fault_loadvnx4hi */
    case 6045:  /* pred_fault_loadvnx2hi */
    case 6044:  /* pred_fault_loadvnx1hi */
    case 6016:  /* pred_compressvnx32hi */
    case 6015:  /* pred_compressvnx16hi */
    case 6014:  /* pred_compressvnx8hi */
    case 6013:  /* pred_compressvnx4hi */
    case 6012:  /* pred_compressvnx2hi */
    case 6011:  /* pred_compressvnx1hi */
    case 5985:  /* pred_gatherei16vnx32hi */
    case 5984:  /* pred_gatherei16vnx16hi */
    case 5983:  /* pred_gatherei16vnx8hi */
    case 5982:  /* pred_gatherei16vnx4hi */
    case 5981:  /* pred_gatherei16vnx2hi */
    case 5980:  /* pred_gatherei16vnx1hi */
    case 5955:  /* pred_gathervnx32hi_scalar */
    case 5954:  /* pred_gathervnx16hi_scalar */
    case 5953:  /* pred_gathervnx8hi_scalar */
    case 5952:  /* pred_gathervnx4hi_scalar */
    case 5951:  /* pred_gathervnx2hi_scalar */
    case 5950:  /* pred_gathervnx1hi_scalar */
    case 5924:  /* pred_gathervnx32hi */
    case 5923:  /* pred_gathervnx16hi */
    case 5922:  /* pred_gathervnx8hi */
    case 5921:  /* pred_gathervnx4hi */
    case 5920:  /* pred_gathervnx2hi */
    case 5919:  /* pred_gathervnx1hi */
    case 5867:  /* pred_slide1downvnx32hi */
    case 5866:  /* pred_slide1upvnx32hi */
    case 5865:  /* pred_slide1downvnx16hi */
    case 5864:  /* pred_slide1upvnx16hi */
    case 5863:  /* pred_slide1downvnx8hi */
    case 5862:  /* pred_slide1upvnx8hi */
    case 5861:  /* pred_slide1downvnx4hi */
    case 5860:  /* pred_slide1upvnx4hi */
    case 5859:  /* pred_slide1downvnx2hi */
    case 5858:  /* pred_slide1upvnx2hi */
    case 5857:  /* pred_slide1downvnx1hi */
    case 5856:  /* pred_slide1upvnx1hi */
    case 5805:  /* pred_slidedownvnx32hi */
    case 5804:  /* pred_slideupvnx32hi */
    case 5803:  /* pred_slidedownvnx16hi */
    case 5802:  /* pred_slideupvnx16hi */
    case 5801:  /* pred_slidedownvnx8hi */
    case 5800:  /* pred_slideupvnx8hi */
    case 5799:  /* pred_slidedownvnx4hi */
    case 5798:  /* pred_slideupvnx4hi */
    case 5797:  /* pred_slidedownvnx2hi */
    case 5796:  /* pred_slideupvnx2hi */
    case 5795:  /* pred_slidedownvnx1hi */
    case 5794:  /* pred_slideupvnx1hi */
    case 5757:  /* *pred_extract_firstvnx32hi */
    case 5756:  /* *pred_extract_firstvnx16hi */
    case 5755:  /* *pred_extract_firstvnx8hi */
    case 5754:  /* *pred_extract_firstvnx4hi */
    case 5753:  /* *pred_extract_firstvnx2hi */
    case 5752:  /* *pred_extract_firstvnx1hi */
    case 5682:  /* pred_widen_reduc_plusuvnx16hivnx1si */
    case 5681:  /* pred_widen_reduc_plusvnx16hivnx1si */
    case 5680:  /* pred_widen_reduc_plusuvnx8hivnx1si */
    case 5679:  /* pred_widen_reduc_plusvnx8hivnx1si */
    case 5678:  /* pred_widen_reduc_plusuvnx4hivnx1si */
    case 5677:  /* pred_widen_reduc_plusvnx4hivnx1si */
    case 5676:  /* pred_widen_reduc_plusuvnx2hivnx1si */
    case 5675:  /* pred_widen_reduc_plusvnx2hivnx1si */
    case 5674:  /* pred_widen_reduc_plusuvnx1hivnx1si */
    case 5673:  /* pred_widen_reduc_plusvnx1hivnx1si */
    case 5650:  /* pred_widen_reduc_plusuvnx32hivnx2si */
    case 5649:  /* pred_widen_reduc_plusvnx32hivnx2si */
    case 5648:  /* pred_widen_reduc_plusuvnx16hivnx2si */
    case 5647:  /* pred_widen_reduc_plusvnx16hivnx2si */
    case 5646:  /* pred_widen_reduc_plusuvnx8hivnx2si */
    case 5645:  /* pred_widen_reduc_plusvnx8hivnx2si */
    case 5644:  /* pred_widen_reduc_plusuvnx4hivnx2si */
    case 5643:  /* pred_widen_reduc_plusvnx4hivnx2si */
    case 5642:  /* pred_widen_reduc_plusuvnx2hivnx2si */
    case 5641:  /* pred_widen_reduc_plusvnx2hivnx2si */
    case 5640:  /* pred_widen_reduc_plusuvnx1hivnx2si */
    case 5639:  /* pred_widen_reduc_plusvnx1hivnx2si */
    case 5592:  /* pred_reduc_xorvnx16hivnx2hi */
    case 5591:  /* pred_reduc_orvnx16hivnx2hi */
    case 5590:  /* pred_reduc_andvnx16hivnx2hi */
    case 5589:  /* pred_reduc_minvnx16hivnx2hi */
    case 5588:  /* pred_reduc_minuvnx16hivnx2hi */
    case 5587:  /* pred_reduc_maxvnx16hivnx2hi */
    case 5586:  /* pred_reduc_maxuvnx16hivnx2hi */
    case 5585:  /* pred_reduc_sumvnx16hivnx2hi */
    case 5584:  /* pred_reduc_xorvnx8hivnx2hi */
    case 5583:  /* pred_reduc_orvnx8hivnx2hi */
    case 5582:  /* pred_reduc_andvnx8hivnx2hi */
    case 5581:  /* pred_reduc_minvnx8hivnx2hi */
    case 5580:  /* pred_reduc_minuvnx8hivnx2hi */
    case 5579:  /* pred_reduc_maxvnx8hivnx2hi */
    case 5578:  /* pred_reduc_maxuvnx8hivnx2hi */
    case 5577:  /* pred_reduc_sumvnx8hivnx2hi */
    case 5576:  /* pred_reduc_xorvnx4hivnx2hi */
    case 5575:  /* pred_reduc_orvnx4hivnx2hi */
    case 5574:  /* pred_reduc_andvnx4hivnx2hi */
    case 5573:  /* pred_reduc_minvnx4hivnx2hi */
    case 5572:  /* pred_reduc_minuvnx4hivnx2hi */
    case 5571:  /* pred_reduc_maxvnx4hivnx2hi */
    case 5570:  /* pred_reduc_maxuvnx4hivnx2hi */
    case 5569:  /* pred_reduc_sumvnx4hivnx2hi */
    case 5568:  /* pred_reduc_xorvnx2hivnx2hi */
    case 5567:  /* pred_reduc_orvnx2hivnx2hi */
    case 5566:  /* pred_reduc_andvnx2hivnx2hi */
    case 5565:  /* pred_reduc_minvnx2hivnx2hi */
    case 5564:  /* pred_reduc_minuvnx2hivnx2hi */
    case 5563:  /* pred_reduc_maxvnx2hivnx2hi */
    case 5562:  /* pred_reduc_maxuvnx2hivnx2hi */
    case 5561:  /* pred_reduc_sumvnx2hivnx2hi */
    case 5560:  /* pred_reduc_xorvnx1hivnx2hi */
    case 5559:  /* pred_reduc_orvnx1hivnx2hi */
    case 5558:  /* pred_reduc_andvnx1hivnx2hi */
    case 5557:  /* pred_reduc_minvnx1hivnx2hi */
    case 5556:  /* pred_reduc_minuvnx1hivnx2hi */
    case 5555:  /* pred_reduc_maxvnx1hivnx2hi */
    case 5554:  /* pred_reduc_maxuvnx1hivnx2hi */
    case 5553:  /* pred_reduc_sumvnx1hivnx2hi */
    case 5432:  /* pred_reduc_xorvnx32hivnx4hi */
    case 5431:  /* pred_reduc_orvnx32hivnx4hi */
    case 5430:  /* pred_reduc_andvnx32hivnx4hi */
    case 5429:  /* pred_reduc_minvnx32hivnx4hi */
    case 5428:  /* pred_reduc_minuvnx32hivnx4hi */
    case 5427:  /* pred_reduc_maxvnx32hivnx4hi */
    case 5426:  /* pred_reduc_maxuvnx32hivnx4hi */
    case 5425:  /* pred_reduc_sumvnx32hivnx4hi */
    case 5424:  /* pred_reduc_xorvnx16hivnx4hi */
    case 5423:  /* pred_reduc_orvnx16hivnx4hi */
    case 5422:  /* pred_reduc_andvnx16hivnx4hi */
    case 5421:  /* pred_reduc_minvnx16hivnx4hi */
    case 5420:  /* pred_reduc_minuvnx16hivnx4hi */
    case 5419:  /* pred_reduc_maxvnx16hivnx4hi */
    case 5418:  /* pred_reduc_maxuvnx16hivnx4hi */
    case 5417:  /* pred_reduc_sumvnx16hivnx4hi */
    case 5416:  /* pred_reduc_xorvnx8hivnx4hi */
    case 5415:  /* pred_reduc_orvnx8hivnx4hi */
    case 5414:  /* pred_reduc_andvnx8hivnx4hi */
    case 5413:  /* pred_reduc_minvnx8hivnx4hi */
    case 5412:  /* pred_reduc_minuvnx8hivnx4hi */
    case 5411:  /* pred_reduc_maxvnx8hivnx4hi */
    case 5410:  /* pred_reduc_maxuvnx8hivnx4hi */
    case 5409:  /* pred_reduc_sumvnx8hivnx4hi */
    case 5408:  /* pred_reduc_xorvnx4hivnx4hi */
    case 5407:  /* pred_reduc_orvnx4hivnx4hi */
    case 5406:  /* pred_reduc_andvnx4hivnx4hi */
    case 5405:  /* pred_reduc_minvnx4hivnx4hi */
    case 5404:  /* pred_reduc_minuvnx4hivnx4hi */
    case 5403:  /* pred_reduc_maxvnx4hivnx4hi */
    case 5402:  /* pred_reduc_maxuvnx4hivnx4hi */
    case 5401:  /* pred_reduc_sumvnx4hivnx4hi */
    case 5400:  /* pred_reduc_xorvnx2hivnx4hi */
    case 5399:  /* pred_reduc_orvnx2hivnx4hi */
    case 5398:  /* pred_reduc_andvnx2hivnx4hi */
    case 5397:  /* pred_reduc_minvnx2hivnx4hi */
    case 5396:  /* pred_reduc_minuvnx2hivnx4hi */
    case 5395:  /* pred_reduc_maxvnx2hivnx4hi */
    case 5394:  /* pred_reduc_maxuvnx2hivnx4hi */
    case 5393:  /* pred_reduc_sumvnx2hivnx4hi */
    case 5392:  /* pred_reduc_xorvnx1hivnx4hi */
    case 5391:  /* pred_reduc_orvnx1hivnx4hi */
    case 5390:  /* pred_reduc_andvnx1hivnx4hi */
    case 5389:  /* pred_reduc_minvnx1hivnx4hi */
    case 5388:  /* pred_reduc_minuvnx1hivnx4hi */
    case 5387:  /* pred_reduc_maxvnx1hivnx4hi */
    case 5386:  /* pred_reduc_maxuvnx1hivnx4hi */
    case 5385:  /* pred_reduc_sumvnx1hivnx4hi */
    case 5304:  /* pred_narrow_fixuns_truncvnx16sf */
    case 5303:  /* pred_narrow_fix_truncvnx16sf */
    case 5302:  /* pred_narrow_fixuns_truncvnx8sf */
    case 5301:  /* pred_narrow_fix_truncvnx8sf */
    case 5300:  /* pred_narrow_fixuns_truncvnx4sf */
    case 5299:  /* pred_narrow_fix_truncvnx4sf */
    case 5298:  /* pred_narrow_fixuns_truncvnx2sf */
    case 5297:  /* pred_narrow_fix_truncvnx2sf */
    case 5296:  /* pred_narrow_fixuns_truncvnx1sf */
    case 5295:  /* pred_narrow_fix_truncvnx1sf */
    case 5286:  /* pred_narrow_fcvt_xu_fvnx16sf */
    case 5285:  /* pred_narrow_fcvt_x_fvnx16sf */
    case 5284:  /* pred_narrow_fcvt_xu_fvnx8sf */
    case 5283:  /* pred_narrow_fcvt_x_fvnx8sf */
    case 5282:  /* pred_narrow_fcvt_xu_fvnx4sf */
    case 5281:  /* pred_narrow_fcvt_x_fvnx4sf */
    case 5280:  /* pred_narrow_fcvt_xu_fvnx2sf */
    case 5279:  /* pred_narrow_fcvt_x_fvnx2sf */
    case 5278:  /* pred_narrow_fcvt_xu_fvnx1sf */
    case 5277:  /* pred_narrow_fcvt_x_fvnx1sf */
    case 5264:  /* pred_widen_floatunsvnx16sf */
    case 5263:  /* pred_widen_floatvnx16sf */
    case 5262:  /* pred_widen_floatunsvnx8sf */
    case 5261:  /* pred_widen_floatvnx8sf */
    case 5260:  /* pred_widen_floatunsvnx4sf */
    case 5259:  /* pred_widen_floatvnx4sf */
    case 5258:  /* pred_widen_floatunsvnx2sf */
    case 5257:  /* pred_widen_floatvnx2sf */
    case 5256:  /* pred_widen_floatunsvnx1sf */
    case 5255:  /* pred_widen_floatvnx1sf */
    case 4590:  /* pred_seriesvnx32hi */
    case 4589:  /* pred_seriesvnx16hi */
    case 4588:  /* pred_seriesvnx8hi */
    case 4587:  /* pred_seriesvnx4hi */
    case 4586:  /* pred_seriesvnx2hi */
    case 4585:  /* pred_seriesvnx1hi */
    case 4568:  /* pred_iotavnx32hi */
    case 4567:  /* pred_iotavnx16hi */
    case 4566:  /* pred_iotavnx8hi */
    case 4565:  /* pred_iotavnx4hi */
    case 4564:  /* pred_iotavnx2hi */
    case 4563:  /* pred_iotavnx1hi */
    case 4439:  /* pred_widen_mul_plususvnx16si_scalar */
    case 4438:  /* pred_widen_mul_plususvnx8si_scalar */
    case 4437:  /* pred_widen_mul_plususvnx4si_scalar */
    case 4436:  /* pred_widen_mul_plususvnx2si_scalar */
    case 4435:  /* pred_widen_mul_plususvnx1si_scalar */
    case 4424:  /* pred_widen_mul_plussuvnx16si_scalar */
    case 4423:  /* pred_widen_mul_plussuvnx8si_scalar */
    case 4422:  /* pred_widen_mul_plussuvnx4si_scalar */
    case 4421:  /* pred_widen_mul_plussuvnx2si_scalar */
    case 4420:  /* pred_widen_mul_plussuvnx1si_scalar */
    case 4409:  /* pred_widen_mul_plussuvnx16si */
    case 4408:  /* pred_widen_mul_plussuvnx8si */
    case 4407:  /* pred_widen_mul_plussuvnx4si */
    case 4406:  /* pred_widen_mul_plussuvnx2si */
    case 4405:  /* pred_widen_mul_plussuvnx1si */
    case 4390:  /* pred_widen_mul_plusuvnx16si_scalar */
    case 4389:  /* pred_widen_mul_plussvnx16si_scalar */
    case 4388:  /* pred_widen_mul_plusuvnx8si_scalar */
    case 4387:  /* pred_widen_mul_plussvnx8si_scalar */
    case 4386:  /* pred_widen_mul_plusuvnx4si_scalar */
    case 4385:  /* pred_widen_mul_plussvnx4si_scalar */
    case 4384:  /* pred_widen_mul_plusuvnx2si_scalar */
    case 4383:  /* pred_widen_mul_plussvnx2si_scalar */
    case 4382:  /* pred_widen_mul_plusuvnx1si_scalar */
    case 4381:  /* pred_widen_mul_plussvnx1si_scalar */
    case 4360:  /* pred_widen_mul_plusuvnx16si */
    case 4359:  /* pred_widen_mul_plussvnx16si */
    case 4358:  /* pred_widen_mul_plusuvnx8si */
    case 4357:  /* pred_widen_mul_plussvnx8si */
    case 4356:  /* pred_widen_mul_plusuvnx4si */
    case 4355:  /* pred_widen_mul_plussvnx4si */
    case 4354:  /* pred_widen_mul_plusuvnx2si */
    case 4353:  /* pred_widen_mul_plussvnx2si */
    case 4352:  /* pred_widen_mul_plusuvnx1si */
    case 4351:  /* pred_widen_mul_plussvnx1si */
    case 4317:  /* *pred_minus_mulvnx32hi_scalar */
    case 4316:  /* *pred_minus_mulvnx16hi_scalar */
    case 4315:  /* *pred_minus_mulvnx8hi_scalar */
    case 4314:  /* *pred_minus_mulvnx4hi_scalar */
    case 4313:  /* *pred_minus_mulvnx2hi_scalar */
    case 4312:  /* *pred_minus_mulvnx1hi_scalar */
    case 4295:  /* *pred_nmsacvnx32hi_scalar */
    case 4294:  /* *pred_nmsacvnx16hi_scalar */
    case 4293:  /* *pred_nmsacvnx8hi_scalar */
    case 4292:  /* *pred_nmsacvnx4hi_scalar */
    case 4291:  /* *pred_nmsacvnx2hi_scalar */
    case 4290:  /* *pred_nmsacvnx1hi_scalar */
    case 4273:  /* *pred_nmsubvnx32hi_scalar */
    case 4272:  /* *pred_nmsubvnx16hi_scalar */
    case 4271:  /* *pred_nmsubvnx8hi_scalar */
    case 4270:  /* *pred_nmsubvnx4hi_scalar */
    case 4269:  /* *pred_nmsubvnx2hi_scalar */
    case 4268:  /* *pred_nmsubvnx1hi_scalar */
    case 4251:  /* *pred_minus_mulvnx32hi */
    case 4250:  /* *pred_minus_mulvnx16hi */
    case 4249:  /* *pred_minus_mulvnx8hi */
    case 4248:  /* *pred_minus_mulvnx4hi */
    case 4247:  /* *pred_minus_mulvnx2hi */
    case 4246:  /* *pred_minus_mulvnx1hi */
    case 4229:  /* *pred_nmsacvnx32hi */
    case 4228:  /* *pred_nmsacvnx16hi */
    case 4227:  /* *pred_nmsacvnx8hi */
    case 4226:  /* *pred_nmsacvnx4hi */
    case 4225:  /* *pred_nmsacvnx2hi */
    case 4224:  /* *pred_nmsacvnx1hi */
    case 4207:  /* *pred_nmsubvnx32hi */
    case 4206:  /* *pred_nmsubvnx16hi */
    case 4205:  /* *pred_nmsubvnx8hi */
    case 4204:  /* *pred_nmsubvnx4hi */
    case 4203:  /* *pred_nmsubvnx2hi */
    case 4202:  /* *pred_nmsubvnx1hi */
    case 4173:  /* *pred_mul_plusvnx32hi_scalar */
    case 4172:  /* *pred_mul_plusvnx16hi_scalar */
    case 4171:  /* *pred_mul_plusvnx8hi_scalar */
    case 4170:  /* *pred_mul_plusvnx4hi_scalar */
    case 4169:  /* *pred_mul_plusvnx2hi_scalar */
    case 4168:  /* *pred_mul_plusvnx1hi_scalar */
    case 4151:  /* *pred_maccvnx32hi_scalar */
    case 4150:  /* *pred_maccvnx16hi_scalar */
    case 4149:  /* *pred_maccvnx8hi_scalar */
    case 4148:  /* *pred_maccvnx4hi_scalar */
    case 4147:  /* *pred_maccvnx2hi_scalar */
    case 4146:  /* *pred_maccvnx1hi_scalar */
    case 4129:  /* *pred_maddvnx32hi_scalar */
    case 4128:  /* *pred_maddvnx16hi_scalar */
    case 4127:  /* *pred_maddvnx8hi_scalar */
    case 4126:  /* *pred_maddvnx4hi_scalar */
    case 4125:  /* *pred_maddvnx2hi_scalar */
    case 4124:  /* *pred_maddvnx1hi_scalar */
    case 4107:  /* *pred_mul_plusvnx32hi */
    case 4106:  /* *pred_mul_plusvnx16hi */
    case 4105:  /* *pred_mul_plusvnx8hi */
    case 4104:  /* *pred_mul_plusvnx4hi */
    case 4103:  /* *pred_mul_plusvnx2hi */
    case 4102:  /* *pred_mul_plusvnx1hi */
    case 4085:  /* *pred_maccvnx32hi */
    case 4084:  /* *pred_maccvnx16hi */
    case 4083:  /* *pred_maccvnx8hi */
    case 4082:  /* *pred_maccvnx4hi */
    case 4081:  /* *pred_maccvnx2hi */
    case 4080:  /* *pred_maccvnx1hi */
    case 4063:  /* *pred_maddvnx32hi */
    case 4062:  /* *pred_maddvnx16hi */
    case 4061:  /* *pred_maddvnx8hi */
    case 4060:  /* *pred_maddvnx4hi */
    case 4059:  /* *pred_maddvnx2hi */
    case 4058:  /* *pred_maddvnx1hi */
    case 4013:  /* *pred_eqnevnx32hi_scalar_narrow */
    case 4012:  /* *pred_eqnevnx16hi_scalar_narrow */
    case 4011:  /* *pred_eqnevnx8hi_scalar_narrow */
    case 4010:  /* *pred_eqnevnx4hi_scalar_narrow */
    case 4009:  /* *pred_eqnevnx2hi_scalar_narrow */
    case 4008:  /* *pred_eqnevnx1hi_scalar_narrow */
    case 3995:  /* *pred_eqnevnx32hi_scalar */
    case 3994:  /* *pred_eqnevnx16hi_scalar */
    case 3993:  /* *pred_eqnevnx8hi_scalar */
    case 3992:  /* *pred_eqnevnx4hi_scalar */
    case 3991:  /* *pred_eqnevnx2hi_scalar */
    case 3990:  /* *pred_eqnevnx1hi_scalar */
    case 3977:  /* *pred_cmpvnx32hi_scalar_narrow */
    case 3976:  /* *pred_cmpvnx16hi_scalar_narrow */
    case 3975:  /* *pred_cmpvnx8hi_scalar_narrow */
    case 3974:  /* *pred_cmpvnx4hi_scalar_narrow */
    case 3973:  /* *pred_cmpvnx2hi_scalar_narrow */
    case 3972:  /* *pred_cmpvnx1hi_scalar_narrow */
    case 3959:  /* *pred_cmpvnx32hi_scalar */
    case 3958:  /* *pred_cmpvnx16hi_scalar */
    case 3957:  /* *pred_cmpvnx8hi_scalar */
    case 3956:  /* *pred_cmpvnx4hi_scalar */
    case 3955:  /* *pred_cmpvnx2hi_scalar */
    case 3954:  /* *pred_cmpvnx1hi_scalar */
    case 3937:  /* *pred_ltgevnx32hi_narrow */
    case 3936:  /* *pred_ltgevnx16hi_narrow */
    case 3935:  /* *pred_ltgevnx8hi_narrow */
    case 3934:  /* *pred_ltgevnx4hi_narrow */
    case 3933:  /* *pred_ltgevnx2hi_narrow */
    case 3932:  /* *pred_ltgevnx1hi_narrow */
    case 3915:  /* *pred_ltgevnx32hi */
    case 3914:  /* *pred_ltgevnx16hi */
    case 3913:  /* *pred_ltgevnx8hi */
    case 3912:  /* *pred_ltgevnx4hi */
    case 3911:  /* *pred_ltgevnx2hi */
    case 3910:  /* *pred_ltgevnx1hi */
    case 3893:  /* *pred_cmpvnx32hi_narrow */
    case 3892:  /* *pred_cmpvnx16hi_narrow */
    case 3891:  /* *pred_cmpvnx8hi_narrow */
    case 3890:  /* *pred_cmpvnx4hi_narrow */
    case 3889:  /* *pred_cmpvnx2hi_narrow */
    case 3888:  /* *pred_cmpvnx1hi_narrow */
    case 3871:  /* *pred_cmpvnx32hi */
    case 3870:  /* *pred_cmpvnx16hi */
    case 3869:  /* *pred_cmpvnx8hi */
    case 3868:  /* *pred_cmpvnx4hi */
    case 3867:  /* *pred_cmpvnx2hi */
    case 3866:  /* *pred_cmpvnx1hi */
    case 3850:  /* pred_narrow_clipuvnx16si_scalar */
    case 3849:  /* pred_narrow_clipvnx16si_scalar */
    case 3848:  /* pred_narrow_clipuvnx8si_scalar */
    case 3847:  /* pred_narrow_clipvnx8si_scalar */
    case 3846:  /* pred_narrow_clipuvnx4si_scalar */
    case 3845:  /* pred_narrow_clipvnx4si_scalar */
    case 3844:  /* pred_narrow_clipuvnx2si_scalar */
    case 3843:  /* pred_narrow_clipvnx2si_scalar */
    case 3842:  /* pred_narrow_clipuvnx1si_scalar */
    case 3841:  /* pred_narrow_clipvnx1si_scalar */
    case 3820:  /* pred_narrow_clipuvnx16si */
    case 3819:  /* pred_narrow_clipvnx16si */
    case 3818:  /* pred_narrow_clipuvnx8si */
    case 3817:  /* pred_narrow_clipvnx8si */
    case 3816:  /* pred_narrow_clipuvnx4si */
    case 3815:  /* pred_narrow_clipvnx4si */
    case 3814:  /* pred_narrow_clipuvnx2si */
    case 3813:  /* pred_narrow_clipvnx2si */
    case 3812:  /* pred_narrow_clipuvnx1si */
    case 3811:  /* pred_narrow_clipvnx1si */
    case 3740:  /* pred_ssravnx32hi_scalar */
    case 3739:  /* pred_ssrlvnx32hi_scalar */
    case 3738:  /* pred_ssravnx16hi_scalar */
    case 3737:  /* pred_ssrlvnx16hi_scalar */
    case 3736:  /* pred_ssravnx8hi_scalar */
    case 3735:  /* pred_ssrlvnx8hi_scalar */
    case 3734:  /* pred_ssravnx4hi_scalar */
    case 3733:  /* pred_ssrlvnx4hi_scalar */
    case 3732:  /* pred_ssravnx2hi_scalar */
    case 3731:  /* pred_ssrlvnx2hi_scalar */
    case 3730:  /* pred_ssravnx1hi_scalar */
    case 3729:  /* pred_ssrlvnx1hi_scalar */
    case 3689:  /* pred_smulvnx32hi_scalar */
    case 3688:  /* pred_asubvnx32hi_scalar */
    case 3687:  /* pred_asubuvnx32hi_scalar */
    case 3686:  /* pred_aaddvnx32hi_scalar */
    case 3685:  /* pred_aadduvnx32hi_scalar */
    case 3684:  /* pred_smulvnx16hi_scalar */
    case 3683:  /* pred_asubvnx16hi_scalar */
    case 3682:  /* pred_asubuvnx16hi_scalar */
    case 3681:  /* pred_aaddvnx16hi_scalar */
    case 3680:  /* pred_aadduvnx16hi_scalar */
    case 3679:  /* pred_smulvnx8hi_scalar */
    case 3678:  /* pred_asubvnx8hi_scalar */
    case 3677:  /* pred_asubuvnx8hi_scalar */
    case 3676:  /* pred_aaddvnx8hi_scalar */
    case 3675:  /* pred_aadduvnx8hi_scalar */
    case 3674:  /* pred_smulvnx4hi_scalar */
    case 3673:  /* pred_asubvnx4hi_scalar */
    case 3672:  /* pred_asubuvnx4hi_scalar */
    case 3671:  /* pred_aaddvnx4hi_scalar */
    case 3670:  /* pred_aadduvnx4hi_scalar */
    case 3669:  /* pred_smulvnx2hi_scalar */
    case 3668:  /* pred_asubvnx2hi_scalar */
    case 3667:  /* pred_asubuvnx2hi_scalar */
    case 3666:  /* pred_aaddvnx2hi_scalar */
    case 3665:  /* pred_aadduvnx2hi_scalar */
    case 3664:  /* pred_smulvnx1hi_scalar */
    case 3663:  /* pred_asubvnx1hi_scalar */
    case 3662:  /* pred_asubuvnx1hi_scalar */
    case 3661:  /* pred_aaddvnx1hi_scalar */
    case 3660:  /* pred_aadduvnx1hi_scalar */
    case 3561:  /* pred_ssravnx32hi */
    case 3560:  /* pred_ssrlvnx32hi */
    case 3559:  /* pred_smulvnx32hi */
    case 3558:  /* pred_asubvnx32hi */
    case 3557:  /* pred_asubuvnx32hi */
    case 3556:  /* pred_aaddvnx32hi */
    case 3555:  /* pred_aadduvnx32hi */
    case 3554:  /* pred_ssravnx16hi */
    case 3553:  /* pred_ssrlvnx16hi */
    case 3552:  /* pred_smulvnx16hi */
    case 3551:  /* pred_asubvnx16hi */
    case 3550:  /* pred_asubuvnx16hi */
    case 3549:  /* pred_aaddvnx16hi */
    case 3548:  /* pred_aadduvnx16hi */
    case 3547:  /* pred_ssravnx8hi */
    case 3546:  /* pred_ssrlvnx8hi */
    case 3545:  /* pred_smulvnx8hi */
    case 3544:  /* pred_asubvnx8hi */
    case 3543:  /* pred_asubuvnx8hi */
    case 3542:  /* pred_aaddvnx8hi */
    case 3541:  /* pred_aadduvnx8hi */
    case 3540:  /* pred_ssravnx4hi */
    case 3539:  /* pred_ssrlvnx4hi */
    case 3538:  /* pred_smulvnx4hi */
    case 3537:  /* pred_asubvnx4hi */
    case 3536:  /* pred_asubuvnx4hi */
    case 3535:  /* pred_aaddvnx4hi */
    case 3534:  /* pred_aadduvnx4hi */
    case 3533:  /* pred_ssravnx2hi */
    case 3532:  /* pred_ssrlvnx2hi */
    case 3531:  /* pred_smulvnx2hi */
    case 3530:  /* pred_asubvnx2hi */
    case 3529:  /* pred_asubuvnx2hi */
    case 3528:  /* pred_aaddvnx2hi */
    case 3527:  /* pred_aadduvnx2hi */
    case 3526:  /* pred_ssravnx1hi */
    case 3525:  /* pred_ssrlvnx1hi */
    case 3524:  /* pred_smulvnx1hi */
    case 3523:  /* pred_asubvnx1hi */
    case 3522:  /* pred_asubuvnx1hi */
    case 3521:  /* pred_aaddvnx1hi */
    case 3520:  /* pred_aadduvnx1hi */
    case 3428:  /* pred_ussubvnx32hi_scalar */
    case 3427:  /* pred_sssubvnx32hi_scalar */
    case 3426:  /* pred_ussubvnx16hi_scalar */
    case 3425:  /* pred_sssubvnx16hi_scalar */
    case 3424:  /* pred_ussubvnx8hi_scalar */
    case 3423:  /* pred_sssubvnx8hi_scalar */
    case 3422:  /* pred_ussubvnx4hi_scalar */
    case 3421:  /* pred_sssubvnx4hi_scalar */
    case 3420:  /* pred_ussubvnx2hi_scalar */
    case 3419:  /* pred_sssubvnx2hi_scalar */
    case 3418:  /* pred_ussubvnx1hi_scalar */
    case 3417:  /* pred_sssubvnx1hi_scalar */
    case 3392:  /* pred_usaddvnx32hi_scalar */
    case 3391:  /* pred_ssaddvnx32hi_scalar */
    case 3390:  /* pred_usaddvnx16hi_scalar */
    case 3389:  /* pred_ssaddvnx16hi_scalar */
    case 3388:  /* pred_usaddvnx8hi_scalar */
    case 3387:  /* pred_ssaddvnx8hi_scalar */
    case 3386:  /* pred_usaddvnx4hi_scalar */
    case 3385:  /* pred_ssaddvnx4hi_scalar */
    case 3384:  /* pred_usaddvnx2hi_scalar */
    case 3383:  /* pred_ssaddvnx2hi_scalar */
    case 3382:  /* pred_usaddvnx1hi_scalar */
    case 3381:  /* pred_ssaddvnx1hi_scalar */
    case 3330:  /* pred_ussubvnx32hi */
    case 3329:  /* pred_usaddvnx32hi */
    case 3328:  /* pred_sssubvnx32hi */
    case 3327:  /* pred_ssaddvnx32hi */
    case 3326:  /* pred_ussubvnx16hi */
    case 3325:  /* pred_usaddvnx16hi */
    case 3324:  /* pred_sssubvnx16hi */
    case 3323:  /* pred_ssaddvnx16hi */
    case 3322:  /* pred_ussubvnx8hi */
    case 3321:  /* pred_usaddvnx8hi */
    case 3320:  /* pred_sssubvnx8hi */
    case 3319:  /* pred_ssaddvnx8hi */
    case 3318:  /* pred_ussubvnx4hi */
    case 3317:  /* pred_usaddvnx4hi */
    case 3316:  /* pred_sssubvnx4hi */
    case 3315:  /* pred_ssaddvnx4hi */
    case 3314:  /* pred_ussubvnx2hi */
    case 3313:  /* pred_usaddvnx2hi */
    case 3312:  /* pred_sssubvnx2hi */
    case 3311:  /* pred_ssaddvnx2hi */
    case 3310:  /* pred_ussubvnx1hi */
    case 3309:  /* pred_usaddvnx1hi */
    case 3308:  /* pred_sssubvnx1hi */
    case 3307:  /* pred_ssaddvnx1hi */
    case 3274:  /* pred_truncvnx16si */
    case 3273:  /* pred_truncvnx8si */
    case 3272:  /* pred_truncvnx4si */
    case 3271:  /* pred_truncvnx2si */
    case 3270:  /* pred_truncvnx1si */
    case 3255:  /* pred_narrow_lshrvnx16si_scalar */
    case 3254:  /* pred_narrow_ashrvnx16si_scalar */
    case 3253:  /* pred_narrow_lshrvnx8si_scalar */
    case 3252:  /* pred_narrow_ashrvnx8si_scalar */
    case 3251:  /* pred_narrow_lshrvnx4si_scalar */
    case 3250:  /* pred_narrow_ashrvnx4si_scalar */
    case 3249:  /* pred_narrow_lshrvnx2si_scalar */
    case 3248:  /* pred_narrow_ashrvnx2si_scalar */
    case 3247:  /* pred_narrow_lshrvnx1si_scalar */
    case 3246:  /* pred_narrow_ashrvnx1si_scalar */
    case 3225:  /* pred_narrow_lshrvnx16si */
    case 3224:  /* pred_narrow_ashrvnx16si */
    case 3223:  /* pred_narrow_lshrvnx8si */
    case 3222:  /* pred_narrow_ashrvnx8si */
    case 3221:  /* pred_narrow_lshrvnx4si */
    case 3220:  /* pred_narrow_ashrvnx4si */
    case 3219:  /* pred_narrow_lshrvnx2si */
    case 3218:  /* pred_narrow_ashrvnx2si */
    case 3217:  /* pred_narrow_lshrvnx1si */
    case 3216:  /* pred_narrow_ashrvnx1si */
    case 3195:  /* pred_zero_extendvnx16si */
    case 3194:  /* pred_extendvnx16si */
    case 3193:  /* pred_zero_extendvnx8si */
    case 3192:  /* pred_extendvnx8si */
    case 3191:  /* pred_zero_extendvnx4si */
    case 3190:  /* pred_extendvnx4si */
    case 3189:  /* pred_zero_extendvnx2si */
    case 3188:  /* pred_extendvnx2si */
    case 3187:  /* pred_zero_extendvnx1si */
    case 3186:  /* pred_extendvnx1si */
    case 3169:  /* pred_widen_mulsuvnx16si_scalar */
    case 3168:  /* pred_widen_mulsuvnx8si_scalar */
    case 3167:  /* pred_widen_mulsuvnx4si_scalar */
    case 3166:  /* pred_widen_mulsuvnx2si_scalar */
    case 3165:  /* pred_widen_mulsuvnx1si_scalar */
    case 3154:  /* pred_widen_mulsuvnx16si */
    case 3153:  /* pred_widen_mulsuvnx8si */
    case 3152:  /* pred_widen_mulsuvnx4si */
    case 3151:  /* pred_widen_mulsuvnx2si */
    case 3150:  /* pred_widen_mulsuvnx1si */
    case 3127:  /* pred_single_widen_subuvnx16si_scalar */
    case 3126:  /* pred_single_widen_adduvnx16si_scalar */
    case 3125:  /* pred_single_widen_subsvnx16si_scalar */
    case 3124:  /* pred_single_widen_addsvnx16si_scalar */
    case 3123:  /* pred_single_widen_subuvnx8si_scalar */
    case 3122:  /* pred_single_widen_adduvnx8si_scalar */
    case 3121:  /* pred_single_widen_subsvnx8si_scalar */
    case 3120:  /* pred_single_widen_addsvnx8si_scalar */
    case 3119:  /* pred_single_widen_subuvnx4si_scalar */
    case 3118:  /* pred_single_widen_adduvnx4si_scalar */
    case 3117:  /* pred_single_widen_subsvnx4si_scalar */
    case 3116:  /* pred_single_widen_addsvnx4si_scalar */
    case 3115:  /* pred_single_widen_subuvnx2si_scalar */
    case 3114:  /* pred_single_widen_adduvnx2si_scalar */
    case 3113:  /* pred_single_widen_subsvnx2si_scalar */
    case 3112:  /* pred_single_widen_addsvnx2si_scalar */
    case 3111:  /* pred_single_widen_subuvnx1si_scalar */
    case 3110:  /* pred_single_widen_adduvnx1si_scalar */
    case 3109:  /* pred_single_widen_subsvnx1si_scalar */
    case 3108:  /* pred_single_widen_addsvnx1si_scalar */
    case 3067:  /* pred_single_widen_subuvnx16si */
    case 3066:  /* pred_single_widen_adduvnx16si */
    case 3065:  /* pred_single_widen_subsvnx16si */
    case 3064:  /* pred_single_widen_addsvnx16si */
    case 3063:  /* pred_single_widen_subuvnx8si */
    case 3062:  /* pred_single_widen_adduvnx8si */
    case 3061:  /* pred_single_widen_subsvnx8si */
    case 3060:  /* pred_single_widen_addsvnx8si */
    case 3059:  /* pred_single_widen_subuvnx4si */
    case 3058:  /* pred_single_widen_adduvnx4si */
    case 3057:  /* pred_single_widen_subsvnx4si */
    case 3056:  /* pred_single_widen_addsvnx4si */
    case 3055:  /* pred_single_widen_subuvnx2si */
    case 3054:  /* pred_single_widen_adduvnx2si */
    case 3053:  /* pred_single_widen_subsvnx2si */
    case 3052:  /* pred_single_widen_addsvnx2si */
    case 3051:  /* pred_single_widen_subuvnx1si */
    case 3050:  /* pred_single_widen_adduvnx1si */
    case 3049:  /* pred_single_widen_subsvnx1si */
    case 3048:  /* pred_single_widen_addsvnx1si */
    case 2999:  /* pred_dual_widen_muluvnx16si_scalar */
    case 2998:  /* pred_dual_widen_subuvnx16si_scalar */
    case 2997:  /* pred_dual_widen_adduvnx16si_scalar */
    case 2996:  /* pred_dual_widen_mulsvnx16si_scalar */
    case 2995:  /* pred_dual_widen_subsvnx16si_scalar */
    case 2994:  /* pred_dual_widen_addsvnx16si_scalar */
    case 2993:  /* pred_dual_widen_muluvnx8si_scalar */
    case 2992:  /* pred_dual_widen_subuvnx8si_scalar */
    case 2991:  /* pred_dual_widen_adduvnx8si_scalar */
    case 2990:  /* pred_dual_widen_mulsvnx8si_scalar */
    case 2989:  /* pred_dual_widen_subsvnx8si_scalar */
    case 2988:  /* pred_dual_widen_addsvnx8si_scalar */
    case 2987:  /* pred_dual_widen_muluvnx4si_scalar */
    case 2986:  /* pred_dual_widen_subuvnx4si_scalar */
    case 2985:  /* pred_dual_widen_adduvnx4si_scalar */
    case 2984:  /* pred_dual_widen_mulsvnx4si_scalar */
    case 2983:  /* pred_dual_widen_subsvnx4si_scalar */
    case 2982:  /* pred_dual_widen_addsvnx4si_scalar */
    case 2981:  /* pred_dual_widen_muluvnx2si_scalar */
    case 2980:  /* pred_dual_widen_subuvnx2si_scalar */
    case 2979:  /* pred_dual_widen_adduvnx2si_scalar */
    case 2978:  /* pred_dual_widen_mulsvnx2si_scalar */
    case 2977:  /* pred_dual_widen_subsvnx2si_scalar */
    case 2976:  /* pred_dual_widen_addsvnx2si_scalar */
    case 2975:  /* pred_dual_widen_muluvnx1si_scalar */
    case 2974:  /* pred_dual_widen_subuvnx1si_scalar */
    case 2973:  /* pred_dual_widen_adduvnx1si_scalar */
    case 2972:  /* pred_dual_widen_mulsvnx1si_scalar */
    case 2971:  /* pred_dual_widen_subsvnx1si_scalar */
    case 2970:  /* pred_dual_widen_addsvnx1si_scalar */
    case 2909:  /* pred_dual_widen_muluvnx16si */
    case 2908:  /* pred_dual_widen_subuvnx16si */
    case 2907:  /* pred_dual_widen_adduvnx16si */
    case 2906:  /* pred_dual_widen_mulsvnx16si */
    case 2905:  /* pred_dual_widen_subsvnx16si */
    case 2904:  /* pred_dual_widen_addsvnx16si */
    case 2903:  /* pred_dual_widen_muluvnx8si */
    case 2902:  /* pred_dual_widen_subuvnx8si */
    case 2901:  /* pred_dual_widen_adduvnx8si */
    case 2900:  /* pred_dual_widen_mulsvnx8si */
    case 2899:  /* pred_dual_widen_subsvnx8si */
    case 2898:  /* pred_dual_widen_addsvnx8si */
    case 2897:  /* pred_dual_widen_muluvnx4si */
    case 2896:  /* pred_dual_widen_subuvnx4si */
    case 2895:  /* pred_dual_widen_adduvnx4si */
    case 2894:  /* pred_dual_widen_mulsvnx4si */
    case 2893:  /* pred_dual_widen_subsvnx4si */
    case 2892:  /* pred_dual_widen_addsvnx4si */
    case 2891:  /* pred_dual_widen_muluvnx2si */
    case 2890:  /* pred_dual_widen_subuvnx2si */
    case 2889:  /* pred_dual_widen_adduvnx2si */
    case 2888:  /* pred_dual_widen_mulsvnx2si */
    case 2887:  /* pred_dual_widen_subsvnx2si */
    case 2886:  /* pred_dual_widen_addsvnx2si */
    case 2885:  /* pred_dual_widen_muluvnx1si */
    case 2884:  /* pred_dual_widen_subuvnx1si */
    case 2883:  /* pred_dual_widen_adduvnx1si */
    case 2882:  /* pred_dual_widen_mulsvnx1si */
    case 2881:  /* pred_dual_widen_subsvnx1si */
    case 2880:  /* pred_dual_widen_addsvnx1si */
    case 2799:  /* pred_zero_extendvnx32hi_vf2 */
    case 2798:  /* pred_extendvnx32hi_vf2 */
    case 2797:  /* pred_zero_extendvnx16hi_vf2 */
    case 2796:  /* pred_extendvnx16hi_vf2 */
    case 2795:  /* pred_zero_extendvnx8hi_vf2 */
    case 2794:  /* pred_extendvnx8hi_vf2 */
    case 2793:  /* pred_zero_extendvnx4hi_vf2 */
    case 2792:  /* pred_extendvnx4hi_vf2 */
    case 2791:  /* pred_zero_extendvnx2hi_vf2 */
    case 2790:  /* pred_extendvnx2hi_vf2 */
    case 2789:  /* pred_zero_extendvnx1hi_vf2 */
    case 2788:  /* pred_extendvnx1hi_vf2 */
    case 2769:  /* pred_one_cmplvnx32hi */
    case 2768:  /* pred_negvnx32hi */
    case 2767:  /* pred_one_cmplvnx16hi */
    case 2766:  /* pred_negvnx16hi */
    case 2765:  /* pred_one_cmplvnx8hi */
    case 2764:  /* pred_negvnx8hi */
    case 2763:  /* pred_one_cmplvnx4hi */
    case 2762:  /* pred_negvnx4hi */
    case 2761:  /* pred_one_cmplvnx2hi */
    case 2760:  /* pred_negvnx2hi */
    case 2759:  /* pred_one_cmplvnx1hi */
    case 2758:  /* pred_negvnx1hi */
    case 2722:  /* pred_msbcvnx32hi_overflow_scalar */
    case 2721:  /* pred_msbcvnx16hi_overflow_scalar */
    case 2720:  /* pred_msbcvnx8hi_overflow_scalar */
    case 2719:  /* pred_msbcvnx4hi_overflow_scalar */
    case 2718:  /* pred_msbcvnx2hi_overflow_scalar */
    case 2717:  /* pred_msbcvnx1hi_overflow_scalar */
    case 2704:  /* pred_madcvnx32hi_overflow_scalar */
    case 2703:  /* pred_madcvnx16hi_overflow_scalar */
    case 2702:  /* pred_madcvnx8hi_overflow_scalar */
    case 2701:  /* pred_madcvnx4hi_overflow_scalar */
    case 2700:  /* pred_madcvnx2hi_overflow_scalar */
    case 2699:  /* pred_madcvnx1hi_overflow_scalar */
    case 2682:  /* pred_msbcvnx32hi_overflow */
    case 2681:  /* pred_msbcvnx16hi_overflow */
    case 2680:  /* pred_msbcvnx8hi_overflow */
    case 2679:  /* pred_msbcvnx4hi_overflow */
    case 2678:  /* pred_msbcvnx2hi_overflow */
    case 2677:  /* pred_msbcvnx1hi_overflow */
    case 2660:  /* pred_madcvnx32hi_overflow */
    case 2659:  /* pred_madcvnx16hi_overflow */
    case 2658:  /* pred_madcvnx8hi_overflow */
    case 2657:  /* pred_madcvnx4hi_overflow */
    case 2656:  /* pred_madcvnx2hi_overflow */
    case 2655:  /* pred_madcvnx1hi_overflow */
    case 2626:  /* pred_msbcvnx32hi_scalar */
    case 2625:  /* pred_msbcvnx16hi_scalar */
    case 2624:  /* pred_msbcvnx8hi_scalar */
    case 2623:  /* pred_msbcvnx4hi_scalar */
    case 2622:  /* pred_msbcvnx2hi_scalar */
    case 2621:  /* pred_msbcvnx1hi_scalar */
    case 2608:  /* pred_madcvnx32hi_scalar */
    case 2607:  /* pred_madcvnx16hi_scalar */
    case 2606:  /* pred_madcvnx8hi_scalar */
    case 2605:  /* pred_madcvnx4hi_scalar */
    case 2604:  /* pred_madcvnx2hi_scalar */
    case 2603:  /* pred_madcvnx1hi_scalar */
    case 2586:  /* pred_msbcvnx32hi */
    case 2585:  /* pred_msbcvnx16hi */
    case 2584:  /* pred_msbcvnx8hi */
    case 2583:  /* pred_msbcvnx4hi */
    case 2582:  /* pred_msbcvnx2hi */
    case 2581:  /* pred_msbcvnx1hi */
    case 2564:  /* pred_madcvnx32hi */
    case 2563:  /* pred_madcvnx16hi */
    case 2562:  /* pred_madcvnx8hi */
    case 2561:  /* pred_madcvnx4hi */
    case 2560:  /* pred_madcvnx2hi */
    case 2559:  /* pred_madcvnx1hi */
    case 2530:  /* pred_sbcvnx32hi_scalar */
    case 2529:  /* pred_sbcvnx16hi_scalar */
    case 2528:  /* pred_sbcvnx8hi_scalar */
    case 2527:  /* pred_sbcvnx4hi_scalar */
    case 2526:  /* pred_sbcvnx2hi_scalar */
    case 2525:  /* pred_sbcvnx1hi_scalar */
    case 2512:  /* pred_adcvnx32hi_scalar */
    case 2511:  /* pred_adcvnx16hi_scalar */
    case 2510:  /* pred_adcvnx8hi_scalar */
    case 2509:  /* pred_adcvnx4hi_scalar */
    case 2508:  /* pred_adcvnx2hi_scalar */
    case 2507:  /* pred_adcvnx1hi_scalar */
    case 2490:  /* pred_sbcvnx32hi */
    case 2489:  /* pred_sbcvnx16hi */
    case 2488:  /* pred_sbcvnx8hi */
    case 2487:  /* pred_sbcvnx4hi */
    case 2486:  /* pred_sbcvnx2hi */
    case 2485:  /* pred_sbcvnx1hi */
    case 2468:  /* pred_adcvnx32hi */
    case 2467:  /* pred_adcvnx16hi */
    case 2466:  /* pred_adcvnx8hi */
    case 2465:  /* pred_adcvnx4hi */
    case 2464:  /* pred_adcvnx2hi */
    case 2463:  /* pred_adcvnx1hi */
    case 2416:  /* pred_mulhsuvnx32hi_scalar */
    case 2415:  /* pred_mulhuvnx32hi_scalar */
    case 2414:  /* pred_mulhvnx32hi_scalar */
    case 2413:  /* pred_mulhsuvnx16hi_scalar */
    case 2412:  /* pred_mulhuvnx16hi_scalar */
    case 2411:  /* pred_mulhvnx16hi_scalar */
    case 2410:  /* pred_mulhsuvnx8hi_scalar */
    case 2409:  /* pred_mulhuvnx8hi_scalar */
    case 2408:  /* pred_mulhvnx8hi_scalar */
    case 2407:  /* pred_mulhsuvnx4hi_scalar */
    case 2406:  /* pred_mulhuvnx4hi_scalar */
    case 2405:  /* pred_mulhvnx4hi_scalar */
    case 2404:  /* pred_mulhsuvnx2hi_scalar */
    case 2403:  /* pred_mulhuvnx2hi_scalar */
    case 2402:  /* pred_mulhvnx2hi_scalar */
    case 2401:  /* pred_mulhsuvnx1hi_scalar */
    case 2400:  /* pred_mulhuvnx1hi_scalar */
    case 2399:  /* pred_mulhvnx1hi_scalar */
    case 2350:  /* pred_mulhsuvnx32hi */
    case 2349:  /* pred_mulhuvnx32hi */
    case 2348:  /* pred_mulhvnx32hi */
    case 2347:  /* pred_mulhsuvnx16hi */
    case 2346:  /* pred_mulhuvnx16hi */
    case 2345:  /* pred_mulhvnx16hi */
    case 2344:  /* pred_mulhsuvnx8hi */
    case 2343:  /* pred_mulhuvnx8hi */
    case 2342:  /* pred_mulhvnx8hi */
    case 2341:  /* pred_mulhsuvnx4hi */
    case 2340:  /* pred_mulhuvnx4hi */
    case 2339:  /* pred_mulhvnx4hi */
    case 2338:  /* pred_mulhsuvnx2hi */
    case 2337:  /* pred_mulhuvnx2hi */
    case 2336:  /* pred_mulhvnx2hi */
    case 2335:  /* pred_mulhsuvnx1hi */
    case 2334:  /* pred_mulhuvnx1hi */
    case 2333:  /* pred_mulhvnx1hi */
    case 2186:  /* pred_subvnx32hi_reverse_scalar */
    case 2185:  /* pred_subvnx16hi_reverse_scalar */
    case 2184:  /* pred_subvnx8hi_reverse_scalar */
    case 2183:  /* pred_subvnx4hi_reverse_scalar */
    case 2182:  /* pred_subvnx2hi_reverse_scalar */
    case 2181:  /* pred_subvnx1hi_reverse_scalar */
    case 2148:  /* pred_umodvnx32hi_scalar */
    case 2147:  /* pred_modvnx32hi_scalar */
    case 2146:  /* pred_udivvnx32hi_scalar */
    case 2145:  /* pred_divvnx32hi_scalar */
    case 2144:  /* pred_subvnx32hi_scalar */
    case 2143:  /* pred_umodvnx16hi_scalar */
    case 2142:  /* pred_modvnx16hi_scalar */
    case 2141:  /* pred_udivvnx16hi_scalar */
    case 2140:  /* pred_divvnx16hi_scalar */
    case 2139:  /* pred_subvnx16hi_scalar */
    case 2138:  /* pred_umodvnx8hi_scalar */
    case 2137:  /* pred_modvnx8hi_scalar */
    case 2136:  /* pred_udivvnx8hi_scalar */
    case 2135:  /* pred_divvnx8hi_scalar */
    case 2134:  /* pred_subvnx8hi_scalar */
    case 2133:  /* pred_umodvnx4hi_scalar */
    case 2132:  /* pred_modvnx4hi_scalar */
    case 2131:  /* pred_udivvnx4hi_scalar */
    case 2130:  /* pred_divvnx4hi_scalar */
    case 2129:  /* pred_subvnx4hi_scalar */
    case 2128:  /* pred_umodvnx2hi_scalar */
    case 2127:  /* pred_modvnx2hi_scalar */
    case 2126:  /* pred_udivvnx2hi_scalar */
    case 2125:  /* pred_divvnx2hi_scalar */
    case 2124:  /* pred_subvnx2hi_scalar */
    case 2123:  /* pred_umodvnx1hi_scalar */
    case 2122:  /* pred_modvnx1hi_scalar */
    case 2121:  /* pred_udivvnx1hi_scalar */
    case 2120:  /* pred_divvnx1hi_scalar */
    case 2119:  /* pred_subvnx1hi_scalar */
    case 2038:  /* pred_mulvnx32hi_scalar */
    case 2037:  /* pred_uminvnx32hi_scalar */
    case 2036:  /* pred_sminvnx32hi_scalar */
    case 2035:  /* pred_umaxvnx32hi_scalar */
    case 2034:  /* pred_smaxvnx32hi_scalar */
    case 2033:  /* pred_xorvnx32hi_scalar */
    case 2032:  /* pred_iorvnx32hi_scalar */
    case 2031:  /* pred_andvnx32hi_scalar */
    case 2030:  /* pred_addvnx32hi_scalar */
    case 2029:  /* pred_mulvnx16hi_scalar */
    case 2028:  /* pred_uminvnx16hi_scalar */
    case 2027:  /* pred_sminvnx16hi_scalar */
    case 2026:  /* pred_umaxvnx16hi_scalar */
    case 2025:  /* pred_smaxvnx16hi_scalar */
    case 2024:  /* pred_xorvnx16hi_scalar */
    case 2023:  /* pred_iorvnx16hi_scalar */
    case 2022:  /* pred_andvnx16hi_scalar */
    case 2021:  /* pred_addvnx16hi_scalar */
    case 2020:  /* pred_mulvnx8hi_scalar */
    case 2019:  /* pred_uminvnx8hi_scalar */
    case 2018:  /* pred_sminvnx8hi_scalar */
    case 2017:  /* pred_umaxvnx8hi_scalar */
    case 2016:  /* pred_smaxvnx8hi_scalar */
    case 2015:  /* pred_xorvnx8hi_scalar */
    case 2014:  /* pred_iorvnx8hi_scalar */
    case 2013:  /* pred_andvnx8hi_scalar */
    case 2012:  /* pred_addvnx8hi_scalar */
    case 2011:  /* pred_mulvnx4hi_scalar */
    case 2010:  /* pred_uminvnx4hi_scalar */
    case 2009:  /* pred_sminvnx4hi_scalar */
    case 2008:  /* pred_umaxvnx4hi_scalar */
    case 2007:  /* pred_smaxvnx4hi_scalar */
    case 2006:  /* pred_xorvnx4hi_scalar */
    case 2005:  /* pred_iorvnx4hi_scalar */
    case 2004:  /* pred_andvnx4hi_scalar */
    case 2003:  /* pred_addvnx4hi_scalar */
    case 2002:  /* pred_mulvnx2hi_scalar */
    case 2001:  /* pred_uminvnx2hi_scalar */
    case 2000:  /* pred_sminvnx2hi_scalar */
    case 1999:  /* pred_umaxvnx2hi_scalar */
    case 1998:  /* pred_smaxvnx2hi_scalar */
    case 1997:  /* pred_xorvnx2hi_scalar */
    case 1996:  /* pred_iorvnx2hi_scalar */
    case 1995:  /* pred_andvnx2hi_scalar */
    case 1994:  /* pred_addvnx2hi_scalar */
    case 1993:  /* pred_mulvnx1hi_scalar */
    case 1992:  /* pred_uminvnx1hi_scalar */
    case 1991:  /* pred_sminvnx1hi_scalar */
    case 1990:  /* pred_umaxvnx1hi_scalar */
    case 1989:  /* pred_smaxvnx1hi_scalar */
    case 1988:  /* pred_xorvnx1hi_scalar */
    case 1987:  /* pred_iorvnx1hi_scalar */
    case 1986:  /* pred_andvnx1hi_scalar */
    case 1985:  /* pred_addvnx1hi_scalar */
    case 1894:  /* pred_lshrvnx32hi_scalar */
    case 1893:  /* pred_ashrvnx32hi_scalar */
    case 1892:  /* pred_ashlvnx32hi_scalar */
    case 1891:  /* pred_lshrvnx16hi_scalar */
    case 1890:  /* pred_ashrvnx16hi_scalar */
    case 1889:  /* pred_ashlvnx16hi_scalar */
    case 1888:  /* pred_lshrvnx8hi_scalar */
    case 1887:  /* pred_ashrvnx8hi_scalar */
    case 1886:  /* pred_ashlvnx8hi_scalar */
    case 1885:  /* pred_lshrvnx4hi_scalar */
    case 1884:  /* pred_ashrvnx4hi_scalar */
    case 1883:  /* pred_ashlvnx4hi_scalar */
    case 1882:  /* pred_lshrvnx2hi_scalar */
    case 1881:  /* pred_ashrvnx2hi_scalar */
    case 1880:  /* pred_ashlvnx2hi_scalar */
    case 1879:  /* pred_lshrvnx1hi_scalar */
    case 1878:  /* pred_ashrvnx1hi_scalar */
    case 1877:  /* pred_ashlvnx1hi_scalar */
    case 1702:  /* pred_umodvnx32hi */
    case 1701:  /* pred_modvnx32hi */
    case 1700:  /* pred_udivvnx32hi */
    case 1699:  /* pred_divvnx32hi */
    case 1698:  /* pred_mulvnx32hi */
    case 1697:  /* pred_uminvnx32hi */
    case 1696:  /* pred_sminvnx32hi */
    case 1695:  /* pred_umaxvnx32hi */
    case 1694:  /* pred_smaxvnx32hi */
    case 1693:  /* pred_lshrvnx32hi */
    case 1692:  /* pred_ashrvnx32hi */
    case 1691:  /* pred_ashlvnx32hi */
    case 1690:  /* pred_xorvnx32hi */
    case 1689:  /* pred_iorvnx32hi */
    case 1688:  /* pred_andvnx32hi */
    case 1687:  /* pred_subvnx32hi */
    case 1686:  /* pred_addvnx32hi */
    case 1685:  /* pred_umodvnx16hi */
    case 1684:  /* pred_modvnx16hi */
    case 1683:  /* pred_udivvnx16hi */
    case 1682:  /* pred_divvnx16hi */
    case 1681:  /* pred_mulvnx16hi */
    case 1680:  /* pred_uminvnx16hi */
    case 1679:  /* pred_sminvnx16hi */
    case 1678:  /* pred_umaxvnx16hi */
    case 1677:  /* pred_smaxvnx16hi */
    case 1676:  /* pred_lshrvnx16hi */
    case 1675:  /* pred_ashrvnx16hi */
    case 1674:  /* pred_ashlvnx16hi */
    case 1673:  /* pred_xorvnx16hi */
    case 1672:  /* pred_iorvnx16hi */
    case 1671:  /* pred_andvnx16hi */
    case 1670:  /* pred_subvnx16hi */
    case 1669:  /* pred_addvnx16hi */
    case 1668:  /* pred_umodvnx8hi */
    case 1667:  /* pred_modvnx8hi */
    case 1666:  /* pred_udivvnx8hi */
    case 1665:  /* pred_divvnx8hi */
    case 1664:  /* pred_mulvnx8hi */
    case 1663:  /* pred_uminvnx8hi */
    case 1662:  /* pred_sminvnx8hi */
    case 1661:  /* pred_umaxvnx8hi */
    case 1660:  /* pred_smaxvnx8hi */
    case 1659:  /* pred_lshrvnx8hi */
    case 1658:  /* pred_ashrvnx8hi */
    case 1657:  /* pred_ashlvnx8hi */
    case 1656:  /* pred_xorvnx8hi */
    case 1655:  /* pred_iorvnx8hi */
    case 1654:  /* pred_andvnx8hi */
    case 1653:  /* pred_subvnx8hi */
    case 1652:  /* pred_addvnx8hi */
    case 1651:  /* pred_umodvnx4hi */
    case 1650:  /* pred_modvnx4hi */
    case 1649:  /* pred_udivvnx4hi */
    case 1648:  /* pred_divvnx4hi */
    case 1647:  /* pred_mulvnx4hi */
    case 1646:  /* pred_uminvnx4hi */
    case 1645:  /* pred_sminvnx4hi */
    case 1644:  /* pred_umaxvnx4hi */
    case 1643:  /* pred_smaxvnx4hi */
    case 1642:  /* pred_lshrvnx4hi */
    case 1641:  /* pred_ashrvnx4hi */
    case 1640:  /* pred_ashlvnx4hi */
    case 1639:  /* pred_xorvnx4hi */
    case 1638:  /* pred_iorvnx4hi */
    case 1637:  /* pred_andvnx4hi */
    case 1636:  /* pred_subvnx4hi */
    case 1635:  /* pred_addvnx4hi */
    case 1634:  /* pred_umodvnx2hi */
    case 1633:  /* pred_modvnx2hi */
    case 1632:  /* pred_udivvnx2hi */
    case 1631:  /* pred_divvnx2hi */
    case 1630:  /* pred_mulvnx2hi */
    case 1629:  /* pred_uminvnx2hi */
    case 1628:  /* pred_sminvnx2hi */
    case 1627:  /* pred_umaxvnx2hi */
    case 1626:  /* pred_smaxvnx2hi */
    case 1625:  /* pred_lshrvnx2hi */
    case 1624:  /* pred_ashrvnx2hi */
    case 1623:  /* pred_ashlvnx2hi */
    case 1622:  /* pred_xorvnx2hi */
    case 1621:  /* pred_iorvnx2hi */
    case 1620:  /* pred_andvnx2hi */
    case 1619:  /* pred_subvnx2hi */
    case 1618:  /* pred_addvnx2hi */
    case 1617:  /* pred_umodvnx1hi */
    case 1616:  /* pred_modvnx1hi */
    case 1615:  /* pred_udivvnx1hi */
    case 1614:  /* pred_divvnx1hi */
    case 1613:  /* pred_mulvnx1hi */
    case 1612:  /* pred_uminvnx1hi */
    case 1611:  /* pred_sminvnx1hi */
    case 1610:  /* pred_umaxvnx1hi */
    case 1609:  /* pred_smaxvnx1hi */
    case 1608:  /* pred_lshrvnx1hi */
    case 1607:  /* pred_ashrvnx1hi */
    case 1606:  /* pred_ashlvnx1hi */
    case 1605:  /* pred_xorvnx1hi */
    case 1604:  /* pred_iorvnx1hi */
    case 1603:  /* pred_andvnx1hi */
    case 1602:  /* pred_subvnx1hi */
    case 1601:  /* pred_addvnx1hi */
    case 1479:  /* pred_indexed_ustorevnx32hivnx32hi */
    case 1478:  /* pred_indexed_ostorevnx32hivnx32hi */
    case 1477:  /* pred_indexed_ustorevnx32hivnx32qi */
    case 1476:  /* pred_indexed_ostorevnx32hivnx32qi */
    case 1467:  /* pred_indexed_ustorevnx16hivnx16si */
    case 1466:  /* pred_indexed_ostorevnx16hivnx16si */
    case 1459:  /* pred_indexed_ustorevnx16hivnx16hi */
    case 1458:  /* pred_indexed_ostorevnx16hivnx16hi */
    case 1451:  /* pred_indexed_ustorevnx16hivnx16qi */
    case 1450:  /* pred_indexed_ostorevnx16hivnx16qi */
    case 1439:  /* pred_indexed_ustorevnx8hivnx8di */
    case 1438:  /* pred_indexed_ostorevnx8hivnx8di */
    case 1427:  /* pred_indexed_ustorevnx8hivnx8si */
    case 1426:  /* pred_indexed_ostorevnx8hivnx8si */
    case 1415:  /* pred_indexed_ustorevnx8hivnx8hi */
    case 1414:  /* pred_indexed_ostorevnx8hivnx8hi */
    case 1403:  /* pred_indexed_ustorevnx8hivnx8qi */
    case 1402:  /* pred_indexed_ostorevnx8hivnx8qi */
    case 1391:  /* pred_indexed_ustorevnx4hivnx4di */
    case 1390:  /* pred_indexed_ostorevnx4hivnx4di */
    case 1379:  /* pred_indexed_ustorevnx4hivnx4si */
    case 1378:  /* pred_indexed_ostorevnx4hivnx4si */
    case 1367:  /* pred_indexed_ustorevnx4hivnx4hi */
    case 1366:  /* pred_indexed_ostorevnx4hivnx4hi */
    case 1355:  /* pred_indexed_ustorevnx4hivnx4qi */
    case 1354:  /* pred_indexed_ostorevnx4hivnx4qi */
    case 1343:  /* pred_indexed_ustorevnx2hivnx2di */
    case 1342:  /* pred_indexed_ostorevnx2hivnx2di */
    case 1331:  /* pred_indexed_ustorevnx2hivnx2si */
    case 1330:  /* pred_indexed_ostorevnx2hivnx2si */
    case 1319:  /* pred_indexed_ustorevnx2hivnx2hi */
    case 1318:  /* pred_indexed_ostorevnx2hivnx2hi */
    case 1307:  /* pred_indexed_ustorevnx2hivnx2qi */
    case 1306:  /* pred_indexed_ostorevnx2hivnx2qi */
    case 1271:  /* pred_indexed_ustorevnx1hivnx1di */
    case 1270:  /* pred_indexed_ostorevnx1hivnx1di */
    case 1269:  /* pred_indexed_ustorevnx1hivnx1si */
    case 1268:  /* pred_indexed_ostorevnx1hivnx1si */
    case 1267:  /* pred_indexed_ustorevnx1hivnx1hi */
    case 1266:  /* pred_indexed_ostorevnx1hivnx1hi */
    case 1265:  /* pred_indexed_ustorevnx1hivnx1qi */
    case 1264:  /* pred_indexed_ostorevnx1hivnx1qi */
    case 1247:  /* pred_indexed_uloadvnx8hi_x4_smaller_eew */
    case 1246:  /* pred_indexed_oloadvnx8hi_x4_smaller_eew */
    case 1245:  /* pred_indexed_uloadvnx4hi_x4_smaller_eew */
    case 1244:  /* pred_indexed_oloadvnx4hi_x4_smaller_eew */
    case 1243:  /* pred_indexed_uloadvnx2hi_x4_smaller_eew */
    case 1242:  /* pred_indexed_oloadvnx2hi_x4_smaller_eew */
    case 1241:  /* pred_indexed_uloadvnx1hi_x4_smaller_eew */
    case 1240:  /* pred_indexed_oloadvnx1hi_x4_smaller_eew */
    case 1213:  /* pred_indexed_uloadvnx16hi_x2_smaller_eew */
    case 1212:  /* pred_indexed_oloadvnx16hi_x2_smaller_eew */
    case 1211:  /* pred_indexed_uloadvnx8hi_x2_smaller_eew */
    case 1210:  /* pred_indexed_oloadvnx8hi_x2_smaller_eew */
    case 1209:  /* pred_indexed_uloadvnx4hi_x2_smaller_eew */
    case 1208:  /* pred_indexed_oloadvnx4hi_x2_smaller_eew */
    case 1207:  /* pred_indexed_uloadvnx2hi_x2_smaller_eew */
    case 1206:  /* pred_indexed_oloadvnx2hi_x2_smaller_eew */
    case 1205:  /* pred_indexed_uloadvnx1hi_x2_smaller_eew */
    case 1204:  /* pred_indexed_oloadvnx1hi_x2_smaller_eew */
    case 1103:  /* pred_indexed_uloadvnx32hi_x2_greater_eew */
    case 1102:  /* pred_indexed_oloadvnx32hi_x2_greater_eew */
    case 1101:  /* pred_indexed_uloadvnx16hi_x2_greater_eew */
    case 1100:  /* pred_indexed_oloadvnx16hi_x2_greater_eew */
    case 1099:  /* pred_indexed_uloadvnx8hi_x2_greater_eew */
    case 1098:  /* pred_indexed_oloadvnx8hi_x2_greater_eew */
    case 1097:  /* pred_indexed_uloadvnx4hi_x2_greater_eew */
    case 1096:  /* pred_indexed_oloadvnx4hi_x2_greater_eew */
    case 1095:  /* pred_indexed_uloadvnx2hi_x2_greater_eew */
    case 1094:  /* pred_indexed_oloadvnx2hi_x2_greater_eew */
    case 1093:  /* pred_indexed_uloadvnx1hi_x2_greater_eew */
    case 1092:  /* pred_indexed_oloadvnx1hi_x2_greater_eew */
    case 1055:  /* pred_indexed_uloadvnx32hi_same_eew */
    case 1054:  /* pred_indexed_oloadvnx32hi_same_eew */
    case 1053:  /* pred_indexed_uloadvnx16hi_same_eew */
    case 1052:  /* pred_indexed_oloadvnx16hi_same_eew */
    case 1051:  /* pred_indexed_uloadvnx8hi_same_eew */
    case 1050:  /* pred_indexed_oloadvnx8hi_same_eew */
    case 1049:  /* pred_indexed_uloadvnx4hi_same_eew */
    case 1048:  /* pred_indexed_oloadvnx4hi_same_eew */
    case 1047:  /* pred_indexed_uloadvnx2hi_same_eew */
    case 1046:  /* pred_indexed_oloadvnx2hi_same_eew */
    case 1045:  /* pred_indexed_uloadvnx1hi_same_eew */
    case 1044:  /* pred_indexed_oloadvnx1hi_same_eew */
    case 1011:  /* pred_strided_storevnx32hi */
    case 1010:  /* pred_strided_storevnx16hi */
    case 1009:  /* pred_strided_storevnx8hi */
    case 1008:  /* pred_strided_storevnx4hi */
    case 1007:  /* pred_strided_storevnx2hi */
    case 1006:  /* pred_strided_storevnx1hi */
    case 980:  /* pred_strided_loadvnx32hi */
    case 979:  /* pred_strided_loadvnx16hi */
    case 978:  /* pred_strided_loadvnx8hi */
    case 977:  /* pred_strided_loadvnx4hi */
    case 976:  /* pred_strided_loadvnx2hi */
    case 975:  /* pred_strided_loadvnx1hi */
    case 945:  /* *pred_broadcastvnx32hi */
    case 944:  /* *pred_broadcastvnx16hi */
    case 943:  /* *pred_broadcastvnx8hi */
    case 942:  /* *pred_broadcastvnx4hi */
    case 941:  /* *pred_broadcastvnx2hi */
    case 940:  /* *pred_broadcastvnx1hi */
    case 919:  /* pred_mergevnx32hi_scalar */
    case 918:  /* pred_mergevnx16hi_scalar */
    case 917:  /* pred_mergevnx8hi_scalar */
    case 916:  /* pred_mergevnx4hi_scalar */
    case 915:  /* pred_mergevnx2hi_scalar */
    case 914:  /* pred_mergevnx1hi_scalar */
    case 888:  /* pred_mergevnx32hi */
    case 887:  /* pred_mergevnx16hi */
    case 886:  /* pred_mergevnx8hi */
    case 885:  /* pred_mergevnx4hi */
    case 884:  /* pred_mergevnx2hi */
    case 883:  /* pred_mergevnx1hi */
    case 843:  /* pred_storevnx32hi */
    case 842:  /* pred_storevnx16hi */
    case 841:  /* pred_storevnx8hi */
    case 840:  /* pred_storevnx4hi */
    case 839:  /* pred_storevnx2hi */
    case 838:  /* pred_storevnx1hi */
    case 812:  /* pred_movvnx32hi */
    case 811:  /* pred_movvnx16hi */
    case 810:  /* pred_movvnx8hi */
    case 809:  /* pred_movvnx4hi */
    case 808:  /* pred_movvnx2hi */
    case 807:  /* pred_movvnx1hi */
    case 755:  /* *movvnx2hi_fract */
    case 754:  /* *movvnx1hi_fract */
    case 732:  /* *movvnx32hi_whole */
    case 731:  /* *movvnx16hi_whole */
    case 730:  /* *movvnx8hi_whole */
    case 729:  /* *movvnx4hi_whole */
    case 728:  /* *movvnx2hi_whole */
      return 16 /* 0x10 */;

    case 6043:  /* pred_fault_loadvnx64qi */
    case 6042:  /* pred_fault_loadvnx32qi */
    case 6041:  /* pred_fault_loadvnx16qi */
    case 6040:  /* pred_fault_loadvnx8qi */
    case 6039:  /* pred_fault_loadvnx4qi */
    case 6038:  /* pred_fault_loadvnx2qi */
    case 6037:  /* pred_fault_loadvnx1qi */
    case 6010:  /* pred_compressvnx64qi */
    case 6009:  /* pred_compressvnx32qi */
    case 6008:  /* pred_compressvnx16qi */
    case 6007:  /* pred_compressvnx8qi */
    case 6006:  /* pred_compressvnx4qi */
    case 6005:  /* pred_compressvnx2qi */
    case 6004:  /* pred_compressvnx1qi */
    case 5979:  /* pred_gatherei16vnx32qi */
    case 5978:  /* pred_gatherei16vnx16qi */
    case 5977:  /* pred_gatherei16vnx8qi */
    case 5976:  /* pred_gatherei16vnx4qi */
    case 5975:  /* pred_gatherei16vnx2qi */
    case 5974:  /* pred_gatherei16vnx1qi */
    case 5949:  /* pred_gathervnx64qi_scalar */
    case 5948:  /* pred_gathervnx32qi_scalar */
    case 5947:  /* pred_gathervnx16qi_scalar */
    case 5946:  /* pred_gathervnx8qi_scalar */
    case 5945:  /* pred_gathervnx4qi_scalar */
    case 5944:  /* pred_gathervnx2qi_scalar */
    case 5943:  /* pred_gathervnx1qi_scalar */
    case 5918:  /* pred_gathervnx64qi */
    case 5917:  /* pred_gathervnx32qi */
    case 5916:  /* pred_gathervnx16qi */
    case 5915:  /* pred_gathervnx8qi */
    case 5914:  /* pred_gathervnx4qi */
    case 5913:  /* pred_gathervnx2qi */
    case 5912:  /* pred_gathervnx1qi */
    case 5855:  /* pred_slide1downvnx64qi */
    case 5854:  /* pred_slide1upvnx64qi */
    case 5853:  /* pred_slide1downvnx32qi */
    case 5852:  /* pred_slide1upvnx32qi */
    case 5851:  /* pred_slide1downvnx16qi */
    case 5850:  /* pred_slide1upvnx16qi */
    case 5849:  /* pred_slide1downvnx8qi */
    case 5848:  /* pred_slide1upvnx8qi */
    case 5847:  /* pred_slide1downvnx4qi */
    case 5846:  /* pred_slide1upvnx4qi */
    case 5845:  /* pred_slide1downvnx2qi */
    case 5844:  /* pred_slide1upvnx2qi */
    case 5843:  /* pred_slide1downvnx1qi */
    case 5842:  /* pred_slide1upvnx1qi */
    case 5793:  /* pred_slidedownvnx64qi */
    case 5792:  /* pred_slideupvnx64qi */
    case 5791:  /* pred_slidedownvnx32qi */
    case 5790:  /* pred_slideupvnx32qi */
    case 5789:  /* pred_slidedownvnx16qi */
    case 5788:  /* pred_slideupvnx16qi */
    case 5787:  /* pred_slidedownvnx8qi */
    case 5786:  /* pred_slideupvnx8qi */
    case 5785:  /* pred_slidedownvnx4qi */
    case 5784:  /* pred_slideupvnx4qi */
    case 5783:  /* pred_slidedownvnx2qi */
    case 5782:  /* pred_slideupvnx2qi */
    case 5781:  /* pred_slidedownvnx1qi */
    case 5780:  /* pred_slideupvnx1qi */
    case 5751:  /* *pred_extract_firstvnx64qi */
    case 5750:  /* *pred_extract_firstvnx32qi */
    case 5749:  /* *pred_extract_firstvnx16qi */
    case 5748:  /* *pred_extract_firstvnx8qi */
    case 5747:  /* *pred_extract_firstvnx4qi */
    case 5746:  /* *pred_extract_firstvnx2qi */
    case 5745:  /* *pred_extract_firstvnx1qi */
    case 5672:  /* pred_widen_reduc_plusuvnx32qivnx2hi */
    case 5671:  /* pred_widen_reduc_plusvnx32qivnx2hi */
    case 5670:  /* pred_widen_reduc_plusuvnx16qivnx2hi */
    case 5669:  /* pred_widen_reduc_plusvnx16qivnx2hi */
    case 5668:  /* pred_widen_reduc_plusuvnx8qivnx2hi */
    case 5667:  /* pred_widen_reduc_plusvnx8qivnx2hi */
    case 5666:  /* pred_widen_reduc_plusuvnx4qivnx2hi */
    case 5665:  /* pred_widen_reduc_plusvnx4qivnx2hi */
    case 5664:  /* pred_widen_reduc_plusuvnx2qivnx2hi */
    case 5663:  /* pred_widen_reduc_plusvnx2qivnx2hi */
    case 5662:  /* pred_widen_reduc_plusuvnx1qivnx2hi */
    case 5661:  /* pred_widen_reduc_plusvnx1qivnx2hi */
    case 5638:  /* pred_widen_reduc_plusuvnx64qivnx4hi */
    case 5637:  /* pred_widen_reduc_plusvnx64qivnx4hi */
    case 5636:  /* pred_widen_reduc_plusuvnx32qivnx4hi */
    case 5635:  /* pred_widen_reduc_plusvnx32qivnx4hi */
    case 5634:  /* pred_widen_reduc_plusuvnx16qivnx4hi */
    case 5633:  /* pred_widen_reduc_plusvnx16qivnx4hi */
    case 5632:  /* pred_widen_reduc_plusuvnx8qivnx4hi */
    case 5631:  /* pred_widen_reduc_plusvnx8qivnx4hi */
    case 5630:  /* pred_widen_reduc_plusuvnx4qivnx4hi */
    case 5629:  /* pred_widen_reduc_plusvnx4qivnx4hi */
    case 5628:  /* pred_widen_reduc_plusuvnx2qivnx4hi */
    case 5627:  /* pred_widen_reduc_plusvnx2qivnx4hi */
    case 5626:  /* pred_widen_reduc_plusuvnx1qivnx4hi */
    case 5625:  /* pred_widen_reduc_plusvnx1qivnx4hi */
    case 5552:  /* pred_reduc_xorvnx32qivnx4qi */
    case 5551:  /* pred_reduc_orvnx32qivnx4qi */
    case 5550:  /* pred_reduc_andvnx32qivnx4qi */
    case 5549:  /* pred_reduc_minvnx32qivnx4qi */
    case 5548:  /* pred_reduc_minuvnx32qivnx4qi */
    case 5547:  /* pred_reduc_maxvnx32qivnx4qi */
    case 5546:  /* pred_reduc_maxuvnx32qivnx4qi */
    case 5545:  /* pred_reduc_sumvnx32qivnx4qi */
    case 5544:  /* pred_reduc_xorvnx16qivnx4qi */
    case 5543:  /* pred_reduc_orvnx16qivnx4qi */
    case 5542:  /* pred_reduc_andvnx16qivnx4qi */
    case 5541:  /* pred_reduc_minvnx16qivnx4qi */
    case 5540:  /* pred_reduc_minuvnx16qivnx4qi */
    case 5539:  /* pred_reduc_maxvnx16qivnx4qi */
    case 5538:  /* pred_reduc_maxuvnx16qivnx4qi */
    case 5537:  /* pred_reduc_sumvnx16qivnx4qi */
    case 5536:  /* pred_reduc_xorvnx8qivnx4qi */
    case 5535:  /* pred_reduc_orvnx8qivnx4qi */
    case 5534:  /* pred_reduc_andvnx8qivnx4qi */
    case 5533:  /* pred_reduc_minvnx8qivnx4qi */
    case 5532:  /* pred_reduc_minuvnx8qivnx4qi */
    case 5531:  /* pred_reduc_maxvnx8qivnx4qi */
    case 5530:  /* pred_reduc_maxuvnx8qivnx4qi */
    case 5529:  /* pred_reduc_sumvnx8qivnx4qi */
    case 5528:  /* pred_reduc_xorvnx4qivnx4qi */
    case 5527:  /* pred_reduc_orvnx4qivnx4qi */
    case 5526:  /* pred_reduc_andvnx4qivnx4qi */
    case 5525:  /* pred_reduc_minvnx4qivnx4qi */
    case 5524:  /* pred_reduc_minuvnx4qivnx4qi */
    case 5523:  /* pred_reduc_maxvnx4qivnx4qi */
    case 5522:  /* pred_reduc_maxuvnx4qivnx4qi */
    case 5521:  /* pred_reduc_sumvnx4qivnx4qi */
    case 5520:  /* pred_reduc_xorvnx2qivnx4qi */
    case 5519:  /* pred_reduc_orvnx2qivnx4qi */
    case 5518:  /* pred_reduc_andvnx2qivnx4qi */
    case 5517:  /* pred_reduc_minvnx2qivnx4qi */
    case 5516:  /* pred_reduc_minuvnx2qivnx4qi */
    case 5515:  /* pred_reduc_maxvnx2qivnx4qi */
    case 5514:  /* pred_reduc_maxuvnx2qivnx4qi */
    case 5513:  /* pred_reduc_sumvnx2qivnx4qi */
    case 5512:  /* pred_reduc_xorvnx1qivnx4qi */
    case 5511:  /* pred_reduc_orvnx1qivnx4qi */
    case 5510:  /* pred_reduc_andvnx1qivnx4qi */
    case 5509:  /* pred_reduc_minvnx1qivnx4qi */
    case 5508:  /* pred_reduc_minuvnx1qivnx4qi */
    case 5507:  /* pred_reduc_maxvnx1qivnx4qi */
    case 5506:  /* pred_reduc_maxuvnx1qivnx4qi */
    case 5505:  /* pred_reduc_sumvnx1qivnx4qi */
    case 5384:  /* pred_reduc_xorvnx64qivnx8qi */
    case 5383:  /* pred_reduc_orvnx64qivnx8qi */
    case 5382:  /* pred_reduc_andvnx64qivnx8qi */
    case 5381:  /* pred_reduc_minvnx64qivnx8qi */
    case 5380:  /* pred_reduc_minuvnx64qivnx8qi */
    case 5379:  /* pred_reduc_maxvnx64qivnx8qi */
    case 5378:  /* pred_reduc_maxuvnx64qivnx8qi */
    case 5377:  /* pred_reduc_sumvnx64qivnx8qi */
    case 5376:  /* pred_reduc_xorvnx32qivnx8qi */
    case 5375:  /* pred_reduc_orvnx32qivnx8qi */
    case 5374:  /* pred_reduc_andvnx32qivnx8qi */
    case 5373:  /* pred_reduc_minvnx32qivnx8qi */
    case 5372:  /* pred_reduc_minuvnx32qivnx8qi */
    case 5371:  /* pred_reduc_maxvnx32qivnx8qi */
    case 5370:  /* pred_reduc_maxuvnx32qivnx8qi */
    case 5369:  /* pred_reduc_sumvnx32qivnx8qi */
    case 5368:  /* pred_reduc_xorvnx16qivnx8qi */
    case 5367:  /* pred_reduc_orvnx16qivnx8qi */
    case 5366:  /* pred_reduc_andvnx16qivnx8qi */
    case 5365:  /* pred_reduc_minvnx16qivnx8qi */
    case 5364:  /* pred_reduc_minuvnx16qivnx8qi */
    case 5363:  /* pred_reduc_maxvnx16qivnx8qi */
    case 5362:  /* pred_reduc_maxuvnx16qivnx8qi */
    case 5361:  /* pred_reduc_sumvnx16qivnx8qi */
    case 5360:  /* pred_reduc_xorvnx8qivnx8qi */
    case 5359:  /* pred_reduc_orvnx8qivnx8qi */
    case 5358:  /* pred_reduc_andvnx8qivnx8qi */
    case 5357:  /* pred_reduc_minvnx8qivnx8qi */
    case 5356:  /* pred_reduc_minuvnx8qivnx8qi */
    case 5355:  /* pred_reduc_maxvnx8qivnx8qi */
    case 5354:  /* pred_reduc_maxuvnx8qivnx8qi */
    case 5353:  /* pred_reduc_sumvnx8qivnx8qi */
    case 5352:  /* pred_reduc_xorvnx4qivnx8qi */
    case 5351:  /* pred_reduc_orvnx4qivnx8qi */
    case 5350:  /* pred_reduc_andvnx4qivnx8qi */
    case 5349:  /* pred_reduc_minvnx4qivnx8qi */
    case 5348:  /* pred_reduc_minuvnx4qivnx8qi */
    case 5347:  /* pred_reduc_maxvnx4qivnx8qi */
    case 5346:  /* pred_reduc_maxuvnx4qivnx8qi */
    case 5345:  /* pred_reduc_sumvnx4qivnx8qi */
    case 5344:  /* pred_reduc_xorvnx2qivnx8qi */
    case 5343:  /* pred_reduc_orvnx2qivnx8qi */
    case 5342:  /* pred_reduc_andvnx2qivnx8qi */
    case 5341:  /* pred_reduc_minvnx2qivnx8qi */
    case 5340:  /* pred_reduc_minuvnx2qivnx8qi */
    case 5339:  /* pred_reduc_maxvnx2qivnx8qi */
    case 5338:  /* pred_reduc_maxuvnx2qivnx8qi */
    case 5337:  /* pred_reduc_sumvnx2qivnx8qi */
    case 5336:  /* pred_reduc_xorvnx1qivnx8qi */
    case 5335:  /* pred_reduc_orvnx1qivnx8qi */
    case 5334:  /* pred_reduc_andvnx1qivnx8qi */
    case 5333:  /* pred_reduc_minvnx1qivnx8qi */
    case 5332:  /* pred_reduc_minuvnx1qivnx8qi */
    case 5331:  /* pred_reduc_maxvnx1qivnx8qi */
    case 5330:  /* pred_reduc_maxuvnx1qivnx8qi */
    case 5329:  /* pred_reduc_sumvnx1qivnx8qi */
    case 4584:  /* pred_seriesvnx64qi */
    case 4583:  /* pred_seriesvnx32qi */
    case 4582:  /* pred_seriesvnx16qi */
    case 4581:  /* pred_seriesvnx8qi */
    case 4580:  /* pred_seriesvnx4qi */
    case 4579:  /* pred_seriesvnx2qi */
    case 4578:  /* pred_seriesvnx1qi */
    case 4562:  /* pred_iotavnx64qi */
    case 4561:  /* pred_iotavnx32qi */
    case 4560:  /* pred_iotavnx16qi */
    case 4559:  /* pred_iotavnx8qi */
    case 4558:  /* pred_iotavnx4qi */
    case 4557:  /* pred_iotavnx2qi */
    case 4556:  /* pred_iotavnx1qi */
    case 4555:  /* pred_sofvnx64bi */
    case 4554:  /* pred_sifvnx64bi */
    case 4553:  /* pred_sbfvnx64bi */
    case 4552:  /* pred_sofvnx32bi */
    case 4551:  /* pred_sifvnx32bi */
    case 4550:  /* pred_sbfvnx32bi */
    case 4549:  /* pred_sofvnx16bi */
    case 4548:  /* pred_sifvnx16bi */
    case 4547:  /* pred_sbfvnx16bi */
    case 4546:  /* pred_sofvnx8bi */
    case 4545:  /* pred_sifvnx8bi */
    case 4544:  /* pred_sbfvnx8bi */
    case 4543:  /* pred_sofvnx4bi */
    case 4542:  /* pred_sifvnx4bi */
    case 4541:  /* pred_sbfvnx4bi */
    case 4540:  /* pred_sofvnx2bi */
    case 4539:  /* pred_sifvnx2bi */
    case 4538:  /* pred_sbfvnx2bi */
    case 4537:  /* pred_sofvnx1bi */
    case 4536:  /* pred_sifvnx1bi */
    case 4535:  /* pred_sbfvnx1bi */
    case 4534:  /* pred_ffsvnx64bidi */
    case 4533:  /* pred_ffsvnx32bidi */
    case 4532:  /* pred_ffsvnx16bidi */
    case 4531:  /* pred_ffsvnx8bidi */
    case 4530:  /* pred_ffsvnx4bidi */
    case 4529:  /* pred_ffsvnx2bidi */
    case 4528:  /* pred_ffsvnx1bidi */
    case 4527:  /* pred_ffsvnx64bisi */
    case 4526:  /* pred_ffsvnx32bisi */
    case 4525:  /* pred_ffsvnx16bisi */
    case 4524:  /* pred_ffsvnx8bisi */
    case 4523:  /* pred_ffsvnx4bisi */
    case 4522:  /* pred_ffsvnx2bisi */
    case 4521:  /* pred_ffsvnx1bisi */
    case 4520:  /* pred_popcountvnx64bidi */
    case 4519:  /* pred_popcountvnx32bidi */
    case 4518:  /* pred_popcountvnx16bidi */
    case 4517:  /* pred_popcountvnx8bidi */
    case 4516:  /* pred_popcountvnx4bidi */
    case 4515:  /* pred_popcountvnx2bidi */
    case 4514:  /* pred_popcountvnx1bidi */
    case 4513:  /* pred_popcountvnx64bisi */
    case 4512:  /* pred_popcountvnx32bisi */
    case 4511:  /* pred_popcountvnx16bisi */
    case 4510:  /* pred_popcountvnx8bisi */
    case 4509:  /* pred_popcountvnx4bisi */
    case 4508:  /* pred_popcountvnx2bisi */
    case 4507:  /* pred_popcountvnx1bisi */
    case 4506:  /* pred_notvnx64bi */
    case 4505:  /* pred_notvnx32bi */
    case 4504:  /* pred_notvnx16bi */
    case 4503:  /* pred_notvnx8bi */
    case 4502:  /* pred_notvnx4bi */
    case 4501:  /* pred_notvnx2bi */
    case 4500:  /* pred_notvnx1bi */
    case 4499:  /* pred_iornotvnx64bi */
    case 4498:  /* pred_andnotvnx64bi */
    case 4497:  /* pred_iornotvnx32bi */
    case 4496:  /* pred_andnotvnx32bi */
    case 4495:  /* pred_iornotvnx16bi */
    case 4494:  /* pred_andnotvnx16bi */
    case 4493:  /* pred_iornotvnx8bi */
    case 4492:  /* pred_andnotvnx8bi */
    case 4491:  /* pred_iornotvnx4bi */
    case 4490:  /* pred_andnotvnx4bi */
    case 4489:  /* pred_iornotvnx2bi */
    case 4488:  /* pred_andnotvnx2bi */
    case 4487:  /* pred_iornotvnx1bi */
    case 4486:  /* pred_andnotvnx1bi */
    case 4485:  /* pred_nxorvnx64bi */
    case 4484:  /* pred_niorvnx64bi */
    case 4483:  /* pred_nandvnx64bi */
    case 4482:  /* pred_nxorvnx32bi */
    case 4481:  /* pred_niorvnx32bi */
    case 4480:  /* pred_nandvnx32bi */
    case 4479:  /* pred_nxorvnx16bi */
    case 4478:  /* pred_niorvnx16bi */
    case 4477:  /* pred_nandvnx16bi */
    case 4476:  /* pred_nxorvnx8bi */
    case 4475:  /* pred_niorvnx8bi */
    case 4474:  /* pred_nandvnx8bi */
    case 4473:  /* pred_nxorvnx4bi */
    case 4472:  /* pred_niorvnx4bi */
    case 4471:  /* pred_nandvnx4bi */
    case 4470:  /* pred_nxorvnx2bi */
    case 4469:  /* pred_niorvnx2bi */
    case 4468:  /* pred_nandvnx2bi */
    case 4467:  /* pred_nxorvnx1bi */
    case 4466:  /* pred_niorvnx1bi */
    case 4465:  /* pred_nandvnx1bi */
    case 4464:  /* pred_xorvnx64bi */
    case 4463:  /* pred_iorvnx64bi */
    case 4462:  /* pred_andvnx64bi */
    case 4461:  /* pred_xorvnx32bi */
    case 4460:  /* pred_iorvnx32bi */
    case 4459:  /* pred_andvnx32bi */
    case 4458:  /* pred_xorvnx16bi */
    case 4457:  /* pred_iorvnx16bi */
    case 4456:  /* pred_andvnx16bi */
    case 4455:  /* pred_xorvnx8bi */
    case 4454:  /* pred_iorvnx8bi */
    case 4453:  /* pred_andvnx8bi */
    case 4452:  /* pred_xorvnx4bi */
    case 4451:  /* pred_iorvnx4bi */
    case 4450:  /* pred_andvnx4bi */
    case 4449:  /* pred_xorvnx2bi */
    case 4448:  /* pred_iorvnx2bi */
    case 4447:  /* pred_andvnx2bi */
    case 4446:  /* pred_xorvnx1bi */
    case 4445:  /* pred_iorvnx1bi */
    case 4444:  /* pred_andvnx1bi */
    case 4434:  /* pred_widen_mul_plususvnx32hi_scalar */
    case 4433:  /* pred_widen_mul_plususvnx16hi_scalar */
    case 4432:  /* pred_widen_mul_plususvnx8hi_scalar */
    case 4431:  /* pred_widen_mul_plususvnx4hi_scalar */
    case 4430:  /* pred_widen_mul_plususvnx2hi_scalar */
    case 4429:  /* pred_widen_mul_plususvnx1hi_scalar */
    case 4419:  /* pred_widen_mul_plussuvnx32hi_scalar */
    case 4418:  /* pred_widen_mul_plussuvnx16hi_scalar */
    case 4417:  /* pred_widen_mul_plussuvnx8hi_scalar */
    case 4416:  /* pred_widen_mul_plussuvnx4hi_scalar */
    case 4415:  /* pred_widen_mul_plussuvnx2hi_scalar */
    case 4414:  /* pred_widen_mul_plussuvnx1hi_scalar */
    case 4404:  /* pred_widen_mul_plussuvnx32hi */
    case 4403:  /* pred_widen_mul_plussuvnx16hi */
    case 4402:  /* pred_widen_mul_plussuvnx8hi */
    case 4401:  /* pred_widen_mul_plussuvnx4hi */
    case 4400:  /* pred_widen_mul_plussuvnx2hi */
    case 4399:  /* pred_widen_mul_plussuvnx1hi */
    case 4380:  /* pred_widen_mul_plusuvnx32hi_scalar */
    case 4379:  /* pred_widen_mul_plussvnx32hi_scalar */
    case 4378:  /* pred_widen_mul_plusuvnx16hi_scalar */
    case 4377:  /* pred_widen_mul_plussvnx16hi_scalar */
    case 4376:  /* pred_widen_mul_plusuvnx8hi_scalar */
    case 4375:  /* pred_widen_mul_plussvnx8hi_scalar */
    case 4374:  /* pred_widen_mul_plusuvnx4hi_scalar */
    case 4373:  /* pred_widen_mul_plussvnx4hi_scalar */
    case 4372:  /* pred_widen_mul_plusuvnx2hi_scalar */
    case 4371:  /* pred_widen_mul_plussvnx2hi_scalar */
    case 4370:  /* pred_widen_mul_plusuvnx1hi_scalar */
    case 4369:  /* pred_widen_mul_plussvnx1hi_scalar */
    case 4350:  /* pred_widen_mul_plusuvnx32hi */
    case 4349:  /* pred_widen_mul_plussvnx32hi */
    case 4348:  /* pred_widen_mul_plusuvnx16hi */
    case 4347:  /* pred_widen_mul_plussvnx16hi */
    case 4346:  /* pred_widen_mul_plusuvnx8hi */
    case 4345:  /* pred_widen_mul_plussvnx8hi */
    case 4344:  /* pred_widen_mul_plusuvnx4hi */
    case 4343:  /* pred_widen_mul_plussvnx4hi */
    case 4342:  /* pred_widen_mul_plusuvnx2hi */
    case 4341:  /* pred_widen_mul_plussvnx2hi */
    case 4340:  /* pred_widen_mul_plusuvnx1hi */
    case 4339:  /* pred_widen_mul_plussvnx1hi */
    case 4311:  /* *pred_minus_mulvnx64qi_scalar */
    case 4310:  /* *pred_minus_mulvnx32qi_scalar */
    case 4309:  /* *pred_minus_mulvnx16qi_scalar */
    case 4308:  /* *pred_minus_mulvnx8qi_scalar */
    case 4307:  /* *pred_minus_mulvnx4qi_scalar */
    case 4306:  /* *pred_minus_mulvnx2qi_scalar */
    case 4305:  /* *pred_minus_mulvnx1qi_scalar */
    case 4289:  /* *pred_nmsacvnx64qi_scalar */
    case 4288:  /* *pred_nmsacvnx32qi_scalar */
    case 4287:  /* *pred_nmsacvnx16qi_scalar */
    case 4286:  /* *pred_nmsacvnx8qi_scalar */
    case 4285:  /* *pred_nmsacvnx4qi_scalar */
    case 4284:  /* *pred_nmsacvnx2qi_scalar */
    case 4283:  /* *pred_nmsacvnx1qi_scalar */
    case 4267:  /* *pred_nmsubvnx64qi_scalar */
    case 4266:  /* *pred_nmsubvnx32qi_scalar */
    case 4265:  /* *pred_nmsubvnx16qi_scalar */
    case 4264:  /* *pred_nmsubvnx8qi_scalar */
    case 4263:  /* *pred_nmsubvnx4qi_scalar */
    case 4262:  /* *pred_nmsubvnx2qi_scalar */
    case 4261:  /* *pred_nmsubvnx1qi_scalar */
    case 4245:  /* *pred_minus_mulvnx64qi */
    case 4244:  /* *pred_minus_mulvnx32qi */
    case 4243:  /* *pred_minus_mulvnx16qi */
    case 4242:  /* *pred_minus_mulvnx8qi */
    case 4241:  /* *pred_minus_mulvnx4qi */
    case 4240:  /* *pred_minus_mulvnx2qi */
    case 4239:  /* *pred_minus_mulvnx1qi */
    case 4223:  /* *pred_nmsacvnx64qi */
    case 4222:  /* *pred_nmsacvnx32qi */
    case 4221:  /* *pred_nmsacvnx16qi */
    case 4220:  /* *pred_nmsacvnx8qi */
    case 4219:  /* *pred_nmsacvnx4qi */
    case 4218:  /* *pred_nmsacvnx2qi */
    case 4217:  /* *pred_nmsacvnx1qi */
    case 4201:  /* *pred_nmsubvnx64qi */
    case 4200:  /* *pred_nmsubvnx32qi */
    case 4199:  /* *pred_nmsubvnx16qi */
    case 4198:  /* *pred_nmsubvnx8qi */
    case 4197:  /* *pred_nmsubvnx4qi */
    case 4196:  /* *pred_nmsubvnx2qi */
    case 4195:  /* *pred_nmsubvnx1qi */
    case 4167:  /* *pred_mul_plusvnx64qi_scalar */
    case 4166:  /* *pred_mul_plusvnx32qi_scalar */
    case 4165:  /* *pred_mul_plusvnx16qi_scalar */
    case 4164:  /* *pred_mul_plusvnx8qi_scalar */
    case 4163:  /* *pred_mul_plusvnx4qi_scalar */
    case 4162:  /* *pred_mul_plusvnx2qi_scalar */
    case 4161:  /* *pred_mul_plusvnx1qi_scalar */
    case 4145:  /* *pred_maccvnx64qi_scalar */
    case 4144:  /* *pred_maccvnx32qi_scalar */
    case 4143:  /* *pred_maccvnx16qi_scalar */
    case 4142:  /* *pred_maccvnx8qi_scalar */
    case 4141:  /* *pred_maccvnx4qi_scalar */
    case 4140:  /* *pred_maccvnx2qi_scalar */
    case 4139:  /* *pred_maccvnx1qi_scalar */
    case 4123:  /* *pred_maddvnx64qi_scalar */
    case 4122:  /* *pred_maddvnx32qi_scalar */
    case 4121:  /* *pred_maddvnx16qi_scalar */
    case 4120:  /* *pred_maddvnx8qi_scalar */
    case 4119:  /* *pred_maddvnx4qi_scalar */
    case 4118:  /* *pred_maddvnx2qi_scalar */
    case 4117:  /* *pred_maddvnx1qi_scalar */
    case 4101:  /* *pred_mul_plusvnx64qi */
    case 4100:  /* *pred_mul_plusvnx32qi */
    case 4099:  /* *pred_mul_plusvnx16qi */
    case 4098:  /* *pred_mul_plusvnx8qi */
    case 4097:  /* *pred_mul_plusvnx4qi */
    case 4096:  /* *pred_mul_plusvnx2qi */
    case 4095:  /* *pred_mul_plusvnx1qi */
    case 4079:  /* *pred_maccvnx64qi */
    case 4078:  /* *pred_maccvnx32qi */
    case 4077:  /* *pred_maccvnx16qi */
    case 4076:  /* *pred_maccvnx8qi */
    case 4075:  /* *pred_maccvnx4qi */
    case 4074:  /* *pred_maccvnx2qi */
    case 4073:  /* *pred_maccvnx1qi */
    case 4057:  /* *pred_maddvnx64qi */
    case 4056:  /* *pred_maddvnx32qi */
    case 4055:  /* *pred_maddvnx16qi */
    case 4054:  /* *pred_maddvnx8qi */
    case 4053:  /* *pred_maddvnx4qi */
    case 4052:  /* *pred_maddvnx2qi */
    case 4051:  /* *pred_maddvnx1qi */
    case 4007:  /* *pred_eqnevnx64qi_scalar_narrow */
    case 4006:  /* *pred_eqnevnx32qi_scalar_narrow */
    case 4005:  /* *pred_eqnevnx16qi_scalar_narrow */
    case 4004:  /* *pred_eqnevnx8qi_scalar_narrow */
    case 4003:  /* *pred_eqnevnx4qi_scalar_narrow */
    case 4002:  /* *pred_eqnevnx2qi_scalar_narrow */
    case 4001:  /* *pred_eqnevnx1qi_scalar_narrow */
    case 3989:  /* *pred_eqnevnx64qi_scalar */
    case 3988:  /* *pred_eqnevnx32qi_scalar */
    case 3987:  /* *pred_eqnevnx16qi_scalar */
    case 3986:  /* *pred_eqnevnx8qi_scalar */
    case 3985:  /* *pred_eqnevnx4qi_scalar */
    case 3984:  /* *pred_eqnevnx2qi_scalar */
    case 3983:  /* *pred_eqnevnx1qi_scalar */
    case 3971:  /* *pred_cmpvnx64qi_scalar_narrow */
    case 3970:  /* *pred_cmpvnx32qi_scalar_narrow */
    case 3969:  /* *pred_cmpvnx16qi_scalar_narrow */
    case 3968:  /* *pred_cmpvnx8qi_scalar_narrow */
    case 3967:  /* *pred_cmpvnx4qi_scalar_narrow */
    case 3966:  /* *pred_cmpvnx2qi_scalar_narrow */
    case 3965:  /* *pred_cmpvnx1qi_scalar_narrow */
    case 3953:  /* *pred_cmpvnx64qi_scalar */
    case 3952:  /* *pred_cmpvnx32qi_scalar */
    case 3951:  /* *pred_cmpvnx16qi_scalar */
    case 3950:  /* *pred_cmpvnx8qi_scalar */
    case 3949:  /* *pred_cmpvnx4qi_scalar */
    case 3948:  /* *pred_cmpvnx2qi_scalar */
    case 3947:  /* *pred_cmpvnx1qi_scalar */
    case 3931:  /* *pred_ltgevnx64qi_narrow */
    case 3930:  /* *pred_ltgevnx32qi_narrow */
    case 3929:  /* *pred_ltgevnx16qi_narrow */
    case 3928:  /* *pred_ltgevnx8qi_narrow */
    case 3927:  /* *pred_ltgevnx4qi_narrow */
    case 3926:  /* *pred_ltgevnx2qi_narrow */
    case 3925:  /* *pred_ltgevnx1qi_narrow */
    case 3909:  /* *pred_ltgevnx64qi */
    case 3908:  /* *pred_ltgevnx32qi */
    case 3907:  /* *pred_ltgevnx16qi */
    case 3906:  /* *pred_ltgevnx8qi */
    case 3905:  /* *pred_ltgevnx4qi */
    case 3904:  /* *pred_ltgevnx2qi */
    case 3903:  /* *pred_ltgevnx1qi */
    case 3887:  /* *pred_cmpvnx64qi_narrow */
    case 3886:  /* *pred_cmpvnx32qi_narrow */
    case 3885:  /* *pred_cmpvnx16qi_narrow */
    case 3884:  /* *pred_cmpvnx8qi_narrow */
    case 3883:  /* *pred_cmpvnx4qi_narrow */
    case 3882:  /* *pred_cmpvnx2qi_narrow */
    case 3881:  /* *pred_cmpvnx1qi_narrow */
    case 3865:  /* *pred_cmpvnx64qi */
    case 3864:  /* *pred_cmpvnx32qi */
    case 3863:  /* *pred_cmpvnx16qi */
    case 3862:  /* *pred_cmpvnx8qi */
    case 3861:  /* *pred_cmpvnx4qi */
    case 3860:  /* *pred_cmpvnx2qi */
    case 3859:  /* *pred_cmpvnx1qi */
    case 3840:  /* pred_narrow_clipuvnx32hi_scalar */
    case 3839:  /* pred_narrow_clipvnx32hi_scalar */
    case 3838:  /* pred_narrow_clipuvnx16hi_scalar */
    case 3837:  /* pred_narrow_clipvnx16hi_scalar */
    case 3836:  /* pred_narrow_clipuvnx8hi_scalar */
    case 3835:  /* pred_narrow_clipvnx8hi_scalar */
    case 3834:  /* pred_narrow_clipuvnx4hi_scalar */
    case 3833:  /* pred_narrow_clipvnx4hi_scalar */
    case 3832:  /* pred_narrow_clipuvnx2hi_scalar */
    case 3831:  /* pred_narrow_clipvnx2hi_scalar */
    case 3830:  /* pred_narrow_clipuvnx1hi_scalar */
    case 3829:  /* pred_narrow_clipvnx1hi_scalar */
    case 3810:  /* pred_narrow_clipuvnx32hi */
    case 3809:  /* pred_narrow_clipvnx32hi */
    case 3808:  /* pred_narrow_clipuvnx16hi */
    case 3807:  /* pred_narrow_clipvnx16hi */
    case 3806:  /* pred_narrow_clipuvnx8hi */
    case 3805:  /* pred_narrow_clipvnx8hi */
    case 3804:  /* pred_narrow_clipuvnx4hi */
    case 3803:  /* pred_narrow_clipvnx4hi */
    case 3802:  /* pred_narrow_clipuvnx2hi */
    case 3801:  /* pred_narrow_clipvnx2hi */
    case 3800:  /* pred_narrow_clipuvnx1hi */
    case 3799:  /* pred_narrow_clipvnx1hi */
    case 3728:  /* pred_ssravnx64qi_scalar */
    case 3727:  /* pred_ssrlvnx64qi_scalar */
    case 3726:  /* pred_ssravnx32qi_scalar */
    case 3725:  /* pred_ssrlvnx32qi_scalar */
    case 3724:  /* pred_ssravnx16qi_scalar */
    case 3723:  /* pred_ssrlvnx16qi_scalar */
    case 3722:  /* pred_ssravnx8qi_scalar */
    case 3721:  /* pred_ssrlvnx8qi_scalar */
    case 3720:  /* pred_ssravnx4qi_scalar */
    case 3719:  /* pred_ssrlvnx4qi_scalar */
    case 3718:  /* pred_ssravnx2qi_scalar */
    case 3717:  /* pred_ssrlvnx2qi_scalar */
    case 3716:  /* pred_ssravnx1qi_scalar */
    case 3715:  /* pred_ssrlvnx1qi_scalar */
    case 3659:  /* pred_smulvnx64qi_scalar */
    case 3658:  /* pred_asubvnx64qi_scalar */
    case 3657:  /* pred_asubuvnx64qi_scalar */
    case 3656:  /* pred_aaddvnx64qi_scalar */
    case 3655:  /* pred_aadduvnx64qi_scalar */
    case 3654:  /* pred_smulvnx32qi_scalar */
    case 3653:  /* pred_asubvnx32qi_scalar */
    case 3652:  /* pred_asubuvnx32qi_scalar */
    case 3651:  /* pred_aaddvnx32qi_scalar */
    case 3650:  /* pred_aadduvnx32qi_scalar */
    case 3649:  /* pred_smulvnx16qi_scalar */
    case 3648:  /* pred_asubvnx16qi_scalar */
    case 3647:  /* pred_asubuvnx16qi_scalar */
    case 3646:  /* pred_aaddvnx16qi_scalar */
    case 3645:  /* pred_aadduvnx16qi_scalar */
    case 3644:  /* pred_smulvnx8qi_scalar */
    case 3643:  /* pred_asubvnx8qi_scalar */
    case 3642:  /* pred_asubuvnx8qi_scalar */
    case 3641:  /* pred_aaddvnx8qi_scalar */
    case 3640:  /* pred_aadduvnx8qi_scalar */
    case 3639:  /* pred_smulvnx4qi_scalar */
    case 3638:  /* pred_asubvnx4qi_scalar */
    case 3637:  /* pred_asubuvnx4qi_scalar */
    case 3636:  /* pred_aaddvnx4qi_scalar */
    case 3635:  /* pred_aadduvnx4qi_scalar */
    case 3634:  /* pred_smulvnx2qi_scalar */
    case 3633:  /* pred_asubvnx2qi_scalar */
    case 3632:  /* pred_asubuvnx2qi_scalar */
    case 3631:  /* pred_aaddvnx2qi_scalar */
    case 3630:  /* pred_aadduvnx2qi_scalar */
    case 3629:  /* pred_smulvnx1qi_scalar */
    case 3628:  /* pred_asubvnx1qi_scalar */
    case 3627:  /* pred_asubuvnx1qi_scalar */
    case 3626:  /* pred_aaddvnx1qi_scalar */
    case 3625:  /* pred_aadduvnx1qi_scalar */
    case 3519:  /* pred_ssravnx64qi */
    case 3518:  /* pred_ssrlvnx64qi */
    case 3517:  /* pred_smulvnx64qi */
    case 3516:  /* pred_asubvnx64qi */
    case 3515:  /* pred_asubuvnx64qi */
    case 3514:  /* pred_aaddvnx64qi */
    case 3513:  /* pred_aadduvnx64qi */
    case 3512:  /* pred_ssravnx32qi */
    case 3511:  /* pred_ssrlvnx32qi */
    case 3510:  /* pred_smulvnx32qi */
    case 3509:  /* pred_asubvnx32qi */
    case 3508:  /* pred_asubuvnx32qi */
    case 3507:  /* pred_aaddvnx32qi */
    case 3506:  /* pred_aadduvnx32qi */
    case 3505:  /* pred_ssravnx16qi */
    case 3504:  /* pred_ssrlvnx16qi */
    case 3503:  /* pred_smulvnx16qi */
    case 3502:  /* pred_asubvnx16qi */
    case 3501:  /* pred_asubuvnx16qi */
    case 3500:  /* pred_aaddvnx16qi */
    case 3499:  /* pred_aadduvnx16qi */
    case 3498:  /* pred_ssravnx8qi */
    case 3497:  /* pred_ssrlvnx8qi */
    case 3496:  /* pred_smulvnx8qi */
    case 3495:  /* pred_asubvnx8qi */
    case 3494:  /* pred_asubuvnx8qi */
    case 3493:  /* pred_aaddvnx8qi */
    case 3492:  /* pred_aadduvnx8qi */
    case 3491:  /* pred_ssravnx4qi */
    case 3490:  /* pred_ssrlvnx4qi */
    case 3489:  /* pred_smulvnx4qi */
    case 3488:  /* pred_asubvnx4qi */
    case 3487:  /* pred_asubuvnx4qi */
    case 3486:  /* pred_aaddvnx4qi */
    case 3485:  /* pred_aadduvnx4qi */
    case 3484:  /* pred_ssravnx2qi */
    case 3483:  /* pred_ssrlvnx2qi */
    case 3482:  /* pred_smulvnx2qi */
    case 3481:  /* pred_asubvnx2qi */
    case 3480:  /* pred_asubuvnx2qi */
    case 3479:  /* pred_aaddvnx2qi */
    case 3478:  /* pred_aadduvnx2qi */
    case 3477:  /* pred_ssravnx1qi */
    case 3476:  /* pred_ssrlvnx1qi */
    case 3475:  /* pred_smulvnx1qi */
    case 3474:  /* pred_asubvnx1qi */
    case 3473:  /* pred_asubuvnx1qi */
    case 3472:  /* pred_aaddvnx1qi */
    case 3471:  /* pred_aadduvnx1qi */
    case 3416:  /* pred_ussubvnx64qi_scalar */
    case 3415:  /* pred_sssubvnx64qi_scalar */
    case 3414:  /* pred_ussubvnx32qi_scalar */
    case 3413:  /* pred_sssubvnx32qi_scalar */
    case 3412:  /* pred_ussubvnx16qi_scalar */
    case 3411:  /* pred_sssubvnx16qi_scalar */
    case 3410:  /* pred_ussubvnx8qi_scalar */
    case 3409:  /* pred_sssubvnx8qi_scalar */
    case 3408:  /* pred_ussubvnx4qi_scalar */
    case 3407:  /* pred_sssubvnx4qi_scalar */
    case 3406:  /* pred_ussubvnx2qi_scalar */
    case 3405:  /* pred_sssubvnx2qi_scalar */
    case 3404:  /* pred_ussubvnx1qi_scalar */
    case 3403:  /* pred_sssubvnx1qi_scalar */
    case 3380:  /* pred_usaddvnx64qi_scalar */
    case 3379:  /* pred_ssaddvnx64qi_scalar */
    case 3378:  /* pred_usaddvnx32qi_scalar */
    case 3377:  /* pred_ssaddvnx32qi_scalar */
    case 3376:  /* pred_usaddvnx16qi_scalar */
    case 3375:  /* pred_ssaddvnx16qi_scalar */
    case 3374:  /* pred_usaddvnx8qi_scalar */
    case 3373:  /* pred_ssaddvnx8qi_scalar */
    case 3372:  /* pred_usaddvnx4qi_scalar */
    case 3371:  /* pred_ssaddvnx4qi_scalar */
    case 3370:  /* pred_usaddvnx2qi_scalar */
    case 3369:  /* pred_ssaddvnx2qi_scalar */
    case 3368:  /* pred_usaddvnx1qi_scalar */
    case 3367:  /* pred_ssaddvnx1qi_scalar */
    case 3306:  /* pred_ussubvnx64qi */
    case 3305:  /* pred_usaddvnx64qi */
    case 3304:  /* pred_sssubvnx64qi */
    case 3303:  /* pred_ssaddvnx64qi */
    case 3302:  /* pred_ussubvnx32qi */
    case 3301:  /* pred_usaddvnx32qi */
    case 3300:  /* pred_sssubvnx32qi */
    case 3299:  /* pred_ssaddvnx32qi */
    case 3298:  /* pred_ussubvnx16qi */
    case 3297:  /* pred_usaddvnx16qi */
    case 3296:  /* pred_sssubvnx16qi */
    case 3295:  /* pred_ssaddvnx16qi */
    case 3294:  /* pred_ussubvnx8qi */
    case 3293:  /* pred_usaddvnx8qi */
    case 3292:  /* pred_sssubvnx8qi */
    case 3291:  /* pred_ssaddvnx8qi */
    case 3290:  /* pred_ussubvnx4qi */
    case 3289:  /* pred_usaddvnx4qi */
    case 3288:  /* pred_sssubvnx4qi */
    case 3287:  /* pred_ssaddvnx4qi */
    case 3286:  /* pred_ussubvnx2qi */
    case 3285:  /* pred_usaddvnx2qi */
    case 3284:  /* pred_sssubvnx2qi */
    case 3283:  /* pred_ssaddvnx2qi */
    case 3282:  /* pred_ussubvnx1qi */
    case 3281:  /* pred_usaddvnx1qi */
    case 3280:  /* pred_sssubvnx1qi */
    case 3279:  /* pred_ssaddvnx1qi */
    case 3269:  /* pred_truncvnx32hi */
    case 3268:  /* pred_truncvnx16hi */
    case 3267:  /* pred_truncvnx8hi */
    case 3266:  /* pred_truncvnx4hi */
    case 3265:  /* pred_truncvnx2hi */
    case 3264:  /* pred_truncvnx1hi */
    case 3245:  /* pred_narrow_lshrvnx32hi_scalar */
    case 3244:  /* pred_narrow_ashrvnx32hi_scalar */
    case 3243:  /* pred_narrow_lshrvnx16hi_scalar */
    case 3242:  /* pred_narrow_ashrvnx16hi_scalar */
    case 3241:  /* pred_narrow_lshrvnx8hi_scalar */
    case 3240:  /* pred_narrow_ashrvnx8hi_scalar */
    case 3239:  /* pred_narrow_lshrvnx4hi_scalar */
    case 3238:  /* pred_narrow_ashrvnx4hi_scalar */
    case 3237:  /* pred_narrow_lshrvnx2hi_scalar */
    case 3236:  /* pred_narrow_ashrvnx2hi_scalar */
    case 3235:  /* pred_narrow_lshrvnx1hi_scalar */
    case 3234:  /* pred_narrow_ashrvnx1hi_scalar */
    case 3215:  /* pred_narrow_lshrvnx32hi */
    case 3214:  /* pred_narrow_ashrvnx32hi */
    case 3213:  /* pred_narrow_lshrvnx16hi */
    case 3212:  /* pred_narrow_ashrvnx16hi */
    case 3211:  /* pred_narrow_lshrvnx8hi */
    case 3210:  /* pred_narrow_ashrvnx8hi */
    case 3209:  /* pred_narrow_lshrvnx4hi */
    case 3208:  /* pred_narrow_ashrvnx4hi */
    case 3207:  /* pred_narrow_lshrvnx2hi */
    case 3206:  /* pred_narrow_ashrvnx2hi */
    case 3205:  /* pred_narrow_lshrvnx1hi */
    case 3204:  /* pred_narrow_ashrvnx1hi */
    case 3185:  /* pred_zero_extendvnx32hi */
    case 3184:  /* pred_extendvnx32hi */
    case 3183:  /* pred_zero_extendvnx16hi */
    case 3182:  /* pred_extendvnx16hi */
    case 3181:  /* pred_zero_extendvnx8hi */
    case 3180:  /* pred_extendvnx8hi */
    case 3179:  /* pred_zero_extendvnx4hi */
    case 3178:  /* pred_extendvnx4hi */
    case 3177:  /* pred_zero_extendvnx2hi */
    case 3176:  /* pred_extendvnx2hi */
    case 3175:  /* pred_zero_extendvnx1hi */
    case 3174:  /* pred_extendvnx1hi */
    case 3164:  /* pred_widen_mulsuvnx32hi_scalar */
    case 3163:  /* pred_widen_mulsuvnx16hi_scalar */
    case 3162:  /* pred_widen_mulsuvnx8hi_scalar */
    case 3161:  /* pred_widen_mulsuvnx4hi_scalar */
    case 3160:  /* pred_widen_mulsuvnx2hi_scalar */
    case 3159:  /* pred_widen_mulsuvnx1hi_scalar */
    case 3149:  /* pred_widen_mulsuvnx32hi */
    case 3148:  /* pred_widen_mulsuvnx16hi */
    case 3147:  /* pred_widen_mulsuvnx8hi */
    case 3146:  /* pred_widen_mulsuvnx4hi */
    case 3145:  /* pred_widen_mulsuvnx2hi */
    case 3144:  /* pred_widen_mulsuvnx1hi */
    case 3107:  /* pred_single_widen_subuvnx32hi_scalar */
    case 3106:  /* pred_single_widen_adduvnx32hi_scalar */
    case 3105:  /* pred_single_widen_subsvnx32hi_scalar */
    case 3104:  /* pred_single_widen_addsvnx32hi_scalar */
    case 3103:  /* pred_single_widen_subuvnx16hi_scalar */
    case 3102:  /* pred_single_widen_adduvnx16hi_scalar */
    case 3101:  /* pred_single_widen_subsvnx16hi_scalar */
    case 3100:  /* pred_single_widen_addsvnx16hi_scalar */
    case 3099:  /* pred_single_widen_subuvnx8hi_scalar */
    case 3098:  /* pred_single_widen_adduvnx8hi_scalar */
    case 3097:  /* pred_single_widen_subsvnx8hi_scalar */
    case 3096:  /* pred_single_widen_addsvnx8hi_scalar */
    case 3095:  /* pred_single_widen_subuvnx4hi_scalar */
    case 3094:  /* pred_single_widen_adduvnx4hi_scalar */
    case 3093:  /* pred_single_widen_subsvnx4hi_scalar */
    case 3092:  /* pred_single_widen_addsvnx4hi_scalar */
    case 3091:  /* pred_single_widen_subuvnx2hi_scalar */
    case 3090:  /* pred_single_widen_adduvnx2hi_scalar */
    case 3089:  /* pred_single_widen_subsvnx2hi_scalar */
    case 3088:  /* pred_single_widen_addsvnx2hi_scalar */
    case 3087:  /* pred_single_widen_subuvnx1hi_scalar */
    case 3086:  /* pred_single_widen_adduvnx1hi_scalar */
    case 3085:  /* pred_single_widen_subsvnx1hi_scalar */
    case 3084:  /* pred_single_widen_addsvnx1hi_scalar */
    case 3047:  /* pred_single_widen_subuvnx32hi */
    case 3046:  /* pred_single_widen_adduvnx32hi */
    case 3045:  /* pred_single_widen_subsvnx32hi */
    case 3044:  /* pred_single_widen_addsvnx32hi */
    case 3043:  /* pred_single_widen_subuvnx16hi */
    case 3042:  /* pred_single_widen_adduvnx16hi */
    case 3041:  /* pred_single_widen_subsvnx16hi */
    case 3040:  /* pred_single_widen_addsvnx16hi */
    case 3039:  /* pred_single_widen_subuvnx8hi */
    case 3038:  /* pred_single_widen_adduvnx8hi */
    case 3037:  /* pred_single_widen_subsvnx8hi */
    case 3036:  /* pred_single_widen_addsvnx8hi */
    case 3035:  /* pred_single_widen_subuvnx4hi */
    case 3034:  /* pred_single_widen_adduvnx4hi */
    case 3033:  /* pred_single_widen_subsvnx4hi */
    case 3032:  /* pred_single_widen_addsvnx4hi */
    case 3031:  /* pred_single_widen_subuvnx2hi */
    case 3030:  /* pred_single_widen_adduvnx2hi */
    case 3029:  /* pred_single_widen_subsvnx2hi */
    case 3028:  /* pred_single_widen_addsvnx2hi */
    case 3027:  /* pred_single_widen_subuvnx1hi */
    case 3026:  /* pred_single_widen_adduvnx1hi */
    case 3025:  /* pred_single_widen_subsvnx1hi */
    case 3024:  /* pred_single_widen_addsvnx1hi */
    case 2969:  /* pred_dual_widen_muluvnx32hi_scalar */
    case 2968:  /* pred_dual_widen_subuvnx32hi_scalar */
    case 2967:  /* pred_dual_widen_adduvnx32hi_scalar */
    case 2966:  /* pred_dual_widen_mulsvnx32hi_scalar */
    case 2965:  /* pred_dual_widen_subsvnx32hi_scalar */
    case 2964:  /* pred_dual_widen_addsvnx32hi_scalar */
    case 2963:  /* pred_dual_widen_muluvnx16hi_scalar */
    case 2962:  /* pred_dual_widen_subuvnx16hi_scalar */
    case 2961:  /* pred_dual_widen_adduvnx16hi_scalar */
    case 2960:  /* pred_dual_widen_mulsvnx16hi_scalar */
    case 2959:  /* pred_dual_widen_subsvnx16hi_scalar */
    case 2958:  /* pred_dual_widen_addsvnx16hi_scalar */
    case 2957:  /* pred_dual_widen_muluvnx8hi_scalar */
    case 2956:  /* pred_dual_widen_subuvnx8hi_scalar */
    case 2955:  /* pred_dual_widen_adduvnx8hi_scalar */
    case 2954:  /* pred_dual_widen_mulsvnx8hi_scalar */
    case 2953:  /* pred_dual_widen_subsvnx8hi_scalar */
    case 2952:  /* pred_dual_widen_addsvnx8hi_scalar */
    case 2951:  /* pred_dual_widen_muluvnx4hi_scalar */
    case 2950:  /* pred_dual_widen_subuvnx4hi_scalar */
    case 2949:  /* pred_dual_widen_adduvnx4hi_scalar */
    case 2948:  /* pred_dual_widen_mulsvnx4hi_scalar */
    case 2947:  /* pred_dual_widen_subsvnx4hi_scalar */
    case 2946:  /* pred_dual_widen_addsvnx4hi_scalar */
    case 2945:  /* pred_dual_widen_muluvnx2hi_scalar */
    case 2944:  /* pred_dual_widen_subuvnx2hi_scalar */
    case 2943:  /* pred_dual_widen_adduvnx2hi_scalar */
    case 2942:  /* pred_dual_widen_mulsvnx2hi_scalar */
    case 2941:  /* pred_dual_widen_subsvnx2hi_scalar */
    case 2940:  /* pred_dual_widen_addsvnx2hi_scalar */
    case 2939:  /* pred_dual_widen_muluvnx1hi_scalar */
    case 2938:  /* pred_dual_widen_subuvnx1hi_scalar */
    case 2937:  /* pred_dual_widen_adduvnx1hi_scalar */
    case 2936:  /* pred_dual_widen_mulsvnx1hi_scalar */
    case 2935:  /* pred_dual_widen_subsvnx1hi_scalar */
    case 2934:  /* pred_dual_widen_addsvnx1hi_scalar */
    case 2879:  /* pred_dual_widen_muluvnx32hi */
    case 2878:  /* pred_dual_widen_subuvnx32hi */
    case 2877:  /* pred_dual_widen_adduvnx32hi */
    case 2876:  /* pred_dual_widen_mulsvnx32hi */
    case 2875:  /* pred_dual_widen_subsvnx32hi */
    case 2874:  /* pred_dual_widen_addsvnx32hi */
    case 2873:  /* pred_dual_widen_muluvnx16hi */
    case 2872:  /* pred_dual_widen_subuvnx16hi */
    case 2871:  /* pred_dual_widen_adduvnx16hi */
    case 2870:  /* pred_dual_widen_mulsvnx16hi */
    case 2869:  /* pred_dual_widen_subsvnx16hi */
    case 2868:  /* pred_dual_widen_addsvnx16hi */
    case 2867:  /* pred_dual_widen_muluvnx8hi */
    case 2866:  /* pred_dual_widen_subuvnx8hi */
    case 2865:  /* pred_dual_widen_adduvnx8hi */
    case 2864:  /* pred_dual_widen_mulsvnx8hi */
    case 2863:  /* pred_dual_widen_subsvnx8hi */
    case 2862:  /* pred_dual_widen_addsvnx8hi */
    case 2861:  /* pred_dual_widen_muluvnx4hi */
    case 2860:  /* pred_dual_widen_subuvnx4hi */
    case 2859:  /* pred_dual_widen_adduvnx4hi */
    case 2858:  /* pred_dual_widen_mulsvnx4hi */
    case 2857:  /* pred_dual_widen_subsvnx4hi */
    case 2856:  /* pred_dual_widen_addsvnx4hi */
    case 2855:  /* pred_dual_widen_muluvnx2hi */
    case 2854:  /* pred_dual_widen_subuvnx2hi */
    case 2853:  /* pred_dual_widen_adduvnx2hi */
    case 2852:  /* pred_dual_widen_mulsvnx2hi */
    case 2851:  /* pred_dual_widen_subsvnx2hi */
    case 2850:  /* pred_dual_widen_addsvnx2hi */
    case 2849:  /* pred_dual_widen_muluvnx1hi */
    case 2848:  /* pred_dual_widen_subuvnx1hi */
    case 2847:  /* pred_dual_widen_adduvnx1hi */
    case 2846:  /* pred_dual_widen_mulsvnx1hi */
    case 2845:  /* pred_dual_widen_subsvnx1hi */
    case 2844:  /* pred_dual_widen_addsvnx1hi */
    case 2757:  /* pred_one_cmplvnx64qi */
    case 2756:  /* pred_negvnx64qi */
    case 2755:  /* pred_one_cmplvnx32qi */
    case 2754:  /* pred_negvnx32qi */
    case 2753:  /* pred_one_cmplvnx16qi */
    case 2752:  /* pred_negvnx16qi */
    case 2751:  /* pred_one_cmplvnx8qi */
    case 2750:  /* pred_negvnx8qi */
    case 2749:  /* pred_one_cmplvnx4qi */
    case 2748:  /* pred_negvnx4qi */
    case 2747:  /* pred_one_cmplvnx2qi */
    case 2746:  /* pred_negvnx2qi */
    case 2745:  /* pred_one_cmplvnx1qi */
    case 2744:  /* pred_negvnx1qi */
    case 2716:  /* pred_msbcvnx64qi_overflow_scalar */
    case 2715:  /* pred_msbcvnx32qi_overflow_scalar */
    case 2714:  /* pred_msbcvnx16qi_overflow_scalar */
    case 2713:  /* pred_msbcvnx8qi_overflow_scalar */
    case 2712:  /* pred_msbcvnx4qi_overflow_scalar */
    case 2711:  /* pred_msbcvnx2qi_overflow_scalar */
    case 2710:  /* pred_msbcvnx1qi_overflow_scalar */
    case 2698:  /* pred_madcvnx64qi_overflow_scalar */
    case 2697:  /* pred_madcvnx32qi_overflow_scalar */
    case 2696:  /* pred_madcvnx16qi_overflow_scalar */
    case 2695:  /* pred_madcvnx8qi_overflow_scalar */
    case 2694:  /* pred_madcvnx4qi_overflow_scalar */
    case 2693:  /* pred_madcvnx2qi_overflow_scalar */
    case 2692:  /* pred_madcvnx1qi_overflow_scalar */
    case 2676:  /* pred_msbcvnx64qi_overflow */
    case 2675:  /* pred_msbcvnx32qi_overflow */
    case 2674:  /* pred_msbcvnx16qi_overflow */
    case 2673:  /* pred_msbcvnx8qi_overflow */
    case 2672:  /* pred_msbcvnx4qi_overflow */
    case 2671:  /* pred_msbcvnx2qi_overflow */
    case 2670:  /* pred_msbcvnx1qi_overflow */
    case 2654:  /* pred_madcvnx64qi_overflow */
    case 2653:  /* pred_madcvnx32qi_overflow */
    case 2652:  /* pred_madcvnx16qi_overflow */
    case 2651:  /* pred_madcvnx8qi_overflow */
    case 2650:  /* pred_madcvnx4qi_overflow */
    case 2649:  /* pred_madcvnx2qi_overflow */
    case 2648:  /* pred_madcvnx1qi_overflow */
    case 2620:  /* pred_msbcvnx64qi_scalar */
    case 2619:  /* pred_msbcvnx32qi_scalar */
    case 2618:  /* pred_msbcvnx16qi_scalar */
    case 2617:  /* pred_msbcvnx8qi_scalar */
    case 2616:  /* pred_msbcvnx4qi_scalar */
    case 2615:  /* pred_msbcvnx2qi_scalar */
    case 2614:  /* pred_msbcvnx1qi_scalar */
    case 2602:  /* pred_madcvnx64qi_scalar */
    case 2601:  /* pred_madcvnx32qi_scalar */
    case 2600:  /* pred_madcvnx16qi_scalar */
    case 2599:  /* pred_madcvnx8qi_scalar */
    case 2598:  /* pred_madcvnx4qi_scalar */
    case 2597:  /* pred_madcvnx2qi_scalar */
    case 2596:  /* pred_madcvnx1qi_scalar */
    case 2580:  /* pred_msbcvnx64qi */
    case 2579:  /* pred_msbcvnx32qi */
    case 2578:  /* pred_msbcvnx16qi */
    case 2577:  /* pred_msbcvnx8qi */
    case 2576:  /* pred_msbcvnx4qi */
    case 2575:  /* pred_msbcvnx2qi */
    case 2574:  /* pred_msbcvnx1qi */
    case 2558:  /* pred_madcvnx64qi */
    case 2557:  /* pred_madcvnx32qi */
    case 2556:  /* pred_madcvnx16qi */
    case 2555:  /* pred_madcvnx8qi */
    case 2554:  /* pred_madcvnx4qi */
    case 2553:  /* pred_madcvnx2qi */
    case 2552:  /* pred_madcvnx1qi */
    case 2524:  /* pred_sbcvnx64qi_scalar */
    case 2523:  /* pred_sbcvnx32qi_scalar */
    case 2522:  /* pred_sbcvnx16qi_scalar */
    case 2521:  /* pred_sbcvnx8qi_scalar */
    case 2520:  /* pred_sbcvnx4qi_scalar */
    case 2519:  /* pred_sbcvnx2qi_scalar */
    case 2518:  /* pred_sbcvnx1qi_scalar */
    case 2506:  /* pred_adcvnx64qi_scalar */
    case 2505:  /* pred_adcvnx32qi_scalar */
    case 2504:  /* pred_adcvnx16qi_scalar */
    case 2503:  /* pred_adcvnx8qi_scalar */
    case 2502:  /* pred_adcvnx4qi_scalar */
    case 2501:  /* pred_adcvnx2qi_scalar */
    case 2500:  /* pred_adcvnx1qi_scalar */
    case 2484:  /* pred_sbcvnx64qi */
    case 2483:  /* pred_sbcvnx32qi */
    case 2482:  /* pred_sbcvnx16qi */
    case 2481:  /* pred_sbcvnx8qi */
    case 2480:  /* pred_sbcvnx4qi */
    case 2479:  /* pred_sbcvnx2qi */
    case 2478:  /* pred_sbcvnx1qi */
    case 2462:  /* pred_adcvnx64qi */
    case 2461:  /* pred_adcvnx32qi */
    case 2460:  /* pred_adcvnx16qi */
    case 2459:  /* pred_adcvnx8qi */
    case 2458:  /* pred_adcvnx4qi */
    case 2457:  /* pred_adcvnx2qi */
    case 2456:  /* pred_adcvnx1qi */
    case 2398:  /* pred_mulhsuvnx64qi_scalar */
    case 2397:  /* pred_mulhuvnx64qi_scalar */
    case 2396:  /* pred_mulhvnx64qi_scalar */
    case 2395:  /* pred_mulhsuvnx32qi_scalar */
    case 2394:  /* pred_mulhuvnx32qi_scalar */
    case 2393:  /* pred_mulhvnx32qi_scalar */
    case 2392:  /* pred_mulhsuvnx16qi_scalar */
    case 2391:  /* pred_mulhuvnx16qi_scalar */
    case 2390:  /* pred_mulhvnx16qi_scalar */
    case 2389:  /* pred_mulhsuvnx8qi_scalar */
    case 2388:  /* pred_mulhuvnx8qi_scalar */
    case 2387:  /* pred_mulhvnx8qi_scalar */
    case 2386:  /* pred_mulhsuvnx4qi_scalar */
    case 2385:  /* pred_mulhuvnx4qi_scalar */
    case 2384:  /* pred_mulhvnx4qi_scalar */
    case 2383:  /* pred_mulhsuvnx2qi_scalar */
    case 2382:  /* pred_mulhuvnx2qi_scalar */
    case 2381:  /* pred_mulhvnx2qi_scalar */
    case 2380:  /* pred_mulhsuvnx1qi_scalar */
    case 2379:  /* pred_mulhuvnx1qi_scalar */
    case 2378:  /* pred_mulhvnx1qi_scalar */
    case 2332:  /* pred_mulhsuvnx64qi */
    case 2331:  /* pred_mulhuvnx64qi */
    case 2330:  /* pred_mulhvnx64qi */
    case 2329:  /* pred_mulhsuvnx32qi */
    case 2328:  /* pred_mulhuvnx32qi */
    case 2327:  /* pred_mulhvnx32qi */
    case 2326:  /* pred_mulhsuvnx16qi */
    case 2325:  /* pred_mulhuvnx16qi */
    case 2324:  /* pred_mulhvnx16qi */
    case 2323:  /* pred_mulhsuvnx8qi */
    case 2322:  /* pred_mulhuvnx8qi */
    case 2321:  /* pred_mulhvnx8qi */
    case 2320:  /* pred_mulhsuvnx4qi */
    case 2319:  /* pred_mulhuvnx4qi */
    case 2318:  /* pred_mulhvnx4qi */
    case 2317:  /* pred_mulhsuvnx2qi */
    case 2316:  /* pred_mulhuvnx2qi */
    case 2315:  /* pred_mulhvnx2qi */
    case 2314:  /* pred_mulhsuvnx1qi */
    case 2313:  /* pred_mulhuvnx1qi */
    case 2312:  /* pred_mulhvnx1qi */
    case 2180:  /* pred_subvnx64qi_reverse_scalar */
    case 2179:  /* pred_subvnx32qi_reverse_scalar */
    case 2178:  /* pred_subvnx16qi_reverse_scalar */
    case 2177:  /* pred_subvnx8qi_reverse_scalar */
    case 2176:  /* pred_subvnx4qi_reverse_scalar */
    case 2175:  /* pred_subvnx2qi_reverse_scalar */
    case 2174:  /* pred_subvnx1qi_reverse_scalar */
    case 2118:  /* pred_umodvnx64qi_scalar */
    case 2117:  /* pred_modvnx64qi_scalar */
    case 2116:  /* pred_udivvnx64qi_scalar */
    case 2115:  /* pred_divvnx64qi_scalar */
    case 2114:  /* pred_subvnx64qi_scalar */
    case 2113:  /* pred_umodvnx32qi_scalar */
    case 2112:  /* pred_modvnx32qi_scalar */
    case 2111:  /* pred_udivvnx32qi_scalar */
    case 2110:  /* pred_divvnx32qi_scalar */
    case 2109:  /* pred_subvnx32qi_scalar */
    case 2108:  /* pred_umodvnx16qi_scalar */
    case 2107:  /* pred_modvnx16qi_scalar */
    case 2106:  /* pred_udivvnx16qi_scalar */
    case 2105:  /* pred_divvnx16qi_scalar */
    case 2104:  /* pred_subvnx16qi_scalar */
    case 2103:  /* pred_umodvnx8qi_scalar */
    case 2102:  /* pred_modvnx8qi_scalar */
    case 2101:  /* pred_udivvnx8qi_scalar */
    case 2100:  /* pred_divvnx8qi_scalar */
    case 2099:  /* pred_subvnx8qi_scalar */
    case 2098:  /* pred_umodvnx4qi_scalar */
    case 2097:  /* pred_modvnx4qi_scalar */
    case 2096:  /* pred_udivvnx4qi_scalar */
    case 2095:  /* pred_divvnx4qi_scalar */
    case 2094:  /* pred_subvnx4qi_scalar */
    case 2093:  /* pred_umodvnx2qi_scalar */
    case 2092:  /* pred_modvnx2qi_scalar */
    case 2091:  /* pred_udivvnx2qi_scalar */
    case 2090:  /* pred_divvnx2qi_scalar */
    case 2089:  /* pred_subvnx2qi_scalar */
    case 2088:  /* pred_umodvnx1qi_scalar */
    case 2087:  /* pred_modvnx1qi_scalar */
    case 2086:  /* pred_udivvnx1qi_scalar */
    case 2085:  /* pred_divvnx1qi_scalar */
    case 2084:  /* pred_subvnx1qi_scalar */
    case 1984:  /* pred_mulvnx64qi_scalar */
    case 1983:  /* pred_uminvnx64qi_scalar */
    case 1982:  /* pred_sminvnx64qi_scalar */
    case 1981:  /* pred_umaxvnx64qi_scalar */
    case 1980:  /* pred_smaxvnx64qi_scalar */
    case 1979:  /* pred_xorvnx64qi_scalar */
    case 1978:  /* pred_iorvnx64qi_scalar */
    case 1977:  /* pred_andvnx64qi_scalar */
    case 1976:  /* pred_addvnx64qi_scalar */
    case 1975:  /* pred_mulvnx32qi_scalar */
    case 1974:  /* pred_uminvnx32qi_scalar */
    case 1973:  /* pred_sminvnx32qi_scalar */
    case 1972:  /* pred_umaxvnx32qi_scalar */
    case 1971:  /* pred_smaxvnx32qi_scalar */
    case 1970:  /* pred_xorvnx32qi_scalar */
    case 1969:  /* pred_iorvnx32qi_scalar */
    case 1968:  /* pred_andvnx32qi_scalar */
    case 1967:  /* pred_addvnx32qi_scalar */
    case 1966:  /* pred_mulvnx16qi_scalar */
    case 1965:  /* pred_uminvnx16qi_scalar */
    case 1964:  /* pred_sminvnx16qi_scalar */
    case 1963:  /* pred_umaxvnx16qi_scalar */
    case 1962:  /* pred_smaxvnx16qi_scalar */
    case 1961:  /* pred_xorvnx16qi_scalar */
    case 1960:  /* pred_iorvnx16qi_scalar */
    case 1959:  /* pred_andvnx16qi_scalar */
    case 1958:  /* pred_addvnx16qi_scalar */
    case 1957:  /* pred_mulvnx8qi_scalar */
    case 1956:  /* pred_uminvnx8qi_scalar */
    case 1955:  /* pred_sminvnx8qi_scalar */
    case 1954:  /* pred_umaxvnx8qi_scalar */
    case 1953:  /* pred_smaxvnx8qi_scalar */
    case 1952:  /* pred_xorvnx8qi_scalar */
    case 1951:  /* pred_iorvnx8qi_scalar */
    case 1950:  /* pred_andvnx8qi_scalar */
    case 1949:  /* pred_addvnx8qi_scalar */
    case 1948:  /* pred_mulvnx4qi_scalar */
    case 1947:  /* pred_uminvnx4qi_scalar */
    case 1946:  /* pred_sminvnx4qi_scalar */
    case 1945:  /* pred_umaxvnx4qi_scalar */
    case 1944:  /* pred_smaxvnx4qi_scalar */
    case 1943:  /* pred_xorvnx4qi_scalar */
    case 1942:  /* pred_iorvnx4qi_scalar */
    case 1941:  /* pred_andvnx4qi_scalar */
    case 1940:  /* pred_addvnx4qi_scalar */
    case 1939:  /* pred_mulvnx2qi_scalar */
    case 1938:  /* pred_uminvnx2qi_scalar */
    case 1937:  /* pred_sminvnx2qi_scalar */
    case 1936:  /* pred_umaxvnx2qi_scalar */
    case 1935:  /* pred_smaxvnx2qi_scalar */
    case 1934:  /* pred_xorvnx2qi_scalar */
    case 1933:  /* pred_iorvnx2qi_scalar */
    case 1932:  /* pred_andvnx2qi_scalar */
    case 1931:  /* pred_addvnx2qi_scalar */
    case 1930:  /* pred_mulvnx1qi_scalar */
    case 1929:  /* pred_uminvnx1qi_scalar */
    case 1928:  /* pred_sminvnx1qi_scalar */
    case 1927:  /* pred_umaxvnx1qi_scalar */
    case 1926:  /* pred_smaxvnx1qi_scalar */
    case 1925:  /* pred_xorvnx1qi_scalar */
    case 1924:  /* pred_iorvnx1qi_scalar */
    case 1923:  /* pred_andvnx1qi_scalar */
    case 1922:  /* pred_addvnx1qi_scalar */
    case 1876:  /* pred_lshrvnx64qi_scalar */
    case 1875:  /* pred_ashrvnx64qi_scalar */
    case 1874:  /* pred_ashlvnx64qi_scalar */
    case 1873:  /* pred_lshrvnx32qi_scalar */
    case 1872:  /* pred_ashrvnx32qi_scalar */
    case 1871:  /* pred_ashlvnx32qi_scalar */
    case 1870:  /* pred_lshrvnx16qi_scalar */
    case 1869:  /* pred_ashrvnx16qi_scalar */
    case 1868:  /* pred_ashlvnx16qi_scalar */
    case 1867:  /* pred_lshrvnx8qi_scalar */
    case 1866:  /* pred_ashrvnx8qi_scalar */
    case 1865:  /* pred_ashlvnx8qi_scalar */
    case 1864:  /* pred_lshrvnx4qi_scalar */
    case 1863:  /* pred_ashrvnx4qi_scalar */
    case 1862:  /* pred_ashlvnx4qi_scalar */
    case 1861:  /* pred_lshrvnx2qi_scalar */
    case 1860:  /* pred_ashrvnx2qi_scalar */
    case 1859:  /* pred_ashlvnx2qi_scalar */
    case 1858:  /* pred_lshrvnx1qi_scalar */
    case 1857:  /* pred_ashrvnx1qi_scalar */
    case 1856:  /* pred_ashlvnx1qi_scalar */
    case 1600:  /* pred_umodvnx64qi */
    case 1599:  /* pred_modvnx64qi */
    case 1598:  /* pred_udivvnx64qi */
    case 1597:  /* pred_divvnx64qi */
    case 1596:  /* pred_mulvnx64qi */
    case 1595:  /* pred_uminvnx64qi */
    case 1594:  /* pred_sminvnx64qi */
    case 1593:  /* pred_umaxvnx64qi */
    case 1592:  /* pred_smaxvnx64qi */
    case 1591:  /* pred_lshrvnx64qi */
    case 1590:  /* pred_ashrvnx64qi */
    case 1589:  /* pred_ashlvnx64qi */
    case 1588:  /* pred_xorvnx64qi */
    case 1587:  /* pred_iorvnx64qi */
    case 1586:  /* pred_andvnx64qi */
    case 1585:  /* pred_subvnx64qi */
    case 1584:  /* pred_addvnx64qi */
    case 1583:  /* pred_umodvnx32qi */
    case 1582:  /* pred_modvnx32qi */
    case 1581:  /* pred_udivvnx32qi */
    case 1580:  /* pred_divvnx32qi */
    case 1579:  /* pred_mulvnx32qi */
    case 1578:  /* pred_uminvnx32qi */
    case 1577:  /* pred_sminvnx32qi */
    case 1576:  /* pred_umaxvnx32qi */
    case 1575:  /* pred_smaxvnx32qi */
    case 1574:  /* pred_lshrvnx32qi */
    case 1573:  /* pred_ashrvnx32qi */
    case 1572:  /* pred_ashlvnx32qi */
    case 1571:  /* pred_xorvnx32qi */
    case 1570:  /* pred_iorvnx32qi */
    case 1569:  /* pred_andvnx32qi */
    case 1568:  /* pred_subvnx32qi */
    case 1567:  /* pred_addvnx32qi */
    case 1566:  /* pred_umodvnx16qi */
    case 1565:  /* pred_modvnx16qi */
    case 1564:  /* pred_udivvnx16qi */
    case 1563:  /* pred_divvnx16qi */
    case 1562:  /* pred_mulvnx16qi */
    case 1561:  /* pred_uminvnx16qi */
    case 1560:  /* pred_sminvnx16qi */
    case 1559:  /* pred_umaxvnx16qi */
    case 1558:  /* pred_smaxvnx16qi */
    case 1557:  /* pred_lshrvnx16qi */
    case 1556:  /* pred_ashrvnx16qi */
    case 1555:  /* pred_ashlvnx16qi */
    case 1554:  /* pred_xorvnx16qi */
    case 1553:  /* pred_iorvnx16qi */
    case 1552:  /* pred_andvnx16qi */
    case 1551:  /* pred_subvnx16qi */
    case 1550:  /* pred_addvnx16qi */
    case 1549:  /* pred_umodvnx8qi */
    case 1548:  /* pred_modvnx8qi */
    case 1547:  /* pred_udivvnx8qi */
    case 1546:  /* pred_divvnx8qi */
    case 1545:  /* pred_mulvnx8qi */
    case 1544:  /* pred_uminvnx8qi */
    case 1543:  /* pred_sminvnx8qi */
    case 1542:  /* pred_umaxvnx8qi */
    case 1541:  /* pred_smaxvnx8qi */
    case 1540:  /* pred_lshrvnx8qi */
    case 1539:  /* pred_ashrvnx8qi */
    case 1538:  /* pred_ashlvnx8qi */
    case 1537:  /* pred_xorvnx8qi */
    case 1536:  /* pred_iorvnx8qi */
    case 1535:  /* pred_andvnx8qi */
    case 1534:  /* pred_subvnx8qi */
    case 1533:  /* pred_addvnx8qi */
    case 1532:  /* pred_umodvnx4qi */
    case 1531:  /* pred_modvnx4qi */
    case 1530:  /* pred_udivvnx4qi */
    case 1529:  /* pred_divvnx4qi */
    case 1528:  /* pred_mulvnx4qi */
    case 1527:  /* pred_uminvnx4qi */
    case 1526:  /* pred_sminvnx4qi */
    case 1525:  /* pred_umaxvnx4qi */
    case 1524:  /* pred_smaxvnx4qi */
    case 1523:  /* pred_lshrvnx4qi */
    case 1522:  /* pred_ashrvnx4qi */
    case 1521:  /* pred_ashlvnx4qi */
    case 1520:  /* pred_xorvnx4qi */
    case 1519:  /* pred_iorvnx4qi */
    case 1518:  /* pred_andvnx4qi */
    case 1517:  /* pred_subvnx4qi */
    case 1516:  /* pred_addvnx4qi */
    case 1515:  /* pred_umodvnx2qi */
    case 1514:  /* pred_modvnx2qi */
    case 1513:  /* pred_udivvnx2qi */
    case 1512:  /* pred_divvnx2qi */
    case 1511:  /* pred_mulvnx2qi */
    case 1510:  /* pred_uminvnx2qi */
    case 1509:  /* pred_sminvnx2qi */
    case 1508:  /* pred_umaxvnx2qi */
    case 1507:  /* pred_smaxvnx2qi */
    case 1506:  /* pred_lshrvnx2qi */
    case 1505:  /* pred_ashrvnx2qi */
    case 1504:  /* pred_ashlvnx2qi */
    case 1503:  /* pred_xorvnx2qi */
    case 1502:  /* pred_iorvnx2qi */
    case 1501:  /* pred_andvnx2qi */
    case 1500:  /* pred_subvnx2qi */
    case 1499:  /* pred_addvnx2qi */
    case 1498:  /* pred_umodvnx1qi */
    case 1497:  /* pred_modvnx1qi */
    case 1496:  /* pred_udivvnx1qi */
    case 1495:  /* pred_divvnx1qi */
    case 1494:  /* pred_mulvnx1qi */
    case 1493:  /* pred_uminvnx1qi */
    case 1492:  /* pred_sminvnx1qi */
    case 1491:  /* pred_umaxvnx1qi */
    case 1490:  /* pred_smaxvnx1qi */
    case 1489:  /* pred_lshrvnx1qi */
    case 1488:  /* pred_ashrvnx1qi */
    case 1487:  /* pred_ashlvnx1qi */
    case 1486:  /* pred_xorvnx1qi */
    case 1485:  /* pred_iorvnx1qi */
    case 1484:  /* pred_andvnx1qi */
    case 1483:  /* pred_subvnx1qi */
    case 1482:  /* pred_addvnx1qi */
    case 1481:  /* pred_indexed_ustorevnx64qivnx64qi */
    case 1480:  /* pred_indexed_ostorevnx64qivnx64qi */
    case 1475:  /* pred_indexed_ustorevnx32qivnx32hi */
    case 1474:  /* pred_indexed_ostorevnx32qivnx32hi */
    case 1473:  /* pred_indexed_ustorevnx32qivnx32qi */
    case 1472:  /* pred_indexed_ostorevnx32qivnx32qi */
    case 1465:  /* pred_indexed_ustorevnx16qivnx16si */
    case 1464:  /* pred_indexed_ostorevnx16qivnx16si */
    case 1457:  /* pred_indexed_ustorevnx16qivnx16hi */
    case 1456:  /* pred_indexed_ostorevnx16qivnx16hi */
    case 1449:  /* pred_indexed_ustorevnx16qivnx16qi */
    case 1448:  /* pred_indexed_ostorevnx16qivnx16qi */
    case 1437:  /* pred_indexed_ustorevnx8qivnx8di */
    case 1436:  /* pred_indexed_ostorevnx8qivnx8di */
    case 1425:  /* pred_indexed_ustorevnx8qivnx8si */
    case 1424:  /* pred_indexed_ostorevnx8qivnx8si */
    case 1413:  /* pred_indexed_ustorevnx8qivnx8hi */
    case 1412:  /* pred_indexed_ostorevnx8qivnx8hi */
    case 1401:  /* pred_indexed_ustorevnx8qivnx8qi */
    case 1400:  /* pred_indexed_ostorevnx8qivnx8qi */
    case 1389:  /* pred_indexed_ustorevnx4qivnx4di */
    case 1388:  /* pred_indexed_ostorevnx4qivnx4di */
    case 1377:  /* pred_indexed_ustorevnx4qivnx4si */
    case 1376:  /* pred_indexed_ostorevnx4qivnx4si */
    case 1365:  /* pred_indexed_ustorevnx4qivnx4hi */
    case 1364:  /* pred_indexed_ostorevnx4qivnx4hi */
    case 1353:  /* pred_indexed_ustorevnx4qivnx4qi */
    case 1352:  /* pred_indexed_ostorevnx4qivnx4qi */
    case 1341:  /* pred_indexed_ustorevnx2qivnx2di */
    case 1340:  /* pred_indexed_ostorevnx2qivnx2di */
    case 1329:  /* pred_indexed_ustorevnx2qivnx2si */
    case 1328:  /* pred_indexed_ostorevnx2qivnx2si */
    case 1317:  /* pred_indexed_ustorevnx2qivnx2hi */
    case 1316:  /* pred_indexed_ostorevnx2qivnx2hi */
    case 1305:  /* pred_indexed_ustorevnx2qivnx2qi */
    case 1304:  /* pred_indexed_ostorevnx2qivnx2qi */
    case 1263:  /* pred_indexed_ustorevnx1qivnx1di */
    case 1262:  /* pred_indexed_ostorevnx1qivnx1di */
    case 1261:  /* pred_indexed_ustorevnx1qivnx1si */
    case 1260:  /* pred_indexed_ostorevnx1qivnx1si */
    case 1259:  /* pred_indexed_ustorevnx1qivnx1hi */
    case 1258:  /* pred_indexed_ostorevnx1qivnx1hi */
    case 1257:  /* pred_indexed_ustorevnx1qivnx1qi */
    case 1256:  /* pred_indexed_ostorevnx1qivnx1qi */
    case 1255:  /* pred_indexed_uloadvnx8qi_x8_smaller_eew */
    case 1254:  /* pred_indexed_oloadvnx8qi_x8_smaller_eew */
    case 1253:  /* pred_indexed_uloadvnx4qi_x8_smaller_eew */
    case 1252:  /* pred_indexed_oloadvnx4qi_x8_smaller_eew */
    case 1251:  /* pred_indexed_uloadvnx2qi_x8_smaller_eew */
    case 1250:  /* pred_indexed_oloadvnx2qi_x8_smaller_eew */
    case 1249:  /* pred_indexed_uloadvnx1qi_x8_smaller_eew */
    case 1248:  /* pred_indexed_oloadvnx1qi_x8_smaller_eew */
    case 1239:  /* pred_indexed_uloadvnx16qi_x4_smaller_eew */
    case 1238:  /* pred_indexed_oloadvnx16qi_x4_smaller_eew */
    case 1237:  /* pred_indexed_uloadvnx8qi_x4_smaller_eew */
    case 1236:  /* pred_indexed_oloadvnx8qi_x4_smaller_eew */
    case 1235:  /* pred_indexed_uloadvnx4qi_x4_smaller_eew */
    case 1234:  /* pred_indexed_oloadvnx4qi_x4_smaller_eew */
    case 1233:  /* pred_indexed_uloadvnx2qi_x4_smaller_eew */
    case 1232:  /* pred_indexed_oloadvnx2qi_x4_smaller_eew */
    case 1231:  /* pred_indexed_uloadvnx1qi_x4_smaller_eew */
    case 1230:  /* pred_indexed_oloadvnx1qi_x4_smaller_eew */
    case 1203:  /* pred_indexed_uloadvnx32qi_x2_smaller_eew */
    case 1202:  /* pred_indexed_oloadvnx32qi_x2_smaller_eew */
    case 1201:  /* pred_indexed_uloadvnx16qi_x2_smaller_eew */
    case 1200:  /* pred_indexed_oloadvnx16qi_x2_smaller_eew */
    case 1199:  /* pred_indexed_uloadvnx8qi_x2_smaller_eew */
    case 1198:  /* pred_indexed_oloadvnx8qi_x2_smaller_eew */
    case 1197:  /* pred_indexed_uloadvnx4qi_x2_smaller_eew */
    case 1196:  /* pred_indexed_oloadvnx4qi_x2_smaller_eew */
    case 1195:  /* pred_indexed_uloadvnx2qi_x2_smaller_eew */
    case 1194:  /* pred_indexed_oloadvnx2qi_x2_smaller_eew */
    case 1193:  /* pred_indexed_uloadvnx1qi_x2_smaller_eew */
    case 1192:  /* pred_indexed_oloadvnx1qi_x2_smaller_eew */
    case 1043:  /* pred_indexed_uloadvnx64qi_same_eew */
    case 1042:  /* pred_indexed_oloadvnx64qi_same_eew */
    case 1041:  /* pred_indexed_uloadvnx32qi_same_eew */
    case 1040:  /* pred_indexed_oloadvnx32qi_same_eew */
    case 1039:  /* pred_indexed_uloadvnx16qi_same_eew */
    case 1038:  /* pred_indexed_oloadvnx16qi_same_eew */
    case 1037:  /* pred_indexed_uloadvnx8qi_same_eew */
    case 1036:  /* pred_indexed_oloadvnx8qi_same_eew */
    case 1035:  /* pred_indexed_uloadvnx4qi_same_eew */
    case 1034:  /* pred_indexed_oloadvnx4qi_same_eew */
    case 1033:  /* pred_indexed_uloadvnx2qi_same_eew */
    case 1032:  /* pred_indexed_oloadvnx2qi_same_eew */
    case 1031:  /* pred_indexed_uloadvnx1qi_same_eew */
    case 1030:  /* pred_indexed_oloadvnx1qi_same_eew */
    case 1005:  /* pred_strided_storevnx64qi */
    case 1004:  /* pred_strided_storevnx32qi */
    case 1003:  /* pred_strided_storevnx16qi */
    case 1002:  /* pred_strided_storevnx8qi */
    case 1001:  /* pred_strided_storevnx4qi */
    case 1000:  /* pred_strided_storevnx2qi */
    case 999:  /* pred_strided_storevnx1qi */
    case 974:  /* pred_strided_loadvnx64qi */
    case 973:  /* pred_strided_loadvnx32qi */
    case 972:  /* pred_strided_loadvnx16qi */
    case 971:  /* pred_strided_loadvnx8qi */
    case 970:  /* pred_strided_loadvnx4qi */
    case 969:  /* pred_strided_loadvnx2qi */
    case 968:  /* pred_strided_loadvnx1qi */
    case 939:  /* *pred_broadcastvnx64qi */
    case 938:  /* *pred_broadcastvnx32qi */
    case 937:  /* *pred_broadcastvnx16qi */
    case 936:  /* *pred_broadcastvnx8qi */
    case 935:  /* *pred_broadcastvnx4qi */
    case 934:  /* *pred_broadcastvnx2qi */
    case 933:  /* *pred_broadcastvnx1qi */
    case 913:  /* pred_mergevnx64qi_scalar */
    case 912:  /* pred_mergevnx32qi_scalar */
    case 911:  /* pred_mergevnx16qi_scalar */
    case 910:  /* pred_mergevnx8qi_scalar */
    case 909:  /* pred_mergevnx4qi_scalar */
    case 908:  /* pred_mergevnx2qi_scalar */
    case 907:  /* pred_mergevnx1qi_scalar */
    case 882:  /* pred_mergevnx64qi */
    case 881:  /* pred_mergevnx32qi */
    case 880:  /* pred_mergevnx16qi */
    case 879:  /* pred_mergevnx8qi */
    case 878:  /* pred_mergevnx4qi */
    case 877:  /* pred_mergevnx2qi */
    case 876:  /* pred_mergevnx1qi */
    case 875:  /* pred_storevnx64bi */
    case 874:  /* pred_storevnx32bi */
    case 873:  /* pred_storevnx16bi */
    case 872:  /* pred_storevnx8bi */
    case 871:  /* pred_storevnx4bi */
    case 870:  /* pred_storevnx2bi */
    case 869:  /* pred_storevnx1bi */
    case 868:  /* pred_movvnx64bi */
    case 867:  /* pred_movvnx32bi */
    case 866:  /* pred_movvnx16bi */
    case 865:  /* pred_movvnx8bi */
    case 864:  /* pred_movvnx4bi */
    case 863:  /* pred_movvnx2bi */
    case 862:  /* pred_movvnx1bi */
    case 837:  /* pred_storevnx64qi */
    case 836:  /* pred_storevnx32qi */
    case 835:  /* pred_storevnx16qi */
    case 834:  /* pred_storevnx8qi */
    case 833:  /* pred_storevnx4qi */
    case 832:  /* pred_storevnx2qi */
    case 831:  /* pred_storevnx1qi */
    case 806:  /* pred_movvnx64qi */
    case 805:  /* pred_movvnx32qi */
    case 804:  /* pred_movvnx16qi */
    case 803:  /* pred_movvnx8qi */
    case 802:  /* pred_movvnx4qi */
    case 801:  /* pred_movvnx2qi */
    case 800:  /* pred_movvnx1qi */
    case 764:  /* *movvnx64bi */
    case 763:  /* *movvnx32bi */
    case 762:  /* *movvnx16bi */
    case 761:  /* *movvnx8bi */
    case 760:  /* *movvnx4bi */
    case 759:  /* *movvnx2bi */
    case 758:  /* *movvnx1bi */
    case 753:  /* *movvnx4qi_fract */
    case 752:  /* *movvnx2qi_fract */
    case 751:  /* *movvnx1qi_fract */
    case 727:  /* *movvnx64qi_whole */
    case 726:  /* *movvnx32qi_whole */
    case 725:  /* *movvnx16qi_whole */
    case 724:  /* *movvnx8qi_whole */
    case 723:  /* *movvnx4qi_whole */
      return 8;

    case 6036:  /* read_vldi_zero_extend */
    case 6035:  /* read_vlsi */
    case 799:  /* vsetvldi_no_side_effects */
    case 798:  /* vsetvlsi_no_side_effects */
    case 795:  /* vsetvl_vtype_change_only */
    case 792:  /* *movvnx64bidi_lra */
    case 791:  /* *movvnx32bidi_lra */
    case 790:  /* *movvnx16bidi_lra */
    case 789:  /* *movvnx8bidi_lra */
    case 788:  /* *movvnx4bidi_lra */
    case 787:  /* *movvnx2bidi_lra */
    case 786:  /* *movvnx1bidi_lra */
    case 785:  /* *movvnx64bisi_lra */
    case 784:  /* *movvnx32bisi_lra */
    case 783:  /* *movvnx16bisi_lra */
    case 782:  /* *movvnx8bisi_lra */
    case 781:  /* *movvnx4bisi_lra */
    case 780:  /* *movvnx2bisi_lra */
    case 779:  /* *movvnx1bisi_lra */
    case 778:  /* *movvnx1sfdi_lra */
    case 777:  /* *movvnx1sfsi_lra */
    case 776:  /* *movvnx1sidi_lra */
    case 775:  /* *movvnx1sisi_lra */
    case 774:  /* *movvnx2hidi_lra */
    case 773:  /* *movvnx2hisi_lra */
    case 772:  /* *movvnx1hidi_lra */
    case 771:  /* *movvnx1hisi_lra */
    case 770:  /* *movvnx4qidi_lra */
    case 769:  /* *movvnx4qisi_lra */
    case 768:  /* *movvnx2qidi_lra */
    case 767:  /* *movvnx2qisi_lra */
    case 766:  /* *movvnx1qidi_lra */
    case 765:  /* *movvnx1qisi_lra */
    case 722:  /* vlmax_avldi */
    case 721:  /* vlmax_avlsi */
    case 720:  /* *vlmul_extx64vnx1qi */
    case 719:  /* *vlmul_extx32vnx1hi */
    case 718:  /* *vlmul_extx32vnx2qi */
    case 717:  /* *vlmul_extx32vnx1qi */
    case 716:  /* *vlmul_extx16vnx1sf */
    case 715:  /* *vlmul_extx16vnx1si */
    case 714:  /* *vlmul_extx16vnx2hi */
    case 713:  /* *vlmul_extx16vnx1hi */
    case 712:  /* *vlmul_extx16vnx4qi */
    case 711:  /* *vlmul_extx16vnx2qi */
    case 710:  /* *vlmul_extx16vnx1qi */
    case 709:  /* *vlmul_extx8vnx1df */
    case 708:  /* *vlmul_extx8vnx2sf */
    case 707:  /* *vlmul_extx8vnx1sf */
    case 706:  /* *vlmul_extx8vnx1di */
    case 705:  /* *vlmul_extx8vnx2si */
    case 704:  /* *vlmul_extx8vnx1si */
    case 703:  /* *vlmul_extx8vnx4hi */
    case 702:  /* *vlmul_extx8vnx2hi */
    case 701:  /* *vlmul_extx8vnx1hi */
    case 700:  /* *vlmul_extx8vnx8qi */
    case 699:  /* *vlmul_extx8vnx4qi */
    case 698:  /* *vlmul_extx8vnx2qi */
    case 697:  /* *vlmul_extx8vnx1qi */
    case 696:  /* *vlmul_extx4vnx2df */
    case 695:  /* *vlmul_extx4vnx1df */
    case 694:  /* *vlmul_extx4vnx4sf */
    case 693:  /* *vlmul_extx4vnx2sf */
    case 692:  /* *vlmul_extx4vnx1sf */
    case 691:  /* *vlmul_extx4vnx2di */
    case 690:  /* *vlmul_extx4vnx1di */
    case 689:  /* *vlmul_extx4vnx4si */
    case 688:  /* *vlmul_extx4vnx2si */
    case 687:  /* *vlmul_extx4vnx1si */
    case 686:  /* *vlmul_extx4vnx8hi */
    case 685:  /* *vlmul_extx4vnx4hi */
    case 684:  /* *vlmul_extx4vnx2hi */
    case 683:  /* *vlmul_extx4vnx1hi */
    case 682:  /* *vlmul_extx4vnx16qi */
    case 681:  /* *vlmul_extx4vnx8qi */
    case 680:  /* *vlmul_extx4vnx4qi */
    case 679:  /* *vlmul_extx4vnx2qi */
    case 678:  /* *vlmul_extx4vnx1qi */
    case 677:  /* *vlmul_extx2vnx4df */
    case 676:  /* *vlmul_extx2vnx2df */
    case 675:  /* *vlmul_extx2vnx1df */
    case 674:  /* *vlmul_extx2vnx8sf */
    case 673:  /* *vlmul_extx2vnx4sf */
    case 672:  /* *vlmul_extx2vnx2sf */
    case 671:  /* *vlmul_extx2vnx1sf */
    case 670:  /* *vlmul_extx2vnx4di */
    case 669:  /* *vlmul_extx2vnx2di */
    case 668:  /* *vlmul_extx2vnx1di */
    case 667:  /* *vlmul_extx2vnx8si */
    case 666:  /* *vlmul_extx2vnx4si */
    case 665:  /* *vlmul_extx2vnx2si */
    case 664:  /* *vlmul_extx2vnx1si */
    case 663:  /* *vlmul_extx2vnx16hi */
    case 662:  /* *vlmul_extx2vnx8hi */
    case 661:  /* *vlmul_extx2vnx4hi */
    case 660:  /* *vlmul_extx2vnx2hi */
    case 659:  /* *vlmul_extx2vnx1hi */
    case 658:  /* *vlmul_extx2vnx32qi */
    case 657:  /* *vlmul_extx2vnx16qi */
    case 656:  /* *vlmul_extx2vnx8qi */
    case 655:  /* *vlmul_extx2vnx4qi */
    case 654:  /* *vlmul_extx2vnx2qi */
    case 653:  /* *vlmul_extx2vnx1qi */
    case 652:  /* vundefinedvnx64bi */
    case 651:  /* vundefinedvnx32bi */
    case 650:  /* vundefinedvnx16bi */
    case 649:  /* vundefinedvnx8bi */
    case 648:  /* vundefinedvnx4bi */
    case 647:  /* vundefinedvnx2bi */
    case 646:  /* vundefinedvnx1bi */
    case 645:  /* vundefinedvnx8df */
    case 644:  /* vundefinedvnx4df */
    case 643:  /* vundefinedvnx2df */
    case 642:  /* vundefinedvnx1df */
    case 641:  /* vundefinedvnx16sf */
    case 640:  /* vundefinedvnx8sf */
    case 639:  /* vundefinedvnx4sf */
    case 638:  /* vundefinedvnx2sf */
    case 637:  /* vundefinedvnx1sf */
    case 636:  /* vundefinedvnx8di */
    case 635:  /* vundefinedvnx4di */
    case 634:  /* vundefinedvnx2di */
    case 633:  /* vundefinedvnx1di */
    case 632:  /* vundefinedvnx16si */
    case 631:  /* vundefinedvnx8si */
    case 630:  /* vundefinedvnx4si */
    case 629:  /* vundefinedvnx2si */
    case 628:  /* vundefinedvnx1si */
    case 627:  /* vundefinedvnx32hi */
    case 626:  /* vundefinedvnx16hi */
    case 625:  /* vundefinedvnx8hi */
    case 624:  /* vundefinedvnx4hi */
    case 623:  /* vundefinedvnx2hi */
    case 622:  /* vundefinedvnx1hi */
    case 621:  /* vundefinedvnx64qi */
    case 620:  /* vundefinedvnx32qi */
    case 619:  /* vundefinedvnx16qi */
    case 618:  /* vundefinedvnx8qi */
    case 617:  /* vundefinedvnx4qi */
    case 616:  /* vundefinedvnx2qi */
    case 615:  /* vundefinedvnx1qi */
    case 614:  /* *th_mempair_load_zero_extendsidi2 */
    case 613:  /* *th_mempair_load_extendsidi2 */
    case 612:  /* *th_mempair_store_di2 */
    case 611:  /* *th_mempair_store_si2 */
    case 610:  /* *th_mempair_load_di2 */
    case 609:  /* *th_mempair_load_si2 */
    case 608:  /* *th_sextw_msubhisi4 */
    case 607:  /* *th_msubhisi4 */
    case 606:  /* *th_mulswsi2 */
    case 605:  /* *th_mulswsi */
    case 604:  /* *th_mulsdi */
    case 603:  /* *th_mulssi */
    case 602:  /* *th_sextw_maddhisi4 */
    case 601:  /* *th_maddhisi4 */
    case 600:  /* *th_mulawsi2 */
    case 599:  /* *th_mulawsi */
    case 598:  /* *th_muladi */
    case 597:  /* *th_mulasi */
    case 596:  /* th_fmv_x_hw */
    case 595:  /* th_fmv_x_w */
    case 594:  /* th_fmv_hw_w_x */
    case 593:  /* *th_cond_gpr_movdidi */
    case 592:  /* *th_cond_gpr_movsidi */
    case 591:  /* *th_cond_gpr_movdisi */
    case 590:  /* *th_cond_gpr_movsisi */
    case 589:  /* *th_cond_movdidi */
    case 588:  /* *th_cond_movsidi */
    case 587:  /* *th_cond_movdisi */
    case 586:  /* *th_cond_movsisi */
    case 585:  /* *th_tstdi3 */
    case 584:  /* *th_tstsi3 */
    case 583:  /* *th_revdi2 */
    case 582:  /* *th_revsi2 */
    case 581:  /* *th_clzdi2 */
    case 580:  /* *th_clzsi2 */
    case 579:  /* *th_extudi4 */
    case 578:  /* *th_extusi4 */
    case 577:  /* *th_extdi4 */
    case 576:  /* *th_extsi4 */
    case 575:  /* *th_srridi3 */
    case 574:  /* *th_srrisi3 */
    case 573:  /* *th_addsldi4 */
    case 572:  /* *th_addslsi4 */
    case 571:  /* *local_pic_store_sfhf */
    case 570:  /* *local_pic_store_sfdf */
    case 569:  /* *local_pic_store_sfsf */
    case 568:  /* *local_pic_store_sfhf */
    case 567:  /* *local_pic_store_sfdf */
    case 566:  /* *local_pic_store_sfsf */
    case 565:  /* *local_pic_store_32dhf */
    case 564:  /* *local_pic_store_32ddf */
    case 563:  /* *local_pic_store_32dsf */
    case 562:  /* *local_pic_store_32dhf */
    case 561:  /* *local_pic_store_32ddf */
    case 560:  /* *local_pic_store_32dsf */
    case 559:  /* *local_pic_storehf */
    case 558:  /* *local_pic_storedf */
    case 557:  /* *local_pic_storesf */
    case 556:  /* *local_pic_storehf */
    case 555:  /* *local_pic_storedf */
    case 554:  /* *local_pic_storesf */
    case 553:  /* *local_pic_storedi */
    case 552:  /* *local_pic_storesi */
    case 551:  /* *local_pic_storehi */
    case 550:  /* *local_pic_storeqi */
    case 549:  /* *local_pic_storedi */
    case 548:  /* *local_pic_storesi */
    case 547:  /* *local_pic_storehi */
    case 546:  /* *local_pic_storeqi */
    case 545:  /* *local_pic_load_sfhf */
    case 544:  /* *local_pic_load_sfdf */
    case 543:  /* *local_pic_load_sfsf */
    case 542:  /* *local_pic_load_32dhf */
    case 541:  /* *local_pic_load_32ddf */
    case 540:  /* *local_pic_load_32dsf */
    case 539:  /* *local_pic_load_32dhf */
    case 538:  /* *local_pic_load_32ddf */
    case 537:  /* *local_pic_load_32dsf */
    case 536:  /* *local_pic_loadhf */
    case 535:  /* *local_pic_loaddf */
    case 534:  /* *local_pic_loadsf */
    case 533:  /* *local_pic_loadhf */
    case 532:  /* *local_pic_loaddf */
    case 531:  /* *local_pic_loadsf */
    case 530:  /* *local_pic_load_usi */
    case 529:  /* *local_pic_load_usi */
    case 528:  /* *local_pic_load_usi */
    case 527:  /* *local_pic_load_uhi */
    case 526:  /* *local_pic_load_uhi */
    case 525:  /* *local_pic_load_uhi */
    case 524:  /* *local_pic_load_uqi */
    case 523:  /* *local_pic_load_uqi */
    case 522:  /* *local_pic_load_uqi */
    case 521:  /* *local_pic_load_ssi */
    case 520:  /* *local_pic_load_ssi */
    case 519:  /* *local_pic_load_ssi */
    case 518:  /* *local_pic_load_shi */
    case 517:  /* *local_pic_load_shi */
    case 516:  /* *local_pic_load_shi */
    case 515:  /* *local_pic_load_sqi */
    case 514:  /* *local_pic_load_sqi */
    case 513:  /* *local_pic_load_sqi */
    case 512:  /* *local_pic_loaddi */
    case 511:  /* *local_pic_loadsi */
    case 510:  /* *local_pic_loadhi */
    case 509:  /* *local_pic_loadqi */
    case 508:  /* subword_atomic_cas_strong */
    case 507:  /* atomic_cas_value_strongdi */
    case 506:  /* atomic_cas_value_strongsi */
    case 505:  /* subword_atomic_exchange_strong */
    case 504:  /* atomic_exchangedi */
    case 503:  /* atomic_exchangesi */
    case 502:  /* subword_atomic_fetch_strong_nand */
    case 501:  /* subword_atomic_fetch_strong_and */
    case 500:  /* subword_atomic_fetch_strong_xor */
    case 499:  /* subword_atomic_fetch_strong_or */
    case 498:  /* subword_atomic_fetch_strong_add */
    case 497:  /* atomic_fetch_anddi */
    case 496:  /* atomic_fetch_xordi */
    case 495:  /* atomic_fetch_ordi */
    case 494:  /* atomic_fetch_adddi */
    case 493:  /* atomic_fetch_andsi */
    case 492:  /* atomic_fetch_xorsi */
    case 491:  /* atomic_fetch_orsi */
    case 490:  /* atomic_fetch_addsi */
    case 489:  /* atomic_anddi */
    case 488:  /* atomic_xordi */
    case 487:  /* atomic_ordi */
    case 486:  /* atomic_adddi */
    case 485:  /* atomic_andsi */
    case 484:  /* atomic_xorsi */
    case 483:  /* atomic_orsi */
    case 482:  /* atomic_addsi */
    case 481:  /* atomic_storedi */
    case 480:  /* atomic_storesi */
    case 479:  /* atomic_loaddi */
    case 478:  /* atomic_loadsi */
    case 477:  /* mem_thread_fence_1 */
    case 476:  /* riscv_sm4ks_di */
    case 475:  /* riscv_sm4ks_si */
    case 474:  /* riscv_sm4ed_di */
    case 473:  /* riscv_sm4ed_si */
    case 472:  /* riscv_sm3p1_di */
    case 471:  /* riscv_sm3p1_si */
    case 470:  /* riscv_sm3p0_di */
    case 469:  /* riscv_sm3p0_si */
    case 468:  /* riscv_sha512sum1 */
    case 467:  /* riscv_sha512sum0 */
    case 466:  /* riscv_sha512sig1 */
    case 465:  /* riscv_sha512sig0 */
    case 464:  /* riscv_sha512sum1r */
    case 463:  /* riscv_sha512sum0r */
    case 462:  /* riscv_sha512sig1l */
    case 461:  /* riscv_sha512sig1h */
    case 460:  /* riscv_sha512sig0l */
    case 459:  /* riscv_sha512sig0h */
    case 458:  /* riscv_sha256sum1_di */
    case 457:  /* riscv_sha256sum1_si */
    case 456:  /* riscv_sha256sum0_di */
    case 455:  /* riscv_sha256sum0_si */
    case 454:  /* riscv_sha256sig1_di */
    case 453:  /* riscv_sha256sig1_si */
    case 452:  /* riscv_sha256sig0_di */
    case 451:  /* riscv_sha256sig0_si */
    case 450:  /* riscv_aes64esm */
    case 449:  /* riscv_aes64es */
    case 448:  /* riscv_aes32esmi */
    case 447:  /* riscv_aes32esi */
    case 446:  /* riscv_aes64ks2 */
    case 445:  /* riscv_aes64ks1i */
    case 444:  /* riscv_aes64im */
    case 443:  /* riscv_aes64dsm */
    case 442:  /* riscv_aes64ds */
    case 441:  /* riscv_aes32dsmi */
    case 440:  /* riscv_aes32dsi */
    case 439:  /* riscv_xperm8_di */
    case 438:  /* riscv_xperm8_si */
    case 437:  /* riscv_xperm4_di */
    case 436:  /* riscv_xperm4_si */
    case 435:  /* riscv_clmulh_di */
    case 434:  /* riscv_clmulh_si */
    case 433:  /* riscv_clmul_di */
    case 432:  /* riscv_clmul_si */
    case 431:  /* riscv_packw */
    case 430:  /* riscv_packh_di */
    case 429:  /* riscv_packh_si */
    case 428:  /* riscv_pack_disi */
    case 427:  /* riscv_pack_dihi */
    case 426:  /* riscv_pack_sisi */
    case 425:  /* riscv_pack_sihi */
    case 424:  /* riscv_unzip */
    case 423:  /* riscv_zip */
    case 422:  /* riscv_brev8_di */
    case 421:  /* riscv_brev8_si */
    case 420:  /* *branchdi_mask_twobits_equals_singlebit */
    case 419:  /* *branchsi_mask_twobits_equals_singlebit */
    case 418:  /* *andidi_extrabit */
    case 417:  /* *andisi_extrabit */
    case 416:  /* *xoridi_extrabit */
    case 415:  /* *ioridi_extrabit */
    case 414:  /* *xorisi_extrabit */
    case 413:  /* *iorisi_extrabit */
    case 412:  /* *bexti */
    case 411:  /* *bexti */
    case 410:  /* *bextdi */
    case 409:  /* *bextsi */
    case 408:  /* *bextdi */
    case 407:  /* *bextsi */
    case 406:  /* *binvidi */
    case 405:  /* *binvisi */
    case 404:  /* *binvdi */
    case 403:  /* *binvsi */
    case 402:  /* *bclridisi_nottwobits */
    case 401:  /* *bclridi_nottwobits */
    case 400:  /* *bclrisi_nottwobits */
    case 399:  /* *bclridi */
    case 398:  /* *bclrisi */
    case 397:  /* *bclrdi */
    case 396:  /* *bclrsi */
    case 395:  /* *bsetidisi */
    case 394:  /* *bsetidi */
    case 393:  /* *bsetisi */
    case 392:  /* *bsetdi_1_mask */
    case 391:  /* *bsetsi_1_mask */
    case 390:  /* *bsetdi_1 */
    case 389:  /* *bsetsi_1 */
    case 388:  /* *bsetdi_mask */
    case 387:  /* *bsetsi_mask */
    case 386:  /* *bsetdi */
    case 385:  /* *bsetsi */
    case 384:  /* *minmax */
    case 383:  /* *minmax */
    case 382:  /* *minmax */
    case 381:  /* *minmax */
    case 380:  /* umaxdi3 */
    case 379:  /* smaxdi3 */
    case 378:  /* umindi3 */
    case 377:  /* smindi3 */
    case 376:  /* umaxsi3 */
    case 375:  /* smaxsi3 */
    case 374:  /* uminsi3 */
    case 373:  /* sminsi3 */
    case 372:  /* *bswapdi2 */
    case 371:  /* *bswapsi2 */
    case 370:  /* orcbdi2 */
    case 369:  /* orcbsi2 */
    case 368:  /* rotlsi3_sext */
    case 367:  /* rotldi3 */
    case 366:  /* rotlsi3 */
    case 365:  /* *rotrsi3_sext */
    case 364:  /* *rotrdi3 */
    case 363:  /* *rotrsi3 */
    case 362:  /* *zero_extendhidi2_zbb */
    case 361:  /* *zero_extendhisi2_zbb */
    case 360:  /* *extendhidi2_zbb */
    case 359:  /* *extendhisi2_zbb */
    case 358:  /* *extendhihi2_zbb */
    case 357:  /* *extendqidi2_zbb */
    case 356:  /* *extendqisi2_zbb */
    case 355:  /* *extendqihi2_zbb */
    case 354:  /* *zero_extendhidi2_bitmanip */
    case 353:  /* *zero_extendhisi2_bitmanip */
    case 352:  /* *popcountdi2 */
    case 351:  /* *ctzdi2 */
    case 350:  /* *clzdi2 */
    case 349:  /* *popcountdisi2 */
    case 348:  /* *ctzdisi2 */
    case 347:  /* *clzdisi2 */
    case 346:  /* *popcountsi2 */
    case 345:  /* *ctzsi2 */
    case 344:  /* *clzsi2 */
    case 343:  /* *xor_notdi */
    case 342:  /* *xor_notsi */
    case 341:  /* *ior_notdi */
    case 340:  /* *and_notdi */
    case 339:  /* *ior_notsi */
    case 338:  /* *and_notsi */
    case 337:  /* *slliuw */
    case 336:  /* *add.uw */
    case 335:  /* *shNadduw */
    case 334:  /* *andi_add.uw */
    case 333:  /* *shNadd */
    case 332:  /* *shNadd */
    case 331:  /* *zero_extendsidi2_bitmanip */
    case 330:  /* riscv_prefetchi_di */
    case 329:  /* riscv_prefetchi_si */
    case 328:  /* prefetch */
    case 327:  /* riscv_zero_di */
    case 326:  /* riscv_zero_si */
    case 325:  /* riscv_inval_di */
    case 324:  /* riscv_inval_si */
    case 323:  /* riscv_flush_di */
    case 322:  /* riscv_flush_si */
    case 321:  /* riscv_clean_di */
    case 320:  /* riscv_clean_si */
    case 319:  /* stack_protect_test_di */
    case 318:  /* stack_protect_test_si */
    case 317:  /* stack_protect_set_di */
    case 316:  /* stack_protect_set_si */
    case 315:  /* stack_tiedi */
    case 314:  /* stack_tiesi */
    case 313:  /* riscv_uret */
    case 312:  /* riscv_sret */
    case 311:  /* riscv_mret */
    case 310:  /* *riscv_fsnvsnanhf2 */
    case 309:  /* *riscv_fsnvsnandf2 */
    case 308:  /* *riscv_fsnvsnansf2 */
    case 307:  /* riscv_fsflags */
    case 306:  /* riscv_frflags */
    case 305:  /* gpr_restore_return */
    case 304:  /* gpr_restore */
    case 303:  /* gpr_save */
    case 302:  /* trap */
    case 301:  /* nop */
    case 300:  /* call_value_internal */
    case 299:  /* call_internal */
    case 298:  /* sibcall_value_internal */
    case 297:  /* sibcall_internal */
    case 296:  /* eh_return_internal */
    case 295:  /* eh_set_lr_di */
    case 294:  /* eh_set_lr_si */
    case 293:  /* simple_return_internal */
    case 292:  /* simple_return */
    case 291:  /* blockage */
    case 290:  /* tablejumpdi */
    case 289:  /* tablejumpsi */
    case 288:  /* indirect_jumpdi */
    case 287:  /* indirect_jumpsi */
    case 286:  /* jump */
    case 285:  /* *sleu_didi */
    case 284:  /* *sle_didi */
    case 283:  /* *sleu_disi */
    case 282:  /* *sle_disi */
    case 281:  /* *sleu_sisi */
    case 280:  /* *sle_sisi */
    case 279:  /* *sltu_didi */
    case 278:  /* *slt_didi */
    case 277:  /* *sltu_disi */
    case 276:  /* *slt_disi */
    case 275:  /* *sltu_sisi */
    case 274:  /* *slt_sisi */
    case 273:  /* *sgeu_didi */
    case 272:  /* *sge_didi */
    case 271:  /* *sgeu_disi */
    case 270:  /* *sge_disi */
    case 269:  /* *sgeu_sisi */
    case 268:  /* *sge_sisi */
    case 267:  /* *sgtu_didi */
    case 266:  /* *sgt_didi */
    case 265:  /* *sgtu_disi */
    case 264:  /* *sgt_disi */
    case 263:  /* *sgtu_sisi */
    case 262:  /* *sgt_sisi */
    case 261:  /* *sne_zero_didi */
    case 260:  /* *sne_zero_disi */
    case 259:  /* *sne_zero_sisi */
    case 258:  /* *seq_zero_didi */
    case 257:  /* *seq_zero_disi */
    case 256:  /* *seq_zero_sisi */
    case 255:  /* *cstorehfdi4 */
    case 254:  /* *cstorehfsi4 */
    case 253:  /* *cstoredfdi4 */
    case 252:  /* *cstoredfsi4 */
    case 251:  /* *cstoresfdi4 */
    case 250:  /* *cstoresfsi4 */
    case 249:  /* *branch_on_bit_rangedi */
    case 248:  /* *branch_on_bit_rangesi */
    case 247:  /* *branch_on_bitdi */
    case 246:  /* *branch_on_bitsi */
    case 245:  /* *movdidicc */
    case 244:  /* *movsidicc */
    case 243:  /* *movsisicc */
    case 242:  /* *branchdi */
    case 241:  /* *branchsi */
    case 240:  /* *branchdi_shiftedmask_equals_zero */
    case 239:  /* *branchsi_shiftedmask_equals_zero */
    case 238:  /* *branchhi_shiftedmask_equals_zero */
    case 237:  /* *branchqi_shiftedmask_equals_zero */
    case 236:  /* *branchdi_shiftedmask_equals_zero */
    case 235:  /* *branchsi_shiftedmask_equals_zero */
    case 234:  /* *branchhi_shiftedmask_equals_zero */
    case 233:  /* *branchqi_shiftedmask_equals_zero */
    case 232:  /* *branchdi_shiftedarith_equals_zero */
    case 231:  /* *branchsi_shiftedarith_equals_zero */
    case 230:  /* *branchhi_shiftedarith_equals_zero */
    case 229:  /* *branchqi_shiftedarith_equals_zero */
    case 228:  /* *branchsi_shiftedarith_equals_zero */
    case 227:  /* *branchhi_shiftedarith_equals_zero */
    case 226:  /* *branchqi_shiftedarith_equals_zero */
    case 225:  /* zero_extendsidi2_shifted */
    case 224:  /* *lshrsi3_zero_extend_3 */
    case 223:  /* *lshrsi3_zero_extend_2 */
    case 222:  /* *lshrsi3_zero_extend_1 */
    case 221:  /* *lshrsi3_extend_mask_1 */
    case 220:  /* *ashrsi3_extend_mask_1 */
    case 219:  /* *ashlsi3_extend_mask_1 */
    case 218:  /* *lshrsi3_extend_mask */
    case 217:  /* *ashrsi3_extend_mask */
    case 216:  /* *ashlsi3_extend_mask */
    case 215:  /* *lshrsi3_extend */
    case 214:  /* *ashrsi3_extend */
    case 213:  /* *ashlsi3_extend */
    case 212:  /* *lshrdi3_mask_1 */
    case 211:  /* *ashrdi3_mask_1 */
    case 210:  /* *ashldi3_mask_1 */
    case 209:  /* *lshrdi3_mask */
    case 208:  /* *ashrdi3_mask */
    case 207:  /* *ashldi3_mask */
    case 206:  /* lshrdi3 */
    case 205:  /* ashrdi3 */
    case 204:  /* ashldi3 */
    case 203:  /* *lshrsi3_mask_1 */
    case 202:  /* *ashrsi3_mask_1 */
    case 201:  /* *ashlsi3_mask_1 */
    case 200:  /* *lshrsi3_mask */
    case 199:  /* *ashrsi3_mask */
    case 198:  /* *ashlsi3_mask */
    case 197:  /* lshrsi3 */
    case 196:  /* ashrsi3 */
    case 195:  /* ashlsi3 */
    case 194:  /* riscv_pause */
    case 193:  /* fence_i */
    case 192:  /* fence */
    case 191:  /* *movdf_softfloat */
    case 190:  /* *movdf_hardfloat_rv64 */
    case 189:  /* *movdf_hardfloat_rv32 */
    case 188:  /* *movsf_softfloat */
    case 187:  /* *movsf_hardfloat */
    case 186:  /* *movqi_internal */
    case 185:  /* *xorsihi3 */
    case 184:  /* *xorhihi3 */
    case 183:  /* *addsihi3 */
    case 182:  /* *addhihi3 */
    case 181:  /* *movhi_internal */
    case 180:  /* *movsi_internal */
    case 179:  /* *movdi_64bit */
    case 178:  /* *movdi_32bit */
    case 177:  /* *mvconst_internal */
    case 176:  /* *mvconst_internal */
    case 175:  /* *lowdi */
    case 174:  /* *lowsi */
    case 173:  /* auipcdi */
    case 172:  /* auipcsi */
    case 171:  /* got_load_tls_iedi */
    case 170:  /* got_load_tls_iesi */
    case 169:  /* got_load_tls_gddi */
    case 168:  /* got_load_tls_gdsi */
    case 167:  /* tls_add_tp_ledi */
    case 166:  /* tls_add_tp_lesi */
    case 165:  /* got_loaddi */
    case 164:  /* got_loadsi */
    case 163:  /* lroundhfdi2 */
    case 162:  /* lrinthfdi2 */
    case 161:  /* lroundhfsi2 */
    case 160:  /* lrinthfsi2 */
    case 159:  /* lrounddfdi2 */
    case 158:  /* lrintdfdi2 */
    case 157:  /* lrounddfsi2 */
    case 156:  /* lrintdfsi2 */
    case 155:  /* lroundsfdi2 */
    case 154:  /* lrintsfdi2 */
    case 153:  /* lroundsfsi2 */
    case 152:  /* lrintsfsi2 */
    case 151:  /* floatunsdihf2 */
    case 150:  /* floatunssihf2 */
    case 149:  /* floatunsdidf2 */
    case 148:  /* floatunssidf2 */
    case 147:  /* floatunsdisf2 */
    case 146:  /* floatunssisf2 */
    case 145:  /* floatdihf2 */
    case 144:  /* floatsihf2 */
    case 143:  /* floatdidf2 */
    case 142:  /* floatsidf2 */
    case 141:  /* floatdisf2 */
    case 140:  /* floatsisf2 */
    case 139:  /* fixuns_trunchfdi2 */
    case 138:  /* fixuns_trunchfsi2 */
    case 137:  /* fixuns_truncdfdi2 */
    case 136:  /* fixuns_truncdfsi2 */
    case 135:  /* fixuns_truncsfdi2 */
    case 134:  /* fixuns_truncsfsi2 */
    case 133:  /* fix_trunchfdi2 */
    case 132:  /* fix_trunchfsi2 */
    case 131:  /* fix_truncdfdi2 */
    case 130:  /* fix_truncdfsi2 */
    case 129:  /* fix_truncsfdi2 */
    case 128:  /* fix_truncsfsi2 */
    case 127:  /* *movhf_softfloat */
    case 126:  /* *movhf_hardfloat */
    case 125:  /* extendhfdf2 */
    case 124:  /* extendsfdf2 */
    case 123:  /* extendhfsf2 */
    case 122:  /* *extendhidi2 */
    case 121:  /* *extendhisi2 */
    case 120:  /* *extendhihi2 */
    case 119:  /* *extendqidi2 */
    case 118:  /* *extendqisi2 */
    case 117:  /* *extendqihi2 */
    case 116:  /* extendsidi2 */
    case 115:  /* zero_extendqidi2 */
    case 114:  /* zero_extendqisi2 */
    case 113:  /* zero_extendqihi2 */
    case 112:  /* *zero_extendhidi2 */
    case 111:  /* *zero_extendhisi2 */
    case 110:  /* *zero_extendsidi2_internal */
    case 109:  /* truncdfhf2 */
    case 108:  /* truncsfhf2 */
    case 107:  /* truncdfsf2 */
    case 106:  /* *one_cmplsi2_internal */
    case 105:  /* one_cmpldi2 */
    case 104:  /* one_cmplsi2 */
    case 103:  /* *xorsi3_internal */
    case 102:  /* *iorsi3_internal */
    case 101:  /* *andsi3_internal */
    case 100:  /* xordi3 */
    case 99:  /* iordi3 */
    case 98:  /* anddi3 */
    case 97:  /* xorsi3 */
    case 96:  /* iorsi3 */
    case 95:  /* andsi3 */
    case 94:  /* smaxhf3 */
    case 93:  /* smaxdf3 */
    case 92:  /* smaxsf3 */
    case 91:  /* sminhf3 */
    case 90:  /* smindf3 */
    case 89:  /* sminsf3 */
    case 88:  /* fmaxhf3 */
    case 87:  /* fmaxdf3 */
    case 86:  /* fmaxsf3 */
    case 85:  /* fminhf3 */
    case 84:  /* fmindf3 */
    case 83:  /* fminsf3 */
    case 82:  /* neghf2 */
    case 81:  /* negdf2 */
    case 80:  /* negsf2 */
    case 79:  /* copysignhf3 */
    case 78:  /* copysigndf3 */
    case 77:  /* copysignsf3 */
    case 76:  /* abshf2 */
    case 75:  /* absdf2 */
    case 74:  /* abssf2 */
    case 73:  /* *fnmahf4 */
    case 72:  /* *fnmadf4 */
    case 71:  /* *fnmasf4 */
    case 70:  /* *fnmshf4 */
    case 69:  /* *fnmsdf4 */
    case 68:  /* *fnmssf4 */
    case 67:  /* *fmshf4 */
    case 66:  /* *fmsdf4 */
    case 65:  /* *fmssf4 */
    case 64:  /* *fmahf4 */
    case 63:  /* *fmadf4 */
    case 62:  /* *fmasf4 */
    case 61:  /* fnmahf4 */
    case 60:  /* fnmadf4 */
    case 59:  /* fnmasf4 */
    case 58:  /* fnmshf4 */
    case 57:  /* fnmsdf4 */
    case 56:  /* fnmssf4 */
    case 55:  /* fmshf4 */
    case 54:  /* fmsdf4 */
    case 53:  /* fmssf4 */
    case 52:  /* fmahf4 */
    case 51:  /* fmadf4 */
    case 50:  /* fmasf4 */
    case 49:  /* sqrthf2 */
    case 48:  /* sqrtdf2 */
    case 47:  /* sqrtsf2 */
    case 46:  /* divhf3 */
    case 45:  /* divdf3 */
    case 44:  /* divsf3 */
    case 43:  /* *umodsi3_extended */
    case 42:  /* *modsi3_extended */
    case 41:  /* *udivsi3_extended */
    case 40:  /* *divsi3_extended */
    case 39:  /* umoddi3 */
    case 38:  /* moddi3 */
    case 37:  /* udivdi3 */
    case 36:  /* divdi3 */
    case 35:  /* umodsi3 */
    case 34:  /* modsi3 */
    case 33:  /* udivsi3 */
    case 32:  /* divsi3 */
    case 31:  /* usmulsi3_highpart */
    case 30:  /* umulsi3_highpart */
    case 29:  /* smulsi3_highpart */
    case 28:  /* usmuldi3_highpart */
    case 27:  /* umuldi3_highpart */
    case 26:  /* smuldi3_highpart */
    case 25:  /* *mulsi3_extended2 */
    case 24:  /* *mulsi3_extended */
    case 23:  /* muldi3 */
    case 22:  /* mulsi3 */
    case 21:  /* mulhf3 */
    case 20:  /* muldf3 */
    case 19:  /* mulsf3 */
    case 18:  /* *negsi2_extended2 */
    case 17:  /* *negsi2_extended */
    case 16:  /* negsi2 */
    case 15:  /* negdi2 */
    case 14:  /* *subsi3_extended2 */
    case 13:  /* *subsi3_extended */
    case 12:  /* subsi3 */
    case 11:  /* subdi3 */
    case 10:  /* subhf3 */
    case 9:  /* subdf3 */
    case 8:  /* subsf3 */
    case 7:  /* *addsi3_extended2 */
    case 6:  /* *addsi3_extended */
    case 5:  /* adddi3 */
    case 4:  /* addsi3 */
    case 3:  /* addhf3 */
    case 2:  /* adddf3 */
    case 1:  /* addsf3 */
      return 255 /* 0xff */;

    case 793:  /* vsetvlsi */
    case 794:  /* vsetvldi */
      extract_constrain_insn_cached (insn);
      return 
#line 876 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[2]));

    case 796:  /* vsetvl_discard_resultsi */
    case 797:  /* vsetvl_discard_resultdi */
      extract_constrain_insn_cached (insn);
      return 
#line 875 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[1]));

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_mode = get_attr_mode (insn)) == MODE_VNX1QI) || (cached_mode == MODE_VNX2QI) || (cached_mode == MODE_VNX4QI) || (cached_mode == MODE_VNX8QI) || (cached_mode == MODE_VNX16QI) || (cached_mode == MODE_VNX32QI) || (cached_mode == MODE_VNX64QI) || (cached_mode == MODE_VNX1BI) || (cached_mode == MODE_VNX2BI) || (cached_mode == MODE_VNX4BI) || (cached_mode == MODE_VNX8BI) || (cached_mode == MODE_VNX16BI) || (cached_mode == MODE_VNX32BI) || (cached_mode == MODE_VNX64BI))
        {
	  return 8;
        }
      else if ((cached_mode == MODE_VNX1HI) || (cached_mode == MODE_VNX2HI) || (cached_mode == MODE_VNX4HI) || (cached_mode == MODE_VNX8HI) || (cached_mode == MODE_VNX16HI) || (cached_mode == MODE_VNX32HI))
        {
	  return 16 /* 0x10 */;
        }
      else if ((cached_mode == MODE_VNX1SI) || (cached_mode == MODE_VNX2SI) || (cached_mode == MODE_VNX4SI) || (cached_mode == MODE_VNX8SI) || (cached_mode == MODE_VNX16SI) || (cached_mode == MODE_VNX1SF) || (cached_mode == MODE_VNX2SF) || (cached_mode == MODE_VNX4SF) || (cached_mode == MODE_VNX8SF) || (cached_mode == MODE_VNX16SF))
        {
	  return 32 /* 0x20 */;
        }
      else if ((cached_mode == MODE_VNX1DI) || (cached_mode == MODE_VNX2DI) || (cached_mode == MODE_VNX4DI) || (cached_mode == MODE_VNX8DI) || (cached_mode == MODE_VNX1DF) || (cached_mode == MODE_VNX2DF) || (cached_mode == MODE_VNX4DF) || (cached_mode == MODE_VNX8DF))
        {
	  return 64 /* 0x40 */;
        }
      else
        {
	  return 255 /* 0xff */;
        }

    default:
      return 32 /* 0x20 */;

    }
}

int
get_attr_ta (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 4599:  /* pred_seriesvnx8di */
    case 4598:  /* pred_seriesvnx4di */
    case 4597:  /* pred_seriesvnx2di */
    case 4596:  /* pred_seriesvnx1di */
    case 4595:  /* pred_seriesvnx16si */
    case 4594:  /* pred_seriesvnx8si */
    case 4593:  /* pred_seriesvnx4si */
    case 4592:  /* pred_seriesvnx2si */
    case 4591:  /* pred_seriesvnx1si */
    case 4590:  /* pred_seriesvnx32hi */
    case 4589:  /* pred_seriesvnx16hi */
    case 4588:  /* pred_seriesvnx8hi */
    case 4587:  /* pred_seriesvnx4hi */
    case 4586:  /* pred_seriesvnx2hi */
    case 4585:  /* pred_seriesvnx1hi */
    case 4584:  /* pred_seriesvnx64qi */
    case 4583:  /* pred_seriesvnx32qi */
    case 4582:  /* pred_seriesvnx16qi */
    case 4581:  /* pred_seriesvnx8qi */
    case 4580:  /* pred_seriesvnx4qi */
    case 4579:  /* pred_seriesvnx2qi */
    case 4578:  /* pred_seriesvnx1qi */
      extract_constrain_insn_cached (insn);
      return 
#line 285 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ta(operands[4]));

    case 4995:  /* *pred_mul_neg_subvnx8df_scalar */
    case 4994:  /* *pred_mul_neg_addvnx8df_scalar */
    case 4993:  /* *pred_mul_neg_subvnx4df_scalar */
    case 4992:  /* *pred_mul_neg_addvnx4df_scalar */
    case 4991:  /* *pred_mul_neg_subvnx2df_scalar */
    case 4990:  /* *pred_mul_neg_addvnx2df_scalar */
    case 4989:  /* *pred_mul_neg_subvnx1df_scalar */
    case 4988:  /* *pred_mul_neg_addvnx1df_scalar */
    case 4987:  /* *pred_mul_neg_subvnx16sf_scalar */
    case 4986:  /* *pred_mul_neg_addvnx16sf_scalar */
    case 4985:  /* *pred_mul_neg_subvnx8sf_scalar */
    case 4984:  /* *pred_mul_neg_addvnx8sf_scalar */
    case 4983:  /* *pred_mul_neg_subvnx4sf_scalar */
    case 4982:  /* *pred_mul_neg_addvnx4sf_scalar */
    case 4981:  /* *pred_mul_neg_subvnx2sf_scalar */
    case 4980:  /* *pred_mul_neg_addvnx2sf_scalar */
    case 4979:  /* *pred_mul_neg_subvnx1sf_scalar */
    case 4978:  /* *pred_mul_neg_addvnx1sf_scalar */
    case 4941:  /* *pred_mul_neg_subvnx8df */
    case 4940:  /* *pred_mul_neg_addvnx8df */
    case 4939:  /* *pred_mul_neg_subvnx4df */
    case 4938:  /* *pred_mul_neg_addvnx4df */
    case 4937:  /* *pred_mul_neg_subvnx2df */
    case 4936:  /* *pred_mul_neg_addvnx2df */
    case 4935:  /* *pred_mul_neg_subvnx1df */
    case 4934:  /* *pred_mul_neg_addvnx1df */
    case 4933:  /* *pred_mul_neg_subvnx16sf */
    case 4932:  /* *pred_mul_neg_addvnx16sf */
    case 4931:  /* *pred_mul_neg_subvnx8sf */
    case 4930:  /* *pred_mul_neg_addvnx8sf */
    case 4929:  /* *pred_mul_neg_subvnx4sf */
    case 4928:  /* *pred_mul_neg_addvnx4sf */
    case 4927:  /* *pred_mul_neg_subvnx2sf */
    case 4926:  /* *pred_mul_neg_addvnx2sf */
    case 4925:  /* *pred_mul_neg_subvnx1sf */
    case 4924:  /* *pred_mul_neg_addvnx1sf */
    case 4887:  /* *pred_mul_subvnx8df_scalar */
    case 4886:  /* *pred_mul_addvnx8df_scalar */
    case 4885:  /* *pred_mul_subvnx4df_scalar */
    case 4884:  /* *pred_mul_addvnx4df_scalar */
    case 4883:  /* *pred_mul_subvnx2df_scalar */
    case 4882:  /* *pred_mul_addvnx2df_scalar */
    case 4881:  /* *pred_mul_subvnx1df_scalar */
    case 4880:  /* *pred_mul_addvnx1df_scalar */
    case 4879:  /* *pred_mul_subvnx16sf_scalar */
    case 4878:  /* *pred_mul_addvnx16sf_scalar */
    case 4877:  /* *pred_mul_subvnx8sf_scalar */
    case 4876:  /* *pred_mul_addvnx8sf_scalar */
    case 4875:  /* *pred_mul_subvnx4sf_scalar */
    case 4874:  /* *pred_mul_addvnx4sf_scalar */
    case 4873:  /* *pred_mul_subvnx2sf_scalar */
    case 4872:  /* *pred_mul_addvnx2sf_scalar */
    case 4871:  /* *pred_mul_subvnx1sf_scalar */
    case 4870:  /* *pred_mul_addvnx1sf_scalar */
    case 4833:  /* *pred_mul_subvnx8df */
    case 4832:  /* *pred_mul_addvnx8df */
    case 4831:  /* *pred_mul_subvnx4df */
    case 4830:  /* *pred_mul_addvnx4df */
    case 4829:  /* *pred_mul_subvnx2df */
    case 4828:  /* *pred_mul_addvnx2df */
    case 4827:  /* *pred_mul_subvnx1df */
    case 4826:  /* *pred_mul_addvnx1df */
    case 4825:  /* *pred_mul_subvnx16sf */
    case 4824:  /* *pred_mul_addvnx16sf */
    case 4823:  /* *pred_mul_subvnx8sf */
    case 4822:  /* *pred_mul_addvnx8sf */
    case 4821:  /* *pred_mul_subvnx4sf */
    case 4820:  /* *pred_mul_addvnx4sf */
    case 4819:  /* *pred_mul_subvnx2sf */
    case 4818:  /* *pred_mul_addvnx2sf */
    case 4817:  /* *pred_mul_subvnx1sf */
    case 4816:  /* *pred_mul_addvnx1sf */
    case 4338:  /* *pred_minus_mulvnx8di_extended_scalar */
    case 4337:  /* *pred_minus_mulvnx4di_extended_scalar */
    case 4336:  /* *pred_minus_mulvnx2di_extended_scalar */
    case 4335:  /* *pred_minus_mulvnx1di_extended_scalar */
    case 4326:  /* *pred_minus_mulvnx8di_scalar */
    case 4325:  /* *pred_minus_mulvnx4di_scalar */
    case 4324:  /* *pred_minus_mulvnx2di_scalar */
    case 4323:  /* *pred_minus_mulvnx1di_scalar */
    case 4322:  /* *pred_minus_mulvnx16si_scalar */
    case 4321:  /* *pred_minus_mulvnx8si_scalar */
    case 4320:  /* *pred_minus_mulvnx4si_scalar */
    case 4319:  /* *pred_minus_mulvnx2si_scalar */
    case 4318:  /* *pred_minus_mulvnx1si_scalar */
    case 4317:  /* *pred_minus_mulvnx32hi_scalar */
    case 4316:  /* *pred_minus_mulvnx16hi_scalar */
    case 4315:  /* *pred_minus_mulvnx8hi_scalar */
    case 4314:  /* *pred_minus_mulvnx4hi_scalar */
    case 4313:  /* *pred_minus_mulvnx2hi_scalar */
    case 4312:  /* *pred_minus_mulvnx1hi_scalar */
    case 4311:  /* *pred_minus_mulvnx64qi_scalar */
    case 4310:  /* *pred_minus_mulvnx32qi_scalar */
    case 4309:  /* *pred_minus_mulvnx16qi_scalar */
    case 4308:  /* *pred_minus_mulvnx8qi_scalar */
    case 4307:  /* *pred_minus_mulvnx4qi_scalar */
    case 4306:  /* *pred_minus_mulvnx2qi_scalar */
    case 4305:  /* *pred_minus_mulvnx1qi_scalar */
    case 4260:  /* *pred_minus_mulvnx8di */
    case 4259:  /* *pred_minus_mulvnx4di */
    case 4258:  /* *pred_minus_mulvnx2di */
    case 4257:  /* *pred_minus_mulvnx1di */
    case 4256:  /* *pred_minus_mulvnx16si */
    case 4255:  /* *pred_minus_mulvnx8si */
    case 4254:  /* *pred_minus_mulvnx4si */
    case 4253:  /* *pred_minus_mulvnx2si */
    case 4252:  /* *pred_minus_mulvnx1si */
    case 4251:  /* *pred_minus_mulvnx32hi */
    case 4250:  /* *pred_minus_mulvnx16hi */
    case 4249:  /* *pred_minus_mulvnx8hi */
    case 4248:  /* *pred_minus_mulvnx4hi */
    case 4247:  /* *pred_minus_mulvnx2hi */
    case 4246:  /* *pred_minus_mulvnx1hi */
    case 4245:  /* *pred_minus_mulvnx64qi */
    case 4244:  /* *pred_minus_mulvnx32qi */
    case 4243:  /* *pred_minus_mulvnx16qi */
    case 4242:  /* *pred_minus_mulvnx8qi */
    case 4241:  /* *pred_minus_mulvnx4qi */
    case 4240:  /* *pred_minus_mulvnx2qi */
    case 4239:  /* *pred_minus_mulvnx1qi */
    case 4194:  /* *pred_mul_plusvnx8di_extended_scalar */
    case 4193:  /* *pred_mul_plusvnx4di_extended_scalar */
    case 4192:  /* *pred_mul_plusvnx2di_extended_scalar */
    case 4191:  /* *pred_mul_plusvnx1di_extended_scalar */
    case 4182:  /* *pred_mul_plusvnx8di_scalar */
    case 4181:  /* *pred_mul_plusvnx4di_scalar */
    case 4180:  /* *pred_mul_plusvnx2di_scalar */
    case 4179:  /* *pred_mul_plusvnx1di_scalar */
    case 4178:  /* *pred_mul_plusvnx16si_scalar */
    case 4177:  /* *pred_mul_plusvnx8si_scalar */
    case 4176:  /* *pred_mul_plusvnx4si_scalar */
    case 4175:  /* *pred_mul_plusvnx2si_scalar */
    case 4174:  /* *pred_mul_plusvnx1si_scalar */
    case 4173:  /* *pred_mul_plusvnx32hi_scalar */
    case 4172:  /* *pred_mul_plusvnx16hi_scalar */
    case 4171:  /* *pred_mul_plusvnx8hi_scalar */
    case 4170:  /* *pred_mul_plusvnx4hi_scalar */
    case 4169:  /* *pred_mul_plusvnx2hi_scalar */
    case 4168:  /* *pred_mul_plusvnx1hi_scalar */
    case 4167:  /* *pred_mul_plusvnx64qi_scalar */
    case 4166:  /* *pred_mul_plusvnx32qi_scalar */
    case 4165:  /* *pred_mul_plusvnx16qi_scalar */
    case 4164:  /* *pred_mul_plusvnx8qi_scalar */
    case 4163:  /* *pred_mul_plusvnx4qi_scalar */
    case 4162:  /* *pred_mul_plusvnx2qi_scalar */
    case 4161:  /* *pred_mul_plusvnx1qi_scalar */
    case 4116:  /* *pred_mul_plusvnx8di */
    case 4115:  /* *pred_mul_plusvnx4di */
    case 4114:  /* *pred_mul_plusvnx2di */
    case 4113:  /* *pred_mul_plusvnx1di */
    case 4112:  /* *pred_mul_plusvnx16si */
    case 4111:  /* *pred_mul_plusvnx8si */
    case 4110:  /* *pred_mul_plusvnx4si */
    case 4109:  /* *pred_mul_plusvnx2si */
    case 4108:  /* *pred_mul_plusvnx1si */
    case 4107:  /* *pred_mul_plusvnx32hi */
    case 4106:  /* *pred_mul_plusvnx16hi */
    case 4105:  /* *pred_mul_plusvnx8hi */
    case 4104:  /* *pred_mul_plusvnx4hi */
    case 4103:  /* *pred_mul_plusvnx2hi */
    case 4102:  /* *pred_mul_plusvnx1hi */
    case 4101:  /* *pred_mul_plusvnx64qi */
    case 4100:  /* *pred_mul_plusvnx32qi */
    case 4099:  /* *pred_mul_plusvnx16qi */
    case 4098:  /* *pred_mul_plusvnx8qi */
    case 4097:  /* *pred_mul_plusvnx4qi */
    case 4096:  /* *pred_mul_plusvnx2qi */
    case 4095:  /* *pred_mul_plusvnx1qi */
      extract_constrain_insn_cached (insn);
      return 
#line 282 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ta(operands[7]));

    case 998:  /* pred_strided_loadvnx8df */
    case 997:  /* pred_strided_loadvnx4df */
    case 996:  /* pred_strided_loadvnx2df */
    case 995:  /* pred_strided_loadvnx1df */
    case 994:  /* pred_strided_loadvnx16sf */
    case 993:  /* pred_strided_loadvnx8sf */
    case 992:  /* pred_strided_loadvnx4sf */
    case 991:  /* pred_strided_loadvnx2sf */
    case 990:  /* pred_strided_loadvnx1sf */
    case 989:  /* pred_strided_loadvnx8di */
    case 988:  /* pred_strided_loadvnx4di */
    case 987:  /* pred_strided_loadvnx2di */
    case 986:  /* pred_strided_loadvnx1di */
    case 985:  /* pred_strided_loadvnx16si */
    case 984:  /* pred_strided_loadvnx8si */
    case 983:  /* pred_strided_loadvnx4si */
    case 982:  /* pred_strided_loadvnx2si */
    case 981:  /* pred_strided_loadvnx1si */
    case 980:  /* pred_strided_loadvnx32hi */
    case 979:  /* pred_strided_loadvnx16hi */
    case 978:  /* pred_strided_loadvnx8hi */
    case 977:  /* pred_strided_loadvnx4hi */
    case 976:  /* pred_strided_loadvnx2hi */
    case 975:  /* pred_strided_loadvnx1hi */
    case 974:  /* pred_strided_loadvnx64qi */
    case 973:  /* pred_strided_loadvnx32qi */
    case 972:  /* pred_strided_loadvnx16qi */
    case 971:  /* pred_strided_loadvnx8qi */
    case 970:  /* pred_strided_loadvnx4qi */
    case 969:  /* pred_strided_loadvnx2qi */
    case 968:  /* pred_strided_loadvnx1qi */
      extract_constrain_insn_cached (insn);
      if (
#line 239 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(VECTOR_MODE_P (GET_MODE (operands[3]))))
        {
	  return 
#line 270 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ta(operands[6]));
        }
      else
        {
	  return 
#line 264 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ta(operands[5]));
        }

    case 963:  /* *pred_broadcastvnx8df */
    case 962:  /* *pred_broadcastvnx4df */
    case 961:  /* *pred_broadcastvnx2df */
    case 960:  /* *pred_broadcastvnx1df */
    case 959:  /* *pred_broadcastvnx16sf */
    case 958:  /* *pred_broadcastvnx8sf */
    case 957:  /* *pred_broadcastvnx4sf */
    case 956:  /* *pred_broadcastvnx2sf */
    case 955:  /* *pred_broadcastvnx1sf */
    case 954:  /* *pred_broadcastvnx8di */
    case 953:  /* *pred_broadcastvnx4di */
    case 952:  /* *pred_broadcastvnx2di */
    case 951:  /* *pred_broadcastvnx1di */
    case 950:  /* *pred_broadcastvnx16si */
    case 949:  /* *pred_broadcastvnx8si */
    case 948:  /* *pred_broadcastvnx4si */
    case 947:  /* *pred_broadcastvnx2si */
    case 946:  /* *pred_broadcastvnx1si */
    case 945:  /* *pred_broadcastvnx32hi */
    case 944:  /* *pred_broadcastvnx16hi */
    case 943:  /* *pred_broadcastvnx8hi */
    case 942:  /* *pred_broadcastvnx4hi */
    case 941:  /* *pred_broadcastvnx2hi */
    case 940:  /* *pred_broadcastvnx1hi */
    case 939:  /* *pred_broadcastvnx64qi */
    case 938:  /* *pred_broadcastvnx32qi */
    case 937:  /* *pred_broadcastvnx16qi */
    case 936:  /* *pred_broadcastvnx8qi */
    case 935:  /* *pred_broadcastvnx4qi */
    case 934:  /* *pred_broadcastvnx2qi */
    case 933:  /* *pred_broadcastvnx1qi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 
#line 264 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ta(operands[5]));
        }
      else
        {
	  if (
#line 239 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(VECTOR_MODE_P (GET_MODE (operands[3]))))
	    {
	      return 
#line 270 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ta(operands[6]));
	    }
	  else
	    {
	      return 
#line 264 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ta(operands[5]));
	    }
        }

    case 830:  /* pred_movvnx8df */
    case 829:  /* pred_movvnx4df */
    case 828:  /* pred_movvnx2df */
    case 827:  /* pred_movvnx1df */
    case 826:  /* pred_movvnx16sf */
    case 825:  /* pred_movvnx8sf */
    case 824:  /* pred_movvnx4sf */
    case 823:  /* pred_movvnx2sf */
    case 822:  /* pred_movvnx1sf */
    case 821:  /* pred_movvnx8di */
    case 820:  /* pred_movvnx4di */
    case 819:  /* pred_movvnx2di */
    case 818:  /* pred_movvnx1di */
    case 817:  /* pred_movvnx16si */
    case 816:  /* pred_movvnx8si */
    case 815:  /* pred_movvnx4si */
    case 814:  /* pred_movvnx2si */
    case 813:  /* pred_movvnx1si */
    case 812:  /* pred_movvnx32hi */
    case 811:  /* pred_movvnx16hi */
    case 810:  /* pred_movvnx8hi */
    case 809:  /* pred_movvnx4hi */
    case 808:  /* pred_movvnx2hi */
    case 807:  /* pred_movvnx1hi */
    case 806:  /* pred_movvnx64qi */
    case 805:  /* pred_movvnx32qi */
    case 804:  /* pred_movvnx16qi */
    case 803:  /* pred_movvnx8qi */
    case 802:  /* pred_movvnx4qi */
    case 801:  /* pred_movvnx2qi */
    case 800:  /* pred_movvnx1qi */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 3)
        {
	  return 
#line 264 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ta(operands[5]));
        }
      else
        {
	  return 255 /* 0xff */;
        }

    case 6036:  /* read_vldi_zero_extend */
    case 6035:  /* read_vlsi */
    case 5779:  /* *pred_extract_firstvnx8df */
    case 5778:  /* *pred_extract_firstvnx4df */
    case 5777:  /* *pred_extract_firstvnx2df */
    case 5776:  /* *pred_extract_firstvnx1df */
    case 5775:  /* *pred_extract_firstvnx16sf */
    case 5774:  /* *pred_extract_firstvnx8sf */
    case 5773:  /* *pred_extract_firstvnx4sf */
    case 5772:  /* *pred_extract_firstvnx2sf */
    case 5771:  /* *pred_extract_firstvnx1sf */
    case 5770:  /* pred_extract_first_truncvnx8di */
    case 5769:  /* pred_extract_first_truncvnx4di */
    case 5768:  /* pred_extract_first_truncvnx2di */
    case 5767:  /* pred_extract_first_truncvnx1di */
    case 5766:  /* *pred_extract_firstvnx8di */
    case 5765:  /* *pred_extract_firstvnx4di */
    case 5764:  /* *pred_extract_firstvnx2di */
    case 5763:  /* *pred_extract_firstvnx1di */
    case 5762:  /* *pred_extract_firstvnx16si */
    case 5761:  /* *pred_extract_firstvnx8si */
    case 5760:  /* *pred_extract_firstvnx4si */
    case 5759:  /* *pred_extract_firstvnx2si */
    case 5758:  /* *pred_extract_firstvnx1si */
    case 5757:  /* *pred_extract_firstvnx32hi */
    case 5756:  /* *pred_extract_firstvnx16hi */
    case 5755:  /* *pred_extract_firstvnx8hi */
    case 5754:  /* *pred_extract_firstvnx4hi */
    case 5753:  /* *pred_extract_firstvnx2hi */
    case 5752:  /* *pred_extract_firstvnx1hi */
    case 5751:  /* *pred_extract_firstvnx64qi */
    case 5750:  /* *pred_extract_firstvnx32qi */
    case 5749:  /* *pred_extract_firstvnx16qi */
    case 5748:  /* *pred_extract_firstvnx8qi */
    case 5747:  /* *pred_extract_firstvnx4qi */
    case 5746:  /* *pred_extract_firstvnx2qi */
    case 5745:  /* *pred_extract_firstvnx1qi */
    case 5175:  /* *pred_eqnevnx8df_scalar_narrow */
    case 5174:  /* *pred_eqnevnx4df_scalar_narrow */
    case 5173:  /* *pred_eqnevnx2df_scalar_narrow */
    case 5172:  /* *pred_eqnevnx1df_scalar_narrow */
    case 5171:  /* *pred_eqnevnx16sf_scalar_narrow */
    case 5170:  /* *pred_eqnevnx8sf_scalar_narrow */
    case 5169:  /* *pred_eqnevnx4sf_scalar_narrow */
    case 5168:  /* *pred_eqnevnx2sf_scalar_narrow */
    case 5167:  /* *pred_eqnevnx1sf_scalar_narrow */
    case 5166:  /* *pred_eqnevnx8df_scalar */
    case 5165:  /* *pred_eqnevnx4df_scalar */
    case 5164:  /* *pred_eqnevnx2df_scalar */
    case 5163:  /* *pred_eqnevnx1df_scalar */
    case 5162:  /* *pred_eqnevnx16sf_scalar */
    case 5161:  /* *pred_eqnevnx8sf_scalar */
    case 5160:  /* *pred_eqnevnx4sf_scalar */
    case 5159:  /* *pred_eqnevnx2sf_scalar */
    case 5158:  /* *pred_eqnevnx1sf_scalar */
    case 5157:  /* *pred_cmpvnx8df_scalar_narrow */
    case 5156:  /* *pred_cmpvnx4df_scalar_narrow */
    case 5155:  /* *pred_cmpvnx2df_scalar_narrow */
    case 5154:  /* *pred_cmpvnx1df_scalar_narrow */
    case 5153:  /* *pred_cmpvnx16sf_scalar_narrow */
    case 5152:  /* *pred_cmpvnx8sf_scalar_narrow */
    case 5151:  /* *pred_cmpvnx4sf_scalar_narrow */
    case 5150:  /* *pred_cmpvnx2sf_scalar_narrow */
    case 5149:  /* *pred_cmpvnx1sf_scalar_narrow */
    case 5148:  /* *pred_cmpvnx8df_scalar */
    case 5147:  /* *pred_cmpvnx4df_scalar */
    case 5146:  /* *pred_cmpvnx2df_scalar */
    case 5145:  /* *pred_cmpvnx1df_scalar */
    case 5144:  /* *pred_cmpvnx16sf_scalar */
    case 5143:  /* *pred_cmpvnx8sf_scalar */
    case 5142:  /* *pred_cmpvnx4sf_scalar */
    case 5141:  /* *pred_cmpvnx2sf_scalar */
    case 5140:  /* *pred_cmpvnx1sf_scalar */
    case 5139:  /* *pred_cmpvnx8df_narrow */
    case 5138:  /* *pred_cmpvnx4df_narrow */
    case 5137:  /* *pred_cmpvnx2df_narrow */
    case 5136:  /* *pred_cmpvnx1df_narrow */
    case 5135:  /* *pred_cmpvnx16sf_narrow */
    case 5134:  /* *pred_cmpvnx8sf_narrow */
    case 5133:  /* *pred_cmpvnx4sf_narrow */
    case 5132:  /* *pred_cmpvnx2sf_narrow */
    case 5131:  /* *pred_cmpvnx1sf_narrow */
    case 5130:  /* *pred_cmpvnx8df */
    case 5129:  /* *pred_cmpvnx4df */
    case 5128:  /* *pred_cmpvnx2df */
    case 5127:  /* *pred_cmpvnx1df */
    case 5126:  /* *pred_cmpvnx16sf */
    case 5125:  /* *pred_cmpvnx8sf */
    case 5124:  /* *pred_cmpvnx4sf */
    case 5123:  /* *pred_cmpvnx2sf */
    case 5122:  /* *pred_cmpvnx1sf */
    case 4555:  /* pred_sofvnx64bi */
    case 4554:  /* pred_sifvnx64bi */
    case 4553:  /* pred_sbfvnx64bi */
    case 4552:  /* pred_sofvnx32bi */
    case 4551:  /* pred_sifvnx32bi */
    case 4550:  /* pred_sbfvnx32bi */
    case 4549:  /* pred_sofvnx16bi */
    case 4548:  /* pred_sifvnx16bi */
    case 4547:  /* pred_sbfvnx16bi */
    case 4546:  /* pred_sofvnx8bi */
    case 4545:  /* pred_sifvnx8bi */
    case 4544:  /* pred_sbfvnx8bi */
    case 4543:  /* pred_sofvnx4bi */
    case 4542:  /* pred_sifvnx4bi */
    case 4541:  /* pred_sbfvnx4bi */
    case 4540:  /* pred_sofvnx2bi */
    case 4539:  /* pred_sifvnx2bi */
    case 4538:  /* pred_sbfvnx2bi */
    case 4537:  /* pred_sofvnx1bi */
    case 4536:  /* pred_sifvnx1bi */
    case 4535:  /* pred_sbfvnx1bi */
    case 4534:  /* pred_ffsvnx64bidi */
    case 4533:  /* pred_ffsvnx32bidi */
    case 4532:  /* pred_ffsvnx16bidi */
    case 4531:  /* pred_ffsvnx8bidi */
    case 4530:  /* pred_ffsvnx4bidi */
    case 4529:  /* pred_ffsvnx2bidi */
    case 4528:  /* pred_ffsvnx1bidi */
    case 4527:  /* pred_ffsvnx64bisi */
    case 4526:  /* pred_ffsvnx32bisi */
    case 4525:  /* pred_ffsvnx16bisi */
    case 4524:  /* pred_ffsvnx8bisi */
    case 4523:  /* pred_ffsvnx4bisi */
    case 4522:  /* pred_ffsvnx2bisi */
    case 4521:  /* pred_ffsvnx1bisi */
    case 4520:  /* pred_popcountvnx64bidi */
    case 4519:  /* pred_popcountvnx32bidi */
    case 4518:  /* pred_popcountvnx16bidi */
    case 4517:  /* pred_popcountvnx8bidi */
    case 4516:  /* pred_popcountvnx4bidi */
    case 4515:  /* pred_popcountvnx2bidi */
    case 4514:  /* pred_popcountvnx1bidi */
    case 4513:  /* pred_popcountvnx64bisi */
    case 4512:  /* pred_popcountvnx32bisi */
    case 4511:  /* pred_popcountvnx16bisi */
    case 4510:  /* pred_popcountvnx8bisi */
    case 4509:  /* pred_popcountvnx4bisi */
    case 4508:  /* pred_popcountvnx2bisi */
    case 4507:  /* pred_popcountvnx1bisi */
    case 4506:  /* pred_notvnx64bi */
    case 4505:  /* pred_notvnx32bi */
    case 4504:  /* pred_notvnx16bi */
    case 4503:  /* pred_notvnx8bi */
    case 4502:  /* pred_notvnx4bi */
    case 4501:  /* pred_notvnx2bi */
    case 4500:  /* pred_notvnx1bi */
    case 4499:  /* pred_iornotvnx64bi */
    case 4498:  /* pred_andnotvnx64bi */
    case 4497:  /* pred_iornotvnx32bi */
    case 4496:  /* pred_andnotvnx32bi */
    case 4495:  /* pred_iornotvnx16bi */
    case 4494:  /* pred_andnotvnx16bi */
    case 4493:  /* pred_iornotvnx8bi */
    case 4492:  /* pred_andnotvnx8bi */
    case 4491:  /* pred_iornotvnx4bi */
    case 4490:  /* pred_andnotvnx4bi */
    case 4489:  /* pred_iornotvnx2bi */
    case 4488:  /* pred_andnotvnx2bi */
    case 4487:  /* pred_iornotvnx1bi */
    case 4486:  /* pred_andnotvnx1bi */
    case 4485:  /* pred_nxorvnx64bi */
    case 4484:  /* pred_niorvnx64bi */
    case 4483:  /* pred_nandvnx64bi */
    case 4482:  /* pred_nxorvnx32bi */
    case 4481:  /* pred_niorvnx32bi */
    case 4480:  /* pred_nandvnx32bi */
    case 4479:  /* pred_nxorvnx16bi */
    case 4478:  /* pred_niorvnx16bi */
    case 4477:  /* pred_nandvnx16bi */
    case 4476:  /* pred_nxorvnx8bi */
    case 4475:  /* pred_niorvnx8bi */
    case 4474:  /* pred_nandvnx8bi */
    case 4473:  /* pred_nxorvnx4bi */
    case 4472:  /* pred_niorvnx4bi */
    case 4471:  /* pred_nandvnx4bi */
    case 4470:  /* pred_nxorvnx2bi */
    case 4469:  /* pred_niorvnx2bi */
    case 4468:  /* pred_nandvnx2bi */
    case 4467:  /* pred_nxorvnx1bi */
    case 4466:  /* pred_niorvnx1bi */
    case 4465:  /* pred_nandvnx1bi */
    case 4464:  /* pred_xorvnx64bi */
    case 4463:  /* pred_iorvnx64bi */
    case 4462:  /* pred_andvnx64bi */
    case 4461:  /* pred_xorvnx32bi */
    case 4460:  /* pred_iorvnx32bi */
    case 4459:  /* pred_andvnx32bi */
    case 4458:  /* pred_xorvnx16bi */
    case 4457:  /* pred_iorvnx16bi */
    case 4456:  /* pred_andvnx16bi */
    case 4455:  /* pred_xorvnx8bi */
    case 4454:  /* pred_iorvnx8bi */
    case 4453:  /* pred_andvnx8bi */
    case 4452:  /* pred_xorvnx4bi */
    case 4451:  /* pred_iorvnx4bi */
    case 4450:  /* pred_andvnx4bi */
    case 4449:  /* pred_xorvnx2bi */
    case 4448:  /* pred_iorvnx2bi */
    case 4447:  /* pred_andvnx2bi */
    case 4446:  /* pred_xorvnx1bi */
    case 4445:  /* pred_iorvnx1bi */
    case 4444:  /* pred_andvnx1bi */
    case 4050:  /* *pred_eqnevnx8di_extended_scalar_narrow */
    case 4049:  /* *pred_eqnevnx4di_extended_scalar_narrow */
    case 4048:  /* *pred_eqnevnx2di_extended_scalar_narrow */
    case 4047:  /* *pred_eqnevnx1di_extended_scalar_narrow */
    case 4046:  /* *pred_eqnevnx8di_extended_scalar */
    case 4045:  /* *pred_eqnevnx4di_extended_scalar */
    case 4044:  /* *pred_eqnevnx2di_extended_scalar */
    case 4043:  /* *pred_eqnevnx1di_extended_scalar */
    case 4042:  /* *pred_cmpvnx8di_extended_scalar_narrow */
    case 4041:  /* *pred_cmpvnx4di_extended_scalar_narrow */
    case 4040:  /* *pred_cmpvnx2di_extended_scalar_narrow */
    case 4039:  /* *pred_cmpvnx1di_extended_scalar_narrow */
    case 4038:  /* *pred_cmpvnx8di_extended_scalar */
    case 4037:  /* *pred_cmpvnx4di_extended_scalar */
    case 4036:  /* *pred_cmpvnx2di_extended_scalar */
    case 4035:  /* *pred_cmpvnx1di_extended_scalar */
    case 4034:  /* *pred_eqnevnx8di_scalar_narrow */
    case 4033:  /* *pred_eqnevnx4di_scalar_narrow */
    case 4032:  /* *pred_eqnevnx2di_scalar_narrow */
    case 4031:  /* *pred_eqnevnx1di_scalar_narrow */
    case 4030:  /* *pred_eqnevnx8di_scalar */
    case 4029:  /* *pred_eqnevnx4di_scalar */
    case 4028:  /* *pred_eqnevnx2di_scalar */
    case 4027:  /* *pred_eqnevnx1di_scalar */
    case 4026:  /* *pred_cmpvnx8di_scalar_narrow */
    case 4025:  /* *pred_cmpvnx4di_scalar_narrow */
    case 4024:  /* *pred_cmpvnx2di_scalar_narrow */
    case 4023:  /* *pred_cmpvnx1di_scalar_narrow */
    case 4022:  /* *pred_cmpvnx8di_scalar */
    case 4021:  /* *pred_cmpvnx4di_scalar */
    case 4020:  /* *pred_cmpvnx2di_scalar */
    case 4019:  /* *pred_cmpvnx1di_scalar */
    case 4018:  /* *pred_eqnevnx16si_scalar_narrow */
    case 4017:  /* *pred_eqnevnx8si_scalar_narrow */
    case 4016:  /* *pred_eqnevnx4si_scalar_narrow */
    case 4015:  /* *pred_eqnevnx2si_scalar_narrow */
    case 4014:  /* *pred_eqnevnx1si_scalar_narrow */
    case 4013:  /* *pred_eqnevnx32hi_scalar_narrow */
    case 4012:  /* *pred_eqnevnx16hi_scalar_narrow */
    case 4011:  /* *pred_eqnevnx8hi_scalar_narrow */
    case 4010:  /* *pred_eqnevnx4hi_scalar_narrow */
    case 4009:  /* *pred_eqnevnx2hi_scalar_narrow */
    case 4008:  /* *pred_eqnevnx1hi_scalar_narrow */
    case 4007:  /* *pred_eqnevnx64qi_scalar_narrow */
    case 4006:  /* *pred_eqnevnx32qi_scalar_narrow */
    case 4005:  /* *pred_eqnevnx16qi_scalar_narrow */
    case 4004:  /* *pred_eqnevnx8qi_scalar_narrow */
    case 4003:  /* *pred_eqnevnx4qi_scalar_narrow */
    case 4002:  /* *pred_eqnevnx2qi_scalar_narrow */
    case 4001:  /* *pred_eqnevnx1qi_scalar_narrow */
    case 4000:  /* *pred_eqnevnx16si_scalar */
    case 3999:  /* *pred_eqnevnx8si_scalar */
    case 3998:  /* *pred_eqnevnx4si_scalar */
    case 3997:  /* *pred_eqnevnx2si_scalar */
    case 3996:  /* *pred_eqnevnx1si_scalar */
    case 3995:  /* *pred_eqnevnx32hi_scalar */
    case 3994:  /* *pred_eqnevnx16hi_scalar */
    case 3993:  /* *pred_eqnevnx8hi_scalar */
    case 3992:  /* *pred_eqnevnx4hi_scalar */
    case 3991:  /* *pred_eqnevnx2hi_scalar */
    case 3990:  /* *pred_eqnevnx1hi_scalar */
    case 3989:  /* *pred_eqnevnx64qi_scalar */
    case 3988:  /* *pred_eqnevnx32qi_scalar */
    case 3987:  /* *pred_eqnevnx16qi_scalar */
    case 3986:  /* *pred_eqnevnx8qi_scalar */
    case 3985:  /* *pred_eqnevnx4qi_scalar */
    case 3984:  /* *pred_eqnevnx2qi_scalar */
    case 3983:  /* *pred_eqnevnx1qi_scalar */
    case 3982:  /* *pred_cmpvnx16si_scalar_narrow */
    case 3981:  /* *pred_cmpvnx8si_scalar_narrow */
    case 3980:  /* *pred_cmpvnx4si_scalar_narrow */
    case 3979:  /* *pred_cmpvnx2si_scalar_narrow */
    case 3978:  /* *pred_cmpvnx1si_scalar_narrow */
    case 3977:  /* *pred_cmpvnx32hi_scalar_narrow */
    case 3976:  /* *pred_cmpvnx16hi_scalar_narrow */
    case 3975:  /* *pred_cmpvnx8hi_scalar_narrow */
    case 3974:  /* *pred_cmpvnx4hi_scalar_narrow */
    case 3973:  /* *pred_cmpvnx2hi_scalar_narrow */
    case 3972:  /* *pred_cmpvnx1hi_scalar_narrow */
    case 3971:  /* *pred_cmpvnx64qi_scalar_narrow */
    case 3970:  /* *pred_cmpvnx32qi_scalar_narrow */
    case 3969:  /* *pred_cmpvnx16qi_scalar_narrow */
    case 3968:  /* *pred_cmpvnx8qi_scalar_narrow */
    case 3967:  /* *pred_cmpvnx4qi_scalar_narrow */
    case 3966:  /* *pred_cmpvnx2qi_scalar_narrow */
    case 3965:  /* *pred_cmpvnx1qi_scalar_narrow */
    case 3964:  /* *pred_cmpvnx16si_scalar */
    case 3963:  /* *pred_cmpvnx8si_scalar */
    case 3962:  /* *pred_cmpvnx4si_scalar */
    case 3961:  /* *pred_cmpvnx2si_scalar */
    case 3960:  /* *pred_cmpvnx1si_scalar */
    case 3959:  /* *pred_cmpvnx32hi_scalar */
    case 3958:  /* *pred_cmpvnx16hi_scalar */
    case 3957:  /* *pred_cmpvnx8hi_scalar */
    case 3956:  /* *pred_cmpvnx4hi_scalar */
    case 3955:  /* *pred_cmpvnx2hi_scalar */
    case 3954:  /* *pred_cmpvnx1hi_scalar */
    case 3953:  /* *pred_cmpvnx64qi_scalar */
    case 3952:  /* *pred_cmpvnx32qi_scalar */
    case 3951:  /* *pred_cmpvnx16qi_scalar */
    case 3950:  /* *pred_cmpvnx8qi_scalar */
    case 3949:  /* *pred_cmpvnx4qi_scalar */
    case 3948:  /* *pred_cmpvnx2qi_scalar */
    case 3947:  /* *pred_cmpvnx1qi_scalar */
    case 3946:  /* *pred_ltgevnx8di_narrow */
    case 3945:  /* *pred_ltgevnx4di_narrow */
    case 3944:  /* *pred_ltgevnx2di_narrow */
    case 3943:  /* *pred_ltgevnx1di_narrow */
    case 3942:  /* *pred_ltgevnx16si_narrow */
    case 3941:  /* *pred_ltgevnx8si_narrow */
    case 3940:  /* *pred_ltgevnx4si_narrow */
    case 3939:  /* *pred_ltgevnx2si_narrow */
    case 3938:  /* *pred_ltgevnx1si_narrow */
    case 3937:  /* *pred_ltgevnx32hi_narrow */
    case 3936:  /* *pred_ltgevnx16hi_narrow */
    case 3935:  /* *pred_ltgevnx8hi_narrow */
    case 3934:  /* *pred_ltgevnx4hi_narrow */
    case 3933:  /* *pred_ltgevnx2hi_narrow */
    case 3932:  /* *pred_ltgevnx1hi_narrow */
    case 3931:  /* *pred_ltgevnx64qi_narrow */
    case 3930:  /* *pred_ltgevnx32qi_narrow */
    case 3929:  /* *pred_ltgevnx16qi_narrow */
    case 3928:  /* *pred_ltgevnx8qi_narrow */
    case 3927:  /* *pred_ltgevnx4qi_narrow */
    case 3926:  /* *pred_ltgevnx2qi_narrow */
    case 3925:  /* *pred_ltgevnx1qi_narrow */
    case 3924:  /* *pred_ltgevnx8di */
    case 3923:  /* *pred_ltgevnx4di */
    case 3922:  /* *pred_ltgevnx2di */
    case 3921:  /* *pred_ltgevnx1di */
    case 3920:  /* *pred_ltgevnx16si */
    case 3919:  /* *pred_ltgevnx8si */
    case 3918:  /* *pred_ltgevnx4si */
    case 3917:  /* *pred_ltgevnx2si */
    case 3916:  /* *pred_ltgevnx1si */
    case 3915:  /* *pred_ltgevnx32hi */
    case 3914:  /* *pred_ltgevnx16hi */
    case 3913:  /* *pred_ltgevnx8hi */
    case 3912:  /* *pred_ltgevnx4hi */
    case 3911:  /* *pred_ltgevnx2hi */
    case 3910:  /* *pred_ltgevnx1hi */
    case 3909:  /* *pred_ltgevnx64qi */
    case 3908:  /* *pred_ltgevnx32qi */
    case 3907:  /* *pred_ltgevnx16qi */
    case 3906:  /* *pred_ltgevnx8qi */
    case 3905:  /* *pred_ltgevnx4qi */
    case 3904:  /* *pred_ltgevnx2qi */
    case 3903:  /* *pred_ltgevnx1qi */
    case 3902:  /* *pred_cmpvnx8di_narrow */
    case 3901:  /* *pred_cmpvnx4di_narrow */
    case 3900:  /* *pred_cmpvnx2di_narrow */
    case 3899:  /* *pred_cmpvnx1di_narrow */
    case 3898:  /* *pred_cmpvnx16si_narrow */
    case 3897:  /* *pred_cmpvnx8si_narrow */
    case 3896:  /* *pred_cmpvnx4si_narrow */
    case 3895:  /* *pred_cmpvnx2si_narrow */
    case 3894:  /* *pred_cmpvnx1si_narrow */
    case 3893:  /* *pred_cmpvnx32hi_narrow */
    case 3892:  /* *pred_cmpvnx16hi_narrow */
    case 3891:  /* *pred_cmpvnx8hi_narrow */
    case 3890:  /* *pred_cmpvnx4hi_narrow */
    case 3889:  /* *pred_cmpvnx2hi_narrow */
    case 3888:  /* *pred_cmpvnx1hi_narrow */
    case 3887:  /* *pred_cmpvnx64qi_narrow */
    case 3886:  /* *pred_cmpvnx32qi_narrow */
    case 3885:  /* *pred_cmpvnx16qi_narrow */
    case 3884:  /* *pred_cmpvnx8qi_narrow */
    case 3883:  /* *pred_cmpvnx4qi_narrow */
    case 3882:  /* *pred_cmpvnx2qi_narrow */
    case 3881:  /* *pred_cmpvnx1qi_narrow */
    case 3880:  /* *pred_cmpvnx8di */
    case 3879:  /* *pred_cmpvnx4di */
    case 3878:  /* *pred_cmpvnx2di */
    case 3877:  /* *pred_cmpvnx1di */
    case 3876:  /* *pred_cmpvnx16si */
    case 3875:  /* *pred_cmpvnx8si */
    case 3874:  /* *pred_cmpvnx4si */
    case 3873:  /* *pred_cmpvnx2si */
    case 3872:  /* *pred_cmpvnx1si */
    case 3871:  /* *pred_cmpvnx32hi */
    case 3870:  /* *pred_cmpvnx16hi */
    case 3869:  /* *pred_cmpvnx8hi */
    case 3868:  /* *pred_cmpvnx4hi */
    case 3867:  /* *pred_cmpvnx2hi */
    case 3866:  /* *pred_cmpvnx1hi */
    case 3865:  /* *pred_cmpvnx64qi */
    case 3864:  /* *pred_cmpvnx32qi */
    case 3863:  /* *pred_cmpvnx16qi */
    case 3862:  /* *pred_cmpvnx8qi */
    case 3861:  /* *pred_cmpvnx4qi */
    case 3860:  /* *pred_cmpvnx2qi */
    case 3859:  /* *pred_cmpvnx1qi */
    case 2743:  /* *pred_msbcvnx8di_overflow_extended_scalar */
    case 2742:  /* *pred_msbcvnx4di_overflow_extended_scalar */
    case 2741:  /* *pred_msbcvnx2di_overflow_extended_scalar */
    case 2740:  /* *pred_msbcvnx1di_overflow_extended_scalar */
    case 2739:  /* *pred_msbcvnx8di_overflow_scalar */
    case 2738:  /* *pred_msbcvnx4di_overflow_scalar */
    case 2737:  /* *pred_msbcvnx2di_overflow_scalar */
    case 2736:  /* *pred_msbcvnx1di_overflow_scalar */
    case 2735:  /* *pred_madcvnx8di_overflow_extended_scalar */
    case 2734:  /* *pred_madcvnx4di_overflow_extended_scalar */
    case 2733:  /* *pred_madcvnx2di_overflow_extended_scalar */
    case 2732:  /* *pred_madcvnx1di_overflow_extended_scalar */
    case 2731:  /* *pred_madcvnx8di_overflow_scalar */
    case 2730:  /* *pred_madcvnx4di_overflow_scalar */
    case 2729:  /* *pred_madcvnx2di_overflow_scalar */
    case 2728:  /* *pred_madcvnx1di_overflow_scalar */
    case 2727:  /* pred_msbcvnx16si_overflow_scalar */
    case 2726:  /* pred_msbcvnx8si_overflow_scalar */
    case 2725:  /* pred_msbcvnx4si_overflow_scalar */
    case 2724:  /* pred_msbcvnx2si_overflow_scalar */
    case 2723:  /* pred_msbcvnx1si_overflow_scalar */
    case 2722:  /* pred_msbcvnx32hi_overflow_scalar */
    case 2721:  /* pred_msbcvnx16hi_overflow_scalar */
    case 2720:  /* pred_msbcvnx8hi_overflow_scalar */
    case 2719:  /* pred_msbcvnx4hi_overflow_scalar */
    case 2718:  /* pred_msbcvnx2hi_overflow_scalar */
    case 2717:  /* pred_msbcvnx1hi_overflow_scalar */
    case 2716:  /* pred_msbcvnx64qi_overflow_scalar */
    case 2715:  /* pred_msbcvnx32qi_overflow_scalar */
    case 2714:  /* pred_msbcvnx16qi_overflow_scalar */
    case 2713:  /* pred_msbcvnx8qi_overflow_scalar */
    case 2712:  /* pred_msbcvnx4qi_overflow_scalar */
    case 2711:  /* pred_msbcvnx2qi_overflow_scalar */
    case 2710:  /* pred_msbcvnx1qi_overflow_scalar */
    case 2709:  /* pred_madcvnx16si_overflow_scalar */
    case 2708:  /* pred_madcvnx8si_overflow_scalar */
    case 2707:  /* pred_madcvnx4si_overflow_scalar */
    case 2706:  /* pred_madcvnx2si_overflow_scalar */
    case 2705:  /* pred_madcvnx1si_overflow_scalar */
    case 2704:  /* pred_madcvnx32hi_overflow_scalar */
    case 2703:  /* pred_madcvnx16hi_overflow_scalar */
    case 2702:  /* pred_madcvnx8hi_overflow_scalar */
    case 2701:  /* pred_madcvnx4hi_overflow_scalar */
    case 2700:  /* pred_madcvnx2hi_overflow_scalar */
    case 2699:  /* pred_madcvnx1hi_overflow_scalar */
    case 2698:  /* pred_madcvnx64qi_overflow_scalar */
    case 2697:  /* pred_madcvnx32qi_overflow_scalar */
    case 2696:  /* pred_madcvnx16qi_overflow_scalar */
    case 2695:  /* pred_madcvnx8qi_overflow_scalar */
    case 2694:  /* pred_madcvnx4qi_overflow_scalar */
    case 2693:  /* pred_madcvnx2qi_overflow_scalar */
    case 2692:  /* pred_madcvnx1qi_overflow_scalar */
    case 2691:  /* pred_msbcvnx8di_overflow */
    case 2690:  /* pred_msbcvnx4di_overflow */
    case 2689:  /* pred_msbcvnx2di_overflow */
    case 2688:  /* pred_msbcvnx1di_overflow */
    case 2687:  /* pred_msbcvnx16si_overflow */
    case 2686:  /* pred_msbcvnx8si_overflow */
    case 2685:  /* pred_msbcvnx4si_overflow */
    case 2684:  /* pred_msbcvnx2si_overflow */
    case 2683:  /* pred_msbcvnx1si_overflow */
    case 2682:  /* pred_msbcvnx32hi_overflow */
    case 2681:  /* pred_msbcvnx16hi_overflow */
    case 2680:  /* pred_msbcvnx8hi_overflow */
    case 2679:  /* pred_msbcvnx4hi_overflow */
    case 2678:  /* pred_msbcvnx2hi_overflow */
    case 2677:  /* pred_msbcvnx1hi_overflow */
    case 2676:  /* pred_msbcvnx64qi_overflow */
    case 2675:  /* pred_msbcvnx32qi_overflow */
    case 2674:  /* pred_msbcvnx16qi_overflow */
    case 2673:  /* pred_msbcvnx8qi_overflow */
    case 2672:  /* pred_msbcvnx4qi_overflow */
    case 2671:  /* pred_msbcvnx2qi_overflow */
    case 2670:  /* pred_msbcvnx1qi_overflow */
    case 2669:  /* pred_madcvnx8di_overflow */
    case 2668:  /* pred_madcvnx4di_overflow */
    case 2667:  /* pred_madcvnx2di_overflow */
    case 2666:  /* pred_madcvnx1di_overflow */
    case 2665:  /* pred_madcvnx16si_overflow */
    case 2664:  /* pred_madcvnx8si_overflow */
    case 2663:  /* pred_madcvnx4si_overflow */
    case 2662:  /* pred_madcvnx2si_overflow */
    case 2661:  /* pred_madcvnx1si_overflow */
    case 2660:  /* pred_madcvnx32hi_overflow */
    case 2659:  /* pred_madcvnx16hi_overflow */
    case 2658:  /* pred_madcvnx8hi_overflow */
    case 2657:  /* pred_madcvnx4hi_overflow */
    case 2656:  /* pred_madcvnx2hi_overflow */
    case 2655:  /* pred_madcvnx1hi_overflow */
    case 2654:  /* pred_madcvnx64qi_overflow */
    case 2653:  /* pred_madcvnx32qi_overflow */
    case 2652:  /* pred_madcvnx16qi_overflow */
    case 2651:  /* pred_madcvnx8qi_overflow */
    case 2650:  /* pred_madcvnx4qi_overflow */
    case 2649:  /* pred_madcvnx2qi_overflow */
    case 2648:  /* pred_madcvnx1qi_overflow */
    case 2647:  /* *pred_msbcvnx8di_extended_scalar */
    case 2646:  /* *pred_msbcvnx4di_extended_scalar */
    case 2645:  /* *pred_msbcvnx2di_extended_scalar */
    case 2644:  /* *pred_msbcvnx1di_extended_scalar */
    case 2643:  /* *pred_msbcvnx8di_scalar */
    case 2642:  /* *pred_msbcvnx4di_scalar */
    case 2641:  /* *pred_msbcvnx2di_scalar */
    case 2640:  /* *pred_msbcvnx1di_scalar */
    case 2639:  /* *pred_madcvnx8di_extended_scalar */
    case 2638:  /* *pred_madcvnx4di_extended_scalar */
    case 2637:  /* *pred_madcvnx2di_extended_scalar */
    case 2636:  /* *pred_madcvnx1di_extended_scalar */
    case 2635:  /* *pred_madcvnx8di_scalar */
    case 2634:  /* *pred_madcvnx4di_scalar */
    case 2633:  /* *pred_madcvnx2di_scalar */
    case 2632:  /* *pred_madcvnx1di_scalar */
    case 2631:  /* pred_msbcvnx16si_scalar */
    case 2630:  /* pred_msbcvnx8si_scalar */
    case 2629:  /* pred_msbcvnx4si_scalar */
    case 2628:  /* pred_msbcvnx2si_scalar */
    case 2627:  /* pred_msbcvnx1si_scalar */
    case 2626:  /* pred_msbcvnx32hi_scalar */
    case 2625:  /* pred_msbcvnx16hi_scalar */
    case 2624:  /* pred_msbcvnx8hi_scalar */
    case 2623:  /* pred_msbcvnx4hi_scalar */
    case 2622:  /* pred_msbcvnx2hi_scalar */
    case 2621:  /* pred_msbcvnx1hi_scalar */
    case 2620:  /* pred_msbcvnx64qi_scalar */
    case 2619:  /* pred_msbcvnx32qi_scalar */
    case 2618:  /* pred_msbcvnx16qi_scalar */
    case 2617:  /* pred_msbcvnx8qi_scalar */
    case 2616:  /* pred_msbcvnx4qi_scalar */
    case 2615:  /* pred_msbcvnx2qi_scalar */
    case 2614:  /* pred_msbcvnx1qi_scalar */
    case 2613:  /* pred_madcvnx16si_scalar */
    case 2612:  /* pred_madcvnx8si_scalar */
    case 2611:  /* pred_madcvnx4si_scalar */
    case 2610:  /* pred_madcvnx2si_scalar */
    case 2609:  /* pred_madcvnx1si_scalar */
    case 2608:  /* pred_madcvnx32hi_scalar */
    case 2607:  /* pred_madcvnx16hi_scalar */
    case 2606:  /* pred_madcvnx8hi_scalar */
    case 2605:  /* pred_madcvnx4hi_scalar */
    case 2604:  /* pred_madcvnx2hi_scalar */
    case 2603:  /* pred_madcvnx1hi_scalar */
    case 2602:  /* pred_madcvnx64qi_scalar */
    case 2601:  /* pred_madcvnx32qi_scalar */
    case 2600:  /* pred_madcvnx16qi_scalar */
    case 2599:  /* pred_madcvnx8qi_scalar */
    case 2598:  /* pred_madcvnx4qi_scalar */
    case 2597:  /* pred_madcvnx2qi_scalar */
    case 2596:  /* pred_madcvnx1qi_scalar */
    case 2595:  /* pred_msbcvnx8di */
    case 2594:  /* pred_msbcvnx4di */
    case 2593:  /* pred_msbcvnx2di */
    case 2592:  /* pred_msbcvnx1di */
    case 2591:  /* pred_msbcvnx16si */
    case 2590:  /* pred_msbcvnx8si */
    case 2589:  /* pred_msbcvnx4si */
    case 2588:  /* pred_msbcvnx2si */
    case 2587:  /* pred_msbcvnx1si */
    case 2586:  /* pred_msbcvnx32hi */
    case 2585:  /* pred_msbcvnx16hi */
    case 2584:  /* pred_msbcvnx8hi */
    case 2583:  /* pred_msbcvnx4hi */
    case 2582:  /* pred_msbcvnx2hi */
    case 2581:  /* pred_msbcvnx1hi */
    case 2580:  /* pred_msbcvnx64qi */
    case 2579:  /* pred_msbcvnx32qi */
    case 2578:  /* pred_msbcvnx16qi */
    case 2577:  /* pred_msbcvnx8qi */
    case 2576:  /* pred_msbcvnx4qi */
    case 2575:  /* pred_msbcvnx2qi */
    case 2574:  /* pred_msbcvnx1qi */
    case 2573:  /* pred_madcvnx8di */
    case 2572:  /* pred_madcvnx4di */
    case 2571:  /* pred_madcvnx2di */
    case 2570:  /* pred_madcvnx1di */
    case 2569:  /* pred_madcvnx16si */
    case 2568:  /* pred_madcvnx8si */
    case 2567:  /* pred_madcvnx4si */
    case 2566:  /* pred_madcvnx2si */
    case 2565:  /* pred_madcvnx1si */
    case 2564:  /* pred_madcvnx32hi */
    case 2563:  /* pred_madcvnx16hi */
    case 2562:  /* pred_madcvnx8hi */
    case 2561:  /* pred_madcvnx4hi */
    case 2560:  /* pred_madcvnx2hi */
    case 2559:  /* pred_madcvnx1hi */
    case 2558:  /* pred_madcvnx64qi */
    case 2557:  /* pred_madcvnx32qi */
    case 2556:  /* pred_madcvnx16qi */
    case 2555:  /* pred_madcvnx8qi */
    case 2554:  /* pred_madcvnx4qi */
    case 2553:  /* pred_madcvnx2qi */
    case 2552:  /* pred_madcvnx1qi */
    case 1481:  /* pred_indexed_ustorevnx64qivnx64qi */
    case 1480:  /* pred_indexed_ostorevnx64qivnx64qi */
    case 1479:  /* pred_indexed_ustorevnx32hivnx32hi */
    case 1478:  /* pred_indexed_ostorevnx32hivnx32hi */
    case 1477:  /* pred_indexed_ustorevnx32hivnx32qi */
    case 1476:  /* pred_indexed_ostorevnx32hivnx32qi */
    case 1475:  /* pred_indexed_ustorevnx32qivnx32hi */
    case 1474:  /* pred_indexed_ostorevnx32qivnx32hi */
    case 1473:  /* pred_indexed_ustorevnx32qivnx32qi */
    case 1472:  /* pred_indexed_ostorevnx32qivnx32qi */
    case 1471:  /* pred_indexed_ustorevnx16sfvnx16si */
    case 1470:  /* pred_indexed_ostorevnx16sfvnx16si */
    case 1469:  /* pred_indexed_ustorevnx16sivnx16si */
    case 1468:  /* pred_indexed_ostorevnx16sivnx16si */
    case 1467:  /* pred_indexed_ustorevnx16hivnx16si */
    case 1466:  /* pred_indexed_ostorevnx16hivnx16si */
    case 1465:  /* pred_indexed_ustorevnx16qivnx16si */
    case 1464:  /* pred_indexed_ostorevnx16qivnx16si */
    case 1463:  /* pred_indexed_ustorevnx16sfvnx16hi */
    case 1462:  /* pred_indexed_ostorevnx16sfvnx16hi */
    case 1461:  /* pred_indexed_ustorevnx16sivnx16hi */
    case 1460:  /* pred_indexed_ostorevnx16sivnx16hi */
    case 1459:  /* pred_indexed_ustorevnx16hivnx16hi */
    case 1458:  /* pred_indexed_ostorevnx16hivnx16hi */
    case 1457:  /* pred_indexed_ustorevnx16qivnx16hi */
    case 1456:  /* pred_indexed_ostorevnx16qivnx16hi */
    case 1455:  /* pred_indexed_ustorevnx16sfvnx16qi */
    case 1454:  /* pred_indexed_ostorevnx16sfvnx16qi */
    case 1453:  /* pred_indexed_ustorevnx16sivnx16qi */
    case 1452:  /* pred_indexed_ostorevnx16sivnx16qi */
    case 1451:  /* pred_indexed_ustorevnx16hivnx16qi */
    case 1450:  /* pred_indexed_ostorevnx16hivnx16qi */
    case 1449:  /* pred_indexed_ustorevnx16qivnx16qi */
    case 1448:  /* pred_indexed_ostorevnx16qivnx16qi */
    case 1447:  /* pred_indexed_ustorevnx8dfvnx8di */
    case 1446:  /* pred_indexed_ostorevnx8dfvnx8di */
    case 1445:  /* pred_indexed_ustorevnx8sfvnx8di */
    case 1444:  /* pred_indexed_ostorevnx8sfvnx8di */
    case 1443:  /* pred_indexed_ustorevnx8divnx8di */
    case 1442:  /* pred_indexed_ostorevnx8divnx8di */
    case 1441:  /* pred_indexed_ustorevnx8sivnx8di */
    case 1440:  /* pred_indexed_ostorevnx8sivnx8di */
    case 1439:  /* pred_indexed_ustorevnx8hivnx8di */
    case 1438:  /* pred_indexed_ostorevnx8hivnx8di */
    case 1437:  /* pred_indexed_ustorevnx8qivnx8di */
    case 1436:  /* pred_indexed_ostorevnx8qivnx8di */
    case 1435:  /* pred_indexed_ustorevnx8dfvnx8si */
    case 1434:  /* pred_indexed_ostorevnx8dfvnx8si */
    case 1433:  /* pred_indexed_ustorevnx8sfvnx8si */
    case 1432:  /* pred_indexed_ostorevnx8sfvnx8si */
    case 1431:  /* pred_indexed_ustorevnx8divnx8si */
    case 1430:  /* pred_indexed_ostorevnx8divnx8si */
    case 1429:  /* pred_indexed_ustorevnx8sivnx8si */
    case 1428:  /* pred_indexed_ostorevnx8sivnx8si */
    case 1427:  /* pred_indexed_ustorevnx8hivnx8si */
    case 1426:  /* pred_indexed_ostorevnx8hivnx8si */
    case 1425:  /* pred_indexed_ustorevnx8qivnx8si */
    case 1424:  /* pred_indexed_ostorevnx8qivnx8si */
    case 1423:  /* pred_indexed_ustorevnx8dfvnx8hi */
    case 1422:  /* pred_indexed_ostorevnx8dfvnx8hi */
    case 1421:  /* pred_indexed_ustorevnx8sfvnx8hi */
    case 1420:  /* pred_indexed_ostorevnx8sfvnx8hi */
    case 1419:  /* pred_indexed_ustorevnx8divnx8hi */
    case 1418:  /* pred_indexed_ostorevnx8divnx8hi */
    case 1417:  /* pred_indexed_ustorevnx8sivnx8hi */
    case 1416:  /* pred_indexed_ostorevnx8sivnx8hi */
    case 1415:  /* pred_indexed_ustorevnx8hivnx8hi */
    case 1414:  /* pred_indexed_ostorevnx8hivnx8hi */
    case 1413:  /* pred_indexed_ustorevnx8qivnx8hi */
    case 1412:  /* pred_indexed_ostorevnx8qivnx8hi */
    case 1411:  /* pred_indexed_ustorevnx8dfvnx8qi */
    case 1410:  /* pred_indexed_ostorevnx8dfvnx8qi */
    case 1409:  /* pred_indexed_ustorevnx8sfvnx8qi */
    case 1408:  /* pred_indexed_ostorevnx8sfvnx8qi */
    case 1407:  /* pred_indexed_ustorevnx8divnx8qi */
    case 1406:  /* pred_indexed_ostorevnx8divnx8qi */
    case 1405:  /* pred_indexed_ustorevnx8sivnx8qi */
    case 1404:  /* pred_indexed_ostorevnx8sivnx8qi */
    case 1403:  /* pred_indexed_ustorevnx8hivnx8qi */
    case 1402:  /* pred_indexed_ostorevnx8hivnx8qi */
    case 1401:  /* pred_indexed_ustorevnx8qivnx8qi */
    case 1400:  /* pred_indexed_ostorevnx8qivnx8qi */
    case 1399:  /* pred_indexed_ustorevnx4dfvnx4di */
    case 1398:  /* pred_indexed_ostorevnx4dfvnx4di */
    case 1397:  /* pred_indexed_ustorevnx4sfvnx4di */
    case 1396:  /* pred_indexed_ostorevnx4sfvnx4di */
    case 1395:  /* pred_indexed_ustorevnx4divnx4di */
    case 1394:  /* pred_indexed_ostorevnx4divnx4di */
    case 1393:  /* pred_indexed_ustorevnx4sivnx4di */
    case 1392:  /* pred_indexed_ostorevnx4sivnx4di */
    case 1391:  /* pred_indexed_ustorevnx4hivnx4di */
    case 1390:  /* pred_indexed_ostorevnx4hivnx4di */
    case 1389:  /* pred_indexed_ustorevnx4qivnx4di */
    case 1388:  /* pred_indexed_ostorevnx4qivnx4di */
    case 1387:  /* pred_indexed_ustorevnx4dfvnx4si */
    case 1386:  /* pred_indexed_ostorevnx4dfvnx4si */
    case 1385:  /* pred_indexed_ustorevnx4sfvnx4si */
    case 1384:  /* pred_indexed_ostorevnx4sfvnx4si */
    case 1383:  /* pred_indexed_ustorevnx4divnx4si */
    case 1382:  /* pred_indexed_ostorevnx4divnx4si */
    case 1381:  /* pred_indexed_ustorevnx4sivnx4si */
    case 1380:  /* pred_indexed_ostorevnx4sivnx4si */
    case 1379:  /* pred_indexed_ustorevnx4hivnx4si */
    case 1378:  /* pred_indexed_ostorevnx4hivnx4si */
    case 1377:  /* pred_indexed_ustorevnx4qivnx4si */
    case 1376:  /* pred_indexed_ostorevnx4qivnx4si */
    case 1375:  /* pred_indexed_ustorevnx4dfvnx4hi */
    case 1374:  /* pred_indexed_ostorevnx4dfvnx4hi */
    case 1373:  /* pred_indexed_ustorevnx4sfvnx4hi */
    case 1372:  /* pred_indexed_ostorevnx4sfvnx4hi */
    case 1371:  /* pred_indexed_ustorevnx4divnx4hi */
    case 1370:  /* pred_indexed_ostorevnx4divnx4hi */
    case 1369:  /* pred_indexed_ustorevnx4sivnx4hi */
    case 1368:  /* pred_indexed_ostorevnx4sivnx4hi */
    case 1367:  /* pred_indexed_ustorevnx4hivnx4hi */
    case 1366:  /* pred_indexed_ostorevnx4hivnx4hi */
    case 1365:  /* pred_indexed_ustorevnx4qivnx4hi */
    case 1364:  /* pred_indexed_ostorevnx4qivnx4hi */
    case 1363:  /* pred_indexed_ustorevnx4dfvnx4qi */
    case 1362:  /* pred_indexed_ostorevnx4dfvnx4qi */
    case 1361:  /* pred_indexed_ustorevnx4sfvnx4qi */
    case 1360:  /* pred_indexed_ostorevnx4sfvnx4qi */
    case 1359:  /* pred_indexed_ustorevnx4divnx4qi */
    case 1358:  /* pred_indexed_ostorevnx4divnx4qi */
    case 1357:  /* pred_indexed_ustorevnx4sivnx4qi */
    case 1356:  /* pred_indexed_ostorevnx4sivnx4qi */
    case 1355:  /* pred_indexed_ustorevnx4hivnx4qi */
    case 1354:  /* pred_indexed_ostorevnx4hivnx4qi */
    case 1353:  /* pred_indexed_ustorevnx4qivnx4qi */
    case 1352:  /* pred_indexed_ostorevnx4qivnx4qi */
    case 1351:  /* pred_indexed_ustorevnx2dfvnx2di */
    case 1350:  /* pred_indexed_ostorevnx2dfvnx2di */
    case 1349:  /* pred_indexed_ustorevnx2sfvnx2di */
    case 1348:  /* pred_indexed_ostorevnx2sfvnx2di */
    case 1347:  /* pred_indexed_ustorevnx2divnx2di */
    case 1346:  /* pred_indexed_ostorevnx2divnx2di */
    case 1345:  /* pred_indexed_ustorevnx2sivnx2di */
    case 1344:  /* pred_indexed_ostorevnx2sivnx2di */
    case 1343:  /* pred_indexed_ustorevnx2hivnx2di */
    case 1342:  /* pred_indexed_ostorevnx2hivnx2di */
    case 1341:  /* pred_indexed_ustorevnx2qivnx2di */
    case 1340:  /* pred_indexed_ostorevnx2qivnx2di */
    case 1339:  /* pred_indexed_ustorevnx2dfvnx2si */
    case 1338:  /* pred_indexed_ostorevnx2dfvnx2si */
    case 1337:  /* pred_indexed_ustorevnx2sfvnx2si */
    case 1336:  /* pred_indexed_ostorevnx2sfvnx2si */
    case 1335:  /* pred_indexed_ustorevnx2divnx2si */
    case 1334:  /* pred_indexed_ostorevnx2divnx2si */
    case 1333:  /* pred_indexed_ustorevnx2sivnx2si */
    case 1332:  /* pred_indexed_ostorevnx2sivnx2si */
    case 1331:  /* pred_indexed_ustorevnx2hivnx2si */
    case 1330:  /* pred_indexed_ostorevnx2hivnx2si */
    case 1329:  /* pred_indexed_ustorevnx2qivnx2si */
    case 1328:  /* pred_indexed_ostorevnx2qivnx2si */
    case 1327:  /* pred_indexed_ustorevnx2dfvnx2hi */
    case 1326:  /* pred_indexed_ostorevnx2dfvnx2hi */
    case 1325:  /* pred_indexed_ustorevnx2sfvnx2hi */
    case 1324:  /* pred_indexed_ostorevnx2sfvnx2hi */
    case 1323:  /* pred_indexed_ustorevnx2divnx2hi */
    case 1322:  /* pred_indexed_ostorevnx2divnx2hi */
    case 1321:  /* pred_indexed_ustorevnx2sivnx2hi */
    case 1320:  /* pred_indexed_ostorevnx2sivnx2hi */
    case 1319:  /* pred_indexed_ustorevnx2hivnx2hi */
    case 1318:  /* pred_indexed_ostorevnx2hivnx2hi */
    case 1317:  /* pred_indexed_ustorevnx2qivnx2hi */
    case 1316:  /* pred_indexed_ostorevnx2qivnx2hi */
    case 1315:  /* pred_indexed_ustorevnx2dfvnx2qi */
    case 1314:  /* pred_indexed_ostorevnx2dfvnx2qi */
    case 1313:  /* pred_indexed_ustorevnx2sfvnx2qi */
    case 1312:  /* pred_indexed_ostorevnx2sfvnx2qi */
    case 1311:  /* pred_indexed_ustorevnx2divnx2qi */
    case 1310:  /* pred_indexed_ostorevnx2divnx2qi */
    case 1309:  /* pred_indexed_ustorevnx2sivnx2qi */
    case 1308:  /* pred_indexed_ostorevnx2sivnx2qi */
    case 1307:  /* pred_indexed_ustorevnx2hivnx2qi */
    case 1306:  /* pred_indexed_ostorevnx2hivnx2qi */
    case 1305:  /* pred_indexed_ustorevnx2qivnx2qi */
    case 1304:  /* pred_indexed_ostorevnx2qivnx2qi */
    case 1303:  /* pred_indexed_ustorevnx1dfvnx1di */
    case 1302:  /* pred_indexed_ostorevnx1dfvnx1di */
    case 1301:  /* pred_indexed_ustorevnx1dfvnx1si */
    case 1300:  /* pred_indexed_ostorevnx1dfvnx1si */
    case 1299:  /* pred_indexed_ustorevnx1dfvnx1hi */
    case 1298:  /* pred_indexed_ostorevnx1dfvnx1hi */
    case 1297:  /* pred_indexed_ustorevnx1dfvnx1qi */
    case 1296:  /* pred_indexed_ostorevnx1dfvnx1qi */
    case 1295:  /* pred_indexed_ustorevnx1sfvnx1di */
    case 1294:  /* pred_indexed_ostorevnx1sfvnx1di */
    case 1293:  /* pred_indexed_ustorevnx1sfvnx1si */
    case 1292:  /* pred_indexed_ostorevnx1sfvnx1si */
    case 1291:  /* pred_indexed_ustorevnx1sfvnx1hi */
    case 1290:  /* pred_indexed_ostorevnx1sfvnx1hi */
    case 1289:  /* pred_indexed_ustorevnx1sfvnx1qi */
    case 1288:  /* pred_indexed_ostorevnx1sfvnx1qi */
    case 1287:  /* pred_indexed_ustorevnx1divnx1di */
    case 1286:  /* pred_indexed_ostorevnx1divnx1di */
    case 1285:  /* pred_indexed_ustorevnx1divnx1si */
    case 1284:  /* pred_indexed_ostorevnx1divnx1si */
    case 1283:  /* pred_indexed_ustorevnx1divnx1hi */
    case 1282:  /* pred_indexed_ostorevnx1divnx1hi */
    case 1281:  /* pred_indexed_ustorevnx1divnx1qi */
    case 1280:  /* pred_indexed_ostorevnx1divnx1qi */
    case 1279:  /* pred_indexed_ustorevnx1sivnx1di */
    case 1278:  /* pred_indexed_ostorevnx1sivnx1di */
    case 1277:  /* pred_indexed_ustorevnx1sivnx1si */
    case 1276:  /* pred_indexed_ostorevnx1sivnx1si */
    case 1275:  /* pred_indexed_ustorevnx1sivnx1hi */
    case 1274:  /* pred_indexed_ostorevnx1sivnx1hi */
    case 1273:  /* pred_indexed_ustorevnx1sivnx1qi */
    case 1272:  /* pred_indexed_ostorevnx1sivnx1qi */
    case 1271:  /* pred_indexed_ustorevnx1hivnx1di */
    case 1270:  /* pred_indexed_ostorevnx1hivnx1di */
    case 1269:  /* pred_indexed_ustorevnx1hivnx1si */
    case 1268:  /* pred_indexed_ostorevnx1hivnx1si */
    case 1267:  /* pred_indexed_ustorevnx1hivnx1hi */
    case 1266:  /* pred_indexed_ostorevnx1hivnx1hi */
    case 1265:  /* pred_indexed_ustorevnx1hivnx1qi */
    case 1264:  /* pred_indexed_ostorevnx1hivnx1qi */
    case 1263:  /* pred_indexed_ustorevnx1qivnx1di */
    case 1262:  /* pred_indexed_ostorevnx1qivnx1di */
    case 1261:  /* pred_indexed_ustorevnx1qivnx1si */
    case 1260:  /* pred_indexed_ostorevnx1qivnx1si */
    case 1259:  /* pred_indexed_ustorevnx1qivnx1hi */
    case 1258:  /* pred_indexed_ostorevnx1qivnx1hi */
    case 1257:  /* pred_indexed_ustorevnx1qivnx1qi */
    case 1256:  /* pred_indexed_ostorevnx1qivnx1qi */
    case 1029:  /* pred_strided_storevnx8df */
    case 1028:  /* pred_strided_storevnx4df */
    case 1027:  /* pred_strided_storevnx2df */
    case 1026:  /* pred_strided_storevnx1df */
    case 1025:  /* pred_strided_storevnx16sf */
    case 1024:  /* pred_strided_storevnx8sf */
    case 1023:  /* pred_strided_storevnx4sf */
    case 1022:  /* pred_strided_storevnx2sf */
    case 1021:  /* pred_strided_storevnx1sf */
    case 1020:  /* pred_strided_storevnx8di */
    case 1019:  /* pred_strided_storevnx4di */
    case 1018:  /* pred_strided_storevnx2di */
    case 1017:  /* pred_strided_storevnx1di */
    case 1016:  /* pred_strided_storevnx16si */
    case 1015:  /* pred_strided_storevnx8si */
    case 1014:  /* pred_strided_storevnx4si */
    case 1013:  /* pred_strided_storevnx2si */
    case 1012:  /* pred_strided_storevnx1si */
    case 1011:  /* pred_strided_storevnx32hi */
    case 1010:  /* pred_strided_storevnx16hi */
    case 1009:  /* pred_strided_storevnx8hi */
    case 1008:  /* pred_strided_storevnx4hi */
    case 1007:  /* pred_strided_storevnx2hi */
    case 1006:  /* pred_strided_storevnx1hi */
    case 1005:  /* pred_strided_storevnx64qi */
    case 1004:  /* pred_strided_storevnx32qi */
    case 1003:  /* pred_strided_storevnx16qi */
    case 1002:  /* pred_strided_storevnx8qi */
    case 1001:  /* pred_strided_storevnx4qi */
    case 1000:  /* pred_strided_storevnx2qi */
    case 999:  /* pred_strided_storevnx1qi */
    case 875:  /* pred_storevnx64bi */
    case 874:  /* pred_storevnx32bi */
    case 873:  /* pred_storevnx16bi */
    case 872:  /* pred_storevnx8bi */
    case 871:  /* pred_storevnx4bi */
    case 870:  /* pred_storevnx2bi */
    case 869:  /* pred_storevnx1bi */
    case 868:  /* pred_movvnx64bi */
    case 867:  /* pred_movvnx32bi */
    case 866:  /* pred_movvnx16bi */
    case 865:  /* pred_movvnx8bi */
    case 864:  /* pred_movvnx4bi */
    case 863:  /* pred_movvnx2bi */
    case 862:  /* pred_movvnx1bi */
    case 861:  /* pred_storevnx8df */
    case 860:  /* pred_storevnx4df */
    case 859:  /* pred_storevnx2df */
    case 858:  /* pred_storevnx1df */
    case 857:  /* pred_storevnx16sf */
    case 856:  /* pred_storevnx8sf */
    case 855:  /* pred_storevnx4sf */
    case 854:  /* pred_storevnx2sf */
    case 853:  /* pred_storevnx1sf */
    case 852:  /* pred_storevnx8di */
    case 851:  /* pred_storevnx4di */
    case 850:  /* pred_storevnx2di */
    case 849:  /* pred_storevnx1di */
    case 848:  /* pred_storevnx16si */
    case 847:  /* pred_storevnx8si */
    case 846:  /* pred_storevnx4si */
    case 845:  /* pred_storevnx2si */
    case 844:  /* pred_storevnx1si */
    case 843:  /* pred_storevnx32hi */
    case 842:  /* pred_storevnx16hi */
    case 841:  /* pred_storevnx8hi */
    case 840:  /* pred_storevnx4hi */
    case 839:  /* pred_storevnx2hi */
    case 838:  /* pred_storevnx1hi */
    case 837:  /* pred_storevnx64qi */
    case 836:  /* pred_storevnx32qi */
    case 835:  /* pred_storevnx16qi */
    case 834:  /* pred_storevnx8qi */
    case 833:  /* pred_storevnx4qi */
    case 832:  /* pred_storevnx2qi */
    case 831:  /* pred_storevnx1qi */
    case 799:  /* vsetvldi_no_side_effects */
    case 798:  /* vsetvlsi_no_side_effects */
    case 795:  /* vsetvl_vtype_change_only */
    case 792:  /* *movvnx64bidi_lra */
    case 791:  /* *movvnx32bidi_lra */
    case 790:  /* *movvnx16bidi_lra */
    case 789:  /* *movvnx8bidi_lra */
    case 788:  /* *movvnx4bidi_lra */
    case 787:  /* *movvnx2bidi_lra */
    case 786:  /* *movvnx1bidi_lra */
    case 785:  /* *movvnx64bisi_lra */
    case 784:  /* *movvnx32bisi_lra */
    case 783:  /* *movvnx16bisi_lra */
    case 782:  /* *movvnx8bisi_lra */
    case 781:  /* *movvnx4bisi_lra */
    case 780:  /* *movvnx2bisi_lra */
    case 779:  /* *movvnx1bisi_lra */
    case 778:  /* *movvnx1sfdi_lra */
    case 777:  /* *movvnx1sfsi_lra */
    case 776:  /* *movvnx1sidi_lra */
    case 775:  /* *movvnx1sisi_lra */
    case 774:  /* *movvnx2hidi_lra */
    case 773:  /* *movvnx2hisi_lra */
    case 772:  /* *movvnx1hidi_lra */
    case 771:  /* *movvnx1hisi_lra */
    case 770:  /* *movvnx4qidi_lra */
    case 769:  /* *movvnx4qisi_lra */
    case 768:  /* *movvnx2qidi_lra */
    case 767:  /* *movvnx2qisi_lra */
    case 766:  /* *movvnx1qidi_lra */
    case 765:  /* *movvnx1qisi_lra */
    case 764:  /* *movvnx64bi */
    case 763:  /* *movvnx32bi */
    case 762:  /* *movvnx16bi */
    case 761:  /* *movvnx8bi */
    case 760:  /* *movvnx4bi */
    case 759:  /* *movvnx2bi */
    case 758:  /* *movvnx1bi */
    case 757:  /* *movvnx1sf_fract */
    case 756:  /* *movvnx1si_fract */
    case 755:  /* *movvnx2hi_fract */
    case 754:  /* *movvnx1hi_fract */
    case 753:  /* *movvnx4qi_fract */
    case 752:  /* *movvnx2qi_fract */
    case 751:  /* *movvnx1qi_fract */
    case 750:  /* *movvnx8df_whole */
    case 749:  /* *movvnx4df_whole */
    case 748:  /* *movvnx2df_whole */
    case 747:  /* *movvnx1df_whole */
    case 746:  /* *movvnx16sf_whole */
    case 745:  /* *movvnx8sf_whole */
    case 744:  /* *movvnx4sf_whole */
    case 743:  /* *movvnx2sf_whole */
    case 742:  /* *movvnx1sf_whole */
    case 741:  /* *movvnx8di_whole */
    case 740:  /* *movvnx4di_whole */
    case 739:  /* *movvnx2di_whole */
    case 738:  /* *movvnx1di_whole */
    case 737:  /* *movvnx16si_whole */
    case 736:  /* *movvnx8si_whole */
    case 735:  /* *movvnx4si_whole */
    case 734:  /* *movvnx2si_whole */
    case 733:  /* *movvnx1si_whole */
    case 732:  /* *movvnx32hi_whole */
    case 731:  /* *movvnx16hi_whole */
    case 730:  /* *movvnx8hi_whole */
    case 729:  /* *movvnx4hi_whole */
    case 728:  /* *movvnx2hi_whole */
    case 727:  /* *movvnx64qi_whole */
    case 726:  /* *movvnx32qi_whole */
    case 725:  /* *movvnx16qi_whole */
    case 724:  /* *movvnx8qi_whole */
    case 723:  /* *movvnx4qi_whole */
    case 722:  /* vlmax_avldi */
    case 721:  /* vlmax_avlsi */
    case 720:  /* *vlmul_extx64vnx1qi */
    case 719:  /* *vlmul_extx32vnx1hi */
    case 718:  /* *vlmul_extx32vnx2qi */
    case 717:  /* *vlmul_extx32vnx1qi */
    case 716:  /* *vlmul_extx16vnx1sf */
    case 715:  /* *vlmul_extx16vnx1si */
    case 714:  /* *vlmul_extx16vnx2hi */
    case 713:  /* *vlmul_extx16vnx1hi */
    case 712:  /* *vlmul_extx16vnx4qi */
    case 711:  /* *vlmul_extx16vnx2qi */
    case 710:  /* *vlmul_extx16vnx1qi */
    case 709:  /* *vlmul_extx8vnx1df */
    case 708:  /* *vlmul_extx8vnx2sf */
    case 707:  /* *vlmul_extx8vnx1sf */
    case 706:  /* *vlmul_extx8vnx1di */
    case 705:  /* *vlmul_extx8vnx2si */
    case 704:  /* *vlmul_extx8vnx1si */
    case 703:  /* *vlmul_extx8vnx4hi */
    case 702:  /* *vlmul_extx8vnx2hi */
    case 701:  /* *vlmul_extx8vnx1hi */
    case 700:  /* *vlmul_extx8vnx8qi */
    case 699:  /* *vlmul_extx8vnx4qi */
    case 698:  /* *vlmul_extx8vnx2qi */
    case 697:  /* *vlmul_extx8vnx1qi */
    case 696:  /* *vlmul_extx4vnx2df */
    case 695:  /* *vlmul_extx4vnx1df */
    case 694:  /* *vlmul_extx4vnx4sf */
    case 693:  /* *vlmul_extx4vnx2sf */
    case 692:  /* *vlmul_extx4vnx1sf */
    case 691:  /* *vlmul_extx4vnx2di */
    case 690:  /* *vlmul_extx4vnx1di */
    case 689:  /* *vlmul_extx4vnx4si */
    case 688:  /* *vlmul_extx4vnx2si */
    case 687:  /* *vlmul_extx4vnx1si */
    case 686:  /* *vlmul_extx4vnx8hi */
    case 685:  /* *vlmul_extx4vnx4hi */
    case 684:  /* *vlmul_extx4vnx2hi */
    case 683:  /* *vlmul_extx4vnx1hi */
    case 682:  /* *vlmul_extx4vnx16qi */
    case 681:  /* *vlmul_extx4vnx8qi */
    case 680:  /* *vlmul_extx4vnx4qi */
    case 679:  /* *vlmul_extx4vnx2qi */
    case 678:  /* *vlmul_extx4vnx1qi */
    case 677:  /* *vlmul_extx2vnx4df */
    case 676:  /* *vlmul_extx2vnx2df */
    case 675:  /* *vlmul_extx2vnx1df */
    case 674:  /* *vlmul_extx2vnx8sf */
    case 673:  /* *vlmul_extx2vnx4sf */
    case 672:  /* *vlmul_extx2vnx2sf */
    case 671:  /* *vlmul_extx2vnx1sf */
    case 670:  /* *vlmul_extx2vnx4di */
    case 669:  /* *vlmul_extx2vnx2di */
    case 668:  /* *vlmul_extx2vnx1di */
    case 667:  /* *vlmul_extx2vnx8si */
    case 666:  /* *vlmul_extx2vnx4si */
    case 665:  /* *vlmul_extx2vnx2si */
    case 664:  /* *vlmul_extx2vnx1si */
    case 663:  /* *vlmul_extx2vnx16hi */
    case 662:  /* *vlmul_extx2vnx8hi */
    case 661:  /* *vlmul_extx2vnx4hi */
    case 660:  /* *vlmul_extx2vnx2hi */
    case 659:  /* *vlmul_extx2vnx1hi */
    case 658:  /* *vlmul_extx2vnx32qi */
    case 657:  /* *vlmul_extx2vnx16qi */
    case 656:  /* *vlmul_extx2vnx8qi */
    case 655:  /* *vlmul_extx2vnx4qi */
    case 654:  /* *vlmul_extx2vnx2qi */
    case 653:  /* *vlmul_extx2vnx1qi */
    case 652:  /* vundefinedvnx64bi */
    case 651:  /* vundefinedvnx32bi */
    case 650:  /* vundefinedvnx16bi */
    case 649:  /* vundefinedvnx8bi */
    case 648:  /* vundefinedvnx4bi */
    case 647:  /* vundefinedvnx2bi */
    case 646:  /* vundefinedvnx1bi */
    case 645:  /* vundefinedvnx8df */
    case 644:  /* vundefinedvnx4df */
    case 643:  /* vundefinedvnx2df */
    case 642:  /* vundefinedvnx1df */
    case 641:  /* vundefinedvnx16sf */
    case 640:  /* vundefinedvnx8sf */
    case 639:  /* vundefinedvnx4sf */
    case 638:  /* vundefinedvnx2sf */
    case 637:  /* vundefinedvnx1sf */
    case 636:  /* vundefinedvnx8di */
    case 635:  /* vundefinedvnx4di */
    case 634:  /* vundefinedvnx2di */
    case 633:  /* vundefinedvnx1di */
    case 632:  /* vundefinedvnx16si */
    case 631:  /* vundefinedvnx8si */
    case 630:  /* vundefinedvnx4si */
    case 629:  /* vundefinedvnx2si */
    case 628:  /* vundefinedvnx1si */
    case 627:  /* vundefinedvnx32hi */
    case 626:  /* vundefinedvnx16hi */
    case 625:  /* vundefinedvnx8hi */
    case 624:  /* vundefinedvnx4hi */
    case 623:  /* vundefinedvnx2hi */
    case 622:  /* vundefinedvnx1hi */
    case 621:  /* vundefinedvnx64qi */
    case 620:  /* vundefinedvnx32qi */
    case 619:  /* vundefinedvnx16qi */
    case 618:  /* vundefinedvnx8qi */
    case 617:  /* vundefinedvnx4qi */
    case 616:  /* vundefinedvnx2qi */
    case 615:  /* vundefinedvnx1qi */
    case 614:  /* *th_mempair_load_zero_extendsidi2 */
    case 613:  /* *th_mempair_load_extendsidi2 */
    case 612:  /* *th_mempair_store_di2 */
    case 611:  /* *th_mempair_store_si2 */
    case 610:  /* *th_mempair_load_di2 */
    case 609:  /* *th_mempair_load_si2 */
    case 608:  /* *th_sextw_msubhisi4 */
    case 607:  /* *th_msubhisi4 */
    case 606:  /* *th_mulswsi2 */
    case 605:  /* *th_mulswsi */
    case 604:  /* *th_mulsdi */
    case 603:  /* *th_mulssi */
    case 602:  /* *th_sextw_maddhisi4 */
    case 601:  /* *th_maddhisi4 */
    case 600:  /* *th_mulawsi2 */
    case 599:  /* *th_mulawsi */
    case 598:  /* *th_muladi */
    case 597:  /* *th_mulasi */
    case 596:  /* th_fmv_x_hw */
    case 595:  /* th_fmv_x_w */
    case 594:  /* th_fmv_hw_w_x */
    case 593:  /* *th_cond_gpr_movdidi */
    case 592:  /* *th_cond_gpr_movsidi */
    case 591:  /* *th_cond_gpr_movdisi */
    case 590:  /* *th_cond_gpr_movsisi */
    case 589:  /* *th_cond_movdidi */
    case 588:  /* *th_cond_movsidi */
    case 587:  /* *th_cond_movdisi */
    case 586:  /* *th_cond_movsisi */
    case 585:  /* *th_tstdi3 */
    case 584:  /* *th_tstsi3 */
    case 583:  /* *th_revdi2 */
    case 582:  /* *th_revsi2 */
    case 581:  /* *th_clzdi2 */
    case 580:  /* *th_clzsi2 */
    case 579:  /* *th_extudi4 */
    case 578:  /* *th_extusi4 */
    case 577:  /* *th_extdi4 */
    case 576:  /* *th_extsi4 */
    case 575:  /* *th_srridi3 */
    case 574:  /* *th_srrisi3 */
    case 573:  /* *th_addsldi4 */
    case 572:  /* *th_addslsi4 */
    case 571:  /* *local_pic_store_sfhf */
    case 570:  /* *local_pic_store_sfdf */
    case 569:  /* *local_pic_store_sfsf */
    case 568:  /* *local_pic_store_sfhf */
    case 567:  /* *local_pic_store_sfdf */
    case 566:  /* *local_pic_store_sfsf */
    case 565:  /* *local_pic_store_32dhf */
    case 564:  /* *local_pic_store_32ddf */
    case 563:  /* *local_pic_store_32dsf */
    case 562:  /* *local_pic_store_32dhf */
    case 561:  /* *local_pic_store_32ddf */
    case 560:  /* *local_pic_store_32dsf */
    case 559:  /* *local_pic_storehf */
    case 558:  /* *local_pic_storedf */
    case 557:  /* *local_pic_storesf */
    case 556:  /* *local_pic_storehf */
    case 555:  /* *local_pic_storedf */
    case 554:  /* *local_pic_storesf */
    case 553:  /* *local_pic_storedi */
    case 552:  /* *local_pic_storesi */
    case 551:  /* *local_pic_storehi */
    case 550:  /* *local_pic_storeqi */
    case 549:  /* *local_pic_storedi */
    case 548:  /* *local_pic_storesi */
    case 547:  /* *local_pic_storehi */
    case 546:  /* *local_pic_storeqi */
    case 545:  /* *local_pic_load_sfhf */
    case 544:  /* *local_pic_load_sfdf */
    case 543:  /* *local_pic_load_sfsf */
    case 542:  /* *local_pic_load_32dhf */
    case 541:  /* *local_pic_load_32ddf */
    case 540:  /* *local_pic_load_32dsf */
    case 539:  /* *local_pic_load_32dhf */
    case 538:  /* *local_pic_load_32ddf */
    case 537:  /* *local_pic_load_32dsf */
    case 536:  /* *local_pic_loadhf */
    case 535:  /* *local_pic_loaddf */
    case 534:  /* *local_pic_loadsf */
    case 533:  /* *local_pic_loadhf */
    case 532:  /* *local_pic_loaddf */
    case 531:  /* *local_pic_loadsf */
    case 530:  /* *local_pic_load_usi */
    case 529:  /* *local_pic_load_usi */
    case 528:  /* *local_pic_load_usi */
    case 527:  /* *local_pic_load_uhi */
    case 526:  /* *local_pic_load_uhi */
    case 525:  /* *local_pic_load_uhi */
    case 524:  /* *local_pic_load_uqi */
    case 523:  /* *local_pic_load_uqi */
    case 522:  /* *local_pic_load_uqi */
    case 521:  /* *local_pic_load_ssi */
    case 520:  /* *local_pic_load_ssi */
    case 519:  /* *local_pic_load_ssi */
    case 518:  /* *local_pic_load_shi */
    case 517:  /* *local_pic_load_shi */
    case 516:  /* *local_pic_load_shi */
    case 515:  /* *local_pic_load_sqi */
    case 514:  /* *local_pic_load_sqi */
    case 513:  /* *local_pic_load_sqi */
    case 512:  /* *local_pic_loaddi */
    case 511:  /* *local_pic_loadsi */
    case 510:  /* *local_pic_loadhi */
    case 509:  /* *local_pic_loadqi */
    case 508:  /* subword_atomic_cas_strong */
    case 507:  /* atomic_cas_value_strongdi */
    case 506:  /* atomic_cas_value_strongsi */
    case 505:  /* subword_atomic_exchange_strong */
    case 504:  /* atomic_exchangedi */
    case 503:  /* atomic_exchangesi */
    case 502:  /* subword_atomic_fetch_strong_nand */
    case 501:  /* subword_atomic_fetch_strong_and */
    case 500:  /* subword_atomic_fetch_strong_xor */
    case 499:  /* subword_atomic_fetch_strong_or */
    case 498:  /* subword_atomic_fetch_strong_add */
    case 497:  /* atomic_fetch_anddi */
    case 496:  /* atomic_fetch_xordi */
    case 495:  /* atomic_fetch_ordi */
    case 494:  /* atomic_fetch_adddi */
    case 493:  /* atomic_fetch_andsi */
    case 492:  /* atomic_fetch_xorsi */
    case 491:  /* atomic_fetch_orsi */
    case 490:  /* atomic_fetch_addsi */
    case 489:  /* atomic_anddi */
    case 488:  /* atomic_xordi */
    case 487:  /* atomic_ordi */
    case 486:  /* atomic_adddi */
    case 485:  /* atomic_andsi */
    case 484:  /* atomic_xorsi */
    case 483:  /* atomic_orsi */
    case 482:  /* atomic_addsi */
    case 481:  /* atomic_storedi */
    case 480:  /* atomic_storesi */
    case 479:  /* atomic_loaddi */
    case 478:  /* atomic_loadsi */
    case 477:  /* mem_thread_fence_1 */
    case 476:  /* riscv_sm4ks_di */
    case 475:  /* riscv_sm4ks_si */
    case 474:  /* riscv_sm4ed_di */
    case 473:  /* riscv_sm4ed_si */
    case 472:  /* riscv_sm3p1_di */
    case 471:  /* riscv_sm3p1_si */
    case 470:  /* riscv_sm3p0_di */
    case 469:  /* riscv_sm3p0_si */
    case 468:  /* riscv_sha512sum1 */
    case 467:  /* riscv_sha512sum0 */
    case 466:  /* riscv_sha512sig1 */
    case 465:  /* riscv_sha512sig0 */
    case 464:  /* riscv_sha512sum1r */
    case 463:  /* riscv_sha512sum0r */
    case 462:  /* riscv_sha512sig1l */
    case 461:  /* riscv_sha512sig1h */
    case 460:  /* riscv_sha512sig0l */
    case 459:  /* riscv_sha512sig0h */
    case 458:  /* riscv_sha256sum1_di */
    case 457:  /* riscv_sha256sum1_si */
    case 456:  /* riscv_sha256sum0_di */
    case 455:  /* riscv_sha256sum0_si */
    case 454:  /* riscv_sha256sig1_di */
    case 453:  /* riscv_sha256sig1_si */
    case 452:  /* riscv_sha256sig0_di */
    case 451:  /* riscv_sha256sig0_si */
    case 450:  /* riscv_aes64esm */
    case 449:  /* riscv_aes64es */
    case 448:  /* riscv_aes32esmi */
    case 447:  /* riscv_aes32esi */
    case 446:  /* riscv_aes64ks2 */
    case 445:  /* riscv_aes64ks1i */
    case 444:  /* riscv_aes64im */
    case 443:  /* riscv_aes64dsm */
    case 442:  /* riscv_aes64ds */
    case 441:  /* riscv_aes32dsmi */
    case 440:  /* riscv_aes32dsi */
    case 439:  /* riscv_xperm8_di */
    case 438:  /* riscv_xperm8_si */
    case 437:  /* riscv_xperm4_di */
    case 436:  /* riscv_xperm4_si */
    case 435:  /* riscv_clmulh_di */
    case 434:  /* riscv_clmulh_si */
    case 433:  /* riscv_clmul_di */
    case 432:  /* riscv_clmul_si */
    case 431:  /* riscv_packw */
    case 430:  /* riscv_packh_di */
    case 429:  /* riscv_packh_si */
    case 428:  /* riscv_pack_disi */
    case 427:  /* riscv_pack_dihi */
    case 426:  /* riscv_pack_sisi */
    case 425:  /* riscv_pack_sihi */
    case 424:  /* riscv_unzip */
    case 423:  /* riscv_zip */
    case 422:  /* riscv_brev8_di */
    case 421:  /* riscv_brev8_si */
    case 420:  /* *branchdi_mask_twobits_equals_singlebit */
    case 419:  /* *branchsi_mask_twobits_equals_singlebit */
    case 418:  /* *andidi_extrabit */
    case 417:  /* *andisi_extrabit */
    case 416:  /* *xoridi_extrabit */
    case 415:  /* *ioridi_extrabit */
    case 414:  /* *xorisi_extrabit */
    case 413:  /* *iorisi_extrabit */
    case 412:  /* *bexti */
    case 411:  /* *bexti */
    case 410:  /* *bextdi */
    case 409:  /* *bextsi */
    case 408:  /* *bextdi */
    case 407:  /* *bextsi */
    case 406:  /* *binvidi */
    case 405:  /* *binvisi */
    case 404:  /* *binvdi */
    case 403:  /* *binvsi */
    case 402:  /* *bclridisi_nottwobits */
    case 401:  /* *bclridi_nottwobits */
    case 400:  /* *bclrisi_nottwobits */
    case 399:  /* *bclridi */
    case 398:  /* *bclrisi */
    case 397:  /* *bclrdi */
    case 396:  /* *bclrsi */
    case 395:  /* *bsetidisi */
    case 394:  /* *bsetidi */
    case 393:  /* *bsetisi */
    case 392:  /* *bsetdi_1_mask */
    case 391:  /* *bsetsi_1_mask */
    case 390:  /* *bsetdi_1 */
    case 389:  /* *bsetsi_1 */
    case 388:  /* *bsetdi_mask */
    case 387:  /* *bsetsi_mask */
    case 386:  /* *bsetdi */
    case 385:  /* *bsetsi */
    case 384:  /* *minmax */
    case 383:  /* *minmax */
    case 382:  /* *minmax */
    case 381:  /* *minmax */
    case 380:  /* umaxdi3 */
    case 379:  /* smaxdi3 */
    case 378:  /* umindi3 */
    case 377:  /* smindi3 */
    case 376:  /* umaxsi3 */
    case 375:  /* smaxsi3 */
    case 374:  /* uminsi3 */
    case 373:  /* sminsi3 */
    case 372:  /* *bswapdi2 */
    case 371:  /* *bswapsi2 */
    case 370:  /* orcbdi2 */
    case 369:  /* orcbsi2 */
    case 368:  /* rotlsi3_sext */
    case 367:  /* rotldi3 */
    case 366:  /* rotlsi3 */
    case 365:  /* *rotrsi3_sext */
    case 364:  /* *rotrdi3 */
    case 363:  /* *rotrsi3 */
    case 362:  /* *zero_extendhidi2_zbb */
    case 361:  /* *zero_extendhisi2_zbb */
    case 360:  /* *extendhidi2_zbb */
    case 359:  /* *extendhisi2_zbb */
    case 358:  /* *extendhihi2_zbb */
    case 357:  /* *extendqidi2_zbb */
    case 356:  /* *extendqisi2_zbb */
    case 355:  /* *extendqihi2_zbb */
    case 354:  /* *zero_extendhidi2_bitmanip */
    case 353:  /* *zero_extendhisi2_bitmanip */
    case 352:  /* *popcountdi2 */
    case 351:  /* *ctzdi2 */
    case 350:  /* *clzdi2 */
    case 349:  /* *popcountdisi2 */
    case 348:  /* *ctzdisi2 */
    case 347:  /* *clzdisi2 */
    case 346:  /* *popcountsi2 */
    case 345:  /* *ctzsi2 */
    case 344:  /* *clzsi2 */
    case 343:  /* *xor_notdi */
    case 342:  /* *xor_notsi */
    case 341:  /* *ior_notdi */
    case 340:  /* *and_notdi */
    case 339:  /* *ior_notsi */
    case 338:  /* *and_notsi */
    case 337:  /* *slliuw */
    case 336:  /* *add.uw */
    case 335:  /* *shNadduw */
    case 334:  /* *andi_add.uw */
    case 333:  /* *shNadd */
    case 332:  /* *shNadd */
    case 331:  /* *zero_extendsidi2_bitmanip */
    case 330:  /* riscv_prefetchi_di */
    case 329:  /* riscv_prefetchi_si */
    case 328:  /* prefetch */
    case 327:  /* riscv_zero_di */
    case 326:  /* riscv_zero_si */
    case 325:  /* riscv_inval_di */
    case 324:  /* riscv_inval_si */
    case 323:  /* riscv_flush_di */
    case 322:  /* riscv_flush_si */
    case 321:  /* riscv_clean_di */
    case 320:  /* riscv_clean_si */
    case 319:  /* stack_protect_test_di */
    case 318:  /* stack_protect_test_si */
    case 317:  /* stack_protect_set_di */
    case 316:  /* stack_protect_set_si */
    case 315:  /* stack_tiedi */
    case 314:  /* stack_tiesi */
    case 313:  /* riscv_uret */
    case 312:  /* riscv_sret */
    case 311:  /* riscv_mret */
    case 310:  /* *riscv_fsnvsnanhf2 */
    case 309:  /* *riscv_fsnvsnandf2 */
    case 308:  /* *riscv_fsnvsnansf2 */
    case 307:  /* riscv_fsflags */
    case 306:  /* riscv_frflags */
    case 305:  /* gpr_restore_return */
    case 304:  /* gpr_restore */
    case 303:  /* gpr_save */
    case 302:  /* trap */
    case 301:  /* nop */
    case 300:  /* call_value_internal */
    case 299:  /* call_internal */
    case 298:  /* sibcall_value_internal */
    case 297:  /* sibcall_internal */
    case 296:  /* eh_return_internal */
    case 295:  /* eh_set_lr_di */
    case 294:  /* eh_set_lr_si */
    case 293:  /* simple_return_internal */
    case 292:  /* simple_return */
    case 291:  /* blockage */
    case 290:  /* tablejumpdi */
    case 289:  /* tablejumpsi */
    case 288:  /* indirect_jumpdi */
    case 287:  /* indirect_jumpsi */
    case 286:  /* jump */
    case 285:  /* *sleu_didi */
    case 284:  /* *sle_didi */
    case 283:  /* *sleu_disi */
    case 282:  /* *sle_disi */
    case 281:  /* *sleu_sisi */
    case 280:  /* *sle_sisi */
    case 279:  /* *sltu_didi */
    case 278:  /* *slt_didi */
    case 277:  /* *sltu_disi */
    case 276:  /* *slt_disi */
    case 275:  /* *sltu_sisi */
    case 274:  /* *slt_sisi */
    case 273:  /* *sgeu_didi */
    case 272:  /* *sge_didi */
    case 271:  /* *sgeu_disi */
    case 270:  /* *sge_disi */
    case 269:  /* *sgeu_sisi */
    case 268:  /* *sge_sisi */
    case 267:  /* *sgtu_didi */
    case 266:  /* *sgt_didi */
    case 265:  /* *sgtu_disi */
    case 264:  /* *sgt_disi */
    case 263:  /* *sgtu_sisi */
    case 262:  /* *sgt_sisi */
    case 261:  /* *sne_zero_didi */
    case 260:  /* *sne_zero_disi */
    case 259:  /* *sne_zero_sisi */
    case 258:  /* *seq_zero_didi */
    case 257:  /* *seq_zero_disi */
    case 256:  /* *seq_zero_sisi */
    case 255:  /* *cstorehfdi4 */
    case 254:  /* *cstorehfsi4 */
    case 253:  /* *cstoredfdi4 */
    case 252:  /* *cstoredfsi4 */
    case 251:  /* *cstoresfdi4 */
    case 250:  /* *cstoresfsi4 */
    case 249:  /* *branch_on_bit_rangedi */
    case 248:  /* *branch_on_bit_rangesi */
    case 247:  /* *branch_on_bitdi */
    case 246:  /* *branch_on_bitsi */
    case 245:  /* *movdidicc */
    case 244:  /* *movsidicc */
    case 243:  /* *movsisicc */
    case 242:  /* *branchdi */
    case 241:  /* *branchsi */
    case 240:  /* *branchdi_shiftedmask_equals_zero */
    case 239:  /* *branchsi_shiftedmask_equals_zero */
    case 238:  /* *branchhi_shiftedmask_equals_zero */
    case 237:  /* *branchqi_shiftedmask_equals_zero */
    case 236:  /* *branchdi_shiftedmask_equals_zero */
    case 235:  /* *branchsi_shiftedmask_equals_zero */
    case 234:  /* *branchhi_shiftedmask_equals_zero */
    case 233:  /* *branchqi_shiftedmask_equals_zero */
    case 232:  /* *branchdi_shiftedarith_equals_zero */
    case 231:  /* *branchsi_shiftedarith_equals_zero */
    case 230:  /* *branchhi_shiftedarith_equals_zero */
    case 229:  /* *branchqi_shiftedarith_equals_zero */
    case 228:  /* *branchsi_shiftedarith_equals_zero */
    case 227:  /* *branchhi_shiftedarith_equals_zero */
    case 226:  /* *branchqi_shiftedarith_equals_zero */
    case 225:  /* zero_extendsidi2_shifted */
    case 224:  /* *lshrsi3_zero_extend_3 */
    case 223:  /* *lshrsi3_zero_extend_2 */
    case 222:  /* *lshrsi3_zero_extend_1 */
    case 221:  /* *lshrsi3_extend_mask_1 */
    case 220:  /* *ashrsi3_extend_mask_1 */
    case 219:  /* *ashlsi3_extend_mask_1 */
    case 218:  /* *lshrsi3_extend_mask */
    case 217:  /* *ashrsi3_extend_mask */
    case 216:  /* *ashlsi3_extend_mask */
    case 215:  /* *lshrsi3_extend */
    case 214:  /* *ashrsi3_extend */
    case 213:  /* *ashlsi3_extend */
    case 212:  /* *lshrdi3_mask_1 */
    case 211:  /* *ashrdi3_mask_1 */
    case 210:  /* *ashldi3_mask_1 */
    case 209:  /* *lshrdi3_mask */
    case 208:  /* *ashrdi3_mask */
    case 207:  /* *ashldi3_mask */
    case 206:  /* lshrdi3 */
    case 205:  /* ashrdi3 */
    case 204:  /* ashldi3 */
    case 203:  /* *lshrsi3_mask_1 */
    case 202:  /* *ashrsi3_mask_1 */
    case 201:  /* *ashlsi3_mask_1 */
    case 200:  /* *lshrsi3_mask */
    case 199:  /* *ashrsi3_mask */
    case 198:  /* *ashlsi3_mask */
    case 197:  /* lshrsi3 */
    case 196:  /* ashrsi3 */
    case 195:  /* ashlsi3 */
    case 194:  /* riscv_pause */
    case 193:  /* fence_i */
    case 192:  /* fence */
    case 191:  /* *movdf_softfloat */
    case 190:  /* *movdf_hardfloat_rv64 */
    case 189:  /* *movdf_hardfloat_rv32 */
    case 188:  /* *movsf_softfloat */
    case 187:  /* *movsf_hardfloat */
    case 186:  /* *movqi_internal */
    case 185:  /* *xorsihi3 */
    case 184:  /* *xorhihi3 */
    case 183:  /* *addsihi3 */
    case 182:  /* *addhihi3 */
    case 181:  /* *movhi_internal */
    case 180:  /* *movsi_internal */
    case 179:  /* *movdi_64bit */
    case 178:  /* *movdi_32bit */
    case 177:  /* *mvconst_internal */
    case 176:  /* *mvconst_internal */
    case 175:  /* *lowdi */
    case 174:  /* *lowsi */
    case 173:  /* auipcdi */
    case 172:  /* auipcsi */
    case 171:  /* got_load_tls_iedi */
    case 170:  /* got_load_tls_iesi */
    case 169:  /* got_load_tls_gddi */
    case 168:  /* got_load_tls_gdsi */
    case 167:  /* tls_add_tp_ledi */
    case 166:  /* tls_add_tp_lesi */
    case 165:  /* got_loaddi */
    case 164:  /* got_loadsi */
    case 163:  /* lroundhfdi2 */
    case 162:  /* lrinthfdi2 */
    case 161:  /* lroundhfsi2 */
    case 160:  /* lrinthfsi2 */
    case 159:  /* lrounddfdi2 */
    case 158:  /* lrintdfdi2 */
    case 157:  /* lrounddfsi2 */
    case 156:  /* lrintdfsi2 */
    case 155:  /* lroundsfdi2 */
    case 154:  /* lrintsfdi2 */
    case 153:  /* lroundsfsi2 */
    case 152:  /* lrintsfsi2 */
    case 151:  /* floatunsdihf2 */
    case 150:  /* floatunssihf2 */
    case 149:  /* floatunsdidf2 */
    case 148:  /* floatunssidf2 */
    case 147:  /* floatunsdisf2 */
    case 146:  /* floatunssisf2 */
    case 145:  /* floatdihf2 */
    case 144:  /* floatsihf2 */
    case 143:  /* floatdidf2 */
    case 142:  /* floatsidf2 */
    case 141:  /* floatdisf2 */
    case 140:  /* floatsisf2 */
    case 139:  /* fixuns_trunchfdi2 */
    case 138:  /* fixuns_trunchfsi2 */
    case 137:  /* fixuns_truncdfdi2 */
    case 136:  /* fixuns_truncdfsi2 */
    case 135:  /* fixuns_truncsfdi2 */
    case 134:  /* fixuns_truncsfsi2 */
    case 133:  /* fix_trunchfdi2 */
    case 132:  /* fix_trunchfsi2 */
    case 131:  /* fix_truncdfdi2 */
    case 130:  /* fix_truncdfsi2 */
    case 129:  /* fix_truncsfdi2 */
    case 128:  /* fix_truncsfsi2 */
    case 127:  /* *movhf_softfloat */
    case 126:  /* *movhf_hardfloat */
    case 125:  /* extendhfdf2 */
    case 124:  /* extendsfdf2 */
    case 123:  /* extendhfsf2 */
    case 122:  /* *extendhidi2 */
    case 121:  /* *extendhisi2 */
    case 120:  /* *extendhihi2 */
    case 119:  /* *extendqidi2 */
    case 118:  /* *extendqisi2 */
    case 117:  /* *extendqihi2 */
    case 116:  /* extendsidi2 */
    case 115:  /* zero_extendqidi2 */
    case 114:  /* zero_extendqisi2 */
    case 113:  /* zero_extendqihi2 */
    case 112:  /* *zero_extendhidi2 */
    case 111:  /* *zero_extendhisi2 */
    case 110:  /* *zero_extendsidi2_internal */
    case 109:  /* truncdfhf2 */
    case 108:  /* truncsfhf2 */
    case 107:  /* truncdfsf2 */
    case 106:  /* *one_cmplsi2_internal */
    case 105:  /* one_cmpldi2 */
    case 104:  /* one_cmplsi2 */
    case 103:  /* *xorsi3_internal */
    case 102:  /* *iorsi3_internal */
    case 101:  /* *andsi3_internal */
    case 100:  /* xordi3 */
    case 99:  /* iordi3 */
    case 98:  /* anddi3 */
    case 97:  /* xorsi3 */
    case 96:  /* iorsi3 */
    case 95:  /* andsi3 */
    case 94:  /* smaxhf3 */
    case 93:  /* smaxdf3 */
    case 92:  /* smaxsf3 */
    case 91:  /* sminhf3 */
    case 90:  /* smindf3 */
    case 89:  /* sminsf3 */
    case 88:  /* fmaxhf3 */
    case 87:  /* fmaxdf3 */
    case 86:  /* fmaxsf3 */
    case 85:  /* fminhf3 */
    case 84:  /* fmindf3 */
    case 83:  /* fminsf3 */
    case 82:  /* neghf2 */
    case 81:  /* negdf2 */
    case 80:  /* negsf2 */
    case 79:  /* copysignhf3 */
    case 78:  /* copysigndf3 */
    case 77:  /* copysignsf3 */
    case 76:  /* abshf2 */
    case 75:  /* absdf2 */
    case 74:  /* abssf2 */
    case 73:  /* *fnmahf4 */
    case 72:  /* *fnmadf4 */
    case 71:  /* *fnmasf4 */
    case 70:  /* *fnmshf4 */
    case 69:  /* *fnmsdf4 */
    case 68:  /* *fnmssf4 */
    case 67:  /* *fmshf4 */
    case 66:  /* *fmsdf4 */
    case 65:  /* *fmssf4 */
    case 64:  /* *fmahf4 */
    case 63:  /* *fmadf4 */
    case 62:  /* *fmasf4 */
    case 61:  /* fnmahf4 */
    case 60:  /* fnmadf4 */
    case 59:  /* fnmasf4 */
    case 58:  /* fnmshf4 */
    case 57:  /* fnmsdf4 */
    case 56:  /* fnmssf4 */
    case 55:  /* fmshf4 */
    case 54:  /* fmsdf4 */
    case 53:  /* fmssf4 */
    case 52:  /* fmahf4 */
    case 51:  /* fmadf4 */
    case 50:  /* fmasf4 */
    case 49:  /* sqrthf2 */
    case 48:  /* sqrtdf2 */
    case 47:  /* sqrtsf2 */
    case 46:  /* divhf3 */
    case 45:  /* divdf3 */
    case 44:  /* divsf3 */
    case 43:  /* *umodsi3_extended */
    case 42:  /* *modsi3_extended */
    case 41:  /* *udivsi3_extended */
    case 40:  /* *divsi3_extended */
    case 39:  /* umoddi3 */
    case 38:  /* moddi3 */
    case 37:  /* udivdi3 */
    case 36:  /* divdi3 */
    case 35:  /* umodsi3 */
    case 34:  /* modsi3 */
    case 33:  /* udivsi3 */
    case 32:  /* divsi3 */
    case 31:  /* usmulsi3_highpart */
    case 30:  /* umulsi3_highpart */
    case 29:  /* smulsi3_highpart */
    case 28:  /* usmuldi3_highpart */
    case 27:  /* umuldi3_highpart */
    case 26:  /* smuldi3_highpart */
    case 25:  /* *mulsi3_extended2 */
    case 24:  /* *mulsi3_extended */
    case 23:  /* muldi3 */
    case 22:  /* mulsi3 */
    case 21:  /* mulhf3 */
    case 20:  /* muldf3 */
    case 19:  /* mulsf3 */
    case 18:  /* *negsi2_extended2 */
    case 17:  /* *negsi2_extended */
    case 16:  /* negsi2 */
    case 15:  /* negdi2 */
    case 14:  /* *subsi3_extended2 */
    case 13:  /* *subsi3_extended */
    case 12:  /* subsi3 */
    case 11:  /* subdi3 */
    case 10:  /* subhf3 */
    case 9:  /* subdf3 */
    case 8:  /* subsf3 */
    case 7:  /* *addsi3_extended2 */
    case 6:  /* *addsi3_extended */
    case 5:  /* adddi3 */
    case 4:  /* addsi3 */
    case 3:  /* addhf3 */
    case 2:  /* adddf3 */
    case 1:  /* addsf3 */
      return 255 /* 0xff */;

    case 793:  /* vsetvlsi */
    case 794:  /* vsetvldi */
      extract_constrain_insn_cached (insn);
      return 
#line 351 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[4]));

    case 796:  /* vsetvl_discard_resultsi */
    case 797:  /* vsetvl_discard_resultdi */
      extract_constrain_insn_cached (insn);
      return 
#line 877 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[3]));

    case 6067:  /* pred_fault_loadvnx8df */
    case 6066:  /* pred_fault_loadvnx4df */
    case 6065:  /* pred_fault_loadvnx2df */
    case 6064:  /* pred_fault_loadvnx1df */
    case 6063:  /* pred_fault_loadvnx16sf */
    case 6062:  /* pred_fault_loadvnx8sf */
    case 6061:  /* pred_fault_loadvnx4sf */
    case 6060:  /* pred_fault_loadvnx2sf */
    case 6059:  /* pred_fault_loadvnx1sf */
    case 6058:  /* pred_fault_loadvnx8di */
    case 6057:  /* pred_fault_loadvnx4di */
    case 6056:  /* pred_fault_loadvnx2di */
    case 6055:  /* pred_fault_loadvnx1di */
    case 6054:  /* pred_fault_loadvnx16si */
    case 6053:  /* pred_fault_loadvnx8si */
    case 6052:  /* pred_fault_loadvnx4si */
    case 6051:  /* pred_fault_loadvnx2si */
    case 6050:  /* pred_fault_loadvnx1si */
    case 6049:  /* pred_fault_loadvnx32hi */
    case 6048:  /* pred_fault_loadvnx16hi */
    case 6047:  /* pred_fault_loadvnx8hi */
    case 6046:  /* pred_fault_loadvnx4hi */
    case 6045:  /* pred_fault_loadvnx2hi */
    case 6044:  /* pred_fault_loadvnx1hi */
    case 6043:  /* pred_fault_loadvnx64qi */
    case 6042:  /* pred_fault_loadvnx32qi */
    case 6041:  /* pred_fault_loadvnx16qi */
    case 6040:  /* pred_fault_loadvnx8qi */
    case 6039:  /* pred_fault_loadvnx4qi */
    case 6038:  /* pred_fault_loadvnx2qi */
    case 6037:  /* pred_fault_loadvnx1qi */
    case 6034:  /* pred_compressvnx8df */
    case 6033:  /* pred_compressvnx4df */
    case 6032:  /* pred_compressvnx2df */
    case 6031:  /* pred_compressvnx1df */
    case 6030:  /* pred_compressvnx16sf */
    case 6029:  /* pred_compressvnx8sf */
    case 6028:  /* pred_compressvnx4sf */
    case 6027:  /* pred_compressvnx2sf */
    case 6026:  /* pred_compressvnx1sf */
    case 6025:  /* pred_compressvnx8di */
    case 6024:  /* pred_compressvnx4di */
    case 6023:  /* pred_compressvnx2di */
    case 6022:  /* pred_compressvnx1di */
    case 6021:  /* pred_compressvnx16si */
    case 6020:  /* pred_compressvnx8si */
    case 6019:  /* pred_compressvnx4si */
    case 6018:  /* pred_compressvnx2si */
    case 6017:  /* pred_compressvnx1si */
    case 6016:  /* pred_compressvnx32hi */
    case 6015:  /* pred_compressvnx16hi */
    case 6014:  /* pred_compressvnx8hi */
    case 6013:  /* pred_compressvnx4hi */
    case 6012:  /* pred_compressvnx2hi */
    case 6011:  /* pred_compressvnx1hi */
    case 6010:  /* pred_compressvnx64qi */
    case 6009:  /* pred_compressvnx32qi */
    case 6008:  /* pred_compressvnx16qi */
    case 6007:  /* pred_compressvnx8qi */
    case 6006:  /* pred_compressvnx4qi */
    case 6005:  /* pred_compressvnx2qi */
    case 6004:  /* pred_compressvnx1qi */
    case 5328:  /* pred_rod_truncvnx8df */
    case 5327:  /* pred_rod_truncvnx4df */
    case 5326:  /* pred_rod_truncvnx2df */
    case 5325:  /* pred_rod_truncvnx1df */
    case 5324:  /* pred_truncvnx8df */
    case 5323:  /* pred_truncvnx4df */
    case 5322:  /* pred_truncvnx2df */
    case 5321:  /* pred_truncvnx1df */
    case 5320:  /* pred_narrow_floatunsvnx8di */
    case 5319:  /* pred_narrow_floatvnx8di */
    case 5318:  /* pred_narrow_floatunsvnx4di */
    case 5317:  /* pred_narrow_floatvnx4di */
    case 5316:  /* pred_narrow_floatunsvnx2di */
    case 5315:  /* pred_narrow_floatvnx2di */
    case 5314:  /* pred_narrow_floatunsvnx1di */
    case 5313:  /* pred_narrow_floatvnx1di */
    case 5312:  /* pred_narrow_fixuns_truncvnx8df */
    case 5311:  /* pred_narrow_fix_truncvnx8df */
    case 5310:  /* pred_narrow_fixuns_truncvnx4df */
    case 5309:  /* pred_narrow_fix_truncvnx4df */
    case 5308:  /* pred_narrow_fixuns_truncvnx2df */
    case 5307:  /* pred_narrow_fix_truncvnx2df */
    case 5306:  /* pred_narrow_fixuns_truncvnx1df */
    case 5305:  /* pred_narrow_fix_truncvnx1df */
    case 5304:  /* pred_narrow_fixuns_truncvnx16sf */
    case 5303:  /* pred_narrow_fix_truncvnx16sf */
    case 5302:  /* pred_narrow_fixuns_truncvnx8sf */
    case 5301:  /* pred_narrow_fix_truncvnx8sf */
    case 5300:  /* pred_narrow_fixuns_truncvnx4sf */
    case 5299:  /* pred_narrow_fix_truncvnx4sf */
    case 5298:  /* pred_narrow_fixuns_truncvnx2sf */
    case 5297:  /* pred_narrow_fix_truncvnx2sf */
    case 5296:  /* pred_narrow_fixuns_truncvnx1sf */
    case 5295:  /* pred_narrow_fix_truncvnx1sf */
    case 5294:  /* pred_narrow_fcvt_xu_fvnx8df */
    case 5293:  /* pred_narrow_fcvt_x_fvnx8df */
    case 5292:  /* pred_narrow_fcvt_xu_fvnx4df */
    case 5291:  /* pred_narrow_fcvt_x_fvnx4df */
    case 5290:  /* pred_narrow_fcvt_xu_fvnx2df */
    case 5289:  /* pred_narrow_fcvt_x_fvnx2df */
    case 5288:  /* pred_narrow_fcvt_xu_fvnx1df */
    case 5287:  /* pred_narrow_fcvt_x_fvnx1df */
    case 5286:  /* pred_narrow_fcvt_xu_fvnx16sf */
    case 5285:  /* pred_narrow_fcvt_x_fvnx16sf */
    case 5284:  /* pred_narrow_fcvt_xu_fvnx8sf */
    case 5283:  /* pred_narrow_fcvt_x_fvnx8sf */
    case 5282:  /* pred_narrow_fcvt_xu_fvnx4sf */
    case 5281:  /* pred_narrow_fcvt_x_fvnx4sf */
    case 5280:  /* pred_narrow_fcvt_xu_fvnx2sf */
    case 5279:  /* pred_narrow_fcvt_x_fvnx2sf */
    case 5278:  /* pred_narrow_fcvt_xu_fvnx1sf */
    case 5277:  /* pred_narrow_fcvt_x_fvnx1sf */
    case 5276:  /* pred_extendvnx8df */
    case 5275:  /* pred_extendvnx4df */
    case 5274:  /* pred_extendvnx2df */
    case 5273:  /* pred_extendvnx1df */
    case 5272:  /* pred_widen_floatunsvnx8df */
    case 5271:  /* pred_widen_floatvnx8df */
    case 5270:  /* pred_widen_floatunsvnx4df */
    case 5269:  /* pred_widen_floatvnx4df */
    case 5268:  /* pred_widen_floatunsvnx2df */
    case 5267:  /* pred_widen_floatvnx2df */
    case 5266:  /* pred_widen_floatunsvnx1df */
    case 5265:  /* pred_widen_floatvnx1df */
    case 5264:  /* pred_widen_floatunsvnx16sf */
    case 5263:  /* pred_widen_floatvnx16sf */
    case 5262:  /* pred_widen_floatunsvnx8sf */
    case 5261:  /* pred_widen_floatvnx8sf */
    case 5260:  /* pred_widen_floatunsvnx4sf */
    case 5259:  /* pred_widen_floatvnx4sf */
    case 5258:  /* pred_widen_floatunsvnx2sf */
    case 5257:  /* pred_widen_floatvnx2sf */
    case 5256:  /* pred_widen_floatunsvnx1sf */
    case 5255:  /* pred_widen_floatvnx1sf */
    case 5254:  /* pred_widen_fixuns_truncvnx8di */
    case 5253:  /* pred_widen_fix_truncvnx8di */
    case 5252:  /* pred_widen_fixuns_truncvnx4di */
    case 5251:  /* pred_widen_fix_truncvnx4di */
    case 5250:  /* pred_widen_fixuns_truncvnx2di */
    case 5249:  /* pred_widen_fix_truncvnx2di */
    case 5248:  /* pred_widen_fixuns_truncvnx1di */
    case 5247:  /* pred_widen_fix_truncvnx1di */
    case 5246:  /* pred_widen_fcvt_xu_fvnx8di */
    case 5245:  /* pred_widen_fcvt_x_fvnx8di */
    case 5244:  /* pred_widen_fcvt_xu_fvnx4di */
    case 5243:  /* pred_widen_fcvt_x_fvnx4di */
    case 5242:  /* pred_widen_fcvt_xu_fvnx2di */
    case 5241:  /* pred_widen_fcvt_x_fvnx2di */
    case 5240:  /* pred_widen_fcvt_xu_fvnx1di */
    case 5239:  /* pred_widen_fcvt_x_fvnx1di */
    case 5238:  /* pred_floatunsvnx8df */
    case 5237:  /* pred_floatvnx8df */
    case 5236:  /* pred_floatunsvnx4df */
    case 5235:  /* pred_floatvnx4df */
    case 5234:  /* pred_floatunsvnx2df */
    case 5233:  /* pred_floatvnx2df */
    case 5232:  /* pred_floatunsvnx1df */
    case 5231:  /* pred_floatvnx1df */
    case 5230:  /* pred_floatunsvnx16sf */
    case 5229:  /* pred_floatvnx16sf */
    case 5228:  /* pred_floatunsvnx8sf */
    case 5227:  /* pred_floatvnx8sf */
    case 5226:  /* pred_floatunsvnx4sf */
    case 5225:  /* pred_floatvnx4sf */
    case 5224:  /* pred_floatunsvnx2sf */
    case 5223:  /* pred_floatvnx2sf */
    case 5222:  /* pred_floatunsvnx1sf */
    case 5221:  /* pred_floatvnx1sf */
    case 5220:  /* pred_fixuns_truncvnx8df */
    case 5219:  /* pred_fix_truncvnx8df */
    case 5218:  /* pred_fixuns_truncvnx4df */
    case 5217:  /* pred_fix_truncvnx4df */
    case 5216:  /* pred_fixuns_truncvnx2df */
    case 5215:  /* pred_fix_truncvnx2df */
    case 5214:  /* pred_fixuns_truncvnx1df */
    case 5213:  /* pred_fix_truncvnx1df */
    case 5212:  /* pred_fixuns_truncvnx16sf */
    case 5211:  /* pred_fix_truncvnx16sf */
    case 5210:  /* pred_fixuns_truncvnx8sf */
    case 5209:  /* pred_fix_truncvnx8sf */
    case 5208:  /* pred_fixuns_truncvnx4sf */
    case 5207:  /* pred_fix_truncvnx4sf */
    case 5206:  /* pred_fixuns_truncvnx2sf */
    case 5205:  /* pred_fix_truncvnx2sf */
    case 5204:  /* pred_fixuns_truncvnx1sf */
    case 5203:  /* pred_fix_truncvnx1sf */
    case 5202:  /* pred_fcvt_xu_fvnx8df */
    case 5201:  /* pred_fcvt_x_fvnx8df */
    case 5200:  /* pred_fcvt_xu_fvnx4df */
    case 5199:  /* pred_fcvt_x_fvnx4df */
    case 5198:  /* pred_fcvt_xu_fvnx2df */
    case 5197:  /* pred_fcvt_x_fvnx2df */
    case 5196:  /* pred_fcvt_xu_fvnx1df */
    case 5195:  /* pred_fcvt_x_fvnx1df */
    case 5194:  /* pred_fcvt_xu_fvnx16sf */
    case 5193:  /* pred_fcvt_x_fvnx16sf */
    case 5192:  /* pred_fcvt_xu_fvnx8sf */
    case 5191:  /* pred_fcvt_x_fvnx8sf */
    case 5190:  /* pred_fcvt_xu_fvnx4sf */
    case 5189:  /* pred_fcvt_x_fvnx4sf */
    case 5188:  /* pred_fcvt_xu_fvnx2sf */
    case 5187:  /* pred_fcvt_x_fvnx2sf */
    case 5186:  /* pred_fcvt_xu_fvnx1sf */
    case 5185:  /* pred_fcvt_x_fvnx1sf */
    case 5049:  /* pred_classvnx8df */
    case 5048:  /* pred_classvnx4df */
    case 5047:  /* pred_classvnx2df */
    case 5046:  /* pred_classvnx1df */
    case 5045:  /* pred_classvnx16sf */
    case 5044:  /* pred_classvnx8sf */
    case 5043:  /* pred_classvnx4sf */
    case 5042:  /* pred_classvnx2sf */
    case 5041:  /* pred_classvnx1sf */
    case 5040:  /* pred_rec7vnx8df */
    case 5039:  /* pred_rsqrt7vnx8df */
    case 5038:  /* pred_rec7vnx4df */
    case 5037:  /* pred_rsqrt7vnx4df */
    case 5036:  /* pred_rec7vnx2df */
    case 5035:  /* pred_rsqrt7vnx2df */
    case 5034:  /* pred_rec7vnx1df */
    case 5033:  /* pred_rsqrt7vnx1df */
    case 5032:  /* pred_rec7vnx16sf */
    case 5031:  /* pred_rsqrt7vnx16sf */
    case 5030:  /* pred_rec7vnx8sf */
    case 5029:  /* pred_rsqrt7vnx8sf */
    case 5028:  /* pred_rec7vnx4sf */
    case 5027:  /* pred_rsqrt7vnx4sf */
    case 5026:  /* pred_rec7vnx2sf */
    case 5025:  /* pred_rsqrt7vnx2sf */
    case 5024:  /* pred_rec7vnx1sf */
    case 5023:  /* pred_rsqrt7vnx1sf */
    case 4577:  /* pred_iotavnx8di */
    case 4576:  /* pred_iotavnx4di */
    case 4575:  /* pred_iotavnx2di */
    case 4574:  /* pred_iotavnx1di */
    case 4573:  /* pred_iotavnx16si */
    case 4572:  /* pred_iotavnx8si */
    case 4571:  /* pred_iotavnx4si */
    case 4570:  /* pred_iotavnx2si */
    case 4569:  /* pred_iotavnx1si */
    case 4568:  /* pred_iotavnx32hi */
    case 4567:  /* pred_iotavnx16hi */
    case 4566:  /* pred_iotavnx8hi */
    case 4565:  /* pred_iotavnx4hi */
    case 4564:  /* pred_iotavnx2hi */
    case 4563:  /* pred_iotavnx1hi */
    case 4562:  /* pred_iotavnx64qi */
    case 4561:  /* pred_iotavnx32qi */
    case 4560:  /* pred_iotavnx16qi */
    case 4559:  /* pred_iotavnx8qi */
    case 4558:  /* pred_iotavnx4qi */
    case 4557:  /* pred_iotavnx2qi */
    case 4556:  /* pred_iotavnx1qi */
    case 2843:  /* pred_zero_extendvnx8di_vf8 */
    case 2842:  /* pred_extendvnx8di_vf8 */
    case 2841:  /* pred_zero_extendvnx4di_vf8 */
    case 2840:  /* pred_extendvnx4di_vf8 */
    case 2839:  /* pred_zero_extendvnx2di_vf8 */
    case 2838:  /* pred_extendvnx2di_vf8 */
    case 2837:  /* pred_zero_extendvnx1di_vf8 */
    case 2836:  /* pred_extendvnx1di_vf8 */
    case 2835:  /* pred_zero_extendvnx8di_vf4 */
    case 2834:  /* pred_extendvnx8di_vf4 */
    case 2833:  /* pred_zero_extendvnx4di_vf4 */
    case 2832:  /* pred_extendvnx4di_vf4 */
    case 2831:  /* pred_zero_extendvnx2di_vf4 */
    case 2830:  /* pred_extendvnx2di_vf4 */
    case 2829:  /* pred_zero_extendvnx1di_vf4 */
    case 2828:  /* pred_extendvnx1di_vf4 */
    case 2827:  /* pred_zero_extendvnx16si_vf4 */
    case 2826:  /* pred_extendvnx16si_vf4 */
    case 2825:  /* pred_zero_extendvnx8si_vf4 */
    case 2824:  /* pred_extendvnx8si_vf4 */
    case 2823:  /* pred_zero_extendvnx4si_vf4 */
    case 2822:  /* pred_extendvnx4si_vf4 */
    case 2821:  /* pred_zero_extendvnx2si_vf4 */
    case 2820:  /* pred_extendvnx2si_vf4 */
    case 2819:  /* pred_zero_extendvnx1si_vf4 */
    case 2818:  /* pred_extendvnx1si_vf4 */
    case 2817:  /* pred_zero_extendvnx8di_vf2 */
    case 2816:  /* pred_extendvnx8di_vf2 */
    case 2815:  /* pred_zero_extendvnx4di_vf2 */
    case 2814:  /* pred_extendvnx4di_vf2 */
    case 2813:  /* pred_zero_extendvnx2di_vf2 */
    case 2812:  /* pred_extendvnx2di_vf2 */
    case 2811:  /* pred_zero_extendvnx1di_vf2 */
    case 2810:  /* pred_extendvnx1di_vf2 */
    case 2809:  /* pred_zero_extendvnx16si_vf2 */
    case 2808:  /* pred_extendvnx16si_vf2 */
    case 2807:  /* pred_zero_extendvnx8si_vf2 */
    case 2806:  /* pred_extendvnx8si_vf2 */
    case 2805:  /* pred_zero_extendvnx4si_vf2 */
    case 2804:  /* pred_extendvnx4si_vf2 */
    case 2803:  /* pred_zero_extendvnx2si_vf2 */
    case 2802:  /* pred_extendvnx2si_vf2 */
    case 2801:  /* pred_zero_extendvnx1si_vf2 */
    case 2800:  /* pred_extendvnx1si_vf2 */
    case 2799:  /* pred_zero_extendvnx32hi_vf2 */
    case 2798:  /* pred_extendvnx32hi_vf2 */
    case 2797:  /* pred_zero_extendvnx16hi_vf2 */
    case 2796:  /* pred_extendvnx16hi_vf2 */
    case 2795:  /* pred_zero_extendvnx8hi_vf2 */
    case 2794:  /* pred_extendvnx8hi_vf2 */
    case 2793:  /* pred_zero_extendvnx4hi_vf2 */
    case 2792:  /* pred_extendvnx4hi_vf2 */
    case 2791:  /* pred_zero_extendvnx2hi_vf2 */
    case 2790:  /* pred_extendvnx2hi_vf2 */
    case 2789:  /* pred_zero_extendvnx1hi_vf2 */
    case 2788:  /* pred_extendvnx1hi_vf2 */
    case 967:  /* *pred_broadcastvnx8di_extended_scalar */
    case 966:  /* *pred_broadcastvnx4di_extended_scalar */
    case 965:  /* *pred_broadcastvnx2di_extended_scalar */
    case 964:  /* *pred_broadcastvnx1di_extended_scalar */
    case 2744:  /* pred_negvnx1qi */
    case 2745:  /* pred_one_cmplvnx1qi */
    case 2746:  /* pred_negvnx2qi */
    case 2747:  /* pred_one_cmplvnx2qi */
    case 2748:  /* pred_negvnx4qi */
    case 2749:  /* pred_one_cmplvnx4qi */
    case 2750:  /* pred_negvnx8qi */
    case 2751:  /* pred_one_cmplvnx8qi */
    case 2752:  /* pred_negvnx16qi */
    case 2753:  /* pred_one_cmplvnx16qi */
    case 2754:  /* pred_negvnx32qi */
    case 2755:  /* pred_one_cmplvnx32qi */
    case 2756:  /* pred_negvnx64qi */
    case 2757:  /* pred_one_cmplvnx64qi */
    case 2758:  /* pred_negvnx1hi */
    case 2759:  /* pred_one_cmplvnx1hi */
    case 2760:  /* pred_negvnx2hi */
    case 2761:  /* pred_one_cmplvnx2hi */
    case 2762:  /* pred_negvnx4hi */
    case 2763:  /* pred_one_cmplvnx4hi */
    case 2764:  /* pred_negvnx8hi */
    case 2765:  /* pred_one_cmplvnx8hi */
    case 2766:  /* pred_negvnx16hi */
    case 2767:  /* pred_one_cmplvnx16hi */
    case 2768:  /* pred_negvnx32hi */
    case 2769:  /* pred_one_cmplvnx32hi */
    case 2770:  /* pred_negvnx1si */
    case 2771:  /* pred_one_cmplvnx1si */
    case 2772:  /* pred_negvnx2si */
    case 2773:  /* pred_one_cmplvnx2si */
    case 2774:  /* pred_negvnx4si */
    case 2775:  /* pred_one_cmplvnx4si */
    case 2776:  /* pred_negvnx8si */
    case 2777:  /* pred_one_cmplvnx8si */
    case 2778:  /* pred_negvnx16si */
    case 2779:  /* pred_one_cmplvnx16si */
    case 2780:  /* pred_negvnx1di */
    case 2781:  /* pred_one_cmplvnx1di */
    case 2782:  /* pred_negvnx2di */
    case 2783:  /* pred_one_cmplvnx2di */
    case 2784:  /* pred_negvnx4di */
    case 2785:  /* pred_one_cmplvnx4di */
    case 2786:  /* pred_negvnx8di */
    case 2787:  /* pred_one_cmplvnx8di */
    case 3174:  /* pred_extendvnx1hi */
    case 3175:  /* pred_zero_extendvnx1hi */
    case 3176:  /* pred_extendvnx2hi */
    case 3177:  /* pred_zero_extendvnx2hi */
    case 3178:  /* pred_extendvnx4hi */
    case 3179:  /* pred_zero_extendvnx4hi */
    case 3180:  /* pred_extendvnx8hi */
    case 3181:  /* pred_zero_extendvnx8hi */
    case 3182:  /* pred_extendvnx16hi */
    case 3183:  /* pred_zero_extendvnx16hi */
    case 3184:  /* pred_extendvnx32hi */
    case 3185:  /* pred_zero_extendvnx32hi */
    case 3186:  /* pred_extendvnx1si */
    case 3187:  /* pred_zero_extendvnx1si */
    case 3188:  /* pred_extendvnx2si */
    case 3189:  /* pred_zero_extendvnx2si */
    case 3190:  /* pred_extendvnx4si */
    case 3191:  /* pred_zero_extendvnx4si */
    case 3192:  /* pred_extendvnx8si */
    case 3193:  /* pred_zero_extendvnx8si */
    case 3194:  /* pred_extendvnx16si */
    case 3195:  /* pred_zero_extendvnx16si */
    case 3196:  /* pred_extendvnx1di */
    case 3197:  /* pred_zero_extendvnx1di */
    case 3198:  /* pred_extendvnx2di */
    case 3199:  /* pred_zero_extendvnx2di */
    case 3200:  /* pred_extendvnx4di */
    case 3201:  /* pred_zero_extendvnx4di */
    case 3202:  /* pred_extendvnx8di */
    case 3203:  /* pred_zero_extendvnx8di */
    case 3264:  /* pred_truncvnx1hi */
    case 3265:  /* pred_truncvnx2hi */
    case 3266:  /* pred_truncvnx4hi */
    case 3267:  /* pred_truncvnx8hi */
    case 3268:  /* pred_truncvnx16hi */
    case 3269:  /* pred_truncvnx32hi */
    case 3270:  /* pred_truncvnx1si */
    case 3271:  /* pred_truncvnx2si */
    case 3272:  /* pred_truncvnx4si */
    case 3273:  /* pred_truncvnx8si */
    case 3274:  /* pred_truncvnx16si */
    case 3275:  /* pred_truncvnx1di */
    case 3276:  /* pred_truncvnx2di */
    case 3277:  /* pred_truncvnx4di */
    case 3278:  /* pred_truncvnx8di */
    case 4996:  /* pred_negvnx1sf */
    case 4997:  /* pred_absvnx1sf */
    case 4998:  /* pred_sqrtvnx1sf */
    case 4999:  /* pred_negvnx2sf */
    case 5000:  /* pred_absvnx2sf */
    case 5001:  /* pred_sqrtvnx2sf */
    case 5002:  /* pred_negvnx4sf */
    case 5003:  /* pred_absvnx4sf */
    case 5004:  /* pred_sqrtvnx4sf */
    case 5005:  /* pred_negvnx8sf */
    case 5006:  /* pred_absvnx8sf */
    case 5007:  /* pred_sqrtvnx8sf */
    case 5008:  /* pred_negvnx16sf */
    case 5009:  /* pred_absvnx16sf */
    case 5010:  /* pred_sqrtvnx16sf */
    case 5011:  /* pred_negvnx1df */
    case 5012:  /* pred_absvnx1df */
    case 5013:  /* pred_sqrtvnx1df */
    case 5014:  /* pred_negvnx2df */
    case 5015:  /* pred_absvnx2df */
    case 5016:  /* pred_sqrtvnx2df */
    case 5017:  /* pred_negvnx4df */
    case 5018:  /* pred_absvnx4df */
    case 5019:  /* pred_sqrtvnx4df */
    case 5020:  /* pred_negvnx8df */
    case 5021:  /* pred_absvnx8df */
    case 5022:  /* pred_sqrtvnx8df */
      extract_constrain_insn_cached (insn);
      return 
#line 264 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ta(operands[5]));

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      extract_constrain_insn_cached (insn);
      if (((cached_type = get_attr_type (insn)) == TYPE_VLDE) || (cached_type == TYPE_VIMOV) || (cached_type == TYPE_VFMOV) || (cached_type == TYPE_VEXT) || (cached_type == TYPE_VMIOTA) || (cached_type == TYPE_VFSQRT) || (cached_type == TYPE_VFRECP) || (cached_type == TYPE_VFCVTITOF) || (cached_type == TYPE_VFCVTFTOI) || (cached_type == TYPE_VFWCVTITOF) || (cached_type == TYPE_VFWCVTFTOI) || (cached_type == TYPE_VFWCVTFTOF) || (cached_type == TYPE_VFNCVTITOF) || (cached_type == TYPE_VFNCVTFTOI) || (cached_type == TYPE_VFNCVTFTOF) || (cached_type == TYPE_VFCLASS) || (cached_type == TYPE_VIMOVXV) || (cached_type == TYPE_VFMOVFV) || (cached_type == TYPE_VCOMPRESS) || (cached_type == TYPE_VLDFF))
        {
	  return 
#line 264 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ta(operands[5]));
        }
      else if (cached_type == TYPE_VLDS)
        {
	  if (
#line 239 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(VECTOR_MODE_P (GET_MODE (operands[3]))))
	    {
	      return 
#line 270 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ta(operands[6]));
	    }
	  else
	    {
	      return 
#line 264 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ta(operands[5]));
	    }
        }
      else if ((cached_type == TYPE_VLDUX) || (cached_type == TYPE_VLDOX) || (cached_type == TYPE_VIALU) || (cached_type == TYPE_VSHIFT) || (cached_type == TYPE_VIMINMAX) || (cached_type == TYPE_VIMUL) || (cached_type == TYPE_VIDIV) || (cached_type == TYPE_VSALU) || (cached_type == TYPE_VIWALU) || (cached_type == TYPE_VIWMUL) || (cached_type == TYPE_VNSHIFT) || (cached_type == TYPE_VIMERGE) || (cached_type == TYPE_VAALU) || (cached_type == TYPE_VSMUL) || (cached_type == TYPE_VSSHIFT) || (cached_type == TYPE_VNCLIP) || (cached_type == TYPE_VFALU) || (cached_type == TYPE_VFMUL) || (cached_type == TYPE_VFMINMAX) || (cached_type == TYPE_VFDIV) || (cached_type == TYPE_VFWALU) || (cached_type == TYPE_VFWMUL) || (cached_type == TYPE_VFSGNJ) || (cached_type == TYPE_VFMERGE) || (cached_type == TYPE_VIRED) || (cached_type == TYPE_VIWRED) || (cached_type == TYPE_VFREDU) || (cached_type == TYPE_VFREDO) || (cached_type == TYPE_VFWREDU) || (cached_type == TYPE_VFWREDO) || (cached_type == TYPE_VSLIDEUP) || (cached_type == TYPE_VSLIDEDOWN) || (cached_type == TYPE_VISLIDE1UP) || (cached_type == TYPE_VISLIDE1DOWN) || (cached_type == TYPE_VFSLIDE1UP) || (cached_type == TYPE_VFSLIDE1DOWN) || (cached_type == TYPE_VGATHER) || (cached_type == TYPE_VIWMULADD) || (cached_type == TYPE_VFWMULADD))
        {
	  return 
#line 270 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ta(operands[6]));
        }
      else if ((cached_type == TYPE_VIMULADD) || (cached_type == TYPE_VFMULADD))
        {
	  return 
#line 282 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ta(operands[7]));
        }
      else if (cached_type == TYPE_VMIDX)
        {
	  return 
#line 285 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ta(operands[4]));
        }
      else
        {
	  return 255 /* 0xff */;
        }

    default:
      extract_constrain_insn_cached (insn);
      return 
#line 270 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_ta(operands[6]));

    }
}

enum attr_type
get_attr_type (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_move_type cached_move_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 967:  /* *pred_broadcastvnx8di_extended_scalar */
    case 966:  /* *pred_broadcastvnx4di_extended_scalar */
    case 965:  /* *pred_broadcastvnx2di_extended_scalar */
    case 964:  /* *pred_broadcastvnx1di_extended_scalar */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return TYPE_VIMOV;
        }
      else
        {
	  return TYPE_VIMOVXV;
        }

    case 963:  /* *pred_broadcastvnx8df */
    case 962:  /* *pred_broadcastvnx4df */
    case 961:  /* *pred_broadcastvnx2df */
    case 960:  /* *pred_broadcastvnx1df */
    case 959:  /* *pred_broadcastvnx16sf */
    case 958:  /* *pred_broadcastvnx8sf */
    case 957:  /* *pred_broadcastvnx4sf */
    case 956:  /* *pred_broadcastvnx2sf */
    case 955:  /* *pred_broadcastvnx1sf */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return TYPE_VFMOV;
        }
      else if (((1ULL << which_alternative) & 0x3cULL))
        {
	  return TYPE_VLDS;
        }
      else
        {
	  return TYPE_VFMOVFV;
        }

    case 954:  /* *pred_broadcastvnx8di */
    case 953:  /* *pred_broadcastvnx4di */
    case 952:  /* *pred_broadcastvnx2di */
    case 951:  /* *pred_broadcastvnx1di */
    case 950:  /* *pred_broadcastvnx16si */
    case 949:  /* *pred_broadcastvnx8si */
    case 948:  /* *pred_broadcastvnx4si */
    case 947:  /* *pred_broadcastvnx2si */
    case 946:  /* *pred_broadcastvnx1si */
    case 945:  /* *pred_broadcastvnx32hi */
    case 944:  /* *pred_broadcastvnx16hi */
    case 943:  /* *pred_broadcastvnx8hi */
    case 942:  /* *pred_broadcastvnx4hi */
    case 941:  /* *pred_broadcastvnx2hi */
    case 940:  /* *pred_broadcastvnx1hi */
    case 939:  /* *pred_broadcastvnx64qi */
    case 938:  /* *pred_broadcastvnx32qi */
    case 937:  /* *pred_broadcastvnx16qi */
    case 936:  /* *pred_broadcastvnx8qi */
    case 935:  /* *pred_broadcastvnx4qi */
    case 934:  /* *pred_broadcastvnx2qi */
    case 933:  /* *pred_broadcastvnx1qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return TYPE_VIMOV;
        }
      else if (((1ULL << which_alternative) & 0x3cULL))
        {
	  return TYPE_VLDS;
        }
      else
        {
	  return TYPE_VIMOVXV;
        }

    case 868:  /* pred_movvnx64bi */
    case 867:  /* pred_movvnx32bi */
    case 866:  /* pred_movvnx16bi */
    case 865:  /* pred_movvnx8bi */
    case 864:  /* pred_movvnx4bi */
    case 863:  /* pred_movvnx2bi */
    case 862:  /* pred_movvnx1bi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_VLDM;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_VSTM;
        }
      else
        {
	  return TYPE_VMALU;
        }

    case 830:  /* pred_movvnx8df */
    case 829:  /* pred_movvnx4df */
    case 828:  /* pred_movvnx2df */
    case 827:  /* pred_movvnx1df */
    case 826:  /* pred_movvnx16sf */
    case 825:  /* pred_movvnx8sf */
    case 824:  /* pred_movvnx4sf */
    case 823:  /* pred_movvnx2sf */
    case 822:  /* pred_movvnx1sf */
    case 821:  /* pred_movvnx8di */
    case 820:  /* pred_movvnx4di */
    case 819:  /* pred_movvnx2di */
    case 818:  /* pred_movvnx1di */
    case 817:  /* pred_movvnx16si */
    case 816:  /* pred_movvnx8si */
    case 815:  /* pred_movvnx4si */
    case 814:  /* pred_movvnx2si */
    case 813:  /* pred_movvnx1si */
    case 812:  /* pred_movvnx32hi */
    case 811:  /* pred_movvnx16hi */
    case 810:  /* pred_movvnx8hi */
    case 809:  /* pred_movvnx4hi */
    case 808:  /* pred_movvnx2hi */
    case 807:  /* pred_movvnx1hi */
    case 806:  /* pred_movvnx64qi */
    case 805:  /* pred_movvnx32qi */
    case 804:  /* pred_movvnx16qi */
    case 803:  /* pred_movvnx8qi */
    case 802:  /* pred_movvnx4qi */
    case 801:  /* pred_movvnx2qi */
    case 800:  /* pred_movvnx1qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return TYPE_VLDE;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_VSTE;
        }
      else
        {
	  return TYPE_VIMOV;
        }

    case 596:  /* th_fmv_x_hw */
    case 595:  /* th_fmv_x_w */
    case 594:  /* th_fmv_hw_w_x */
      extract_constrain_insn_cached (insn);
      if ((
#line 178 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_64BIT)) == (0))
        {
	  return TYPE_MULTI;
        }
      else
        {
	  return TYPE_MOVE;
        }

    case 191:  /* *movdf_softfloat */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 1)
        {
	  return TYPE_LOAD;
        }
      else if (!((1ULL << which_alternative) & 0x3ULL))
        {
	  return TYPE_STORE;
        }
      else if ((
#line 178 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_64BIT)) == (0))
        {
	  return TYPE_MULTI;
        }
      else
        {
	  return TYPE_MOVE;
        }

    case 190:  /* *movdf_hardfloat_rv64 */
    case 189:  /* *movdf_hardfloat_rv32 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 8)
        {
	  return TYPE_LOAD;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_FPLOAD;
        }
      else if (!((1ULL << which_alternative) & 0x1efULL))
        {
	  return TYPE_STORE;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_FPSTORE;
        }
      else if (((1ULL << which_alternative) & 0x22ULL))
        {
	  return TYPE_MTC;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_MFC;
        }
      else if (which_alternative == 0)
        {
	  return TYPE_FMOVE;
        }
      else if ((
#line 178 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_64BIT)) == (0))
        {
	  return TYPE_MULTI;
        }
      else
        {
	  return TYPE_MOVE;
        }

    case 188:  /* *movsf_softfloat */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 1)
        {
	  return TYPE_LOAD;
        }
      else if (!((1ULL << which_alternative) & 0x3ULL))
        {
	  return TYPE_STORE;
        }
      else
        {
	  return TYPE_MOVE;
        }

    case 186:  /* *movqi_internal */
    case 181:  /* *movhi_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 2)
        {
	  return TYPE_LOAD;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_STORE;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_MTC;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_MFC;
        }
      else if (which_alternative == 0)
        {
	  return TYPE_MOVE;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_CONST;
        }
      else
        {
	  return TYPE_RDVLENB;
        }

    case 180:  /* *movsi_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 2)
        {
	  return TYPE_LOAD;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_FPLOAD;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_STORE;
        }
      else if (which_alternative == 7)
        {
	  return TYPE_FPSTORE;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_MTC;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_MFC;
        }
      else if (which_alternative == 0)
        {
	  return TYPE_MOVE;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_CONST;
        }
      else
        {
	  return TYPE_RDVLENB;
        }

    case 127:  /* *movhf_softfloat */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 2)
        {
	  return TYPE_LOAD;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_STORE;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_MTC;
        }
      else if (!((1ULL << which_alternative) & 0x1fULL))
        {
	  return TYPE_MFC;
        }
      else if (which_alternative == 0)
        {
	  return TYPE_FMOVE;
        }
      else
        {
	  return TYPE_MOVE;
        }

    case 187:  /* *movsf_hardfloat */
    case 126:  /* *movhf_hardfloat */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 8)
        {
	  return TYPE_LOAD;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_FPLOAD;
        }
      else if (!((1ULL << which_alternative) & 0x1efULL))
        {
	  return TYPE_STORE;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_FPSTORE;
        }
      else if (((1ULL << which_alternative) & 0x22ULL))
        {
	  return TYPE_MTC;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_MFC;
        }
      else if (which_alternative == 0)
        {
	  return TYPE_FMOVE;
        }
      else
        {
	  return TYPE_MOVE;
        }

    case 116:  /* extendsidi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return TYPE_LOAD;
        }
      else if ((
#line 178 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/riscv.md"
(TARGET_64BIT)) == (0))
        {
	  return TYPE_MULTI;
        }
      else
        {
	  return TYPE_MOVE;
        }

    case 115:  /* zero_extendqidi2 */
    case 114:  /* zero_extendqisi2 */
    case 113:  /* zero_extendqihi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return TYPE_LOAD;
        }
      else
        {
	  return TYPE_LOGICAL;
        }

    case 122:  /* *extendhidi2 */
    case 121:  /* *extendhisi2 */
    case 120:  /* *extendhihi2 */
    case 119:  /* *extendqidi2 */
    case 118:  /* *extendqisi2 */
    case 117:  /* *extendqihi2 */
    case 112:  /* *zero_extendhidi2 */
    case 111:  /* *zero_extendhisi2 */
    case 110:  /* *zero_extendsidi2_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return TYPE_LOAD;
        }
      else
        {
	  return TYPE_MULTI;
        }

    case 331:  /* *zero_extendsidi2_bitmanip */
    case 353:  /* *zero_extendhisi2_bitmanip */
    case 354:  /* *zero_extendhidi2_bitmanip */
    case 355:  /* *extendqihi2_zbb */
    case 356:  /* *extendqisi2_zbb */
    case 357:  /* *extendqidi2_zbb */
    case 358:  /* *extendhihi2_zbb */
    case 359:  /* *extendhisi2_zbb */
    case 360:  /* *extendhidi2_zbb */
    case 361:  /* *zero_extendhisi2_zbb */
    case 362:  /* *zero_extendhidi2_zbb */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_BITMANIP;
        }
      else
        {
	  return TYPE_LOAD;
        }

    case 723:  /* *movvnx4qi_whole */
    case 724:  /* *movvnx8qi_whole */
    case 725:  /* *movvnx16qi_whole */
    case 726:  /* *movvnx32qi_whole */
    case 727:  /* *movvnx64qi_whole */
    case 728:  /* *movvnx2hi_whole */
    case 729:  /* *movvnx4hi_whole */
    case 730:  /* *movvnx8hi_whole */
    case 731:  /* *movvnx16hi_whole */
    case 732:  /* *movvnx32hi_whole */
    case 733:  /* *movvnx1si_whole */
    case 734:  /* *movvnx2si_whole */
    case 735:  /* *movvnx4si_whole */
    case 736:  /* *movvnx8si_whole */
    case 737:  /* *movvnx16si_whole */
    case 738:  /* *movvnx1di_whole */
    case 739:  /* *movvnx2di_whole */
    case 740:  /* *movvnx4di_whole */
    case 741:  /* *movvnx8di_whole */
    case 742:  /* *movvnx1sf_whole */
    case 743:  /* *movvnx2sf_whole */
    case 744:  /* *movvnx4sf_whole */
    case 745:  /* *movvnx8sf_whole */
    case 746:  /* *movvnx16sf_whole */
    case 747:  /* *movvnx1df_whole */
    case 748:  /* *movvnx2df_whole */
    case 749:  /* *movvnx4df_whole */
    case 750:  /* *movvnx8df_whole */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_VLDR;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_VSTR;
        }
      else
        {
	  return TYPE_VMOV;
        }

    case 178:  /* *movdi_32bit */
    case 179:  /* *movdi_64bit */
      if (get_attr_got (insn) == GOT_LOAD)
        {
	  return TYPE_LOAD;
        }
      else if ((cached_move_type = get_attr_move_type (insn)) == MOVE_TYPE_LOAD)
        {
	  return TYPE_LOAD;
        }
      else if (cached_move_type == MOVE_TYPE_FPLOAD)
        {
	  return TYPE_FPLOAD;
        }
      else if (cached_move_type == MOVE_TYPE_STORE)
        {
	  return TYPE_STORE;
        }
      else if (cached_move_type == MOVE_TYPE_FPSTORE)
        {
	  return TYPE_FPSTORE;
        }
      else if (cached_move_type == MOVE_TYPE_MTC)
        {
	  return TYPE_MTC;
        }
      else if (cached_move_type == MOVE_TYPE_MFC)
        {
	  return TYPE_MFC;
        }
      else if (cached_move_type == MOVE_TYPE_FMOVE)
        {
	  return TYPE_FMOVE;
        }
      else if (cached_move_type == MOVE_TYPE_ARITH)
        {
	  return TYPE_ARITH;
        }
      else if (cached_move_type == MOVE_TYPE_LOGICAL)
        {
	  return TYPE_LOGICAL;
        }
      else if (cached_move_type == MOVE_TYPE_ANDI)
        {
	  return TYPE_LOGICAL;
        }
      else if (cached_move_type == MOVE_TYPE_SHIFT_SHIFT)
        {
	  return TYPE_MULTI;
        }
      else if (((cached_move_type == MOVE_TYPE_MOVE) || (cached_move_type == MOVE_TYPE_CONST)) && (get_attr_dword_mode (insn) == DWORD_MODE_YES))
        {
	  return TYPE_MULTI;
        }
      else if (cached_move_type == MOVE_TYPE_MOVE)
        {
	  return TYPE_MOVE;
        }
      else if (cached_move_type == MOVE_TYPE_CONST)
        {
	  return TYPE_CONST;
        }
      else if (cached_move_type == MOVE_TYPE_RDVLENB)
        {
	  return TYPE_RDVLENB;
        }
      else
        {
	  return TYPE_UNKNOWN;
        }

    case 751:  /* *movvnx1qi_fract */
    case 752:  /* *movvnx2qi_fract */
    case 753:  /* *movvnx4qi_fract */
    case 754:  /* *movvnx1hi_fract */
    case 755:  /* *movvnx2hi_fract */
    case 756:  /* *movvnx1si_fract */
    case 757:  /* *movvnx1sf_fract */
    case 758:  /* *movvnx1bi */
    case 759:  /* *movvnx2bi */
    case 760:  /* *movvnx4bi */
    case 761:  /* *movvnx8bi */
    case 762:  /* *movvnx16bi */
    case 763:  /* *movvnx32bi */
    case 764:  /* *movvnx64bi */
      return TYPE_VMOV;

    case 6004:  /* pred_compressvnx1qi */
    case 6005:  /* pred_compressvnx2qi */
    case 6006:  /* pred_compressvnx4qi */
    case 6007:  /* pred_compressvnx8qi */
    case 6008:  /* pred_compressvnx16qi */
    case 6009:  /* pred_compressvnx32qi */
    case 6010:  /* pred_compressvnx64qi */
    case 6011:  /* pred_compressvnx1hi */
    case 6012:  /* pred_compressvnx2hi */
    case 6013:  /* pred_compressvnx4hi */
    case 6014:  /* pred_compressvnx8hi */
    case 6015:  /* pred_compressvnx16hi */
    case 6016:  /* pred_compressvnx32hi */
    case 6017:  /* pred_compressvnx1si */
    case 6018:  /* pred_compressvnx2si */
    case 6019:  /* pred_compressvnx4si */
    case 6020:  /* pred_compressvnx8si */
    case 6021:  /* pred_compressvnx16si */
    case 6022:  /* pred_compressvnx1di */
    case 6023:  /* pred_compressvnx2di */
    case 6024:  /* pred_compressvnx4di */
    case 6025:  /* pred_compressvnx8di */
    case 6026:  /* pred_compressvnx1sf */
    case 6027:  /* pred_compressvnx2sf */
    case 6028:  /* pred_compressvnx4sf */
    case 6029:  /* pred_compressvnx8sf */
    case 6030:  /* pred_compressvnx16sf */
    case 6031:  /* pred_compressvnx1df */
    case 6032:  /* pred_compressvnx2df */
    case 6033:  /* pred_compressvnx4df */
    case 6034:  /* pred_compressvnx8df */
      return TYPE_VCOMPRESS;

    case 5912:  /* pred_gathervnx1qi */
    case 5913:  /* pred_gathervnx2qi */
    case 5914:  /* pred_gathervnx4qi */
    case 5915:  /* pred_gathervnx8qi */
    case 5916:  /* pred_gathervnx16qi */
    case 5917:  /* pred_gathervnx32qi */
    case 5918:  /* pred_gathervnx64qi */
    case 5919:  /* pred_gathervnx1hi */
    case 5920:  /* pred_gathervnx2hi */
    case 5921:  /* pred_gathervnx4hi */
    case 5922:  /* pred_gathervnx8hi */
    case 5923:  /* pred_gathervnx16hi */
    case 5924:  /* pred_gathervnx32hi */
    case 5925:  /* pred_gathervnx1si */
    case 5926:  /* pred_gathervnx2si */
    case 5927:  /* pred_gathervnx4si */
    case 5928:  /* pred_gathervnx8si */
    case 5929:  /* pred_gathervnx16si */
    case 5930:  /* pred_gathervnx1di */
    case 5931:  /* pred_gathervnx2di */
    case 5932:  /* pred_gathervnx4di */
    case 5933:  /* pred_gathervnx8di */
    case 5934:  /* pred_gathervnx1sf */
    case 5935:  /* pred_gathervnx2sf */
    case 5936:  /* pred_gathervnx4sf */
    case 5937:  /* pred_gathervnx8sf */
    case 5938:  /* pred_gathervnx16sf */
    case 5939:  /* pred_gathervnx1df */
    case 5940:  /* pred_gathervnx2df */
    case 5941:  /* pred_gathervnx4df */
    case 5942:  /* pred_gathervnx8df */
    case 5943:  /* pred_gathervnx1qi_scalar */
    case 5944:  /* pred_gathervnx2qi_scalar */
    case 5945:  /* pred_gathervnx4qi_scalar */
    case 5946:  /* pred_gathervnx8qi_scalar */
    case 5947:  /* pred_gathervnx16qi_scalar */
    case 5948:  /* pred_gathervnx32qi_scalar */
    case 5949:  /* pred_gathervnx64qi_scalar */
    case 5950:  /* pred_gathervnx1hi_scalar */
    case 5951:  /* pred_gathervnx2hi_scalar */
    case 5952:  /* pred_gathervnx4hi_scalar */
    case 5953:  /* pred_gathervnx8hi_scalar */
    case 5954:  /* pred_gathervnx16hi_scalar */
    case 5955:  /* pred_gathervnx32hi_scalar */
    case 5956:  /* pred_gathervnx1si_scalar */
    case 5957:  /* pred_gathervnx2si_scalar */
    case 5958:  /* pred_gathervnx4si_scalar */
    case 5959:  /* pred_gathervnx8si_scalar */
    case 5960:  /* pred_gathervnx16si_scalar */
    case 5961:  /* pred_gathervnx1di_scalar */
    case 5962:  /* pred_gathervnx2di_scalar */
    case 5963:  /* pred_gathervnx4di_scalar */
    case 5964:  /* pred_gathervnx8di_scalar */
    case 5965:  /* pred_gathervnx1sf_scalar */
    case 5966:  /* pred_gathervnx2sf_scalar */
    case 5967:  /* pred_gathervnx4sf_scalar */
    case 5968:  /* pred_gathervnx8sf_scalar */
    case 5969:  /* pred_gathervnx16sf_scalar */
    case 5970:  /* pred_gathervnx1df_scalar */
    case 5971:  /* pred_gathervnx2df_scalar */
    case 5972:  /* pred_gathervnx4df_scalar */
    case 5973:  /* pred_gathervnx8df_scalar */
    case 5974:  /* pred_gatherei16vnx1qi */
    case 5975:  /* pred_gatherei16vnx2qi */
    case 5976:  /* pred_gatherei16vnx4qi */
    case 5977:  /* pred_gatherei16vnx8qi */
    case 5978:  /* pred_gatherei16vnx16qi */
    case 5979:  /* pred_gatherei16vnx32qi */
    case 5980:  /* pred_gatherei16vnx1hi */
    case 5981:  /* pred_gatherei16vnx2hi */
    case 5982:  /* pred_gatherei16vnx4hi */
    case 5983:  /* pred_gatherei16vnx8hi */
    case 5984:  /* pred_gatherei16vnx16hi */
    case 5985:  /* pred_gatherei16vnx32hi */
    case 5986:  /* pred_gatherei16vnx1si */
    case 5987:  /* pred_gatherei16vnx2si */
    case 5988:  /* pred_gatherei16vnx4si */
    case 5989:  /* pred_gatherei16vnx8si */
    case 5990:  /* pred_gatherei16vnx16si */
    case 5991:  /* pred_gatherei16vnx1di */
    case 5992:  /* pred_gatherei16vnx2di */
    case 5993:  /* pred_gatherei16vnx4di */
    case 5994:  /* pred_gatherei16vnx8di */
    case 5995:  /* pred_gatherei16vnx1sf */
    case 5996:  /* pred_gatherei16vnx2sf */
    case 5997:  /* pred_gatherei16vnx4sf */
    case 5998:  /* pred_gatherei16vnx8sf */
    case 5999:  /* pred_gatherei16vnx16sf */
    case 6000:  /* pred_gatherei16vnx1df */
    case 6001:  /* pred_gatherei16vnx2df */
    case 6002:  /* pred_gatherei16vnx4df */
    case 6003:  /* pred_gatherei16vnx8df */
      return TYPE_VGATHER;

    case 5895:  /* pred_slide1downvnx1sf */
    case 5897:  /* pred_slide1downvnx2sf */
    case 5899:  /* pred_slide1downvnx4sf */
    case 5901:  /* pred_slide1downvnx8sf */
    case 5903:  /* pred_slide1downvnx16sf */
    case 5905:  /* pred_slide1downvnx1df */
    case 5907:  /* pred_slide1downvnx2df */
    case 5909:  /* pred_slide1downvnx4df */
    case 5911:  /* pred_slide1downvnx8df */
      return TYPE_VFSLIDE1DOWN;

    case 5894:  /* pred_slide1upvnx1sf */
    case 5896:  /* pred_slide1upvnx2sf */
    case 5898:  /* pred_slide1upvnx4sf */
    case 5900:  /* pred_slide1upvnx8sf */
    case 5902:  /* pred_slide1upvnx16sf */
    case 5904:  /* pred_slide1upvnx1df */
    case 5906:  /* pred_slide1upvnx2df */
    case 5908:  /* pred_slide1upvnx4df */
    case 5910:  /* pred_slide1upvnx8df */
      return TYPE_VFSLIDE1UP;

    case 5843:  /* pred_slide1downvnx1qi */
    case 5845:  /* pred_slide1downvnx2qi */
    case 5847:  /* pred_slide1downvnx4qi */
    case 5849:  /* pred_slide1downvnx8qi */
    case 5851:  /* pred_slide1downvnx16qi */
    case 5853:  /* pred_slide1downvnx32qi */
    case 5855:  /* pred_slide1downvnx64qi */
    case 5857:  /* pred_slide1downvnx1hi */
    case 5859:  /* pred_slide1downvnx2hi */
    case 5861:  /* pred_slide1downvnx4hi */
    case 5863:  /* pred_slide1downvnx8hi */
    case 5865:  /* pred_slide1downvnx16hi */
    case 5867:  /* pred_slide1downvnx32hi */
    case 5869:  /* pred_slide1downvnx1si */
    case 5871:  /* pred_slide1downvnx2si */
    case 5873:  /* pred_slide1downvnx4si */
    case 5875:  /* pred_slide1downvnx8si */
    case 5877:  /* pred_slide1downvnx16si */
    case 5879:  /* *pred_slide1downvnx1di */
    case 5881:  /* *pred_slide1downvnx2di */
    case 5883:  /* *pred_slide1downvnx4di */
    case 5885:  /* *pred_slide1downvnx8di */
    case 5887:  /* *pred_slide1downvnx1di_extended */
    case 5889:  /* *pred_slide1downvnx2di_extended */
    case 5891:  /* *pred_slide1downvnx4di_extended */
    case 5893:  /* *pred_slide1downvnx8di_extended */
      return TYPE_VISLIDE1DOWN;

    case 5842:  /* pred_slide1upvnx1qi */
    case 5844:  /* pred_slide1upvnx2qi */
    case 5846:  /* pred_slide1upvnx4qi */
    case 5848:  /* pred_slide1upvnx8qi */
    case 5850:  /* pred_slide1upvnx16qi */
    case 5852:  /* pred_slide1upvnx32qi */
    case 5854:  /* pred_slide1upvnx64qi */
    case 5856:  /* pred_slide1upvnx1hi */
    case 5858:  /* pred_slide1upvnx2hi */
    case 5860:  /* pred_slide1upvnx4hi */
    case 5862:  /* pred_slide1upvnx8hi */
    case 5864:  /* pred_slide1upvnx16hi */
    case 5866:  /* pred_slide1upvnx32hi */
    case 5868:  /* pred_slide1upvnx1si */
    case 5870:  /* pred_slide1upvnx2si */
    case 5872:  /* pred_slide1upvnx4si */
    case 5874:  /* pred_slide1upvnx8si */
    case 5876:  /* pred_slide1upvnx16si */
    case 5878:  /* *pred_slide1upvnx1di */
    case 5880:  /* *pred_slide1upvnx2di */
    case 5882:  /* *pred_slide1upvnx4di */
    case 5884:  /* *pred_slide1upvnx8di */
    case 5886:  /* *pred_slide1upvnx1di_extended */
    case 5888:  /* *pred_slide1upvnx2di_extended */
    case 5890:  /* *pred_slide1upvnx4di_extended */
    case 5892:  /* *pred_slide1upvnx8di_extended */
      return TYPE_VISLIDE1UP;

    case 5781:  /* pred_slidedownvnx1qi */
    case 5783:  /* pred_slidedownvnx2qi */
    case 5785:  /* pred_slidedownvnx4qi */
    case 5787:  /* pred_slidedownvnx8qi */
    case 5789:  /* pred_slidedownvnx16qi */
    case 5791:  /* pred_slidedownvnx32qi */
    case 5793:  /* pred_slidedownvnx64qi */
    case 5795:  /* pred_slidedownvnx1hi */
    case 5797:  /* pred_slidedownvnx2hi */
    case 5799:  /* pred_slidedownvnx4hi */
    case 5801:  /* pred_slidedownvnx8hi */
    case 5803:  /* pred_slidedownvnx16hi */
    case 5805:  /* pred_slidedownvnx32hi */
    case 5807:  /* pred_slidedownvnx1si */
    case 5809:  /* pred_slidedownvnx2si */
    case 5811:  /* pred_slidedownvnx4si */
    case 5813:  /* pred_slidedownvnx8si */
    case 5815:  /* pred_slidedownvnx16si */
    case 5817:  /* pred_slidedownvnx1di */
    case 5819:  /* pred_slidedownvnx2di */
    case 5821:  /* pred_slidedownvnx4di */
    case 5823:  /* pred_slidedownvnx8di */
    case 5825:  /* pred_slidedownvnx1sf */
    case 5827:  /* pred_slidedownvnx2sf */
    case 5829:  /* pred_slidedownvnx4sf */
    case 5831:  /* pred_slidedownvnx8sf */
    case 5833:  /* pred_slidedownvnx16sf */
    case 5835:  /* pred_slidedownvnx1df */
    case 5837:  /* pred_slidedownvnx2df */
    case 5839:  /* pred_slidedownvnx4df */
    case 5841:  /* pred_slidedownvnx8df */
      return TYPE_VSLIDEDOWN;

    case 5780:  /* pred_slideupvnx1qi */
    case 5782:  /* pred_slideupvnx2qi */
    case 5784:  /* pred_slideupvnx4qi */
    case 5786:  /* pred_slideupvnx8qi */
    case 5788:  /* pred_slideupvnx16qi */
    case 5790:  /* pred_slideupvnx32qi */
    case 5792:  /* pred_slideupvnx64qi */
    case 5794:  /* pred_slideupvnx1hi */
    case 5796:  /* pred_slideupvnx2hi */
    case 5798:  /* pred_slideupvnx4hi */
    case 5800:  /* pred_slideupvnx8hi */
    case 5802:  /* pred_slideupvnx16hi */
    case 5804:  /* pred_slideupvnx32hi */
    case 5806:  /* pred_slideupvnx1si */
    case 5808:  /* pred_slideupvnx2si */
    case 5810:  /* pred_slideupvnx4si */
    case 5812:  /* pred_slideupvnx8si */
    case 5814:  /* pred_slideupvnx16si */
    case 5816:  /* pred_slideupvnx1di */
    case 5818:  /* pred_slideupvnx2di */
    case 5820:  /* pred_slideupvnx4di */
    case 5822:  /* pred_slideupvnx8di */
    case 5824:  /* pred_slideupvnx1sf */
    case 5826:  /* pred_slideupvnx2sf */
    case 5828:  /* pred_slideupvnx4sf */
    case 5830:  /* pred_slideupvnx8sf */
    case 5832:  /* pred_slideupvnx16sf */
    case 5834:  /* pred_slideupvnx1df */
    case 5836:  /* pred_slideupvnx2df */
    case 5838:  /* pred_slideupvnx4df */
    case 5840:  /* pred_slideupvnx8df */
      return TYPE_VSLIDEUP;

    case 5771:  /* *pred_extract_firstvnx1sf */
    case 5772:  /* *pred_extract_firstvnx2sf */
    case 5773:  /* *pred_extract_firstvnx4sf */
    case 5774:  /* *pred_extract_firstvnx8sf */
    case 5775:  /* *pred_extract_firstvnx16sf */
    case 5776:  /* *pred_extract_firstvnx1df */
    case 5777:  /* *pred_extract_firstvnx2df */
    case 5778:  /* *pred_extract_firstvnx4df */
    case 5779:  /* *pred_extract_firstvnx8df */
      return TYPE_VFMOVVF;

    case 5745:  /* *pred_extract_firstvnx1qi */
    case 5746:  /* *pred_extract_firstvnx2qi */
    case 5747:  /* *pred_extract_firstvnx4qi */
    case 5748:  /* *pred_extract_firstvnx8qi */
    case 5749:  /* *pred_extract_firstvnx16qi */
    case 5750:  /* *pred_extract_firstvnx32qi */
    case 5751:  /* *pred_extract_firstvnx64qi */
    case 5752:  /* *pred_extract_firstvnx1hi */
    case 5753:  /* *pred_extract_firstvnx2hi */
    case 5754:  /* *pred_extract_firstvnx4hi */
    case 5755:  /* *pred_extract_firstvnx8hi */
    case 5756:  /* *pred_extract_firstvnx16hi */
    case 5757:  /* *pred_extract_firstvnx32hi */
    case 5758:  /* *pred_extract_firstvnx1si */
    case 5759:  /* *pred_extract_firstvnx2si */
    case 5760:  /* *pred_extract_firstvnx4si */
    case 5761:  /* *pred_extract_firstvnx8si */
    case 5762:  /* *pred_extract_firstvnx16si */
    case 5763:  /* *pred_extract_firstvnx1di */
    case 5764:  /* *pred_extract_firstvnx2di */
    case 5765:  /* *pred_extract_firstvnx4di */
    case 5766:  /* *pred_extract_firstvnx8di */
    case 5767:  /* pred_extract_first_truncvnx1di */
    case 5768:  /* pred_extract_first_truncvnx2di */
    case 5769:  /* pred_extract_first_truncvnx4di */
    case 5770:  /* pred_extract_first_truncvnx8di */
      return TYPE_VIMOVVX;

    case 4578:  /* pred_seriesvnx1qi */
    case 4579:  /* pred_seriesvnx2qi */
    case 4580:  /* pred_seriesvnx4qi */
    case 4581:  /* pred_seriesvnx8qi */
    case 4582:  /* pred_seriesvnx16qi */
    case 4583:  /* pred_seriesvnx32qi */
    case 4584:  /* pred_seriesvnx64qi */
    case 4585:  /* pred_seriesvnx1hi */
    case 4586:  /* pred_seriesvnx2hi */
    case 4587:  /* pred_seriesvnx4hi */
    case 4588:  /* pred_seriesvnx8hi */
    case 4589:  /* pred_seriesvnx16hi */
    case 4590:  /* pred_seriesvnx32hi */
    case 4591:  /* pred_seriesvnx1si */
    case 4592:  /* pred_seriesvnx2si */
    case 4593:  /* pred_seriesvnx4si */
    case 4594:  /* pred_seriesvnx8si */
    case 4595:  /* pred_seriesvnx16si */
    case 4596:  /* pred_seriesvnx1di */
    case 4597:  /* pred_seriesvnx2di */
    case 4598:  /* pred_seriesvnx4di */
    case 4599:  /* pred_seriesvnx8di */
      return TYPE_VMIDX;

    case 4556:  /* pred_iotavnx1qi */
    case 4557:  /* pred_iotavnx2qi */
    case 4558:  /* pred_iotavnx4qi */
    case 4559:  /* pred_iotavnx8qi */
    case 4560:  /* pred_iotavnx16qi */
    case 4561:  /* pred_iotavnx32qi */
    case 4562:  /* pred_iotavnx64qi */
    case 4563:  /* pred_iotavnx1hi */
    case 4564:  /* pred_iotavnx2hi */
    case 4565:  /* pred_iotavnx4hi */
    case 4566:  /* pred_iotavnx8hi */
    case 4567:  /* pred_iotavnx16hi */
    case 4568:  /* pred_iotavnx32hi */
    case 4569:  /* pred_iotavnx1si */
    case 4570:  /* pred_iotavnx2si */
    case 4571:  /* pred_iotavnx4si */
    case 4572:  /* pred_iotavnx8si */
    case 4573:  /* pred_iotavnx16si */
    case 4574:  /* pred_iotavnx1di */
    case 4575:  /* pred_iotavnx2di */
    case 4576:  /* pred_iotavnx4di */
    case 4577:  /* pred_iotavnx8di */
      return TYPE_VMIOTA;

    case 4535:  /* pred_sbfvnx1bi */
    case 4536:  /* pred_sifvnx1bi */
    case 4537:  /* pred_sofvnx1bi */
    case 4538:  /* pred_sbfvnx2bi */
    case 4539:  /* pred_sifvnx2bi */
    case 4540:  /* pred_sofvnx2bi */
    case 4541:  /* pred_sbfvnx4bi */
    case 4542:  /* pred_sifvnx4bi */
    case 4543:  /* pred_sofvnx4bi */
    case 4544:  /* pred_sbfvnx8bi */
    case 4545:  /* pred_sifvnx8bi */
    case 4546:  /* pred_sofvnx8bi */
    case 4547:  /* pred_sbfvnx16bi */
    case 4548:  /* pred_sifvnx16bi */
    case 4549:  /* pred_sofvnx16bi */
    case 4550:  /* pred_sbfvnx32bi */
    case 4551:  /* pred_sifvnx32bi */
    case 4552:  /* pred_sofvnx32bi */
    case 4553:  /* pred_sbfvnx64bi */
    case 4554:  /* pred_sifvnx64bi */
    case 4555:  /* pred_sofvnx64bi */
      return TYPE_VMSFS;

    case 4521:  /* pred_ffsvnx1bisi */
    case 4522:  /* pred_ffsvnx2bisi */
    case 4523:  /* pred_ffsvnx4bisi */
    case 4524:  /* pred_ffsvnx8bisi */
    case 4525:  /* pred_ffsvnx16bisi */
    case 4526:  /* pred_ffsvnx32bisi */
    case 4527:  /* pred_ffsvnx64bisi */
    case 4528:  /* pred_ffsvnx1bidi */
    case 4529:  /* pred_ffsvnx2bidi */
    case 4530:  /* pred_ffsvnx4bidi */
    case 4531:  /* pred_ffsvnx8bidi */
    case 4532:  /* pred_ffsvnx16bidi */
    case 4533:  /* pred_ffsvnx32bidi */
    case 4534:  /* pred_ffsvnx64bidi */
      return TYPE_VMFFS;

    case 4507:  /* pred_popcountvnx1bisi */
    case 4508:  /* pred_popcountvnx2bisi */
    case 4509:  /* pred_popcountvnx4bisi */
    case 4510:  /* pred_popcountvnx8bisi */
    case 4511:  /* pred_popcountvnx16bisi */
    case 4512:  /* pred_popcountvnx32bisi */
    case 4513:  /* pred_popcountvnx64bisi */
    case 4514:  /* pred_popcountvnx1bidi */
    case 4515:  /* pred_popcountvnx2bidi */
    case 4516:  /* pred_popcountvnx4bidi */
    case 4517:  /* pred_popcountvnx8bidi */
    case 4518:  /* pred_popcountvnx16bidi */
    case 4519:  /* pred_popcountvnx32bidi */
    case 4520:  /* pred_popcountvnx64bidi */
      return TYPE_VMPOP;

    case 4444:  /* pred_andvnx1bi */
    case 4445:  /* pred_iorvnx1bi */
    case 4446:  /* pred_xorvnx1bi */
    case 4447:  /* pred_andvnx2bi */
    case 4448:  /* pred_iorvnx2bi */
    case 4449:  /* pred_xorvnx2bi */
    case 4450:  /* pred_andvnx4bi */
    case 4451:  /* pred_iorvnx4bi */
    case 4452:  /* pred_xorvnx4bi */
    case 4453:  /* pred_andvnx8bi */
    case 4454:  /* pred_iorvnx8bi */
    case 4455:  /* pred_xorvnx8bi */
    case 4456:  /* pred_andvnx16bi */
    case 4457:  /* pred_iorvnx16bi */
    case 4458:  /* pred_xorvnx16bi */
    case 4459:  /* pred_andvnx32bi */
    case 4460:  /* pred_iorvnx32bi */
    case 4461:  /* pred_xorvnx32bi */
    case 4462:  /* pred_andvnx64bi */
    case 4463:  /* pred_iorvnx64bi */
    case 4464:  /* pred_xorvnx64bi */
    case 4465:  /* pred_nandvnx1bi */
    case 4466:  /* pred_niorvnx1bi */
    case 4467:  /* pred_nxorvnx1bi */
    case 4468:  /* pred_nandvnx2bi */
    case 4469:  /* pred_niorvnx2bi */
    case 4470:  /* pred_nxorvnx2bi */
    case 4471:  /* pred_nandvnx4bi */
    case 4472:  /* pred_niorvnx4bi */
    case 4473:  /* pred_nxorvnx4bi */
    case 4474:  /* pred_nandvnx8bi */
    case 4475:  /* pred_niorvnx8bi */
    case 4476:  /* pred_nxorvnx8bi */
    case 4477:  /* pred_nandvnx16bi */
    case 4478:  /* pred_niorvnx16bi */
    case 4479:  /* pred_nxorvnx16bi */
    case 4480:  /* pred_nandvnx32bi */
    case 4481:  /* pred_niorvnx32bi */
    case 4482:  /* pred_nxorvnx32bi */
    case 4483:  /* pred_nandvnx64bi */
    case 4484:  /* pred_niorvnx64bi */
    case 4485:  /* pred_nxorvnx64bi */
    case 4486:  /* pred_andnotvnx1bi */
    case 4487:  /* pred_iornotvnx1bi */
    case 4488:  /* pred_andnotvnx2bi */
    case 4489:  /* pred_iornotvnx2bi */
    case 4490:  /* pred_andnotvnx4bi */
    case 4491:  /* pred_iornotvnx4bi */
    case 4492:  /* pred_andnotvnx8bi */
    case 4493:  /* pred_iornotvnx8bi */
    case 4494:  /* pred_andnotvnx16bi */
    case 4495:  /* pred_iornotvnx16bi */
    case 4496:  /* pred_andnotvnx32bi */
    case 4497:  /* pred_iornotvnx32bi */
    case 4498:  /* pred_andnotvnx64bi */
    case 4499:  /* pred_iornotvnx64bi */
    case 4500:  /* pred_notvnx1bi */
    case 4501:  /* pred_notvnx2bi */
    case 4502:  /* pred_notvnx4bi */
    case 4503:  /* pred_notvnx8bi */
    case 4504:  /* pred_notvnx16bi */
    case 4505:  /* pred_notvnx32bi */
    case 4506:  /* pred_notvnx64bi */
      return TYPE_VMALU;

    case 5735:  /* pred_widen_reduc_plusovnx1sfvnx1df */
    case 5737:  /* pred_widen_reduc_plusovnx2sfvnx1df */
    case 5739:  /* pred_widen_reduc_plusovnx4sfvnx1df */
    case 5741:  /* pred_widen_reduc_plusovnx8sfvnx1df */
    case 5743:  /* pred_widen_reduc_plusovnx16sfvnx1df */
      return TYPE_VFWREDO;

    case 5736:  /* pred_widen_reduc_plusuvnx1sfvnx1df */
    case 5738:  /* pred_widen_reduc_plusuvnx2sfvnx1df */
    case 5740:  /* pred_widen_reduc_plusuvnx4sfvnx1df */
    case 5742:  /* pred_widen_reduc_plusuvnx8sfvnx1df */
    case 5744:  /* pred_widen_reduc_plusuvnx16sfvnx1df */
      return TYPE_VFWREDU;

    case 5709:  /* pred_reduc_plusovnx1sfvnx2sf */
    case 5711:  /* pred_reduc_plusovnx2sfvnx2sf */
    case 5713:  /* pred_reduc_plusovnx4sfvnx2sf */
    case 5715:  /* pred_reduc_plusovnx8sfvnx2sf */
    case 5717:  /* pred_reduc_plusovnx16sfvnx2sf */
    case 5719:  /* pred_reduc_plusovnx1dfvnx1df */
    case 5721:  /* pred_reduc_plusovnx2dfvnx1df */
    case 5723:  /* pred_reduc_plusovnx4dfvnx1df */
    case 5725:  /* pred_reduc_plusovnx8dfvnx1df */
    case 5727:  /* pred_reduc_plusovnx1sfvnx1sf */
    case 5729:  /* pred_reduc_plusovnx2sfvnx1sf */
    case 5731:  /* pred_reduc_plusovnx4sfvnx1sf */
    case 5733:  /* pred_reduc_plusovnx8sfvnx1sf */
      return TYPE_VFREDO;

    case 5683:  /* pred_reduc_maxvnx1sfvnx2sf */
    case 5684:  /* pred_reduc_minvnx1sfvnx2sf */
    case 5685:  /* pred_reduc_maxvnx2sfvnx2sf */
    case 5686:  /* pred_reduc_minvnx2sfvnx2sf */
    case 5687:  /* pred_reduc_maxvnx4sfvnx2sf */
    case 5688:  /* pred_reduc_minvnx4sfvnx2sf */
    case 5689:  /* pred_reduc_maxvnx8sfvnx2sf */
    case 5690:  /* pred_reduc_minvnx8sfvnx2sf */
    case 5691:  /* pred_reduc_maxvnx16sfvnx2sf */
    case 5692:  /* pred_reduc_minvnx16sfvnx2sf */
    case 5693:  /* pred_reduc_maxvnx1dfvnx1df */
    case 5694:  /* pred_reduc_minvnx1dfvnx1df */
    case 5695:  /* pred_reduc_maxvnx2dfvnx1df */
    case 5696:  /* pred_reduc_minvnx2dfvnx1df */
    case 5697:  /* pred_reduc_maxvnx4dfvnx1df */
    case 5698:  /* pred_reduc_minvnx4dfvnx1df */
    case 5699:  /* pred_reduc_maxvnx8dfvnx1df */
    case 5700:  /* pred_reduc_minvnx8dfvnx1df */
    case 5701:  /* pred_reduc_maxvnx1sfvnx1sf */
    case 5702:  /* pred_reduc_minvnx1sfvnx1sf */
    case 5703:  /* pred_reduc_maxvnx2sfvnx1sf */
    case 5704:  /* pred_reduc_minvnx2sfvnx1sf */
    case 5705:  /* pred_reduc_maxvnx4sfvnx1sf */
    case 5706:  /* pred_reduc_minvnx4sfvnx1sf */
    case 5707:  /* pred_reduc_maxvnx8sfvnx1sf */
    case 5708:  /* pred_reduc_minvnx8sfvnx1sf */
    case 5710:  /* pred_reduc_plusuvnx1sfvnx2sf */
    case 5712:  /* pred_reduc_plusuvnx2sfvnx2sf */
    case 5714:  /* pred_reduc_plusuvnx4sfvnx2sf */
    case 5716:  /* pred_reduc_plusuvnx8sfvnx2sf */
    case 5718:  /* pred_reduc_plusuvnx16sfvnx2sf */
    case 5720:  /* pred_reduc_plusuvnx1dfvnx1df */
    case 5722:  /* pred_reduc_plusuvnx2dfvnx1df */
    case 5724:  /* pred_reduc_plusuvnx4dfvnx1df */
    case 5726:  /* pred_reduc_plusuvnx8dfvnx1df */
    case 5728:  /* pred_reduc_plusuvnx1sfvnx1sf */
    case 5730:  /* pred_reduc_plusuvnx2sfvnx1sf */
    case 5732:  /* pred_reduc_plusuvnx4sfvnx1sf */
    case 5734:  /* pred_reduc_plusuvnx8sfvnx1sf */
      return TYPE_VFREDU;

    case 5625:  /* pred_widen_reduc_plusvnx1qivnx4hi */
    case 5626:  /* pred_widen_reduc_plusuvnx1qivnx4hi */
    case 5627:  /* pred_widen_reduc_plusvnx2qivnx4hi */
    case 5628:  /* pred_widen_reduc_plusuvnx2qivnx4hi */
    case 5629:  /* pred_widen_reduc_plusvnx4qivnx4hi */
    case 5630:  /* pred_widen_reduc_plusuvnx4qivnx4hi */
    case 5631:  /* pred_widen_reduc_plusvnx8qivnx4hi */
    case 5632:  /* pred_widen_reduc_plusuvnx8qivnx4hi */
    case 5633:  /* pred_widen_reduc_plusvnx16qivnx4hi */
    case 5634:  /* pred_widen_reduc_plusuvnx16qivnx4hi */
    case 5635:  /* pred_widen_reduc_plusvnx32qivnx4hi */
    case 5636:  /* pred_widen_reduc_plusuvnx32qivnx4hi */
    case 5637:  /* pred_widen_reduc_plusvnx64qivnx4hi */
    case 5638:  /* pred_widen_reduc_plusuvnx64qivnx4hi */
    case 5639:  /* pred_widen_reduc_plusvnx1hivnx2si */
    case 5640:  /* pred_widen_reduc_plusuvnx1hivnx2si */
    case 5641:  /* pred_widen_reduc_plusvnx2hivnx2si */
    case 5642:  /* pred_widen_reduc_plusuvnx2hivnx2si */
    case 5643:  /* pred_widen_reduc_plusvnx4hivnx2si */
    case 5644:  /* pred_widen_reduc_plusuvnx4hivnx2si */
    case 5645:  /* pred_widen_reduc_plusvnx8hivnx2si */
    case 5646:  /* pred_widen_reduc_plusuvnx8hivnx2si */
    case 5647:  /* pred_widen_reduc_plusvnx16hivnx2si */
    case 5648:  /* pred_widen_reduc_plusuvnx16hivnx2si */
    case 5649:  /* pred_widen_reduc_plusvnx32hivnx2si */
    case 5650:  /* pred_widen_reduc_plusuvnx32hivnx2si */
    case 5651:  /* pred_widen_reduc_plusvnx1sivnx2di */
    case 5652:  /* pred_widen_reduc_plusuvnx1sivnx2di */
    case 5653:  /* pred_widen_reduc_plusvnx2sivnx2di */
    case 5654:  /* pred_widen_reduc_plusuvnx2sivnx2di */
    case 5655:  /* pred_widen_reduc_plusvnx4sivnx2di */
    case 5656:  /* pred_widen_reduc_plusuvnx4sivnx2di */
    case 5657:  /* pred_widen_reduc_plusvnx8sivnx2di */
    case 5658:  /* pred_widen_reduc_plusuvnx8sivnx2di */
    case 5659:  /* pred_widen_reduc_plusvnx16sivnx2di */
    case 5660:  /* pred_widen_reduc_plusuvnx16sivnx2di */
    case 5661:  /* pred_widen_reduc_plusvnx1qivnx2hi */
    case 5662:  /* pred_widen_reduc_plusuvnx1qivnx2hi */
    case 5663:  /* pred_widen_reduc_plusvnx2qivnx2hi */
    case 5664:  /* pred_widen_reduc_plusuvnx2qivnx2hi */
    case 5665:  /* pred_widen_reduc_plusvnx4qivnx2hi */
    case 5666:  /* pred_widen_reduc_plusuvnx4qivnx2hi */
    case 5667:  /* pred_widen_reduc_plusvnx8qivnx2hi */
    case 5668:  /* pred_widen_reduc_plusuvnx8qivnx2hi */
    case 5669:  /* pred_widen_reduc_plusvnx16qivnx2hi */
    case 5670:  /* pred_widen_reduc_plusuvnx16qivnx2hi */
    case 5671:  /* pred_widen_reduc_plusvnx32qivnx2hi */
    case 5672:  /* pred_widen_reduc_plusuvnx32qivnx2hi */
    case 5673:  /* pred_widen_reduc_plusvnx1hivnx1si */
    case 5674:  /* pred_widen_reduc_plusuvnx1hivnx1si */
    case 5675:  /* pred_widen_reduc_plusvnx2hivnx1si */
    case 5676:  /* pred_widen_reduc_plusuvnx2hivnx1si */
    case 5677:  /* pred_widen_reduc_plusvnx4hivnx1si */
    case 5678:  /* pred_widen_reduc_plusuvnx4hivnx1si */
    case 5679:  /* pred_widen_reduc_plusvnx8hivnx1si */
    case 5680:  /* pred_widen_reduc_plusuvnx8hivnx1si */
    case 5681:  /* pred_widen_reduc_plusvnx16hivnx1si */
    case 5682:  /* pred_widen_reduc_plusuvnx16hivnx1si */
      return TYPE_VIWRED;

    case 5329:  /* pred_reduc_sumvnx1qivnx8qi */
    case 5330:  /* pred_reduc_maxuvnx1qivnx8qi */
    case 5331:  /* pred_reduc_maxvnx1qivnx8qi */
    case 5332:  /* pred_reduc_minuvnx1qivnx8qi */
    case 5333:  /* pred_reduc_minvnx1qivnx8qi */
    case 5334:  /* pred_reduc_andvnx1qivnx8qi */
    case 5335:  /* pred_reduc_orvnx1qivnx8qi */
    case 5336:  /* pred_reduc_xorvnx1qivnx8qi */
    case 5337:  /* pred_reduc_sumvnx2qivnx8qi */
    case 5338:  /* pred_reduc_maxuvnx2qivnx8qi */
    case 5339:  /* pred_reduc_maxvnx2qivnx8qi */
    case 5340:  /* pred_reduc_minuvnx2qivnx8qi */
    case 5341:  /* pred_reduc_minvnx2qivnx8qi */
    case 5342:  /* pred_reduc_andvnx2qivnx8qi */
    case 5343:  /* pred_reduc_orvnx2qivnx8qi */
    case 5344:  /* pred_reduc_xorvnx2qivnx8qi */
    case 5345:  /* pred_reduc_sumvnx4qivnx8qi */
    case 5346:  /* pred_reduc_maxuvnx4qivnx8qi */
    case 5347:  /* pred_reduc_maxvnx4qivnx8qi */
    case 5348:  /* pred_reduc_minuvnx4qivnx8qi */
    case 5349:  /* pred_reduc_minvnx4qivnx8qi */
    case 5350:  /* pred_reduc_andvnx4qivnx8qi */
    case 5351:  /* pred_reduc_orvnx4qivnx8qi */
    case 5352:  /* pred_reduc_xorvnx4qivnx8qi */
    case 5353:  /* pred_reduc_sumvnx8qivnx8qi */
    case 5354:  /* pred_reduc_maxuvnx8qivnx8qi */
    case 5355:  /* pred_reduc_maxvnx8qivnx8qi */
    case 5356:  /* pred_reduc_minuvnx8qivnx8qi */
    case 5357:  /* pred_reduc_minvnx8qivnx8qi */
    case 5358:  /* pred_reduc_andvnx8qivnx8qi */
    case 5359:  /* pred_reduc_orvnx8qivnx8qi */
    case 5360:  /* pred_reduc_xorvnx8qivnx8qi */
    case 5361:  /* pred_reduc_sumvnx16qivnx8qi */
    case 5362:  /* pred_reduc_maxuvnx16qivnx8qi */
    case 5363:  /* pred_reduc_maxvnx16qivnx8qi */
    case 5364:  /* pred_reduc_minuvnx16qivnx8qi */
    case 5365:  /* pred_reduc_minvnx16qivnx8qi */
    case 5366:  /* pred_reduc_andvnx16qivnx8qi */
    case 5367:  /* pred_reduc_orvnx16qivnx8qi */
    case 5368:  /* pred_reduc_xorvnx16qivnx8qi */
    case 5369:  /* pred_reduc_sumvnx32qivnx8qi */
    case 5370:  /* pred_reduc_maxuvnx32qivnx8qi */
    case 5371:  /* pred_reduc_maxvnx32qivnx8qi */
    case 5372:  /* pred_reduc_minuvnx32qivnx8qi */
    case 5373:  /* pred_reduc_minvnx32qivnx8qi */
    case 5374:  /* pred_reduc_andvnx32qivnx8qi */
    case 5375:  /* pred_reduc_orvnx32qivnx8qi */
    case 5376:  /* pred_reduc_xorvnx32qivnx8qi */
    case 5377:  /* pred_reduc_sumvnx64qivnx8qi */
    case 5378:  /* pred_reduc_maxuvnx64qivnx8qi */
    case 5379:  /* pred_reduc_maxvnx64qivnx8qi */
    case 5380:  /* pred_reduc_minuvnx64qivnx8qi */
    case 5381:  /* pred_reduc_minvnx64qivnx8qi */
    case 5382:  /* pred_reduc_andvnx64qivnx8qi */
    case 5383:  /* pred_reduc_orvnx64qivnx8qi */
    case 5384:  /* pred_reduc_xorvnx64qivnx8qi */
    case 5385:  /* pred_reduc_sumvnx1hivnx4hi */
    case 5386:  /* pred_reduc_maxuvnx1hivnx4hi */
    case 5387:  /* pred_reduc_maxvnx1hivnx4hi */
    case 5388:  /* pred_reduc_minuvnx1hivnx4hi */
    case 5389:  /* pred_reduc_minvnx1hivnx4hi */
    case 5390:  /* pred_reduc_andvnx1hivnx4hi */
    case 5391:  /* pred_reduc_orvnx1hivnx4hi */
    case 5392:  /* pred_reduc_xorvnx1hivnx4hi */
    case 5393:  /* pred_reduc_sumvnx2hivnx4hi */
    case 5394:  /* pred_reduc_maxuvnx2hivnx4hi */
    case 5395:  /* pred_reduc_maxvnx2hivnx4hi */
    case 5396:  /* pred_reduc_minuvnx2hivnx4hi */
    case 5397:  /* pred_reduc_minvnx2hivnx4hi */
    case 5398:  /* pred_reduc_andvnx2hivnx4hi */
    case 5399:  /* pred_reduc_orvnx2hivnx4hi */
    case 5400:  /* pred_reduc_xorvnx2hivnx4hi */
    case 5401:  /* pred_reduc_sumvnx4hivnx4hi */
    case 5402:  /* pred_reduc_maxuvnx4hivnx4hi */
    case 5403:  /* pred_reduc_maxvnx4hivnx4hi */
    case 5404:  /* pred_reduc_minuvnx4hivnx4hi */
    case 5405:  /* pred_reduc_minvnx4hivnx4hi */
    case 5406:  /* pred_reduc_andvnx4hivnx4hi */
    case 5407:  /* pred_reduc_orvnx4hivnx4hi */
    case 5408:  /* pred_reduc_xorvnx4hivnx4hi */
    case 5409:  /* pred_reduc_sumvnx8hivnx4hi */
    case 5410:  /* pred_reduc_maxuvnx8hivnx4hi */
    case 5411:  /* pred_reduc_maxvnx8hivnx4hi */
    case 5412:  /* pred_reduc_minuvnx8hivnx4hi */
    case 5413:  /* pred_reduc_minvnx8hivnx4hi */
    case 5414:  /* pred_reduc_andvnx8hivnx4hi */
    case 5415:  /* pred_reduc_orvnx8hivnx4hi */
    case 5416:  /* pred_reduc_xorvnx8hivnx4hi */
    case 5417:  /* pred_reduc_sumvnx16hivnx4hi */
    case 5418:  /* pred_reduc_maxuvnx16hivnx4hi */
    case 5419:  /* pred_reduc_maxvnx16hivnx4hi */
    case 5420:  /* pred_reduc_minuvnx16hivnx4hi */
    case 5421:  /* pred_reduc_minvnx16hivnx4hi */
    case 5422:  /* pred_reduc_andvnx16hivnx4hi */
    case 5423:  /* pred_reduc_orvnx16hivnx4hi */
    case 5424:  /* pred_reduc_xorvnx16hivnx4hi */
    case 5425:  /* pred_reduc_sumvnx32hivnx4hi */
    case 5426:  /* pred_reduc_maxuvnx32hivnx4hi */
    case 5427:  /* pred_reduc_maxvnx32hivnx4hi */
    case 5428:  /* pred_reduc_minuvnx32hivnx4hi */
    case 5429:  /* pred_reduc_minvnx32hivnx4hi */
    case 5430:  /* pred_reduc_andvnx32hivnx4hi */
    case 5431:  /* pred_reduc_orvnx32hivnx4hi */
    case 5432:  /* pred_reduc_xorvnx32hivnx4hi */
    case 5433:  /* pred_reduc_sumvnx1sivnx2si */
    case 5434:  /* pred_reduc_maxuvnx1sivnx2si */
    case 5435:  /* pred_reduc_maxvnx1sivnx2si */
    case 5436:  /* pred_reduc_minuvnx1sivnx2si */
    case 5437:  /* pred_reduc_minvnx1sivnx2si */
    case 5438:  /* pred_reduc_andvnx1sivnx2si */
    case 5439:  /* pred_reduc_orvnx1sivnx2si */
    case 5440:  /* pred_reduc_xorvnx1sivnx2si */
    case 5441:  /* pred_reduc_sumvnx2sivnx2si */
    case 5442:  /* pred_reduc_maxuvnx2sivnx2si */
    case 5443:  /* pred_reduc_maxvnx2sivnx2si */
    case 5444:  /* pred_reduc_minuvnx2sivnx2si */
    case 5445:  /* pred_reduc_minvnx2sivnx2si */
    case 5446:  /* pred_reduc_andvnx2sivnx2si */
    case 5447:  /* pred_reduc_orvnx2sivnx2si */
    case 5448:  /* pred_reduc_xorvnx2sivnx2si */
    case 5449:  /* pred_reduc_sumvnx4sivnx2si */
    case 5450:  /* pred_reduc_maxuvnx4sivnx2si */
    case 5451:  /* pred_reduc_maxvnx4sivnx2si */
    case 5452:  /* pred_reduc_minuvnx4sivnx2si */
    case 5453:  /* pred_reduc_minvnx4sivnx2si */
    case 5454:  /* pred_reduc_andvnx4sivnx2si */
    case 5455:  /* pred_reduc_orvnx4sivnx2si */
    case 5456:  /* pred_reduc_xorvnx4sivnx2si */
    case 5457:  /* pred_reduc_sumvnx8sivnx2si */
    case 5458:  /* pred_reduc_maxuvnx8sivnx2si */
    case 5459:  /* pred_reduc_maxvnx8sivnx2si */
    case 5460:  /* pred_reduc_minuvnx8sivnx2si */
    case 5461:  /* pred_reduc_minvnx8sivnx2si */
    case 5462:  /* pred_reduc_andvnx8sivnx2si */
    case 5463:  /* pred_reduc_orvnx8sivnx2si */
    case 5464:  /* pred_reduc_xorvnx8sivnx2si */
    case 5465:  /* pred_reduc_sumvnx16sivnx2si */
    case 5466:  /* pred_reduc_maxuvnx16sivnx2si */
    case 5467:  /* pred_reduc_maxvnx16sivnx2si */
    case 5468:  /* pred_reduc_minuvnx16sivnx2si */
    case 5469:  /* pred_reduc_minvnx16sivnx2si */
    case 5470:  /* pred_reduc_andvnx16sivnx2si */
    case 5471:  /* pred_reduc_orvnx16sivnx2si */
    case 5472:  /* pred_reduc_xorvnx16sivnx2si */
    case 5473:  /* pred_reduc_sumvnx1divnx1DI */
    case 5474:  /* pred_reduc_maxuvnx1divnx1DI */
    case 5475:  /* pred_reduc_maxvnx1divnx1DI */
    case 5476:  /* pred_reduc_minuvnx1divnx1DI */
    case 5477:  /* pred_reduc_minvnx1divnx1DI */
    case 5478:  /* pred_reduc_andvnx1divnx1DI */
    case 5479:  /* pred_reduc_orvnx1divnx1DI */
    case 5480:  /* pred_reduc_xorvnx1divnx1DI */
    case 5481:  /* pred_reduc_sumvnx2divnx1DI */
    case 5482:  /* pred_reduc_maxuvnx2divnx1DI */
    case 5483:  /* pred_reduc_maxvnx2divnx1DI */
    case 5484:  /* pred_reduc_minuvnx2divnx1DI */
    case 5485:  /* pred_reduc_minvnx2divnx1DI */
    case 5486:  /* pred_reduc_andvnx2divnx1DI */
    case 5487:  /* pred_reduc_orvnx2divnx1DI */
    case 5488:  /* pred_reduc_xorvnx2divnx1DI */
    case 5489:  /* pred_reduc_sumvnx4divnx1DI */
    case 5490:  /* pred_reduc_maxuvnx4divnx1DI */
    case 5491:  /* pred_reduc_maxvnx4divnx1DI */
    case 5492:  /* pred_reduc_minuvnx4divnx1DI */
    case 5493:  /* pred_reduc_minvnx4divnx1DI */
    case 5494:  /* pred_reduc_andvnx4divnx1DI */
    case 5495:  /* pred_reduc_orvnx4divnx1DI */
    case 5496:  /* pred_reduc_xorvnx4divnx1DI */
    case 5497:  /* pred_reduc_sumvnx8divnx1DI */
    case 5498:  /* pred_reduc_maxuvnx8divnx1DI */
    case 5499:  /* pred_reduc_maxvnx8divnx1DI */
    case 5500:  /* pred_reduc_minuvnx8divnx1DI */
    case 5501:  /* pred_reduc_minvnx8divnx1DI */
    case 5502:  /* pred_reduc_andvnx8divnx1DI */
    case 5503:  /* pred_reduc_orvnx8divnx1DI */
    case 5504:  /* pred_reduc_xorvnx8divnx1DI */
    case 5505:  /* pred_reduc_sumvnx1qivnx4qi */
    case 5506:  /* pred_reduc_maxuvnx1qivnx4qi */
    case 5507:  /* pred_reduc_maxvnx1qivnx4qi */
    case 5508:  /* pred_reduc_minuvnx1qivnx4qi */
    case 5509:  /* pred_reduc_minvnx1qivnx4qi */
    case 5510:  /* pred_reduc_andvnx1qivnx4qi */
    case 5511:  /* pred_reduc_orvnx1qivnx4qi */
    case 5512:  /* pred_reduc_xorvnx1qivnx4qi */
    case 5513:  /* pred_reduc_sumvnx2qivnx4qi */
    case 5514:  /* pred_reduc_maxuvnx2qivnx4qi */
    case 5515:  /* pred_reduc_maxvnx2qivnx4qi */
    case 5516:  /* pred_reduc_minuvnx2qivnx4qi */
    case 5517:  /* pred_reduc_minvnx2qivnx4qi */
    case 5518:  /* pred_reduc_andvnx2qivnx4qi */
    case 5519:  /* pred_reduc_orvnx2qivnx4qi */
    case 5520:  /* pred_reduc_xorvnx2qivnx4qi */
    case 5521:  /* pred_reduc_sumvnx4qivnx4qi */
    case 5522:  /* pred_reduc_maxuvnx4qivnx4qi */
    case 5523:  /* pred_reduc_maxvnx4qivnx4qi */
    case 5524:  /* pred_reduc_minuvnx4qivnx4qi */
    case 5525:  /* pred_reduc_minvnx4qivnx4qi */
    case 5526:  /* pred_reduc_andvnx4qivnx4qi */
    case 5527:  /* pred_reduc_orvnx4qivnx4qi */
    case 5528:  /* pred_reduc_xorvnx4qivnx4qi */
    case 5529:  /* pred_reduc_sumvnx8qivnx4qi */
    case 5530:  /* pred_reduc_maxuvnx8qivnx4qi */
    case 5531:  /* pred_reduc_maxvnx8qivnx4qi */
    case 5532:  /* pred_reduc_minuvnx8qivnx4qi */
    case 5533:  /* pred_reduc_minvnx8qivnx4qi */
    case 5534:  /* pred_reduc_andvnx8qivnx4qi */
    case 5535:  /* pred_reduc_orvnx8qivnx4qi */
    case 5536:  /* pred_reduc_xorvnx8qivnx4qi */
    case 5537:  /* pred_reduc_sumvnx16qivnx4qi */
    case 5538:  /* pred_reduc_maxuvnx16qivnx4qi */
    case 5539:  /* pred_reduc_maxvnx16qivnx4qi */
    case 5540:  /* pred_reduc_minuvnx16qivnx4qi */
    case 5541:  /* pred_reduc_minvnx16qivnx4qi */
    case 5542:  /* pred_reduc_andvnx16qivnx4qi */
    case 5543:  /* pred_reduc_orvnx16qivnx4qi */
    case 5544:  /* pred_reduc_xorvnx16qivnx4qi */
    case 5545:  /* pred_reduc_sumvnx32qivnx4qi */
    case 5546:  /* pred_reduc_maxuvnx32qivnx4qi */
    case 5547:  /* pred_reduc_maxvnx32qivnx4qi */
    case 5548:  /* pred_reduc_minuvnx32qivnx4qi */
    case 5549:  /* pred_reduc_minvnx32qivnx4qi */
    case 5550:  /* pred_reduc_andvnx32qivnx4qi */
    case 5551:  /* pred_reduc_orvnx32qivnx4qi */
    case 5552:  /* pred_reduc_xorvnx32qivnx4qi */
    case 5553:  /* pred_reduc_sumvnx1hivnx2hi */
    case 5554:  /* pred_reduc_maxuvnx1hivnx2hi */
    case 5555:  /* pred_reduc_maxvnx1hivnx2hi */
    case 5556:  /* pred_reduc_minuvnx1hivnx2hi */
    case 5557:  /* pred_reduc_minvnx1hivnx2hi */
    case 5558:  /* pred_reduc_andvnx1hivnx2hi */
    case 5559:  /* pred_reduc_orvnx1hivnx2hi */
    case 5560:  /* pred_reduc_xorvnx1hivnx2hi */
    case 5561:  /* pred_reduc_sumvnx2hivnx2hi */
    case 5562:  /* pred_reduc_maxuvnx2hivnx2hi */
    case 5563:  /* pred_reduc_maxvnx2hivnx2hi */
    case 5564:  /* pred_reduc_minuvnx2hivnx2hi */
    case 5565:  /* pred_reduc_minvnx2hivnx2hi */
    case 5566:  /* pred_reduc_andvnx2hivnx2hi */
    case 5567:  /* pred_reduc_orvnx2hivnx2hi */
    case 5568:  /* pred_reduc_xorvnx2hivnx2hi */
    case 5569:  /* pred_reduc_sumvnx4hivnx2hi */
    case 5570:  /* pred_reduc_maxuvnx4hivnx2hi */
    case 5571:  /* pred_reduc_maxvnx4hivnx2hi */
    case 5572:  /* pred_reduc_minuvnx4hivnx2hi */
    case 5573:  /* pred_reduc_minvnx4hivnx2hi */
    case 5574:  /* pred_reduc_andvnx4hivnx2hi */
    case 5575:  /* pred_reduc_orvnx4hivnx2hi */
    case 5576:  /* pred_reduc_xorvnx4hivnx2hi */
    case 5577:  /* pred_reduc_sumvnx8hivnx2hi */
    case 5578:  /* pred_reduc_maxuvnx8hivnx2hi */
    case 5579:  /* pred_reduc_maxvnx8hivnx2hi */
    case 5580:  /* pred_reduc_minuvnx8hivnx2hi */
    case 5581:  /* pred_reduc_minvnx8hivnx2hi */
    case 5582:  /* pred_reduc_andvnx8hivnx2hi */
    case 5583:  /* pred_reduc_orvnx8hivnx2hi */
    case 5584:  /* pred_reduc_xorvnx8hivnx2hi */
    case 5585:  /* pred_reduc_sumvnx16hivnx2hi */
    case 5586:  /* pred_reduc_maxuvnx16hivnx2hi */
    case 5587:  /* pred_reduc_maxvnx16hivnx2hi */
    case 5588:  /* pred_reduc_minuvnx16hivnx2hi */
    case 5589:  /* pred_reduc_minvnx16hivnx2hi */
    case 5590:  /* pred_reduc_andvnx16hivnx2hi */
    case 5591:  /* pred_reduc_orvnx16hivnx2hi */
    case 5592:  /* pred_reduc_xorvnx16hivnx2hi */
    case 5593:  /* pred_reduc_sumvnx1sivnx1si */
    case 5594:  /* pred_reduc_maxuvnx1sivnx1si */
    case 5595:  /* pred_reduc_maxvnx1sivnx1si */
    case 5596:  /* pred_reduc_minuvnx1sivnx1si */
    case 5597:  /* pred_reduc_minvnx1sivnx1si */
    case 5598:  /* pred_reduc_andvnx1sivnx1si */
    case 5599:  /* pred_reduc_orvnx1sivnx1si */
    case 5600:  /* pred_reduc_xorvnx1sivnx1si */
    case 5601:  /* pred_reduc_sumvnx2sivnx1si */
    case 5602:  /* pred_reduc_maxuvnx2sivnx1si */
    case 5603:  /* pred_reduc_maxvnx2sivnx1si */
    case 5604:  /* pred_reduc_minuvnx2sivnx1si */
    case 5605:  /* pred_reduc_minvnx2sivnx1si */
    case 5606:  /* pred_reduc_andvnx2sivnx1si */
    case 5607:  /* pred_reduc_orvnx2sivnx1si */
    case 5608:  /* pred_reduc_xorvnx2sivnx1si */
    case 5609:  /* pred_reduc_sumvnx4sivnx1si */
    case 5610:  /* pred_reduc_maxuvnx4sivnx1si */
    case 5611:  /* pred_reduc_maxvnx4sivnx1si */
    case 5612:  /* pred_reduc_minuvnx4sivnx1si */
    case 5613:  /* pred_reduc_minvnx4sivnx1si */
    case 5614:  /* pred_reduc_andvnx4sivnx1si */
    case 5615:  /* pred_reduc_orvnx4sivnx1si */
    case 5616:  /* pred_reduc_xorvnx4sivnx1si */
    case 5617:  /* pred_reduc_sumvnx8sivnx1si */
    case 5618:  /* pred_reduc_maxuvnx8sivnx1si */
    case 5619:  /* pred_reduc_maxvnx8sivnx1si */
    case 5620:  /* pred_reduc_minuvnx8sivnx1si */
    case 5621:  /* pred_reduc_minvnx8sivnx1si */
    case 5622:  /* pred_reduc_andvnx8sivnx1si */
    case 5623:  /* pred_reduc_orvnx8sivnx1si */
    case 5624:  /* pred_reduc_xorvnx8sivnx1si */
      return TYPE_VIRED;

    case 5321:  /* pred_truncvnx1df */
    case 5322:  /* pred_truncvnx2df */
    case 5323:  /* pred_truncvnx4df */
    case 5324:  /* pred_truncvnx8df */
    case 5325:  /* pred_rod_truncvnx1df */
    case 5326:  /* pred_rod_truncvnx2df */
    case 5327:  /* pred_rod_truncvnx4df */
    case 5328:  /* pred_rod_truncvnx8df */
      return TYPE_VFNCVTFTOF;

    case 5277:  /* pred_narrow_fcvt_x_fvnx1sf */
    case 5278:  /* pred_narrow_fcvt_xu_fvnx1sf */
    case 5279:  /* pred_narrow_fcvt_x_fvnx2sf */
    case 5280:  /* pred_narrow_fcvt_xu_fvnx2sf */
    case 5281:  /* pred_narrow_fcvt_x_fvnx4sf */
    case 5282:  /* pred_narrow_fcvt_xu_fvnx4sf */
    case 5283:  /* pred_narrow_fcvt_x_fvnx8sf */
    case 5284:  /* pred_narrow_fcvt_xu_fvnx8sf */
    case 5285:  /* pred_narrow_fcvt_x_fvnx16sf */
    case 5286:  /* pred_narrow_fcvt_xu_fvnx16sf */
    case 5287:  /* pred_narrow_fcvt_x_fvnx1df */
    case 5288:  /* pred_narrow_fcvt_xu_fvnx1df */
    case 5289:  /* pred_narrow_fcvt_x_fvnx2df */
    case 5290:  /* pred_narrow_fcvt_xu_fvnx2df */
    case 5291:  /* pred_narrow_fcvt_x_fvnx4df */
    case 5292:  /* pred_narrow_fcvt_xu_fvnx4df */
    case 5293:  /* pred_narrow_fcvt_x_fvnx8df */
    case 5294:  /* pred_narrow_fcvt_xu_fvnx8df */
    case 5295:  /* pred_narrow_fix_truncvnx1sf */
    case 5296:  /* pred_narrow_fixuns_truncvnx1sf */
    case 5297:  /* pred_narrow_fix_truncvnx2sf */
    case 5298:  /* pred_narrow_fixuns_truncvnx2sf */
    case 5299:  /* pred_narrow_fix_truncvnx4sf */
    case 5300:  /* pred_narrow_fixuns_truncvnx4sf */
    case 5301:  /* pred_narrow_fix_truncvnx8sf */
    case 5302:  /* pred_narrow_fixuns_truncvnx8sf */
    case 5303:  /* pred_narrow_fix_truncvnx16sf */
    case 5304:  /* pred_narrow_fixuns_truncvnx16sf */
    case 5305:  /* pred_narrow_fix_truncvnx1df */
    case 5306:  /* pred_narrow_fixuns_truncvnx1df */
    case 5307:  /* pred_narrow_fix_truncvnx2df */
    case 5308:  /* pred_narrow_fixuns_truncvnx2df */
    case 5309:  /* pred_narrow_fix_truncvnx4df */
    case 5310:  /* pred_narrow_fixuns_truncvnx4df */
    case 5311:  /* pred_narrow_fix_truncvnx8df */
    case 5312:  /* pred_narrow_fixuns_truncvnx8df */
      return TYPE_VFNCVTFTOI;

    case 5313:  /* pred_narrow_floatvnx1di */
    case 5314:  /* pred_narrow_floatunsvnx1di */
    case 5315:  /* pred_narrow_floatvnx2di */
    case 5316:  /* pred_narrow_floatunsvnx2di */
    case 5317:  /* pred_narrow_floatvnx4di */
    case 5318:  /* pred_narrow_floatunsvnx4di */
    case 5319:  /* pred_narrow_floatvnx8di */
    case 5320:  /* pred_narrow_floatunsvnx8di */
      return TYPE_VFNCVTITOF;

    case 5273:  /* pred_extendvnx1df */
    case 5274:  /* pred_extendvnx2df */
    case 5275:  /* pred_extendvnx4df */
    case 5276:  /* pred_extendvnx8df */
      return TYPE_VFWCVTFTOF;

    case 5239:  /* pred_widen_fcvt_x_fvnx1di */
    case 5240:  /* pred_widen_fcvt_xu_fvnx1di */
    case 5241:  /* pred_widen_fcvt_x_fvnx2di */
    case 5242:  /* pred_widen_fcvt_xu_fvnx2di */
    case 5243:  /* pred_widen_fcvt_x_fvnx4di */
    case 5244:  /* pred_widen_fcvt_xu_fvnx4di */
    case 5245:  /* pred_widen_fcvt_x_fvnx8di */
    case 5246:  /* pred_widen_fcvt_xu_fvnx8di */
    case 5247:  /* pred_widen_fix_truncvnx1di */
    case 5248:  /* pred_widen_fixuns_truncvnx1di */
    case 5249:  /* pred_widen_fix_truncvnx2di */
    case 5250:  /* pred_widen_fixuns_truncvnx2di */
    case 5251:  /* pred_widen_fix_truncvnx4di */
    case 5252:  /* pred_widen_fixuns_truncvnx4di */
    case 5253:  /* pred_widen_fix_truncvnx8di */
    case 5254:  /* pred_widen_fixuns_truncvnx8di */
      return TYPE_VFWCVTFTOI;

    case 5255:  /* pred_widen_floatvnx1sf */
    case 5256:  /* pred_widen_floatunsvnx1sf */
    case 5257:  /* pred_widen_floatvnx2sf */
    case 5258:  /* pred_widen_floatunsvnx2sf */
    case 5259:  /* pred_widen_floatvnx4sf */
    case 5260:  /* pred_widen_floatunsvnx4sf */
    case 5261:  /* pred_widen_floatvnx8sf */
    case 5262:  /* pred_widen_floatunsvnx8sf */
    case 5263:  /* pred_widen_floatvnx16sf */
    case 5264:  /* pred_widen_floatunsvnx16sf */
    case 5265:  /* pred_widen_floatvnx1df */
    case 5266:  /* pred_widen_floatunsvnx1df */
    case 5267:  /* pred_widen_floatvnx2df */
    case 5268:  /* pred_widen_floatunsvnx2df */
    case 5269:  /* pred_widen_floatvnx4df */
    case 5270:  /* pred_widen_floatunsvnx4df */
    case 5271:  /* pred_widen_floatvnx8df */
    case 5272:  /* pred_widen_floatunsvnx8df */
      return TYPE_VFWCVTITOF;

    case 5185:  /* pred_fcvt_x_fvnx1sf */
    case 5186:  /* pred_fcvt_xu_fvnx1sf */
    case 5187:  /* pred_fcvt_x_fvnx2sf */
    case 5188:  /* pred_fcvt_xu_fvnx2sf */
    case 5189:  /* pred_fcvt_x_fvnx4sf */
    case 5190:  /* pred_fcvt_xu_fvnx4sf */
    case 5191:  /* pred_fcvt_x_fvnx8sf */
    case 5192:  /* pred_fcvt_xu_fvnx8sf */
    case 5193:  /* pred_fcvt_x_fvnx16sf */
    case 5194:  /* pred_fcvt_xu_fvnx16sf */
    case 5195:  /* pred_fcvt_x_fvnx1df */
    case 5196:  /* pred_fcvt_xu_fvnx1df */
    case 5197:  /* pred_fcvt_x_fvnx2df */
    case 5198:  /* pred_fcvt_xu_fvnx2df */
    case 5199:  /* pred_fcvt_x_fvnx4df */
    case 5200:  /* pred_fcvt_xu_fvnx4df */
    case 5201:  /* pred_fcvt_x_fvnx8df */
    case 5202:  /* pred_fcvt_xu_fvnx8df */
    case 5203:  /* pred_fix_truncvnx1sf */
    case 5204:  /* pred_fixuns_truncvnx1sf */
    case 5205:  /* pred_fix_truncvnx2sf */
    case 5206:  /* pred_fixuns_truncvnx2sf */
    case 5207:  /* pred_fix_truncvnx4sf */
    case 5208:  /* pred_fixuns_truncvnx4sf */
    case 5209:  /* pred_fix_truncvnx8sf */
    case 5210:  /* pred_fixuns_truncvnx8sf */
    case 5211:  /* pred_fix_truncvnx16sf */
    case 5212:  /* pred_fixuns_truncvnx16sf */
    case 5213:  /* pred_fix_truncvnx1df */
    case 5214:  /* pred_fixuns_truncvnx1df */
    case 5215:  /* pred_fix_truncvnx2df */
    case 5216:  /* pred_fixuns_truncvnx2df */
    case 5217:  /* pred_fix_truncvnx4df */
    case 5218:  /* pred_fixuns_truncvnx4df */
    case 5219:  /* pred_fix_truncvnx8df */
    case 5220:  /* pred_fixuns_truncvnx8df */
      return TYPE_VFCVTFTOI;

    case 5221:  /* pred_floatvnx1sf */
    case 5222:  /* pred_floatunsvnx1sf */
    case 5223:  /* pred_floatvnx2sf */
    case 5224:  /* pred_floatunsvnx2sf */
    case 5225:  /* pred_floatvnx4sf */
    case 5226:  /* pred_floatunsvnx4sf */
    case 5227:  /* pred_floatvnx8sf */
    case 5228:  /* pred_floatunsvnx8sf */
    case 5229:  /* pred_floatvnx16sf */
    case 5230:  /* pred_floatunsvnx16sf */
    case 5231:  /* pred_floatvnx1df */
    case 5232:  /* pred_floatunsvnx1df */
    case 5233:  /* pred_floatvnx2df */
    case 5234:  /* pred_floatunsvnx2df */
    case 5235:  /* pred_floatvnx4df */
    case 5236:  /* pred_floatunsvnx4df */
    case 5237:  /* pred_floatvnx8df */
    case 5238:  /* pred_floatunsvnx8df */
      return TYPE_VFCVTITOF;

    case 5176:  /* pred_mergevnx1sf_scalar */
    case 5177:  /* pred_mergevnx2sf_scalar */
    case 5178:  /* pred_mergevnx4sf_scalar */
    case 5179:  /* pred_mergevnx8sf_scalar */
    case 5180:  /* pred_mergevnx16sf_scalar */
    case 5181:  /* pred_mergevnx1df_scalar */
    case 5182:  /* pred_mergevnx2df_scalar */
    case 5183:  /* pred_mergevnx4df_scalar */
    case 5184:  /* pred_mergevnx8df_scalar */
      return TYPE_VFMERGE;

    case 5041:  /* pred_classvnx1sf */
    case 5042:  /* pred_classvnx2sf */
    case 5043:  /* pred_classvnx4sf */
    case 5044:  /* pred_classvnx8sf */
    case 5045:  /* pred_classvnx16sf */
    case 5046:  /* pred_classvnx1df */
    case 5047:  /* pred_classvnx2df */
    case 5048:  /* pred_classvnx4df */
    case 5049:  /* pred_classvnx8df */
      return TYPE_VFCLASS;

    case 4726:  /* pred_copysignvnx1sf */
    case 4727:  /* pred_ncopysignvnx1sf */
    case 4728:  /* pred_xorsignvnx1sf */
    case 4729:  /* pred_copysignvnx2sf */
    case 4730:  /* pred_ncopysignvnx2sf */
    case 4731:  /* pred_xorsignvnx2sf */
    case 4732:  /* pred_copysignvnx4sf */
    case 4733:  /* pred_ncopysignvnx4sf */
    case 4734:  /* pred_xorsignvnx4sf */
    case 4735:  /* pred_copysignvnx8sf */
    case 4736:  /* pred_ncopysignvnx8sf */
    case 4737:  /* pred_xorsignvnx8sf */
    case 4738:  /* pred_copysignvnx16sf */
    case 4739:  /* pred_ncopysignvnx16sf */
    case 4740:  /* pred_xorsignvnx16sf */
    case 4741:  /* pred_copysignvnx1df */
    case 4742:  /* pred_ncopysignvnx1df */
    case 4743:  /* pred_xorsignvnx1df */
    case 4744:  /* pred_copysignvnx2df */
    case 4745:  /* pred_ncopysignvnx2df */
    case 4746:  /* pred_xorsignvnx2df */
    case 4747:  /* pred_copysignvnx4df */
    case 4748:  /* pred_ncopysignvnx4df */
    case 4749:  /* pred_xorsignvnx4df */
    case 4750:  /* pred_copysignvnx8df */
    case 4751:  /* pred_ncopysignvnx8df */
    case 4752:  /* pred_xorsignvnx8df */
    case 4753:  /* pred_copysignvnx1sf_scalar */
    case 4754:  /* pred_ncopysignvnx1sf_scalar */
    case 4755:  /* pred_xorsignvnx1sf_scalar */
    case 4756:  /* pred_copysignvnx2sf_scalar */
    case 4757:  /* pred_ncopysignvnx2sf_scalar */
    case 4758:  /* pred_xorsignvnx2sf_scalar */
    case 4759:  /* pred_copysignvnx4sf_scalar */
    case 4760:  /* pred_ncopysignvnx4sf_scalar */
    case 4761:  /* pred_xorsignvnx4sf_scalar */
    case 4762:  /* pred_copysignvnx8sf_scalar */
    case 4763:  /* pred_ncopysignvnx8sf_scalar */
    case 4764:  /* pred_xorsignvnx8sf_scalar */
    case 4765:  /* pred_copysignvnx16sf_scalar */
    case 4766:  /* pred_ncopysignvnx16sf_scalar */
    case 4767:  /* pred_xorsignvnx16sf_scalar */
    case 4768:  /* pred_copysignvnx1df_scalar */
    case 4769:  /* pred_ncopysignvnx1df_scalar */
    case 4770:  /* pred_xorsignvnx1df_scalar */
    case 4771:  /* pred_copysignvnx2df_scalar */
    case 4772:  /* pred_ncopysignvnx2df_scalar */
    case 4773:  /* pred_xorsignvnx2df_scalar */
    case 4774:  /* pred_copysignvnx4df_scalar */
    case 4775:  /* pred_ncopysignvnx4df_scalar */
    case 4776:  /* pred_xorsignvnx4df_scalar */
    case 4777:  /* pred_copysignvnx8df_scalar */
    case 4778:  /* pred_ncopysignvnx8df_scalar */
    case 4779:  /* pred_xorsignvnx8df_scalar */
    case 4996:  /* pred_negvnx1sf */
    case 4997:  /* pred_absvnx1sf */
    case 4999:  /* pred_negvnx2sf */
    case 5000:  /* pred_absvnx2sf */
    case 5002:  /* pred_negvnx4sf */
    case 5003:  /* pred_absvnx4sf */
    case 5005:  /* pred_negvnx8sf */
    case 5006:  /* pred_absvnx8sf */
    case 5008:  /* pred_negvnx16sf */
    case 5009:  /* pred_absvnx16sf */
    case 5011:  /* pred_negvnx1df */
    case 5012:  /* pred_absvnx1df */
    case 5014:  /* pred_negvnx2df */
    case 5015:  /* pred_absvnx2df */
    case 5017:  /* pred_negvnx4df */
    case 5018:  /* pred_absvnx4df */
    case 5020:  /* pred_negvnx8df */
    case 5021:  /* pred_absvnx8df */
      return TYPE_VFSGNJ;

    case 4602:  /* pred_smaxvnx1sf */
    case 4603:  /* pred_sminvnx1sf */
    case 4608:  /* pred_smaxvnx2sf */
    case 4609:  /* pred_sminvnx2sf */
    case 4614:  /* pred_smaxvnx4sf */
    case 4615:  /* pred_sminvnx4sf */
    case 4620:  /* pred_smaxvnx8sf */
    case 4621:  /* pred_sminvnx8sf */
    case 4626:  /* pred_smaxvnx16sf */
    case 4627:  /* pred_sminvnx16sf */
    case 4632:  /* pred_smaxvnx1df */
    case 4633:  /* pred_sminvnx1df */
    case 4638:  /* pred_smaxvnx2df */
    case 4639:  /* pred_sminvnx2df */
    case 4644:  /* pred_smaxvnx4df */
    case 4645:  /* pred_sminvnx4df */
    case 4650:  /* pred_smaxvnx8df */
    case 4651:  /* pred_sminvnx8df */
    case 4656:  /* pred_smaxvnx1sf_scalar */
    case 4657:  /* pred_sminvnx1sf_scalar */
    case 4660:  /* pred_smaxvnx2sf_scalar */
    case 4661:  /* pred_sminvnx2sf_scalar */
    case 4664:  /* pred_smaxvnx4sf_scalar */
    case 4665:  /* pred_sminvnx4sf_scalar */
    case 4668:  /* pred_smaxvnx8sf_scalar */
    case 4669:  /* pred_sminvnx8sf_scalar */
    case 4672:  /* pred_smaxvnx16sf_scalar */
    case 4673:  /* pred_sminvnx16sf_scalar */
    case 4676:  /* pred_smaxvnx1df_scalar */
    case 4677:  /* pred_sminvnx1df_scalar */
    case 4680:  /* pred_smaxvnx2df_scalar */
    case 4681:  /* pred_sminvnx2df_scalar */
    case 4684:  /* pred_smaxvnx4df_scalar */
    case 4685:  /* pred_sminvnx4df_scalar */
    case 4688:  /* pred_smaxvnx8df_scalar */
    case 4689:  /* pred_sminvnx8df_scalar */
      return TYPE_VFMINMAX;

    case 5122:  /* *pred_cmpvnx1sf */
    case 5123:  /* *pred_cmpvnx2sf */
    case 5124:  /* *pred_cmpvnx4sf */
    case 5125:  /* *pred_cmpvnx8sf */
    case 5126:  /* *pred_cmpvnx16sf */
    case 5127:  /* *pred_cmpvnx1df */
    case 5128:  /* *pred_cmpvnx2df */
    case 5129:  /* *pred_cmpvnx4df */
    case 5130:  /* *pred_cmpvnx8df */
    case 5131:  /* *pred_cmpvnx1sf_narrow */
    case 5132:  /* *pred_cmpvnx2sf_narrow */
    case 5133:  /* *pred_cmpvnx4sf_narrow */
    case 5134:  /* *pred_cmpvnx8sf_narrow */
    case 5135:  /* *pred_cmpvnx16sf_narrow */
    case 5136:  /* *pred_cmpvnx1df_narrow */
    case 5137:  /* *pred_cmpvnx2df_narrow */
    case 5138:  /* *pred_cmpvnx4df_narrow */
    case 5139:  /* *pred_cmpvnx8df_narrow */
    case 5140:  /* *pred_cmpvnx1sf_scalar */
    case 5141:  /* *pred_cmpvnx2sf_scalar */
    case 5142:  /* *pred_cmpvnx4sf_scalar */
    case 5143:  /* *pred_cmpvnx8sf_scalar */
    case 5144:  /* *pred_cmpvnx16sf_scalar */
    case 5145:  /* *pred_cmpvnx1df_scalar */
    case 5146:  /* *pred_cmpvnx2df_scalar */
    case 5147:  /* *pred_cmpvnx4df_scalar */
    case 5148:  /* *pred_cmpvnx8df_scalar */
    case 5149:  /* *pred_cmpvnx1sf_scalar_narrow */
    case 5150:  /* *pred_cmpvnx2sf_scalar_narrow */
    case 5151:  /* *pred_cmpvnx4sf_scalar_narrow */
    case 5152:  /* *pred_cmpvnx8sf_scalar_narrow */
    case 5153:  /* *pred_cmpvnx16sf_scalar_narrow */
    case 5154:  /* *pred_cmpvnx1df_scalar_narrow */
    case 5155:  /* *pred_cmpvnx2df_scalar_narrow */
    case 5156:  /* *pred_cmpvnx4df_scalar_narrow */
    case 5157:  /* *pred_cmpvnx8df_scalar_narrow */
    case 5158:  /* *pred_eqnevnx1sf_scalar */
    case 5159:  /* *pred_eqnevnx2sf_scalar */
    case 5160:  /* *pred_eqnevnx4sf_scalar */
    case 5161:  /* *pred_eqnevnx8sf_scalar */
    case 5162:  /* *pred_eqnevnx16sf_scalar */
    case 5163:  /* *pred_eqnevnx1df_scalar */
    case 5164:  /* *pred_eqnevnx2df_scalar */
    case 5165:  /* *pred_eqnevnx4df_scalar */
    case 5166:  /* *pred_eqnevnx8df_scalar */
    case 5167:  /* *pred_eqnevnx1sf_scalar_narrow */
    case 5168:  /* *pred_eqnevnx2sf_scalar_narrow */
    case 5169:  /* *pred_eqnevnx4sf_scalar_narrow */
    case 5170:  /* *pred_eqnevnx8sf_scalar_narrow */
    case 5171:  /* *pred_eqnevnx16sf_scalar_narrow */
    case 5172:  /* *pred_eqnevnx1df_scalar_narrow */
    case 5173:  /* *pred_eqnevnx2df_scalar_narrow */
    case 5174:  /* *pred_eqnevnx4df_scalar_narrow */
    case 5175:  /* *pred_eqnevnx8df_scalar_narrow */
      return TYPE_VFCMP;

    case 5024:  /* pred_rec7vnx1sf */
    case 5026:  /* pred_rec7vnx2sf */
    case 5028:  /* pred_rec7vnx4sf */
    case 5030:  /* pred_rec7vnx8sf */
    case 5032:  /* pred_rec7vnx16sf */
    case 5034:  /* pred_rec7vnx1df */
    case 5036:  /* pred_rec7vnx2df */
    case 5038:  /* pred_rec7vnx4df */
    case 5040:  /* pred_rec7vnx8df */
      return TYPE_VFRECP;

    case 4998:  /* pred_sqrtvnx1sf */
    case 5001:  /* pred_sqrtvnx2sf */
    case 5004:  /* pred_sqrtvnx4sf */
    case 5007:  /* pred_sqrtvnx8sf */
    case 5010:  /* pred_sqrtvnx16sf */
    case 5013:  /* pred_sqrtvnx1df */
    case 5016:  /* pred_sqrtvnx2df */
    case 5019:  /* pred_sqrtvnx4df */
    case 5022:  /* pred_sqrtvnx8df */
    case 5023:  /* pred_rsqrt7vnx1sf */
    case 5025:  /* pred_rsqrt7vnx2sf */
    case 5027:  /* pred_rsqrt7vnx4sf */
    case 5029:  /* pred_rsqrt7vnx8sf */
    case 5031:  /* pred_rsqrt7vnx16sf */
    case 5033:  /* pred_rsqrt7vnx1df */
    case 5035:  /* pred_rsqrt7vnx2df */
    case 5037:  /* pred_rsqrt7vnx4df */
    case 5039:  /* pred_rsqrt7vnx8df */
      return TYPE_VFSQRT;

    case 5090:  /* pred_widen_mul_addvnx1df */
    case 5091:  /* pred_widen_mul_subvnx1df */
    case 5092:  /* pred_widen_mul_addvnx2df */
    case 5093:  /* pred_widen_mul_subvnx2df */
    case 5094:  /* pred_widen_mul_addvnx4df */
    case 5095:  /* pred_widen_mul_subvnx4df */
    case 5096:  /* pred_widen_mul_addvnx8df */
    case 5097:  /* pred_widen_mul_subvnx8df */
    case 5098:  /* pred_widen_mul_addvnx1df_scalar */
    case 5099:  /* pred_widen_mul_subvnx1df_scalar */
    case 5100:  /* pred_widen_mul_addvnx2df_scalar */
    case 5101:  /* pred_widen_mul_subvnx2df_scalar */
    case 5102:  /* pred_widen_mul_addvnx4df_scalar */
    case 5103:  /* pred_widen_mul_subvnx4df_scalar */
    case 5104:  /* pred_widen_mul_addvnx8df_scalar */
    case 5105:  /* pred_widen_mul_subvnx8df_scalar */
    case 5106:  /* pred_widen_mul_neg_addvnx1df */
    case 5107:  /* pred_widen_mul_neg_subvnx1df */
    case 5108:  /* pred_widen_mul_neg_addvnx2df */
    case 5109:  /* pred_widen_mul_neg_subvnx2df */
    case 5110:  /* pred_widen_mul_neg_addvnx4df */
    case 5111:  /* pred_widen_mul_neg_subvnx4df */
    case 5112:  /* pred_widen_mul_neg_addvnx8df */
    case 5113:  /* pred_widen_mul_neg_subvnx8df */
    case 5114:  /* pred_widen_mul_neg_addvnx1df_scalar */
    case 5115:  /* pred_widen_mul_neg_subvnx1df_scalar */
    case 5116:  /* pred_widen_mul_neg_addvnx2df_scalar */
    case 5117:  /* pred_widen_mul_neg_subvnx2df_scalar */
    case 5118:  /* pred_widen_mul_neg_addvnx4df_scalar */
    case 5119:  /* pred_widen_mul_neg_subvnx4df_scalar */
    case 5120:  /* pred_widen_mul_neg_addvnx8df_scalar */
    case 5121:  /* pred_widen_mul_neg_subvnx8df_scalar */
      return TYPE_VFWMULADD;

    case 4780:  /* *pred_maddvnx1sf */
    case 4781:  /* *pred_msubvnx1sf */
    case 4782:  /* *pred_maddvnx2sf */
    case 4783:  /* *pred_msubvnx2sf */
    case 4784:  /* *pred_maddvnx4sf */
    case 4785:  /* *pred_msubvnx4sf */
    case 4786:  /* *pred_maddvnx8sf */
    case 4787:  /* *pred_msubvnx8sf */
    case 4788:  /* *pred_maddvnx16sf */
    case 4789:  /* *pred_msubvnx16sf */
    case 4790:  /* *pred_maddvnx1df */
    case 4791:  /* *pred_msubvnx1df */
    case 4792:  /* *pred_maddvnx2df */
    case 4793:  /* *pred_msubvnx2df */
    case 4794:  /* *pred_maddvnx4df */
    case 4795:  /* *pred_msubvnx4df */
    case 4796:  /* *pred_maddvnx8df */
    case 4797:  /* *pred_msubvnx8df */
    case 4798:  /* *pred_maccvnx1sf */
    case 4799:  /* *pred_msacvnx1sf */
    case 4800:  /* *pred_maccvnx2sf */
    case 4801:  /* *pred_msacvnx2sf */
    case 4802:  /* *pred_maccvnx4sf */
    case 4803:  /* *pred_msacvnx4sf */
    case 4804:  /* *pred_maccvnx8sf */
    case 4805:  /* *pred_msacvnx8sf */
    case 4806:  /* *pred_maccvnx16sf */
    case 4807:  /* *pred_msacvnx16sf */
    case 4808:  /* *pred_maccvnx1df */
    case 4809:  /* *pred_msacvnx1df */
    case 4810:  /* *pred_maccvnx2df */
    case 4811:  /* *pred_msacvnx2df */
    case 4812:  /* *pred_maccvnx4df */
    case 4813:  /* *pred_msacvnx4df */
    case 4814:  /* *pred_maccvnx8df */
    case 4815:  /* *pred_msacvnx8df */
    case 4816:  /* *pred_mul_addvnx1sf */
    case 4817:  /* *pred_mul_subvnx1sf */
    case 4818:  /* *pred_mul_addvnx2sf */
    case 4819:  /* *pred_mul_subvnx2sf */
    case 4820:  /* *pred_mul_addvnx4sf */
    case 4821:  /* *pred_mul_subvnx4sf */
    case 4822:  /* *pred_mul_addvnx8sf */
    case 4823:  /* *pred_mul_subvnx8sf */
    case 4824:  /* *pred_mul_addvnx16sf */
    case 4825:  /* *pred_mul_subvnx16sf */
    case 4826:  /* *pred_mul_addvnx1df */
    case 4827:  /* *pred_mul_subvnx1df */
    case 4828:  /* *pred_mul_addvnx2df */
    case 4829:  /* *pred_mul_subvnx2df */
    case 4830:  /* *pred_mul_addvnx4df */
    case 4831:  /* *pred_mul_subvnx4df */
    case 4832:  /* *pred_mul_addvnx8df */
    case 4833:  /* *pred_mul_subvnx8df */
    case 4834:  /* *pred_maddvnx1sf_scalar */
    case 4835:  /* *pred_msubvnx1sf_scalar */
    case 4836:  /* *pred_maddvnx2sf_scalar */
    case 4837:  /* *pred_msubvnx2sf_scalar */
    case 4838:  /* *pred_maddvnx4sf_scalar */
    case 4839:  /* *pred_msubvnx4sf_scalar */
    case 4840:  /* *pred_maddvnx8sf_scalar */
    case 4841:  /* *pred_msubvnx8sf_scalar */
    case 4842:  /* *pred_maddvnx16sf_scalar */
    case 4843:  /* *pred_msubvnx16sf_scalar */
    case 4844:  /* *pred_maddvnx1df_scalar */
    case 4845:  /* *pred_msubvnx1df_scalar */
    case 4846:  /* *pred_maddvnx2df_scalar */
    case 4847:  /* *pred_msubvnx2df_scalar */
    case 4848:  /* *pred_maddvnx4df_scalar */
    case 4849:  /* *pred_msubvnx4df_scalar */
    case 4850:  /* *pred_maddvnx8df_scalar */
    case 4851:  /* *pred_msubvnx8df_scalar */
    case 4852:  /* *pred_maccvnx1sf_scalar */
    case 4853:  /* *pred_msacvnx1sf_scalar */
    case 4854:  /* *pred_maccvnx2sf_scalar */
    case 4855:  /* *pred_msacvnx2sf_scalar */
    case 4856:  /* *pred_maccvnx4sf_scalar */
    case 4857:  /* *pred_msacvnx4sf_scalar */
    case 4858:  /* *pred_maccvnx8sf_scalar */
    case 4859:  /* *pred_msacvnx8sf_scalar */
    case 4860:  /* *pred_maccvnx16sf_scalar */
    case 4861:  /* *pred_msacvnx16sf_scalar */
    case 4862:  /* *pred_maccvnx1df_scalar */
    case 4863:  /* *pred_msacvnx1df_scalar */
    case 4864:  /* *pred_maccvnx2df_scalar */
    case 4865:  /* *pred_msacvnx2df_scalar */
    case 4866:  /* *pred_maccvnx4df_scalar */
    case 4867:  /* *pred_msacvnx4df_scalar */
    case 4868:  /* *pred_maccvnx8df_scalar */
    case 4869:  /* *pred_msacvnx8df_scalar */
    case 4870:  /* *pred_mul_addvnx1sf_scalar */
    case 4871:  /* *pred_mul_subvnx1sf_scalar */
    case 4872:  /* *pred_mul_addvnx2sf_scalar */
    case 4873:  /* *pred_mul_subvnx2sf_scalar */
    case 4874:  /* *pred_mul_addvnx4sf_scalar */
    case 4875:  /* *pred_mul_subvnx4sf_scalar */
    case 4876:  /* *pred_mul_addvnx8sf_scalar */
    case 4877:  /* *pred_mul_subvnx8sf_scalar */
    case 4878:  /* *pred_mul_addvnx16sf_scalar */
    case 4879:  /* *pred_mul_subvnx16sf_scalar */
    case 4880:  /* *pred_mul_addvnx1df_scalar */
    case 4881:  /* *pred_mul_subvnx1df_scalar */
    case 4882:  /* *pred_mul_addvnx2df_scalar */
    case 4883:  /* *pred_mul_subvnx2df_scalar */
    case 4884:  /* *pred_mul_addvnx4df_scalar */
    case 4885:  /* *pred_mul_subvnx4df_scalar */
    case 4886:  /* *pred_mul_addvnx8df_scalar */
    case 4887:  /* *pred_mul_subvnx8df_scalar */
    case 4888:  /* *pred_nmsubvnx1sf */
    case 4889:  /* *pred_nmaddvnx1sf */
    case 4890:  /* *pred_nmsubvnx2sf */
    case 4891:  /* *pred_nmaddvnx2sf */
    case 4892:  /* *pred_nmsubvnx4sf */
    case 4893:  /* *pred_nmaddvnx4sf */
    case 4894:  /* *pred_nmsubvnx8sf */
    case 4895:  /* *pred_nmaddvnx8sf */
    case 4896:  /* *pred_nmsubvnx16sf */
    case 4897:  /* *pred_nmaddvnx16sf */
    case 4898:  /* *pred_nmsubvnx1df */
    case 4899:  /* *pred_nmaddvnx1df */
    case 4900:  /* *pred_nmsubvnx2df */
    case 4901:  /* *pred_nmaddvnx2df */
    case 4902:  /* *pred_nmsubvnx4df */
    case 4903:  /* *pred_nmaddvnx4df */
    case 4904:  /* *pred_nmsubvnx8df */
    case 4905:  /* *pred_nmaddvnx8df */
    case 4906:  /* *pred_nmsacvnx1sf */
    case 4907:  /* *pred_nmaccvnx1sf */
    case 4908:  /* *pred_nmsacvnx2sf */
    case 4909:  /* *pred_nmaccvnx2sf */
    case 4910:  /* *pred_nmsacvnx4sf */
    case 4911:  /* *pred_nmaccvnx4sf */
    case 4912:  /* *pred_nmsacvnx8sf */
    case 4913:  /* *pred_nmaccvnx8sf */
    case 4914:  /* *pred_nmsacvnx16sf */
    case 4915:  /* *pred_nmaccvnx16sf */
    case 4916:  /* *pred_nmsacvnx1df */
    case 4917:  /* *pred_nmaccvnx1df */
    case 4918:  /* *pred_nmsacvnx2df */
    case 4919:  /* *pred_nmaccvnx2df */
    case 4920:  /* *pred_nmsacvnx4df */
    case 4921:  /* *pred_nmaccvnx4df */
    case 4922:  /* *pred_nmsacvnx8df */
    case 4923:  /* *pred_nmaccvnx8df */
    case 4924:  /* *pred_mul_neg_addvnx1sf */
    case 4925:  /* *pred_mul_neg_subvnx1sf */
    case 4926:  /* *pred_mul_neg_addvnx2sf */
    case 4927:  /* *pred_mul_neg_subvnx2sf */
    case 4928:  /* *pred_mul_neg_addvnx4sf */
    case 4929:  /* *pred_mul_neg_subvnx4sf */
    case 4930:  /* *pred_mul_neg_addvnx8sf */
    case 4931:  /* *pred_mul_neg_subvnx8sf */
    case 4932:  /* *pred_mul_neg_addvnx16sf */
    case 4933:  /* *pred_mul_neg_subvnx16sf */
    case 4934:  /* *pred_mul_neg_addvnx1df */
    case 4935:  /* *pred_mul_neg_subvnx1df */
    case 4936:  /* *pred_mul_neg_addvnx2df */
    case 4937:  /* *pred_mul_neg_subvnx2df */
    case 4938:  /* *pred_mul_neg_addvnx4df */
    case 4939:  /* *pred_mul_neg_subvnx4df */
    case 4940:  /* *pred_mul_neg_addvnx8df */
    case 4941:  /* *pred_mul_neg_subvnx8df */
    case 4942:  /* *pred_nmsubvnx1sf_scalar */
    case 4943:  /* *pred_nmaddvnx1sf_scalar */
    case 4944:  /* *pred_nmsubvnx2sf_scalar */
    case 4945:  /* *pred_nmaddvnx2sf_scalar */
    case 4946:  /* *pred_nmsubvnx4sf_scalar */
    case 4947:  /* *pred_nmaddvnx4sf_scalar */
    case 4948:  /* *pred_nmsubvnx8sf_scalar */
    case 4949:  /* *pred_nmaddvnx8sf_scalar */
    case 4950:  /* *pred_nmsubvnx16sf_scalar */
    case 4951:  /* *pred_nmaddvnx16sf_scalar */
    case 4952:  /* *pred_nmsubvnx1df_scalar */
    case 4953:  /* *pred_nmaddvnx1df_scalar */
    case 4954:  /* *pred_nmsubvnx2df_scalar */
    case 4955:  /* *pred_nmaddvnx2df_scalar */
    case 4956:  /* *pred_nmsubvnx4df_scalar */
    case 4957:  /* *pred_nmaddvnx4df_scalar */
    case 4958:  /* *pred_nmsubvnx8df_scalar */
    case 4959:  /* *pred_nmaddvnx8df_scalar */
    case 4960:  /* *pred_nmsacvnx1sf_scalar */
    case 4961:  /* *pred_nmaccvnx1sf_scalar */
    case 4962:  /* *pred_nmsacvnx2sf_scalar */
    case 4963:  /* *pred_nmaccvnx2sf_scalar */
    case 4964:  /* *pred_nmsacvnx4sf_scalar */
    case 4965:  /* *pred_nmaccvnx4sf_scalar */
    case 4966:  /* *pred_nmsacvnx8sf_scalar */
    case 4967:  /* *pred_nmaccvnx8sf_scalar */
    case 4968:  /* *pred_nmsacvnx16sf_scalar */
    case 4969:  /* *pred_nmaccvnx16sf_scalar */
    case 4970:  /* *pred_nmsacvnx1df_scalar */
    case 4971:  /* *pred_nmaccvnx1df_scalar */
    case 4972:  /* *pred_nmsacvnx2df_scalar */
    case 4973:  /* *pred_nmaccvnx2df_scalar */
    case 4974:  /* *pred_nmsacvnx4df_scalar */
    case 4975:  /* *pred_nmaccvnx4df_scalar */
    case 4976:  /* *pred_nmsacvnx8df_scalar */
    case 4977:  /* *pred_nmaccvnx8df_scalar */
    case 4978:  /* *pred_mul_neg_addvnx1sf_scalar */
    case 4979:  /* *pred_mul_neg_subvnx1sf_scalar */
    case 4980:  /* *pred_mul_neg_addvnx2sf_scalar */
    case 4981:  /* *pred_mul_neg_subvnx2sf_scalar */
    case 4982:  /* *pred_mul_neg_addvnx4sf_scalar */
    case 4983:  /* *pred_mul_neg_subvnx4sf_scalar */
    case 4984:  /* *pred_mul_neg_addvnx8sf_scalar */
    case 4985:  /* *pred_mul_neg_subvnx8sf_scalar */
    case 4986:  /* *pred_mul_neg_addvnx16sf_scalar */
    case 4987:  /* *pred_mul_neg_subvnx16sf_scalar */
    case 4988:  /* *pred_mul_neg_addvnx1df_scalar */
    case 4989:  /* *pred_mul_neg_subvnx1df_scalar */
    case 4990:  /* *pred_mul_neg_addvnx2df_scalar */
    case 4991:  /* *pred_mul_neg_subvnx2df_scalar */
    case 4992:  /* *pred_mul_neg_addvnx4df_scalar */
    case 4993:  /* *pred_mul_neg_subvnx4df_scalar */
    case 4994:  /* *pred_mul_neg_addvnx8df_scalar */
    case 4995:  /* *pred_mul_neg_subvnx8df_scalar */
      return TYPE_VFMULADD;

    case 5052:  /* pred_dual_widen_mulvnx1df */
    case 5055:  /* pred_dual_widen_mulvnx2df */
    case 5058:  /* pred_dual_widen_mulvnx4df */
    case 5061:  /* pred_dual_widen_mulvnx8df */
    case 5064:  /* pred_dual_widen_mulvnx1df_scalar */
    case 5067:  /* pred_dual_widen_mulvnx2df_scalar */
    case 5070:  /* pred_dual_widen_mulvnx4df_scalar */
    case 5073:  /* pred_dual_widen_mulvnx8df_scalar */
      return TYPE_VFWMUL;

    case 4605:  /* pred_divvnx1sf */
    case 4611:  /* pred_divvnx2sf */
    case 4617:  /* pred_divvnx4sf */
    case 4623:  /* pred_divvnx8sf */
    case 4629:  /* pred_divvnx16sf */
    case 4635:  /* pred_divvnx1df */
    case 4641:  /* pred_divvnx2df */
    case 4647:  /* pred_divvnx4df */
    case 4653:  /* pred_divvnx8df */
    case 4691:  /* pred_divvnx1sf_scalar */
    case 4693:  /* pred_divvnx2sf_scalar */
    case 4695:  /* pred_divvnx4sf_scalar */
    case 4697:  /* pred_divvnx8sf_scalar */
    case 4699:  /* pred_divvnx16sf_scalar */
    case 4701:  /* pred_divvnx1df_scalar */
    case 4703:  /* pred_divvnx2df_scalar */
    case 4705:  /* pred_divvnx4df_scalar */
    case 4707:  /* pred_divvnx8df_scalar */
    case 4709:  /* pred_divvnx1sf_reverse_scalar */
    case 4711:  /* pred_divvnx2sf_reverse_scalar */
    case 4713:  /* pred_divvnx4sf_reverse_scalar */
    case 4715:  /* pred_divvnx8sf_reverse_scalar */
    case 4717:  /* pred_divvnx16sf_reverse_scalar */
    case 4719:  /* pred_divvnx1df_reverse_scalar */
    case 4721:  /* pred_divvnx2df_reverse_scalar */
    case 4723:  /* pred_divvnx4df_reverse_scalar */
    case 4725:  /* pred_divvnx8df_reverse_scalar */
      return TYPE_VFDIV;

    case 4601:  /* pred_mulvnx1sf */
    case 4607:  /* pred_mulvnx2sf */
    case 4613:  /* pred_mulvnx4sf */
    case 4619:  /* pred_mulvnx8sf */
    case 4625:  /* pred_mulvnx16sf */
    case 4631:  /* pred_mulvnx1df */
    case 4637:  /* pred_mulvnx2df */
    case 4643:  /* pred_mulvnx4df */
    case 4649:  /* pred_mulvnx8df */
    case 4655:  /* pred_mulvnx1sf_scalar */
    case 4659:  /* pred_mulvnx2sf_scalar */
    case 4663:  /* pred_mulvnx4sf_scalar */
    case 4667:  /* pred_mulvnx8sf_scalar */
    case 4671:  /* pred_mulvnx16sf_scalar */
    case 4675:  /* pred_mulvnx1df_scalar */
    case 4679:  /* pred_mulvnx2df_scalar */
    case 4683:  /* pred_mulvnx4df_scalar */
    case 4687:  /* pred_mulvnx8df_scalar */
      return TYPE_VFMUL;

    case 5050:  /* pred_dual_widen_addvnx1df */
    case 5051:  /* pred_dual_widen_subvnx1df */
    case 5053:  /* pred_dual_widen_addvnx2df */
    case 5054:  /* pred_dual_widen_subvnx2df */
    case 5056:  /* pred_dual_widen_addvnx4df */
    case 5057:  /* pred_dual_widen_subvnx4df */
    case 5059:  /* pred_dual_widen_addvnx8df */
    case 5060:  /* pred_dual_widen_subvnx8df */
    case 5062:  /* pred_dual_widen_addvnx1df_scalar */
    case 5063:  /* pred_dual_widen_subvnx1df_scalar */
    case 5065:  /* pred_dual_widen_addvnx2df_scalar */
    case 5066:  /* pred_dual_widen_subvnx2df_scalar */
    case 5068:  /* pred_dual_widen_addvnx4df_scalar */
    case 5069:  /* pred_dual_widen_subvnx4df_scalar */
    case 5071:  /* pred_dual_widen_addvnx8df_scalar */
    case 5072:  /* pred_dual_widen_subvnx8df_scalar */
    case 5074:  /* pred_single_widen_addvnx1df */
    case 5075:  /* pred_single_widen_subvnx1df */
    case 5076:  /* pred_single_widen_addvnx2df */
    case 5077:  /* pred_single_widen_subvnx2df */
    case 5078:  /* pred_single_widen_addvnx4df */
    case 5079:  /* pred_single_widen_subvnx4df */
    case 5080:  /* pred_single_widen_addvnx8df */
    case 5081:  /* pred_single_widen_subvnx8df */
    case 5082:  /* pred_single_widen_addvnx1df_scalar */
    case 5083:  /* pred_single_widen_subvnx1df_scalar */
    case 5084:  /* pred_single_widen_addvnx2df_scalar */
    case 5085:  /* pred_single_widen_subvnx2df_scalar */
    case 5086:  /* pred_single_widen_addvnx4df_scalar */
    case 5087:  /* pred_single_widen_subvnx4df_scalar */
    case 5088:  /* pred_single_widen_addvnx8df_scalar */
    case 5089:  /* pred_single_widen_subvnx8df_scalar */
      return TYPE_VFWALU;

    case 4600:  /* pred_addvnx1sf */
    case 4604:  /* pred_subvnx1sf */
    case 4606:  /* pred_addvnx2sf */
    case 4610:  /* pred_subvnx2sf */
    case 4612:  /* pred_addvnx4sf */
    case 4616:  /* pred_subvnx4sf */
    case 4618:  /* pred_addvnx8sf */
    case 4622:  /* pred_subvnx8sf */
    case 4624:  /* pred_addvnx16sf */
    case 4628:  /* pred_subvnx16sf */
    case 4630:  /* pred_addvnx1df */
    case 4634:  /* pred_subvnx1df */
    case 4636:  /* pred_addvnx2df */
    case 4640:  /* pred_subvnx2df */
    case 4642:  /* pred_addvnx4df */
    case 4646:  /* pred_subvnx4df */
    case 4648:  /* pred_addvnx8df */
    case 4652:  /* pred_subvnx8df */
    case 4654:  /* pred_addvnx1sf_scalar */
    case 4658:  /* pred_addvnx2sf_scalar */
    case 4662:  /* pred_addvnx4sf_scalar */
    case 4666:  /* pred_addvnx8sf_scalar */
    case 4670:  /* pred_addvnx16sf_scalar */
    case 4674:  /* pred_addvnx1df_scalar */
    case 4678:  /* pred_addvnx2df_scalar */
    case 4682:  /* pred_addvnx4df_scalar */
    case 4686:  /* pred_addvnx8df_scalar */
    case 4690:  /* pred_subvnx1sf_scalar */
    case 4692:  /* pred_subvnx2sf_scalar */
    case 4694:  /* pred_subvnx4sf_scalar */
    case 4696:  /* pred_subvnx8sf_scalar */
    case 4698:  /* pred_subvnx16sf_scalar */
    case 4700:  /* pred_subvnx1df_scalar */
    case 4702:  /* pred_subvnx2df_scalar */
    case 4704:  /* pred_subvnx4df_scalar */
    case 4706:  /* pred_subvnx8df_scalar */
    case 4708:  /* pred_subvnx1sf_reverse_scalar */
    case 4710:  /* pred_subvnx2sf_reverse_scalar */
    case 4712:  /* pred_subvnx4sf_reverse_scalar */
    case 4714:  /* pred_subvnx8sf_reverse_scalar */
    case 4716:  /* pred_subvnx16sf_reverse_scalar */
    case 4718:  /* pred_subvnx1df_reverse_scalar */
    case 4720:  /* pred_subvnx2df_reverse_scalar */
    case 4722:  /* pred_subvnx4df_reverse_scalar */
    case 4724:  /* pred_subvnx8df_reverse_scalar */
      return TYPE_VFALU;

    case 3799:  /* pred_narrow_clipvnx1hi */
    case 3800:  /* pred_narrow_clipuvnx1hi */
    case 3801:  /* pred_narrow_clipvnx2hi */
    case 3802:  /* pred_narrow_clipuvnx2hi */
    case 3803:  /* pred_narrow_clipvnx4hi */
    case 3804:  /* pred_narrow_clipuvnx4hi */
    case 3805:  /* pred_narrow_clipvnx8hi */
    case 3806:  /* pred_narrow_clipuvnx8hi */
    case 3807:  /* pred_narrow_clipvnx16hi */
    case 3808:  /* pred_narrow_clipuvnx16hi */
    case 3809:  /* pred_narrow_clipvnx32hi */
    case 3810:  /* pred_narrow_clipuvnx32hi */
    case 3811:  /* pred_narrow_clipvnx1si */
    case 3812:  /* pred_narrow_clipuvnx1si */
    case 3813:  /* pred_narrow_clipvnx2si */
    case 3814:  /* pred_narrow_clipuvnx2si */
    case 3815:  /* pred_narrow_clipvnx4si */
    case 3816:  /* pred_narrow_clipuvnx4si */
    case 3817:  /* pred_narrow_clipvnx8si */
    case 3818:  /* pred_narrow_clipuvnx8si */
    case 3819:  /* pred_narrow_clipvnx16si */
    case 3820:  /* pred_narrow_clipuvnx16si */
    case 3821:  /* pred_narrow_clipvnx1di */
    case 3822:  /* pred_narrow_clipuvnx1di */
    case 3823:  /* pred_narrow_clipvnx2di */
    case 3824:  /* pred_narrow_clipuvnx2di */
    case 3825:  /* pred_narrow_clipvnx4di */
    case 3826:  /* pred_narrow_clipuvnx4di */
    case 3827:  /* pred_narrow_clipvnx8di */
    case 3828:  /* pred_narrow_clipuvnx8di */
    case 3829:  /* pred_narrow_clipvnx1hi_scalar */
    case 3830:  /* pred_narrow_clipuvnx1hi_scalar */
    case 3831:  /* pred_narrow_clipvnx2hi_scalar */
    case 3832:  /* pred_narrow_clipuvnx2hi_scalar */
    case 3833:  /* pred_narrow_clipvnx4hi_scalar */
    case 3834:  /* pred_narrow_clipuvnx4hi_scalar */
    case 3835:  /* pred_narrow_clipvnx8hi_scalar */
    case 3836:  /* pred_narrow_clipuvnx8hi_scalar */
    case 3837:  /* pred_narrow_clipvnx16hi_scalar */
    case 3838:  /* pred_narrow_clipuvnx16hi_scalar */
    case 3839:  /* pred_narrow_clipvnx32hi_scalar */
    case 3840:  /* pred_narrow_clipuvnx32hi_scalar */
    case 3841:  /* pred_narrow_clipvnx1si_scalar */
    case 3842:  /* pred_narrow_clipuvnx1si_scalar */
    case 3843:  /* pred_narrow_clipvnx2si_scalar */
    case 3844:  /* pred_narrow_clipuvnx2si_scalar */
    case 3845:  /* pred_narrow_clipvnx4si_scalar */
    case 3846:  /* pred_narrow_clipuvnx4si_scalar */
    case 3847:  /* pred_narrow_clipvnx8si_scalar */
    case 3848:  /* pred_narrow_clipuvnx8si_scalar */
    case 3849:  /* pred_narrow_clipvnx16si_scalar */
    case 3850:  /* pred_narrow_clipuvnx16si_scalar */
    case 3851:  /* pred_narrow_clipvnx1di_scalar */
    case 3852:  /* pred_narrow_clipuvnx1di_scalar */
    case 3853:  /* pred_narrow_clipvnx2di_scalar */
    case 3854:  /* pred_narrow_clipuvnx2di_scalar */
    case 3855:  /* pred_narrow_clipvnx4di_scalar */
    case 3856:  /* pred_narrow_clipuvnx4di_scalar */
    case 3857:  /* pred_narrow_clipvnx8di_scalar */
    case 3858:  /* pred_narrow_clipuvnx8di_scalar */
      return TYPE_VNCLIP;

    case 3476:  /* pred_ssrlvnx1qi */
    case 3477:  /* pred_ssravnx1qi */
    case 3483:  /* pred_ssrlvnx2qi */
    case 3484:  /* pred_ssravnx2qi */
    case 3490:  /* pred_ssrlvnx4qi */
    case 3491:  /* pred_ssravnx4qi */
    case 3497:  /* pred_ssrlvnx8qi */
    case 3498:  /* pred_ssravnx8qi */
    case 3504:  /* pred_ssrlvnx16qi */
    case 3505:  /* pred_ssravnx16qi */
    case 3511:  /* pred_ssrlvnx32qi */
    case 3512:  /* pred_ssravnx32qi */
    case 3518:  /* pred_ssrlvnx64qi */
    case 3519:  /* pred_ssravnx64qi */
    case 3525:  /* pred_ssrlvnx1hi */
    case 3526:  /* pred_ssravnx1hi */
    case 3532:  /* pred_ssrlvnx2hi */
    case 3533:  /* pred_ssravnx2hi */
    case 3539:  /* pred_ssrlvnx4hi */
    case 3540:  /* pred_ssravnx4hi */
    case 3546:  /* pred_ssrlvnx8hi */
    case 3547:  /* pred_ssravnx8hi */
    case 3553:  /* pred_ssrlvnx16hi */
    case 3554:  /* pred_ssravnx16hi */
    case 3560:  /* pred_ssrlvnx32hi */
    case 3561:  /* pred_ssravnx32hi */
    case 3567:  /* pred_ssrlvnx1si */
    case 3568:  /* pred_ssravnx1si */
    case 3574:  /* pred_ssrlvnx2si */
    case 3575:  /* pred_ssravnx2si */
    case 3581:  /* pred_ssrlvnx4si */
    case 3582:  /* pred_ssravnx4si */
    case 3588:  /* pred_ssrlvnx8si */
    case 3589:  /* pred_ssravnx8si */
    case 3595:  /* pred_ssrlvnx16si */
    case 3596:  /* pred_ssravnx16si */
    case 3602:  /* pred_ssrlvnx1di */
    case 3603:  /* pred_ssravnx1di */
    case 3609:  /* pred_ssrlvnx2di */
    case 3610:  /* pred_ssravnx2di */
    case 3616:  /* pred_ssrlvnx4di */
    case 3617:  /* pred_ssravnx4di */
    case 3623:  /* pred_ssrlvnx8di */
    case 3624:  /* pred_ssravnx8di */
    case 3715:  /* pred_ssrlvnx1qi_scalar */
    case 3716:  /* pred_ssravnx1qi_scalar */
    case 3717:  /* pred_ssrlvnx2qi_scalar */
    case 3718:  /* pred_ssravnx2qi_scalar */
    case 3719:  /* pred_ssrlvnx4qi_scalar */
    case 3720:  /* pred_ssravnx4qi_scalar */
    case 3721:  /* pred_ssrlvnx8qi_scalar */
    case 3722:  /* pred_ssravnx8qi_scalar */
    case 3723:  /* pred_ssrlvnx16qi_scalar */
    case 3724:  /* pred_ssravnx16qi_scalar */
    case 3725:  /* pred_ssrlvnx32qi_scalar */
    case 3726:  /* pred_ssravnx32qi_scalar */
    case 3727:  /* pred_ssrlvnx64qi_scalar */
    case 3728:  /* pred_ssravnx64qi_scalar */
    case 3729:  /* pred_ssrlvnx1hi_scalar */
    case 3730:  /* pred_ssravnx1hi_scalar */
    case 3731:  /* pred_ssrlvnx2hi_scalar */
    case 3732:  /* pred_ssravnx2hi_scalar */
    case 3733:  /* pred_ssrlvnx4hi_scalar */
    case 3734:  /* pred_ssravnx4hi_scalar */
    case 3735:  /* pred_ssrlvnx8hi_scalar */
    case 3736:  /* pred_ssravnx8hi_scalar */
    case 3737:  /* pred_ssrlvnx16hi_scalar */
    case 3738:  /* pred_ssravnx16hi_scalar */
    case 3739:  /* pred_ssrlvnx32hi_scalar */
    case 3740:  /* pred_ssravnx32hi_scalar */
    case 3741:  /* pred_ssrlvnx1si_scalar */
    case 3742:  /* pred_ssravnx1si_scalar */
    case 3743:  /* pred_ssrlvnx2si_scalar */
    case 3744:  /* pred_ssravnx2si_scalar */
    case 3745:  /* pred_ssrlvnx4si_scalar */
    case 3746:  /* pred_ssravnx4si_scalar */
    case 3747:  /* pred_ssrlvnx8si_scalar */
    case 3748:  /* pred_ssravnx8si_scalar */
    case 3749:  /* pred_ssrlvnx16si_scalar */
    case 3750:  /* pred_ssravnx16si_scalar */
    case 3751:  /* pred_ssrlvnx1di_scalar */
    case 3752:  /* pred_ssravnx1di_scalar */
    case 3753:  /* pred_ssrlvnx2di_scalar */
    case 3754:  /* pred_ssravnx2di_scalar */
    case 3755:  /* pred_ssrlvnx4di_scalar */
    case 3756:  /* pred_ssravnx4di_scalar */
    case 3757:  /* pred_ssrlvnx8di_scalar */
    case 3758:  /* pred_ssravnx8di_scalar */
      return TYPE_VSSHIFT;

    case 3475:  /* pred_smulvnx1qi */
    case 3482:  /* pred_smulvnx2qi */
    case 3489:  /* pred_smulvnx4qi */
    case 3496:  /* pred_smulvnx8qi */
    case 3503:  /* pred_smulvnx16qi */
    case 3510:  /* pred_smulvnx32qi */
    case 3517:  /* pred_smulvnx64qi */
    case 3524:  /* pred_smulvnx1hi */
    case 3531:  /* pred_smulvnx2hi */
    case 3538:  /* pred_smulvnx4hi */
    case 3545:  /* pred_smulvnx8hi */
    case 3552:  /* pred_smulvnx16hi */
    case 3559:  /* pred_smulvnx32hi */
    case 3566:  /* pred_smulvnx1si */
    case 3573:  /* pred_smulvnx2si */
    case 3580:  /* pred_smulvnx4si */
    case 3587:  /* pred_smulvnx8si */
    case 3594:  /* pred_smulvnx16si */
    case 3601:  /* pred_smulvnx1di */
    case 3608:  /* pred_smulvnx2di */
    case 3615:  /* pred_smulvnx4di */
    case 3622:  /* pred_smulvnx8di */
    case 3629:  /* pred_smulvnx1qi_scalar */
    case 3634:  /* pred_smulvnx2qi_scalar */
    case 3639:  /* pred_smulvnx4qi_scalar */
    case 3644:  /* pred_smulvnx8qi_scalar */
    case 3649:  /* pred_smulvnx16qi_scalar */
    case 3654:  /* pred_smulvnx32qi_scalar */
    case 3659:  /* pred_smulvnx64qi_scalar */
    case 3664:  /* pred_smulvnx1hi_scalar */
    case 3669:  /* pred_smulvnx2hi_scalar */
    case 3674:  /* pred_smulvnx4hi_scalar */
    case 3679:  /* pred_smulvnx8hi_scalar */
    case 3684:  /* pred_smulvnx16hi_scalar */
    case 3689:  /* pred_smulvnx32hi_scalar */
    case 3694:  /* pred_smulvnx1si_scalar */
    case 3699:  /* pred_smulvnx2si_scalar */
    case 3704:  /* pred_smulvnx4si_scalar */
    case 3709:  /* pred_smulvnx8si_scalar */
    case 3714:  /* pred_smulvnx16si_scalar */
    case 3763:  /* *pred_smulvnx1di_scalar */
    case 3768:  /* *pred_smulvnx2di_scalar */
    case 3773:  /* *pred_smulvnx4di_scalar */
    case 3778:  /* *pred_smulvnx8di_scalar */
    case 3783:  /* *pred_smulvnx1di_extended_scalar */
    case 3788:  /* *pred_smulvnx2di_extended_scalar */
    case 3793:  /* *pred_smulvnx4di_extended_scalar */
    case 3798:  /* *pred_smulvnx8di_extended_scalar */
      return TYPE_VSMUL;

    case 3471:  /* pred_aadduvnx1qi */
    case 3472:  /* pred_aaddvnx1qi */
    case 3473:  /* pred_asubuvnx1qi */
    case 3474:  /* pred_asubvnx1qi */
    case 3478:  /* pred_aadduvnx2qi */
    case 3479:  /* pred_aaddvnx2qi */
    case 3480:  /* pred_asubuvnx2qi */
    case 3481:  /* pred_asubvnx2qi */
    case 3485:  /* pred_aadduvnx4qi */
    case 3486:  /* pred_aaddvnx4qi */
    case 3487:  /* pred_asubuvnx4qi */
    case 3488:  /* pred_asubvnx4qi */
    case 3492:  /* pred_aadduvnx8qi */
    case 3493:  /* pred_aaddvnx8qi */
    case 3494:  /* pred_asubuvnx8qi */
    case 3495:  /* pred_asubvnx8qi */
    case 3499:  /* pred_aadduvnx16qi */
    case 3500:  /* pred_aaddvnx16qi */
    case 3501:  /* pred_asubuvnx16qi */
    case 3502:  /* pred_asubvnx16qi */
    case 3506:  /* pred_aadduvnx32qi */
    case 3507:  /* pred_aaddvnx32qi */
    case 3508:  /* pred_asubuvnx32qi */
    case 3509:  /* pred_asubvnx32qi */
    case 3513:  /* pred_aadduvnx64qi */
    case 3514:  /* pred_aaddvnx64qi */
    case 3515:  /* pred_asubuvnx64qi */
    case 3516:  /* pred_asubvnx64qi */
    case 3520:  /* pred_aadduvnx1hi */
    case 3521:  /* pred_aaddvnx1hi */
    case 3522:  /* pred_asubuvnx1hi */
    case 3523:  /* pred_asubvnx1hi */
    case 3527:  /* pred_aadduvnx2hi */
    case 3528:  /* pred_aaddvnx2hi */
    case 3529:  /* pred_asubuvnx2hi */
    case 3530:  /* pred_asubvnx2hi */
    case 3534:  /* pred_aadduvnx4hi */
    case 3535:  /* pred_aaddvnx4hi */
    case 3536:  /* pred_asubuvnx4hi */
    case 3537:  /* pred_asubvnx4hi */
    case 3541:  /* pred_aadduvnx8hi */
    case 3542:  /* pred_aaddvnx8hi */
    case 3543:  /* pred_asubuvnx8hi */
    case 3544:  /* pred_asubvnx8hi */
    case 3548:  /* pred_aadduvnx16hi */
    case 3549:  /* pred_aaddvnx16hi */
    case 3550:  /* pred_asubuvnx16hi */
    case 3551:  /* pred_asubvnx16hi */
    case 3555:  /* pred_aadduvnx32hi */
    case 3556:  /* pred_aaddvnx32hi */
    case 3557:  /* pred_asubuvnx32hi */
    case 3558:  /* pred_asubvnx32hi */
    case 3562:  /* pred_aadduvnx1si */
    case 3563:  /* pred_aaddvnx1si */
    case 3564:  /* pred_asubuvnx1si */
    case 3565:  /* pred_asubvnx1si */
    case 3569:  /* pred_aadduvnx2si */
    case 3570:  /* pred_aaddvnx2si */
    case 3571:  /* pred_asubuvnx2si */
    case 3572:  /* pred_asubvnx2si */
    case 3576:  /* pred_aadduvnx4si */
    case 3577:  /* pred_aaddvnx4si */
    case 3578:  /* pred_asubuvnx4si */
    case 3579:  /* pred_asubvnx4si */
    case 3583:  /* pred_aadduvnx8si */
    case 3584:  /* pred_aaddvnx8si */
    case 3585:  /* pred_asubuvnx8si */
    case 3586:  /* pred_asubvnx8si */
    case 3590:  /* pred_aadduvnx16si */
    case 3591:  /* pred_aaddvnx16si */
    case 3592:  /* pred_asubuvnx16si */
    case 3593:  /* pred_asubvnx16si */
    case 3597:  /* pred_aadduvnx1di */
    case 3598:  /* pred_aaddvnx1di */
    case 3599:  /* pred_asubuvnx1di */
    case 3600:  /* pred_asubvnx1di */
    case 3604:  /* pred_aadduvnx2di */
    case 3605:  /* pred_aaddvnx2di */
    case 3606:  /* pred_asubuvnx2di */
    case 3607:  /* pred_asubvnx2di */
    case 3611:  /* pred_aadduvnx4di */
    case 3612:  /* pred_aaddvnx4di */
    case 3613:  /* pred_asubuvnx4di */
    case 3614:  /* pred_asubvnx4di */
    case 3618:  /* pred_aadduvnx8di */
    case 3619:  /* pred_aaddvnx8di */
    case 3620:  /* pred_asubuvnx8di */
    case 3621:  /* pred_asubvnx8di */
    case 3625:  /* pred_aadduvnx1qi_scalar */
    case 3626:  /* pred_aaddvnx1qi_scalar */
    case 3627:  /* pred_asubuvnx1qi_scalar */
    case 3628:  /* pred_asubvnx1qi_scalar */
    case 3630:  /* pred_aadduvnx2qi_scalar */
    case 3631:  /* pred_aaddvnx2qi_scalar */
    case 3632:  /* pred_asubuvnx2qi_scalar */
    case 3633:  /* pred_asubvnx2qi_scalar */
    case 3635:  /* pred_aadduvnx4qi_scalar */
    case 3636:  /* pred_aaddvnx4qi_scalar */
    case 3637:  /* pred_asubuvnx4qi_scalar */
    case 3638:  /* pred_asubvnx4qi_scalar */
    case 3640:  /* pred_aadduvnx8qi_scalar */
    case 3641:  /* pred_aaddvnx8qi_scalar */
    case 3642:  /* pred_asubuvnx8qi_scalar */
    case 3643:  /* pred_asubvnx8qi_scalar */
    case 3645:  /* pred_aadduvnx16qi_scalar */
    case 3646:  /* pred_aaddvnx16qi_scalar */
    case 3647:  /* pred_asubuvnx16qi_scalar */
    case 3648:  /* pred_asubvnx16qi_scalar */
    case 3650:  /* pred_aadduvnx32qi_scalar */
    case 3651:  /* pred_aaddvnx32qi_scalar */
    case 3652:  /* pred_asubuvnx32qi_scalar */
    case 3653:  /* pred_asubvnx32qi_scalar */
    case 3655:  /* pred_aadduvnx64qi_scalar */
    case 3656:  /* pred_aaddvnx64qi_scalar */
    case 3657:  /* pred_asubuvnx64qi_scalar */
    case 3658:  /* pred_asubvnx64qi_scalar */
    case 3660:  /* pred_aadduvnx1hi_scalar */
    case 3661:  /* pred_aaddvnx1hi_scalar */
    case 3662:  /* pred_asubuvnx1hi_scalar */
    case 3663:  /* pred_asubvnx1hi_scalar */
    case 3665:  /* pred_aadduvnx2hi_scalar */
    case 3666:  /* pred_aaddvnx2hi_scalar */
    case 3667:  /* pred_asubuvnx2hi_scalar */
    case 3668:  /* pred_asubvnx2hi_scalar */
    case 3670:  /* pred_aadduvnx4hi_scalar */
    case 3671:  /* pred_aaddvnx4hi_scalar */
    case 3672:  /* pred_asubuvnx4hi_scalar */
    case 3673:  /* pred_asubvnx4hi_scalar */
    case 3675:  /* pred_aadduvnx8hi_scalar */
    case 3676:  /* pred_aaddvnx8hi_scalar */
    case 3677:  /* pred_asubuvnx8hi_scalar */
    case 3678:  /* pred_asubvnx8hi_scalar */
    case 3680:  /* pred_aadduvnx16hi_scalar */
    case 3681:  /* pred_aaddvnx16hi_scalar */
    case 3682:  /* pred_asubuvnx16hi_scalar */
    case 3683:  /* pred_asubvnx16hi_scalar */
    case 3685:  /* pred_aadduvnx32hi_scalar */
    case 3686:  /* pred_aaddvnx32hi_scalar */
    case 3687:  /* pred_asubuvnx32hi_scalar */
    case 3688:  /* pred_asubvnx32hi_scalar */
    case 3690:  /* pred_aadduvnx1si_scalar */
    case 3691:  /* pred_aaddvnx1si_scalar */
    case 3692:  /* pred_asubuvnx1si_scalar */
    case 3693:  /* pred_asubvnx1si_scalar */
    case 3695:  /* pred_aadduvnx2si_scalar */
    case 3696:  /* pred_aaddvnx2si_scalar */
    case 3697:  /* pred_asubuvnx2si_scalar */
    case 3698:  /* pred_asubvnx2si_scalar */
    case 3700:  /* pred_aadduvnx4si_scalar */
    case 3701:  /* pred_aaddvnx4si_scalar */
    case 3702:  /* pred_asubuvnx4si_scalar */
    case 3703:  /* pred_asubvnx4si_scalar */
    case 3705:  /* pred_aadduvnx8si_scalar */
    case 3706:  /* pred_aaddvnx8si_scalar */
    case 3707:  /* pred_asubuvnx8si_scalar */
    case 3708:  /* pred_asubvnx8si_scalar */
    case 3710:  /* pred_aadduvnx16si_scalar */
    case 3711:  /* pred_aaddvnx16si_scalar */
    case 3712:  /* pred_asubuvnx16si_scalar */
    case 3713:  /* pred_asubvnx16si_scalar */
    case 3759:  /* *pred_aadduvnx1di_scalar */
    case 3760:  /* *pred_aaddvnx1di_scalar */
    case 3761:  /* *pred_asubuvnx1di_scalar */
    case 3762:  /* *pred_asubvnx1di_scalar */
    case 3764:  /* *pred_aadduvnx2di_scalar */
    case 3765:  /* *pred_aaddvnx2di_scalar */
    case 3766:  /* *pred_asubuvnx2di_scalar */
    case 3767:  /* *pred_asubvnx2di_scalar */
    case 3769:  /* *pred_aadduvnx4di_scalar */
    case 3770:  /* *pred_aaddvnx4di_scalar */
    case 3771:  /* *pred_asubuvnx4di_scalar */
    case 3772:  /* *pred_asubvnx4di_scalar */
    case 3774:  /* *pred_aadduvnx8di_scalar */
    case 3775:  /* *pred_aaddvnx8di_scalar */
    case 3776:  /* *pred_asubuvnx8di_scalar */
    case 3777:  /* *pred_asubvnx8di_scalar */
    case 3779:  /* *pred_aadduvnx1di_extended_scalar */
    case 3780:  /* *pred_aaddvnx1di_extended_scalar */
    case 3781:  /* *pred_asubuvnx1di_extended_scalar */
    case 3782:  /* *pred_asubvnx1di_extended_scalar */
    case 3784:  /* *pred_aadduvnx2di_extended_scalar */
    case 3785:  /* *pred_aaddvnx2di_extended_scalar */
    case 3786:  /* *pred_asubuvnx2di_extended_scalar */
    case 3787:  /* *pred_asubvnx2di_extended_scalar */
    case 3789:  /* *pred_aadduvnx4di_extended_scalar */
    case 3790:  /* *pred_aaddvnx4di_extended_scalar */
    case 3791:  /* *pred_asubuvnx4di_extended_scalar */
    case 3792:  /* *pred_asubvnx4di_extended_scalar */
    case 3794:  /* *pred_aadduvnx8di_extended_scalar */
    case 3795:  /* *pred_aaddvnx8di_extended_scalar */
    case 3796:  /* *pred_asubuvnx8di_extended_scalar */
    case 3797:  /* *pred_asubvnx8di_extended_scalar */
      return TYPE_VAALU;

    case 3279:  /* pred_ssaddvnx1qi */
    case 3280:  /* pred_sssubvnx1qi */
    case 3281:  /* pred_usaddvnx1qi */
    case 3282:  /* pred_ussubvnx1qi */
    case 3283:  /* pred_ssaddvnx2qi */
    case 3284:  /* pred_sssubvnx2qi */
    case 3285:  /* pred_usaddvnx2qi */
    case 3286:  /* pred_ussubvnx2qi */
    case 3287:  /* pred_ssaddvnx4qi */
    case 3288:  /* pred_sssubvnx4qi */
    case 3289:  /* pred_usaddvnx4qi */
    case 3290:  /* pred_ussubvnx4qi */
    case 3291:  /* pred_ssaddvnx8qi */
    case 3292:  /* pred_sssubvnx8qi */
    case 3293:  /* pred_usaddvnx8qi */
    case 3294:  /* pred_ussubvnx8qi */
    case 3295:  /* pred_ssaddvnx16qi */
    case 3296:  /* pred_sssubvnx16qi */
    case 3297:  /* pred_usaddvnx16qi */
    case 3298:  /* pred_ussubvnx16qi */
    case 3299:  /* pred_ssaddvnx32qi */
    case 3300:  /* pred_sssubvnx32qi */
    case 3301:  /* pred_usaddvnx32qi */
    case 3302:  /* pred_ussubvnx32qi */
    case 3303:  /* pred_ssaddvnx64qi */
    case 3304:  /* pred_sssubvnx64qi */
    case 3305:  /* pred_usaddvnx64qi */
    case 3306:  /* pred_ussubvnx64qi */
    case 3307:  /* pred_ssaddvnx1hi */
    case 3308:  /* pred_sssubvnx1hi */
    case 3309:  /* pred_usaddvnx1hi */
    case 3310:  /* pred_ussubvnx1hi */
    case 3311:  /* pred_ssaddvnx2hi */
    case 3312:  /* pred_sssubvnx2hi */
    case 3313:  /* pred_usaddvnx2hi */
    case 3314:  /* pred_ussubvnx2hi */
    case 3315:  /* pred_ssaddvnx4hi */
    case 3316:  /* pred_sssubvnx4hi */
    case 3317:  /* pred_usaddvnx4hi */
    case 3318:  /* pred_ussubvnx4hi */
    case 3319:  /* pred_ssaddvnx8hi */
    case 3320:  /* pred_sssubvnx8hi */
    case 3321:  /* pred_usaddvnx8hi */
    case 3322:  /* pred_ussubvnx8hi */
    case 3323:  /* pred_ssaddvnx16hi */
    case 3324:  /* pred_sssubvnx16hi */
    case 3325:  /* pred_usaddvnx16hi */
    case 3326:  /* pred_ussubvnx16hi */
    case 3327:  /* pred_ssaddvnx32hi */
    case 3328:  /* pred_sssubvnx32hi */
    case 3329:  /* pred_usaddvnx32hi */
    case 3330:  /* pred_ussubvnx32hi */
    case 3331:  /* pred_ssaddvnx1si */
    case 3332:  /* pred_sssubvnx1si */
    case 3333:  /* pred_usaddvnx1si */
    case 3334:  /* pred_ussubvnx1si */
    case 3335:  /* pred_ssaddvnx2si */
    case 3336:  /* pred_sssubvnx2si */
    case 3337:  /* pred_usaddvnx2si */
    case 3338:  /* pred_ussubvnx2si */
    case 3339:  /* pred_ssaddvnx4si */
    case 3340:  /* pred_sssubvnx4si */
    case 3341:  /* pred_usaddvnx4si */
    case 3342:  /* pred_ussubvnx4si */
    case 3343:  /* pred_ssaddvnx8si */
    case 3344:  /* pred_sssubvnx8si */
    case 3345:  /* pred_usaddvnx8si */
    case 3346:  /* pred_ussubvnx8si */
    case 3347:  /* pred_ssaddvnx16si */
    case 3348:  /* pred_sssubvnx16si */
    case 3349:  /* pred_usaddvnx16si */
    case 3350:  /* pred_ussubvnx16si */
    case 3351:  /* pred_ssaddvnx1di */
    case 3352:  /* pred_sssubvnx1di */
    case 3353:  /* pred_usaddvnx1di */
    case 3354:  /* pred_ussubvnx1di */
    case 3355:  /* pred_ssaddvnx2di */
    case 3356:  /* pred_sssubvnx2di */
    case 3357:  /* pred_usaddvnx2di */
    case 3358:  /* pred_ussubvnx2di */
    case 3359:  /* pred_ssaddvnx4di */
    case 3360:  /* pred_sssubvnx4di */
    case 3361:  /* pred_usaddvnx4di */
    case 3362:  /* pred_ussubvnx4di */
    case 3363:  /* pred_ssaddvnx8di */
    case 3364:  /* pred_sssubvnx8di */
    case 3365:  /* pred_usaddvnx8di */
    case 3366:  /* pred_ussubvnx8di */
    case 3367:  /* pred_ssaddvnx1qi_scalar */
    case 3368:  /* pred_usaddvnx1qi_scalar */
    case 3369:  /* pred_ssaddvnx2qi_scalar */
    case 3370:  /* pred_usaddvnx2qi_scalar */
    case 3371:  /* pred_ssaddvnx4qi_scalar */
    case 3372:  /* pred_usaddvnx4qi_scalar */
    case 3373:  /* pred_ssaddvnx8qi_scalar */
    case 3374:  /* pred_usaddvnx8qi_scalar */
    case 3375:  /* pred_ssaddvnx16qi_scalar */
    case 3376:  /* pred_usaddvnx16qi_scalar */
    case 3377:  /* pred_ssaddvnx32qi_scalar */
    case 3378:  /* pred_usaddvnx32qi_scalar */
    case 3379:  /* pred_ssaddvnx64qi_scalar */
    case 3380:  /* pred_usaddvnx64qi_scalar */
    case 3381:  /* pred_ssaddvnx1hi_scalar */
    case 3382:  /* pred_usaddvnx1hi_scalar */
    case 3383:  /* pred_ssaddvnx2hi_scalar */
    case 3384:  /* pred_usaddvnx2hi_scalar */
    case 3385:  /* pred_ssaddvnx4hi_scalar */
    case 3386:  /* pred_usaddvnx4hi_scalar */
    case 3387:  /* pred_ssaddvnx8hi_scalar */
    case 3388:  /* pred_usaddvnx8hi_scalar */
    case 3389:  /* pred_ssaddvnx16hi_scalar */
    case 3390:  /* pred_usaddvnx16hi_scalar */
    case 3391:  /* pred_ssaddvnx32hi_scalar */
    case 3392:  /* pred_usaddvnx32hi_scalar */
    case 3393:  /* pred_ssaddvnx1si_scalar */
    case 3394:  /* pred_usaddvnx1si_scalar */
    case 3395:  /* pred_ssaddvnx2si_scalar */
    case 3396:  /* pred_usaddvnx2si_scalar */
    case 3397:  /* pred_ssaddvnx4si_scalar */
    case 3398:  /* pred_usaddvnx4si_scalar */
    case 3399:  /* pred_ssaddvnx8si_scalar */
    case 3400:  /* pred_usaddvnx8si_scalar */
    case 3401:  /* pred_ssaddvnx16si_scalar */
    case 3402:  /* pred_usaddvnx16si_scalar */
    case 3403:  /* pred_sssubvnx1qi_scalar */
    case 3404:  /* pred_ussubvnx1qi_scalar */
    case 3405:  /* pred_sssubvnx2qi_scalar */
    case 3406:  /* pred_ussubvnx2qi_scalar */
    case 3407:  /* pred_sssubvnx4qi_scalar */
    case 3408:  /* pred_ussubvnx4qi_scalar */
    case 3409:  /* pred_sssubvnx8qi_scalar */
    case 3410:  /* pred_ussubvnx8qi_scalar */
    case 3411:  /* pred_sssubvnx16qi_scalar */
    case 3412:  /* pred_ussubvnx16qi_scalar */
    case 3413:  /* pred_sssubvnx32qi_scalar */
    case 3414:  /* pred_ussubvnx32qi_scalar */
    case 3415:  /* pred_sssubvnx64qi_scalar */
    case 3416:  /* pred_ussubvnx64qi_scalar */
    case 3417:  /* pred_sssubvnx1hi_scalar */
    case 3418:  /* pred_ussubvnx1hi_scalar */
    case 3419:  /* pred_sssubvnx2hi_scalar */
    case 3420:  /* pred_ussubvnx2hi_scalar */
    case 3421:  /* pred_sssubvnx4hi_scalar */
    case 3422:  /* pred_ussubvnx4hi_scalar */
    case 3423:  /* pred_sssubvnx8hi_scalar */
    case 3424:  /* pred_ussubvnx8hi_scalar */
    case 3425:  /* pred_sssubvnx16hi_scalar */
    case 3426:  /* pred_ussubvnx16hi_scalar */
    case 3427:  /* pred_sssubvnx32hi_scalar */
    case 3428:  /* pred_ussubvnx32hi_scalar */
    case 3429:  /* pred_sssubvnx1si_scalar */
    case 3430:  /* pred_ussubvnx1si_scalar */
    case 3431:  /* pred_sssubvnx2si_scalar */
    case 3432:  /* pred_ussubvnx2si_scalar */
    case 3433:  /* pred_sssubvnx4si_scalar */
    case 3434:  /* pred_ussubvnx4si_scalar */
    case 3435:  /* pred_sssubvnx8si_scalar */
    case 3436:  /* pred_ussubvnx8si_scalar */
    case 3437:  /* pred_sssubvnx16si_scalar */
    case 3438:  /* pred_ussubvnx16si_scalar */
    case 3439:  /* *pred_ssaddvnx1di_scalar */
    case 3440:  /* *pred_usaddvnx1di_scalar */
    case 3441:  /* *pred_ssaddvnx2di_scalar */
    case 3442:  /* *pred_usaddvnx2di_scalar */
    case 3443:  /* *pred_ssaddvnx4di_scalar */
    case 3444:  /* *pred_usaddvnx4di_scalar */
    case 3445:  /* *pred_ssaddvnx8di_scalar */
    case 3446:  /* *pred_usaddvnx8di_scalar */
    case 3447:  /* *pred_ssaddvnx1di_extended_scalar */
    case 3448:  /* *pred_usaddvnx1di_extended_scalar */
    case 3449:  /* *pred_ssaddvnx2di_extended_scalar */
    case 3450:  /* *pred_usaddvnx2di_extended_scalar */
    case 3451:  /* *pred_ssaddvnx4di_extended_scalar */
    case 3452:  /* *pred_usaddvnx4di_extended_scalar */
    case 3453:  /* *pred_ssaddvnx8di_extended_scalar */
    case 3454:  /* *pred_usaddvnx8di_extended_scalar */
    case 3455:  /* *pred_sssubvnx1di_scalar */
    case 3456:  /* *pred_ussubvnx1di_scalar */
    case 3457:  /* *pred_sssubvnx2di_scalar */
    case 3458:  /* *pred_ussubvnx2di_scalar */
    case 3459:  /* *pred_sssubvnx4di_scalar */
    case 3460:  /* *pred_ussubvnx4di_scalar */
    case 3461:  /* *pred_sssubvnx8di_scalar */
    case 3462:  /* *pred_ussubvnx8di_scalar */
    case 3463:  /* *pred_sssubvnx1di_extended_scalar */
    case 3464:  /* *pred_ussubvnx1di_extended_scalar */
    case 3465:  /* *pred_sssubvnx2di_extended_scalar */
    case 3466:  /* *pred_ussubvnx2di_extended_scalar */
    case 3467:  /* *pred_sssubvnx4di_extended_scalar */
    case 3468:  /* *pred_ussubvnx4di_extended_scalar */
    case 3469:  /* *pred_sssubvnx8di_extended_scalar */
    case 3470:  /* *pred_ussubvnx8di_extended_scalar */
      return TYPE_VSALU;

    case 876:  /* pred_mergevnx1qi */
    case 877:  /* pred_mergevnx2qi */
    case 878:  /* pred_mergevnx4qi */
    case 879:  /* pred_mergevnx8qi */
    case 880:  /* pred_mergevnx16qi */
    case 881:  /* pred_mergevnx32qi */
    case 882:  /* pred_mergevnx64qi */
    case 883:  /* pred_mergevnx1hi */
    case 884:  /* pred_mergevnx2hi */
    case 885:  /* pred_mergevnx4hi */
    case 886:  /* pred_mergevnx8hi */
    case 887:  /* pred_mergevnx16hi */
    case 888:  /* pred_mergevnx32hi */
    case 889:  /* pred_mergevnx1si */
    case 890:  /* pred_mergevnx2si */
    case 891:  /* pred_mergevnx4si */
    case 892:  /* pred_mergevnx8si */
    case 893:  /* pred_mergevnx16si */
    case 894:  /* pred_mergevnx1di */
    case 895:  /* pred_mergevnx2di */
    case 896:  /* pred_mergevnx4di */
    case 897:  /* pred_mergevnx8di */
    case 898:  /* pred_mergevnx1sf */
    case 899:  /* pred_mergevnx2sf */
    case 900:  /* pred_mergevnx4sf */
    case 901:  /* pred_mergevnx8sf */
    case 902:  /* pred_mergevnx16sf */
    case 903:  /* pred_mergevnx1df */
    case 904:  /* pred_mergevnx2df */
    case 905:  /* pred_mergevnx4df */
    case 906:  /* pred_mergevnx8df */
    case 907:  /* pred_mergevnx1qi_scalar */
    case 908:  /* pred_mergevnx2qi_scalar */
    case 909:  /* pred_mergevnx4qi_scalar */
    case 910:  /* pred_mergevnx8qi_scalar */
    case 911:  /* pred_mergevnx16qi_scalar */
    case 912:  /* pred_mergevnx32qi_scalar */
    case 913:  /* pred_mergevnx64qi_scalar */
    case 914:  /* pred_mergevnx1hi_scalar */
    case 915:  /* pred_mergevnx2hi_scalar */
    case 916:  /* pred_mergevnx4hi_scalar */
    case 917:  /* pred_mergevnx8hi_scalar */
    case 918:  /* pred_mergevnx16hi_scalar */
    case 919:  /* pred_mergevnx32hi_scalar */
    case 920:  /* pred_mergevnx1si_scalar */
    case 921:  /* pred_mergevnx2si_scalar */
    case 922:  /* pred_mergevnx4si_scalar */
    case 923:  /* pred_mergevnx8si_scalar */
    case 924:  /* pred_mergevnx16si_scalar */
    case 925:  /* *pred_mergevnx1di_scalar */
    case 926:  /* *pred_mergevnx2di_scalar */
    case 927:  /* *pred_mergevnx4di_scalar */
    case 928:  /* *pred_mergevnx8di_scalar */
    case 929:  /* *pred_mergevnx1di_extended_scalar */
    case 930:  /* *pred_mergevnx2di_extended_scalar */
    case 931:  /* *pred_mergevnx4di_extended_scalar */
    case 932:  /* *pred_mergevnx8di_extended_scalar */
      return TYPE_VIMERGE;

    case 4339:  /* pred_widen_mul_plussvnx1hi */
    case 4340:  /* pred_widen_mul_plusuvnx1hi */
    case 4341:  /* pred_widen_mul_plussvnx2hi */
    case 4342:  /* pred_widen_mul_plusuvnx2hi */
    case 4343:  /* pred_widen_mul_plussvnx4hi */
    case 4344:  /* pred_widen_mul_plusuvnx4hi */
    case 4345:  /* pred_widen_mul_plussvnx8hi */
    case 4346:  /* pred_widen_mul_plusuvnx8hi */
    case 4347:  /* pred_widen_mul_plussvnx16hi */
    case 4348:  /* pred_widen_mul_plusuvnx16hi */
    case 4349:  /* pred_widen_mul_plussvnx32hi */
    case 4350:  /* pred_widen_mul_plusuvnx32hi */
    case 4351:  /* pred_widen_mul_plussvnx1si */
    case 4352:  /* pred_widen_mul_plusuvnx1si */
    case 4353:  /* pred_widen_mul_plussvnx2si */
    case 4354:  /* pred_widen_mul_plusuvnx2si */
    case 4355:  /* pred_widen_mul_plussvnx4si */
    case 4356:  /* pred_widen_mul_plusuvnx4si */
    case 4357:  /* pred_widen_mul_plussvnx8si */
    case 4358:  /* pred_widen_mul_plusuvnx8si */
    case 4359:  /* pred_widen_mul_plussvnx16si */
    case 4360:  /* pred_widen_mul_plusuvnx16si */
    case 4361:  /* pred_widen_mul_plussvnx1di */
    case 4362:  /* pred_widen_mul_plusuvnx1di */
    case 4363:  /* pred_widen_mul_plussvnx2di */
    case 4364:  /* pred_widen_mul_plusuvnx2di */
    case 4365:  /* pred_widen_mul_plussvnx4di */
    case 4366:  /* pred_widen_mul_plusuvnx4di */
    case 4367:  /* pred_widen_mul_plussvnx8di */
    case 4368:  /* pred_widen_mul_plusuvnx8di */
    case 4369:  /* pred_widen_mul_plussvnx1hi_scalar */
    case 4370:  /* pred_widen_mul_plusuvnx1hi_scalar */
    case 4371:  /* pred_widen_mul_plussvnx2hi_scalar */
    case 4372:  /* pred_widen_mul_plusuvnx2hi_scalar */
    case 4373:  /* pred_widen_mul_plussvnx4hi_scalar */
    case 4374:  /* pred_widen_mul_plusuvnx4hi_scalar */
    case 4375:  /* pred_widen_mul_plussvnx8hi_scalar */
    case 4376:  /* pred_widen_mul_plusuvnx8hi_scalar */
    case 4377:  /* pred_widen_mul_plussvnx16hi_scalar */
    case 4378:  /* pred_widen_mul_plusuvnx16hi_scalar */
    case 4379:  /* pred_widen_mul_plussvnx32hi_scalar */
    case 4380:  /* pred_widen_mul_plusuvnx32hi_scalar */
    case 4381:  /* pred_widen_mul_plussvnx1si_scalar */
    case 4382:  /* pred_widen_mul_plusuvnx1si_scalar */
    case 4383:  /* pred_widen_mul_plussvnx2si_scalar */
    case 4384:  /* pred_widen_mul_plusuvnx2si_scalar */
    case 4385:  /* pred_widen_mul_plussvnx4si_scalar */
    case 4386:  /* pred_widen_mul_plusuvnx4si_scalar */
    case 4387:  /* pred_widen_mul_plussvnx8si_scalar */
    case 4388:  /* pred_widen_mul_plusuvnx8si_scalar */
    case 4389:  /* pred_widen_mul_plussvnx16si_scalar */
    case 4390:  /* pred_widen_mul_plusuvnx16si_scalar */
    case 4391:  /* pred_widen_mul_plussvnx1di_scalar */
    case 4392:  /* pred_widen_mul_plusuvnx1di_scalar */
    case 4393:  /* pred_widen_mul_plussvnx2di_scalar */
    case 4394:  /* pred_widen_mul_plusuvnx2di_scalar */
    case 4395:  /* pred_widen_mul_plussvnx4di_scalar */
    case 4396:  /* pred_widen_mul_plusuvnx4di_scalar */
    case 4397:  /* pred_widen_mul_plussvnx8di_scalar */
    case 4398:  /* pred_widen_mul_plusuvnx8di_scalar */
    case 4399:  /* pred_widen_mul_plussuvnx1hi */
    case 4400:  /* pred_widen_mul_plussuvnx2hi */
    case 4401:  /* pred_widen_mul_plussuvnx4hi */
    case 4402:  /* pred_widen_mul_plussuvnx8hi */
    case 4403:  /* pred_widen_mul_plussuvnx16hi */
    case 4404:  /* pred_widen_mul_plussuvnx32hi */
    case 4405:  /* pred_widen_mul_plussuvnx1si */
    case 4406:  /* pred_widen_mul_plussuvnx2si */
    case 4407:  /* pred_widen_mul_plussuvnx4si */
    case 4408:  /* pred_widen_mul_plussuvnx8si */
    case 4409:  /* pred_widen_mul_plussuvnx16si */
    case 4410:  /* pred_widen_mul_plussuvnx1di */
    case 4411:  /* pred_widen_mul_plussuvnx2di */
    case 4412:  /* pred_widen_mul_plussuvnx4di */
    case 4413:  /* pred_widen_mul_plussuvnx8di */
    case 4414:  /* pred_widen_mul_plussuvnx1hi_scalar */
    case 4415:  /* pred_widen_mul_plussuvnx2hi_scalar */
    case 4416:  /* pred_widen_mul_plussuvnx4hi_scalar */
    case 4417:  /* pred_widen_mul_plussuvnx8hi_scalar */
    case 4418:  /* pred_widen_mul_plussuvnx16hi_scalar */
    case 4419:  /* pred_widen_mul_plussuvnx32hi_scalar */
    case 4420:  /* pred_widen_mul_plussuvnx1si_scalar */
    case 4421:  /* pred_widen_mul_plussuvnx2si_scalar */
    case 4422:  /* pred_widen_mul_plussuvnx4si_scalar */
    case 4423:  /* pred_widen_mul_plussuvnx8si_scalar */
    case 4424:  /* pred_widen_mul_plussuvnx16si_scalar */
    case 4425:  /* pred_widen_mul_plussuvnx1di_scalar */
    case 4426:  /* pred_widen_mul_plussuvnx2di_scalar */
    case 4427:  /* pred_widen_mul_plussuvnx4di_scalar */
    case 4428:  /* pred_widen_mul_plussuvnx8di_scalar */
    case 4429:  /* pred_widen_mul_plususvnx1hi_scalar */
    case 4430:  /* pred_widen_mul_plususvnx2hi_scalar */
    case 4431:  /* pred_widen_mul_plususvnx4hi_scalar */
    case 4432:  /* pred_widen_mul_plususvnx8hi_scalar */
    case 4433:  /* pred_widen_mul_plususvnx16hi_scalar */
    case 4434:  /* pred_widen_mul_plususvnx32hi_scalar */
    case 4435:  /* pred_widen_mul_plususvnx1si_scalar */
    case 4436:  /* pred_widen_mul_plususvnx2si_scalar */
    case 4437:  /* pred_widen_mul_plususvnx4si_scalar */
    case 4438:  /* pred_widen_mul_plususvnx8si_scalar */
    case 4439:  /* pred_widen_mul_plususvnx16si_scalar */
    case 4440:  /* pred_widen_mul_plususvnx1di_scalar */
    case 4441:  /* pred_widen_mul_plususvnx2di_scalar */
    case 4442:  /* pred_widen_mul_plususvnx4di_scalar */
    case 4443:  /* pred_widen_mul_plususvnx8di_scalar */
      return TYPE_VIWMULADD;

    case 4051:  /* *pred_maddvnx1qi */
    case 4052:  /* *pred_maddvnx2qi */
    case 4053:  /* *pred_maddvnx4qi */
    case 4054:  /* *pred_maddvnx8qi */
    case 4055:  /* *pred_maddvnx16qi */
    case 4056:  /* *pred_maddvnx32qi */
    case 4057:  /* *pred_maddvnx64qi */
    case 4058:  /* *pred_maddvnx1hi */
    case 4059:  /* *pred_maddvnx2hi */
    case 4060:  /* *pred_maddvnx4hi */
    case 4061:  /* *pred_maddvnx8hi */
    case 4062:  /* *pred_maddvnx16hi */
    case 4063:  /* *pred_maddvnx32hi */
    case 4064:  /* *pred_maddvnx1si */
    case 4065:  /* *pred_maddvnx2si */
    case 4066:  /* *pred_maddvnx4si */
    case 4067:  /* *pred_maddvnx8si */
    case 4068:  /* *pred_maddvnx16si */
    case 4069:  /* *pred_maddvnx1di */
    case 4070:  /* *pred_maddvnx2di */
    case 4071:  /* *pred_maddvnx4di */
    case 4072:  /* *pred_maddvnx8di */
    case 4073:  /* *pred_maccvnx1qi */
    case 4074:  /* *pred_maccvnx2qi */
    case 4075:  /* *pred_maccvnx4qi */
    case 4076:  /* *pred_maccvnx8qi */
    case 4077:  /* *pred_maccvnx16qi */
    case 4078:  /* *pred_maccvnx32qi */
    case 4079:  /* *pred_maccvnx64qi */
    case 4080:  /* *pred_maccvnx1hi */
    case 4081:  /* *pred_maccvnx2hi */
    case 4082:  /* *pred_maccvnx4hi */
    case 4083:  /* *pred_maccvnx8hi */
    case 4084:  /* *pred_maccvnx16hi */
    case 4085:  /* *pred_maccvnx32hi */
    case 4086:  /* *pred_maccvnx1si */
    case 4087:  /* *pred_maccvnx2si */
    case 4088:  /* *pred_maccvnx4si */
    case 4089:  /* *pred_maccvnx8si */
    case 4090:  /* *pred_maccvnx16si */
    case 4091:  /* *pred_maccvnx1di */
    case 4092:  /* *pred_maccvnx2di */
    case 4093:  /* *pred_maccvnx4di */
    case 4094:  /* *pred_maccvnx8di */
    case 4095:  /* *pred_mul_plusvnx1qi */
    case 4096:  /* *pred_mul_plusvnx2qi */
    case 4097:  /* *pred_mul_plusvnx4qi */
    case 4098:  /* *pred_mul_plusvnx8qi */
    case 4099:  /* *pred_mul_plusvnx16qi */
    case 4100:  /* *pred_mul_plusvnx32qi */
    case 4101:  /* *pred_mul_plusvnx64qi */
    case 4102:  /* *pred_mul_plusvnx1hi */
    case 4103:  /* *pred_mul_plusvnx2hi */
    case 4104:  /* *pred_mul_plusvnx4hi */
    case 4105:  /* *pred_mul_plusvnx8hi */
    case 4106:  /* *pred_mul_plusvnx16hi */
    case 4107:  /* *pred_mul_plusvnx32hi */
    case 4108:  /* *pred_mul_plusvnx1si */
    case 4109:  /* *pred_mul_plusvnx2si */
    case 4110:  /* *pred_mul_plusvnx4si */
    case 4111:  /* *pred_mul_plusvnx8si */
    case 4112:  /* *pred_mul_plusvnx16si */
    case 4113:  /* *pred_mul_plusvnx1di */
    case 4114:  /* *pred_mul_plusvnx2di */
    case 4115:  /* *pred_mul_plusvnx4di */
    case 4116:  /* *pred_mul_plusvnx8di */
    case 4117:  /* *pred_maddvnx1qi_scalar */
    case 4118:  /* *pred_maddvnx2qi_scalar */
    case 4119:  /* *pred_maddvnx4qi_scalar */
    case 4120:  /* *pred_maddvnx8qi_scalar */
    case 4121:  /* *pred_maddvnx16qi_scalar */
    case 4122:  /* *pred_maddvnx32qi_scalar */
    case 4123:  /* *pred_maddvnx64qi_scalar */
    case 4124:  /* *pred_maddvnx1hi_scalar */
    case 4125:  /* *pred_maddvnx2hi_scalar */
    case 4126:  /* *pred_maddvnx4hi_scalar */
    case 4127:  /* *pred_maddvnx8hi_scalar */
    case 4128:  /* *pred_maddvnx16hi_scalar */
    case 4129:  /* *pred_maddvnx32hi_scalar */
    case 4130:  /* *pred_maddvnx1si_scalar */
    case 4131:  /* *pred_maddvnx2si_scalar */
    case 4132:  /* *pred_maddvnx4si_scalar */
    case 4133:  /* *pred_maddvnx8si_scalar */
    case 4134:  /* *pred_maddvnx16si_scalar */
    case 4135:  /* *pred_maddvnx1di_scalar */
    case 4136:  /* *pred_maddvnx2di_scalar */
    case 4137:  /* *pred_maddvnx4di_scalar */
    case 4138:  /* *pred_maddvnx8di_scalar */
    case 4139:  /* *pred_maccvnx1qi_scalar */
    case 4140:  /* *pred_maccvnx2qi_scalar */
    case 4141:  /* *pred_maccvnx4qi_scalar */
    case 4142:  /* *pred_maccvnx8qi_scalar */
    case 4143:  /* *pred_maccvnx16qi_scalar */
    case 4144:  /* *pred_maccvnx32qi_scalar */
    case 4145:  /* *pred_maccvnx64qi_scalar */
    case 4146:  /* *pred_maccvnx1hi_scalar */
    case 4147:  /* *pred_maccvnx2hi_scalar */
    case 4148:  /* *pred_maccvnx4hi_scalar */
    case 4149:  /* *pred_maccvnx8hi_scalar */
    case 4150:  /* *pred_maccvnx16hi_scalar */
    case 4151:  /* *pred_maccvnx32hi_scalar */
    case 4152:  /* *pred_maccvnx1si_scalar */
    case 4153:  /* *pred_maccvnx2si_scalar */
    case 4154:  /* *pred_maccvnx4si_scalar */
    case 4155:  /* *pred_maccvnx8si_scalar */
    case 4156:  /* *pred_maccvnx16si_scalar */
    case 4157:  /* *pred_maccvnx1di_scalar */
    case 4158:  /* *pred_maccvnx2di_scalar */
    case 4159:  /* *pred_maccvnx4di_scalar */
    case 4160:  /* *pred_maccvnx8di_scalar */
    case 4161:  /* *pred_mul_plusvnx1qi_scalar */
    case 4162:  /* *pred_mul_plusvnx2qi_scalar */
    case 4163:  /* *pred_mul_plusvnx4qi_scalar */
    case 4164:  /* *pred_mul_plusvnx8qi_scalar */
    case 4165:  /* *pred_mul_plusvnx16qi_scalar */
    case 4166:  /* *pred_mul_plusvnx32qi_scalar */
    case 4167:  /* *pred_mul_plusvnx64qi_scalar */
    case 4168:  /* *pred_mul_plusvnx1hi_scalar */
    case 4169:  /* *pred_mul_plusvnx2hi_scalar */
    case 4170:  /* *pred_mul_plusvnx4hi_scalar */
    case 4171:  /* *pred_mul_plusvnx8hi_scalar */
    case 4172:  /* *pred_mul_plusvnx16hi_scalar */
    case 4173:  /* *pred_mul_plusvnx32hi_scalar */
    case 4174:  /* *pred_mul_plusvnx1si_scalar */
    case 4175:  /* *pred_mul_plusvnx2si_scalar */
    case 4176:  /* *pred_mul_plusvnx4si_scalar */
    case 4177:  /* *pred_mul_plusvnx8si_scalar */
    case 4178:  /* *pred_mul_plusvnx16si_scalar */
    case 4179:  /* *pred_mul_plusvnx1di_scalar */
    case 4180:  /* *pred_mul_plusvnx2di_scalar */
    case 4181:  /* *pred_mul_plusvnx4di_scalar */
    case 4182:  /* *pred_mul_plusvnx8di_scalar */
    case 4183:  /* *pred_maddvnx1di_extended_scalar */
    case 4184:  /* *pred_maddvnx2di_extended_scalar */
    case 4185:  /* *pred_maddvnx4di_extended_scalar */
    case 4186:  /* *pred_maddvnx8di_extended_scalar */
    case 4187:  /* *pred_maccvnx1di_extended_scalar */
    case 4188:  /* *pred_maccvnx2di_extended_scalar */
    case 4189:  /* *pred_maccvnx4di_extended_scalar */
    case 4190:  /* *pred_maccvnx8di_extended_scalar */
    case 4191:  /* *pred_mul_plusvnx1di_extended_scalar */
    case 4192:  /* *pred_mul_plusvnx2di_extended_scalar */
    case 4193:  /* *pred_mul_plusvnx4di_extended_scalar */
    case 4194:  /* *pred_mul_plusvnx8di_extended_scalar */
    case 4195:  /* *pred_nmsubvnx1qi */
    case 4196:  /* *pred_nmsubvnx2qi */
    case 4197:  /* *pred_nmsubvnx4qi */
    case 4198:  /* *pred_nmsubvnx8qi */
    case 4199:  /* *pred_nmsubvnx16qi */
    case 4200:  /* *pred_nmsubvnx32qi */
    case 4201:  /* *pred_nmsubvnx64qi */
    case 4202:  /* *pred_nmsubvnx1hi */
    case 4203:  /* *pred_nmsubvnx2hi */
    case 4204:  /* *pred_nmsubvnx4hi */
    case 4205:  /* *pred_nmsubvnx8hi */
    case 4206:  /* *pred_nmsubvnx16hi */
    case 4207:  /* *pred_nmsubvnx32hi */
    case 4208:  /* *pred_nmsubvnx1si */
    case 4209:  /* *pred_nmsubvnx2si */
    case 4210:  /* *pred_nmsubvnx4si */
    case 4211:  /* *pred_nmsubvnx8si */
    case 4212:  /* *pred_nmsubvnx16si */
    case 4213:  /* *pred_nmsubvnx1di */
    case 4214:  /* *pred_nmsubvnx2di */
    case 4215:  /* *pred_nmsubvnx4di */
    case 4216:  /* *pred_nmsubvnx8di */
    case 4217:  /* *pred_nmsacvnx1qi */
    case 4218:  /* *pred_nmsacvnx2qi */
    case 4219:  /* *pred_nmsacvnx4qi */
    case 4220:  /* *pred_nmsacvnx8qi */
    case 4221:  /* *pred_nmsacvnx16qi */
    case 4222:  /* *pred_nmsacvnx32qi */
    case 4223:  /* *pred_nmsacvnx64qi */
    case 4224:  /* *pred_nmsacvnx1hi */
    case 4225:  /* *pred_nmsacvnx2hi */
    case 4226:  /* *pred_nmsacvnx4hi */
    case 4227:  /* *pred_nmsacvnx8hi */
    case 4228:  /* *pred_nmsacvnx16hi */
    case 4229:  /* *pred_nmsacvnx32hi */
    case 4230:  /* *pred_nmsacvnx1si */
    case 4231:  /* *pred_nmsacvnx2si */
    case 4232:  /* *pred_nmsacvnx4si */
    case 4233:  /* *pred_nmsacvnx8si */
    case 4234:  /* *pred_nmsacvnx16si */
    case 4235:  /* *pred_nmsacvnx1di */
    case 4236:  /* *pred_nmsacvnx2di */
    case 4237:  /* *pred_nmsacvnx4di */
    case 4238:  /* *pred_nmsacvnx8di */
    case 4239:  /* *pred_minus_mulvnx1qi */
    case 4240:  /* *pred_minus_mulvnx2qi */
    case 4241:  /* *pred_minus_mulvnx4qi */
    case 4242:  /* *pred_minus_mulvnx8qi */
    case 4243:  /* *pred_minus_mulvnx16qi */
    case 4244:  /* *pred_minus_mulvnx32qi */
    case 4245:  /* *pred_minus_mulvnx64qi */
    case 4246:  /* *pred_minus_mulvnx1hi */
    case 4247:  /* *pred_minus_mulvnx2hi */
    case 4248:  /* *pred_minus_mulvnx4hi */
    case 4249:  /* *pred_minus_mulvnx8hi */
    case 4250:  /* *pred_minus_mulvnx16hi */
    case 4251:  /* *pred_minus_mulvnx32hi */
    case 4252:  /* *pred_minus_mulvnx1si */
    case 4253:  /* *pred_minus_mulvnx2si */
    case 4254:  /* *pred_minus_mulvnx4si */
    case 4255:  /* *pred_minus_mulvnx8si */
    case 4256:  /* *pred_minus_mulvnx16si */
    case 4257:  /* *pred_minus_mulvnx1di */
    case 4258:  /* *pred_minus_mulvnx2di */
    case 4259:  /* *pred_minus_mulvnx4di */
    case 4260:  /* *pred_minus_mulvnx8di */
    case 4261:  /* *pred_nmsubvnx1qi_scalar */
    case 4262:  /* *pred_nmsubvnx2qi_scalar */
    case 4263:  /* *pred_nmsubvnx4qi_scalar */
    case 4264:  /* *pred_nmsubvnx8qi_scalar */
    case 4265:  /* *pred_nmsubvnx16qi_scalar */
    case 4266:  /* *pred_nmsubvnx32qi_scalar */
    case 4267:  /* *pred_nmsubvnx64qi_scalar */
    case 4268:  /* *pred_nmsubvnx1hi_scalar */
    case 4269:  /* *pred_nmsubvnx2hi_scalar */
    case 4270:  /* *pred_nmsubvnx4hi_scalar */
    case 4271:  /* *pred_nmsubvnx8hi_scalar */
    case 4272:  /* *pred_nmsubvnx16hi_scalar */
    case 4273:  /* *pred_nmsubvnx32hi_scalar */
    case 4274:  /* *pred_nmsubvnx1si_scalar */
    case 4275:  /* *pred_nmsubvnx2si_scalar */
    case 4276:  /* *pred_nmsubvnx4si_scalar */
    case 4277:  /* *pred_nmsubvnx8si_scalar */
    case 4278:  /* *pred_nmsubvnx16si_scalar */
    case 4279:  /* *pred_nmsubvnx1di_scalar */
    case 4280:  /* *pred_nmsubvnx2di_scalar */
    case 4281:  /* *pred_nmsubvnx4di_scalar */
    case 4282:  /* *pred_nmsubvnx8di_scalar */
    case 4283:  /* *pred_nmsacvnx1qi_scalar */
    case 4284:  /* *pred_nmsacvnx2qi_scalar */
    case 4285:  /* *pred_nmsacvnx4qi_scalar */
    case 4286:  /* *pred_nmsacvnx8qi_scalar */
    case 4287:  /* *pred_nmsacvnx16qi_scalar */
    case 4288:  /* *pred_nmsacvnx32qi_scalar */
    case 4289:  /* *pred_nmsacvnx64qi_scalar */
    case 4290:  /* *pred_nmsacvnx1hi_scalar */
    case 4291:  /* *pred_nmsacvnx2hi_scalar */
    case 4292:  /* *pred_nmsacvnx4hi_scalar */
    case 4293:  /* *pred_nmsacvnx8hi_scalar */
    case 4294:  /* *pred_nmsacvnx16hi_scalar */
    case 4295:  /* *pred_nmsacvnx32hi_scalar */
    case 4296:  /* *pred_nmsacvnx1si_scalar */
    case 4297:  /* *pred_nmsacvnx2si_scalar */
    case 4298:  /* *pred_nmsacvnx4si_scalar */
    case 4299:  /* *pred_nmsacvnx8si_scalar */
    case 4300:  /* *pred_nmsacvnx16si_scalar */
    case 4301:  /* *pred_nmsacvnx1di_scalar */
    case 4302:  /* *pred_nmsacvnx2di_scalar */
    case 4303:  /* *pred_nmsacvnx4di_scalar */
    case 4304:  /* *pred_nmsacvnx8di_scalar */
    case 4305:  /* *pred_minus_mulvnx1qi_scalar */
    case 4306:  /* *pred_minus_mulvnx2qi_scalar */
    case 4307:  /* *pred_minus_mulvnx4qi_scalar */
    case 4308:  /* *pred_minus_mulvnx8qi_scalar */
    case 4309:  /* *pred_minus_mulvnx16qi_scalar */
    case 4310:  /* *pred_minus_mulvnx32qi_scalar */
    case 4311:  /* *pred_minus_mulvnx64qi_scalar */
    case 4312:  /* *pred_minus_mulvnx1hi_scalar */
    case 4313:  /* *pred_minus_mulvnx2hi_scalar */
    case 4314:  /* *pred_minus_mulvnx4hi_scalar */
    case 4315:  /* *pred_minus_mulvnx8hi_scalar */
    case 4316:  /* *pred_minus_mulvnx16hi_scalar */
    case 4317:  /* *pred_minus_mulvnx32hi_scalar */
    case 4318:  /* *pred_minus_mulvnx1si_scalar */
    case 4319:  /* *pred_minus_mulvnx2si_scalar */
    case 4320:  /* *pred_minus_mulvnx4si_scalar */
    case 4321:  /* *pred_minus_mulvnx8si_scalar */
    case 4322:  /* *pred_minus_mulvnx16si_scalar */
    case 4323:  /* *pred_minus_mulvnx1di_scalar */
    case 4324:  /* *pred_minus_mulvnx2di_scalar */
    case 4325:  /* *pred_minus_mulvnx4di_scalar */
    case 4326:  /* *pred_minus_mulvnx8di_scalar */
    case 4327:  /* *pred_nmsubvnx1di_extended_scalar */
    case 4328:  /* *pred_nmsubvnx2di_extended_scalar */
    case 4329:  /* *pred_nmsubvnx4di_extended_scalar */
    case 4330:  /* *pred_nmsubvnx8di_extended_scalar */
    case 4331:  /* *pred_nmsacvnx1di_extended_scalar */
    case 4332:  /* *pred_nmsacvnx2di_extended_scalar */
    case 4333:  /* *pred_nmsacvnx4di_extended_scalar */
    case 4334:  /* *pred_nmsacvnx8di_extended_scalar */
    case 4335:  /* *pred_minus_mulvnx1di_extended_scalar */
    case 4336:  /* *pred_minus_mulvnx2di_extended_scalar */
    case 4337:  /* *pred_minus_mulvnx4di_extended_scalar */
    case 4338:  /* *pred_minus_mulvnx8di_extended_scalar */
      return TYPE_VIMULADD;

    case 2846:  /* pred_dual_widen_mulsvnx1hi */
    case 2849:  /* pred_dual_widen_muluvnx1hi */
    case 2852:  /* pred_dual_widen_mulsvnx2hi */
    case 2855:  /* pred_dual_widen_muluvnx2hi */
    case 2858:  /* pred_dual_widen_mulsvnx4hi */
    case 2861:  /* pred_dual_widen_muluvnx4hi */
    case 2864:  /* pred_dual_widen_mulsvnx8hi */
    case 2867:  /* pred_dual_widen_muluvnx8hi */
    case 2870:  /* pred_dual_widen_mulsvnx16hi */
    case 2873:  /* pred_dual_widen_muluvnx16hi */
    case 2876:  /* pred_dual_widen_mulsvnx32hi */
    case 2879:  /* pred_dual_widen_muluvnx32hi */
    case 2882:  /* pred_dual_widen_mulsvnx1si */
    case 2885:  /* pred_dual_widen_muluvnx1si */
    case 2888:  /* pred_dual_widen_mulsvnx2si */
    case 2891:  /* pred_dual_widen_muluvnx2si */
    case 2894:  /* pred_dual_widen_mulsvnx4si */
    case 2897:  /* pred_dual_widen_muluvnx4si */
    case 2900:  /* pred_dual_widen_mulsvnx8si */
    case 2903:  /* pred_dual_widen_muluvnx8si */
    case 2906:  /* pred_dual_widen_mulsvnx16si */
    case 2909:  /* pred_dual_widen_muluvnx16si */
    case 2912:  /* pred_dual_widen_mulsvnx1di */
    case 2915:  /* pred_dual_widen_muluvnx1di */
    case 2918:  /* pred_dual_widen_mulsvnx2di */
    case 2921:  /* pred_dual_widen_muluvnx2di */
    case 2924:  /* pred_dual_widen_mulsvnx4di */
    case 2927:  /* pred_dual_widen_muluvnx4di */
    case 2930:  /* pred_dual_widen_mulsvnx8di */
    case 2933:  /* pred_dual_widen_muluvnx8di */
    case 2936:  /* pred_dual_widen_mulsvnx1hi_scalar */
    case 2939:  /* pred_dual_widen_muluvnx1hi_scalar */
    case 2942:  /* pred_dual_widen_mulsvnx2hi_scalar */
    case 2945:  /* pred_dual_widen_muluvnx2hi_scalar */
    case 2948:  /* pred_dual_widen_mulsvnx4hi_scalar */
    case 2951:  /* pred_dual_widen_muluvnx4hi_scalar */
    case 2954:  /* pred_dual_widen_mulsvnx8hi_scalar */
    case 2957:  /* pred_dual_widen_muluvnx8hi_scalar */
    case 2960:  /* pred_dual_widen_mulsvnx16hi_scalar */
    case 2963:  /* pred_dual_widen_muluvnx16hi_scalar */
    case 2966:  /* pred_dual_widen_mulsvnx32hi_scalar */
    case 2969:  /* pred_dual_widen_muluvnx32hi_scalar */
    case 2972:  /* pred_dual_widen_mulsvnx1si_scalar */
    case 2975:  /* pred_dual_widen_muluvnx1si_scalar */
    case 2978:  /* pred_dual_widen_mulsvnx2si_scalar */
    case 2981:  /* pred_dual_widen_muluvnx2si_scalar */
    case 2984:  /* pred_dual_widen_mulsvnx4si_scalar */
    case 2987:  /* pred_dual_widen_muluvnx4si_scalar */
    case 2990:  /* pred_dual_widen_mulsvnx8si_scalar */
    case 2993:  /* pred_dual_widen_muluvnx8si_scalar */
    case 2996:  /* pred_dual_widen_mulsvnx16si_scalar */
    case 2999:  /* pred_dual_widen_muluvnx16si_scalar */
    case 3002:  /* pred_dual_widen_mulsvnx1di_scalar */
    case 3005:  /* pred_dual_widen_muluvnx1di_scalar */
    case 3008:  /* pred_dual_widen_mulsvnx2di_scalar */
    case 3011:  /* pred_dual_widen_muluvnx2di_scalar */
    case 3014:  /* pred_dual_widen_mulsvnx4di_scalar */
    case 3017:  /* pred_dual_widen_muluvnx4di_scalar */
    case 3020:  /* pred_dual_widen_mulsvnx8di_scalar */
    case 3023:  /* pred_dual_widen_muluvnx8di_scalar */
    case 3144:  /* pred_widen_mulsuvnx1hi */
    case 3145:  /* pred_widen_mulsuvnx2hi */
    case 3146:  /* pred_widen_mulsuvnx4hi */
    case 3147:  /* pred_widen_mulsuvnx8hi */
    case 3148:  /* pred_widen_mulsuvnx16hi */
    case 3149:  /* pred_widen_mulsuvnx32hi */
    case 3150:  /* pred_widen_mulsuvnx1si */
    case 3151:  /* pred_widen_mulsuvnx2si */
    case 3152:  /* pred_widen_mulsuvnx4si */
    case 3153:  /* pred_widen_mulsuvnx8si */
    case 3154:  /* pred_widen_mulsuvnx16si */
    case 3155:  /* pred_widen_mulsuvnx1di */
    case 3156:  /* pred_widen_mulsuvnx2di */
    case 3157:  /* pred_widen_mulsuvnx4di */
    case 3158:  /* pred_widen_mulsuvnx8di */
    case 3159:  /* pred_widen_mulsuvnx1hi_scalar */
    case 3160:  /* pred_widen_mulsuvnx2hi_scalar */
    case 3161:  /* pred_widen_mulsuvnx4hi_scalar */
    case 3162:  /* pred_widen_mulsuvnx8hi_scalar */
    case 3163:  /* pred_widen_mulsuvnx16hi_scalar */
    case 3164:  /* pred_widen_mulsuvnx32hi_scalar */
    case 3165:  /* pred_widen_mulsuvnx1si_scalar */
    case 3166:  /* pred_widen_mulsuvnx2si_scalar */
    case 3167:  /* pred_widen_mulsuvnx4si_scalar */
    case 3168:  /* pred_widen_mulsuvnx8si_scalar */
    case 3169:  /* pred_widen_mulsuvnx16si_scalar */
    case 3170:  /* pred_widen_mulsuvnx1di_scalar */
    case 3171:  /* pred_widen_mulsuvnx2di_scalar */
    case 3172:  /* pred_widen_mulsuvnx4di_scalar */
    case 3173:  /* pred_widen_mulsuvnx8di_scalar */
      return TYPE_VIWMUL;

    case 1495:  /* pred_divvnx1qi */
    case 1496:  /* pred_udivvnx1qi */
    case 1497:  /* pred_modvnx1qi */
    case 1498:  /* pred_umodvnx1qi */
    case 1512:  /* pred_divvnx2qi */
    case 1513:  /* pred_udivvnx2qi */
    case 1514:  /* pred_modvnx2qi */
    case 1515:  /* pred_umodvnx2qi */
    case 1529:  /* pred_divvnx4qi */
    case 1530:  /* pred_udivvnx4qi */
    case 1531:  /* pred_modvnx4qi */
    case 1532:  /* pred_umodvnx4qi */
    case 1546:  /* pred_divvnx8qi */
    case 1547:  /* pred_udivvnx8qi */
    case 1548:  /* pred_modvnx8qi */
    case 1549:  /* pred_umodvnx8qi */
    case 1563:  /* pred_divvnx16qi */
    case 1564:  /* pred_udivvnx16qi */
    case 1565:  /* pred_modvnx16qi */
    case 1566:  /* pred_umodvnx16qi */
    case 1580:  /* pred_divvnx32qi */
    case 1581:  /* pred_udivvnx32qi */
    case 1582:  /* pred_modvnx32qi */
    case 1583:  /* pred_umodvnx32qi */
    case 1597:  /* pred_divvnx64qi */
    case 1598:  /* pred_udivvnx64qi */
    case 1599:  /* pred_modvnx64qi */
    case 1600:  /* pred_umodvnx64qi */
    case 1614:  /* pred_divvnx1hi */
    case 1615:  /* pred_udivvnx1hi */
    case 1616:  /* pred_modvnx1hi */
    case 1617:  /* pred_umodvnx1hi */
    case 1631:  /* pred_divvnx2hi */
    case 1632:  /* pred_udivvnx2hi */
    case 1633:  /* pred_modvnx2hi */
    case 1634:  /* pred_umodvnx2hi */
    case 1648:  /* pred_divvnx4hi */
    case 1649:  /* pred_udivvnx4hi */
    case 1650:  /* pred_modvnx4hi */
    case 1651:  /* pred_umodvnx4hi */
    case 1665:  /* pred_divvnx8hi */
    case 1666:  /* pred_udivvnx8hi */
    case 1667:  /* pred_modvnx8hi */
    case 1668:  /* pred_umodvnx8hi */
    case 1682:  /* pred_divvnx16hi */
    case 1683:  /* pred_udivvnx16hi */
    case 1684:  /* pred_modvnx16hi */
    case 1685:  /* pred_umodvnx16hi */
    case 1699:  /* pred_divvnx32hi */
    case 1700:  /* pred_udivvnx32hi */
    case 1701:  /* pred_modvnx32hi */
    case 1702:  /* pred_umodvnx32hi */
    case 1716:  /* pred_divvnx1si */
    case 1717:  /* pred_udivvnx1si */
    case 1718:  /* pred_modvnx1si */
    case 1719:  /* pred_umodvnx1si */
    case 1733:  /* pred_divvnx2si */
    case 1734:  /* pred_udivvnx2si */
    case 1735:  /* pred_modvnx2si */
    case 1736:  /* pred_umodvnx2si */
    case 1750:  /* pred_divvnx4si */
    case 1751:  /* pred_udivvnx4si */
    case 1752:  /* pred_modvnx4si */
    case 1753:  /* pred_umodvnx4si */
    case 1767:  /* pred_divvnx8si */
    case 1768:  /* pred_udivvnx8si */
    case 1769:  /* pred_modvnx8si */
    case 1770:  /* pred_umodvnx8si */
    case 1784:  /* pred_divvnx16si */
    case 1785:  /* pred_udivvnx16si */
    case 1786:  /* pred_modvnx16si */
    case 1787:  /* pred_umodvnx16si */
    case 1801:  /* pred_divvnx1di */
    case 1802:  /* pred_udivvnx1di */
    case 1803:  /* pred_modvnx1di */
    case 1804:  /* pred_umodvnx1di */
    case 1818:  /* pred_divvnx2di */
    case 1819:  /* pred_udivvnx2di */
    case 1820:  /* pred_modvnx2di */
    case 1821:  /* pred_umodvnx2di */
    case 1835:  /* pred_divvnx4di */
    case 1836:  /* pred_udivvnx4di */
    case 1837:  /* pred_modvnx4di */
    case 1838:  /* pred_umodvnx4di */
    case 1852:  /* pred_divvnx8di */
    case 1853:  /* pred_udivvnx8di */
    case 1854:  /* pred_modvnx8di */
    case 1855:  /* pred_umodvnx8di */
    case 2085:  /* pred_divvnx1qi_scalar */
    case 2086:  /* pred_udivvnx1qi_scalar */
    case 2087:  /* pred_modvnx1qi_scalar */
    case 2088:  /* pred_umodvnx1qi_scalar */
    case 2090:  /* pred_divvnx2qi_scalar */
    case 2091:  /* pred_udivvnx2qi_scalar */
    case 2092:  /* pred_modvnx2qi_scalar */
    case 2093:  /* pred_umodvnx2qi_scalar */
    case 2095:  /* pred_divvnx4qi_scalar */
    case 2096:  /* pred_udivvnx4qi_scalar */
    case 2097:  /* pred_modvnx4qi_scalar */
    case 2098:  /* pred_umodvnx4qi_scalar */
    case 2100:  /* pred_divvnx8qi_scalar */
    case 2101:  /* pred_udivvnx8qi_scalar */
    case 2102:  /* pred_modvnx8qi_scalar */
    case 2103:  /* pred_umodvnx8qi_scalar */
    case 2105:  /* pred_divvnx16qi_scalar */
    case 2106:  /* pred_udivvnx16qi_scalar */
    case 2107:  /* pred_modvnx16qi_scalar */
    case 2108:  /* pred_umodvnx16qi_scalar */
    case 2110:  /* pred_divvnx32qi_scalar */
    case 2111:  /* pred_udivvnx32qi_scalar */
    case 2112:  /* pred_modvnx32qi_scalar */
    case 2113:  /* pred_umodvnx32qi_scalar */
    case 2115:  /* pred_divvnx64qi_scalar */
    case 2116:  /* pred_udivvnx64qi_scalar */
    case 2117:  /* pred_modvnx64qi_scalar */
    case 2118:  /* pred_umodvnx64qi_scalar */
    case 2120:  /* pred_divvnx1hi_scalar */
    case 2121:  /* pred_udivvnx1hi_scalar */
    case 2122:  /* pred_modvnx1hi_scalar */
    case 2123:  /* pred_umodvnx1hi_scalar */
    case 2125:  /* pred_divvnx2hi_scalar */
    case 2126:  /* pred_udivvnx2hi_scalar */
    case 2127:  /* pred_modvnx2hi_scalar */
    case 2128:  /* pred_umodvnx2hi_scalar */
    case 2130:  /* pred_divvnx4hi_scalar */
    case 2131:  /* pred_udivvnx4hi_scalar */
    case 2132:  /* pred_modvnx4hi_scalar */
    case 2133:  /* pred_umodvnx4hi_scalar */
    case 2135:  /* pred_divvnx8hi_scalar */
    case 2136:  /* pred_udivvnx8hi_scalar */
    case 2137:  /* pred_modvnx8hi_scalar */
    case 2138:  /* pred_umodvnx8hi_scalar */
    case 2140:  /* pred_divvnx16hi_scalar */
    case 2141:  /* pred_udivvnx16hi_scalar */
    case 2142:  /* pred_modvnx16hi_scalar */
    case 2143:  /* pred_umodvnx16hi_scalar */
    case 2145:  /* pred_divvnx32hi_scalar */
    case 2146:  /* pred_udivvnx32hi_scalar */
    case 2147:  /* pred_modvnx32hi_scalar */
    case 2148:  /* pred_umodvnx32hi_scalar */
    case 2150:  /* pred_divvnx1si_scalar */
    case 2151:  /* pred_udivvnx1si_scalar */
    case 2152:  /* pred_modvnx1si_scalar */
    case 2153:  /* pred_umodvnx1si_scalar */
    case 2155:  /* pred_divvnx2si_scalar */
    case 2156:  /* pred_udivvnx2si_scalar */
    case 2157:  /* pred_modvnx2si_scalar */
    case 2158:  /* pred_umodvnx2si_scalar */
    case 2160:  /* pred_divvnx4si_scalar */
    case 2161:  /* pred_udivvnx4si_scalar */
    case 2162:  /* pred_modvnx4si_scalar */
    case 2163:  /* pred_umodvnx4si_scalar */
    case 2165:  /* pred_divvnx8si_scalar */
    case 2166:  /* pred_udivvnx8si_scalar */
    case 2167:  /* pred_modvnx8si_scalar */
    case 2168:  /* pred_umodvnx8si_scalar */
    case 2170:  /* pred_divvnx16si_scalar */
    case 2171:  /* pred_udivvnx16si_scalar */
    case 2172:  /* pred_modvnx16si_scalar */
    case 2173:  /* pred_umodvnx16si_scalar */
    case 2265:  /* *pred_divvnx1di_scalar */
    case 2266:  /* *pred_udivvnx1di_scalar */
    case 2267:  /* *pred_modvnx1di_scalar */
    case 2268:  /* *pred_umodvnx1di_scalar */
    case 2270:  /* *pred_divvnx2di_scalar */
    case 2271:  /* *pred_udivvnx2di_scalar */
    case 2272:  /* *pred_modvnx2di_scalar */
    case 2273:  /* *pred_umodvnx2di_scalar */
    case 2275:  /* *pred_divvnx4di_scalar */
    case 2276:  /* *pred_udivvnx4di_scalar */
    case 2277:  /* *pred_modvnx4di_scalar */
    case 2278:  /* *pred_umodvnx4di_scalar */
    case 2280:  /* *pred_divvnx8di_scalar */
    case 2281:  /* *pred_udivvnx8di_scalar */
    case 2282:  /* *pred_modvnx8di_scalar */
    case 2283:  /* *pred_umodvnx8di_scalar */
    case 2285:  /* *pred_divvnx1di_extended_scalar */
    case 2286:  /* *pred_udivvnx1di_extended_scalar */
    case 2287:  /* *pred_modvnx1di_extended_scalar */
    case 2288:  /* *pred_umodvnx1di_extended_scalar */
    case 2290:  /* *pred_divvnx2di_extended_scalar */
    case 2291:  /* *pred_udivvnx2di_extended_scalar */
    case 2292:  /* *pred_modvnx2di_extended_scalar */
    case 2293:  /* *pred_umodvnx2di_extended_scalar */
    case 2295:  /* *pred_divvnx4di_extended_scalar */
    case 2296:  /* *pred_udivvnx4di_extended_scalar */
    case 2297:  /* *pred_modvnx4di_extended_scalar */
    case 2298:  /* *pred_umodvnx4di_extended_scalar */
    case 2300:  /* *pred_divvnx8di_extended_scalar */
    case 2301:  /* *pred_udivvnx8di_extended_scalar */
    case 2302:  /* *pred_modvnx8di_extended_scalar */
    case 2303:  /* *pred_umodvnx8di_extended_scalar */
      return TYPE_VIDIV;

    case 1494:  /* pred_mulvnx1qi */
    case 1511:  /* pred_mulvnx2qi */
    case 1528:  /* pred_mulvnx4qi */
    case 1545:  /* pred_mulvnx8qi */
    case 1562:  /* pred_mulvnx16qi */
    case 1579:  /* pred_mulvnx32qi */
    case 1596:  /* pred_mulvnx64qi */
    case 1613:  /* pred_mulvnx1hi */
    case 1630:  /* pred_mulvnx2hi */
    case 1647:  /* pred_mulvnx4hi */
    case 1664:  /* pred_mulvnx8hi */
    case 1681:  /* pred_mulvnx16hi */
    case 1698:  /* pred_mulvnx32hi */
    case 1715:  /* pred_mulvnx1si */
    case 1732:  /* pred_mulvnx2si */
    case 1749:  /* pred_mulvnx4si */
    case 1766:  /* pred_mulvnx8si */
    case 1783:  /* pred_mulvnx16si */
    case 1800:  /* pred_mulvnx1di */
    case 1817:  /* pred_mulvnx2di */
    case 1834:  /* pred_mulvnx4di */
    case 1851:  /* pred_mulvnx8di */
    case 1930:  /* pred_mulvnx1qi_scalar */
    case 1939:  /* pred_mulvnx2qi_scalar */
    case 1948:  /* pred_mulvnx4qi_scalar */
    case 1957:  /* pred_mulvnx8qi_scalar */
    case 1966:  /* pred_mulvnx16qi_scalar */
    case 1975:  /* pred_mulvnx32qi_scalar */
    case 1984:  /* pred_mulvnx64qi_scalar */
    case 1993:  /* pred_mulvnx1hi_scalar */
    case 2002:  /* pred_mulvnx2hi_scalar */
    case 2011:  /* pred_mulvnx4hi_scalar */
    case 2020:  /* pred_mulvnx8hi_scalar */
    case 2029:  /* pred_mulvnx16hi_scalar */
    case 2038:  /* pred_mulvnx32hi_scalar */
    case 2047:  /* pred_mulvnx1si_scalar */
    case 2056:  /* pred_mulvnx2si_scalar */
    case 2065:  /* pred_mulvnx4si_scalar */
    case 2074:  /* pred_mulvnx8si_scalar */
    case 2083:  /* pred_mulvnx16si_scalar */
    case 2200:  /* *pred_mulvnx1di_scalar */
    case 2209:  /* *pred_mulvnx2di_scalar */
    case 2218:  /* *pred_mulvnx4di_scalar */
    case 2227:  /* *pred_mulvnx8di_scalar */
    case 2236:  /* *pred_mulvnx1di_extended_scalar */
    case 2245:  /* *pred_mulvnx2di_extended_scalar */
    case 2254:  /* *pred_mulvnx4di_extended_scalar */
    case 2263:  /* *pred_mulvnx8di_extended_scalar */
    case 2312:  /* pred_mulhvnx1qi */
    case 2313:  /* pred_mulhuvnx1qi */
    case 2314:  /* pred_mulhsuvnx1qi */
    case 2315:  /* pred_mulhvnx2qi */
    case 2316:  /* pred_mulhuvnx2qi */
    case 2317:  /* pred_mulhsuvnx2qi */
    case 2318:  /* pred_mulhvnx4qi */
    case 2319:  /* pred_mulhuvnx4qi */
    case 2320:  /* pred_mulhsuvnx4qi */
    case 2321:  /* pred_mulhvnx8qi */
    case 2322:  /* pred_mulhuvnx8qi */
    case 2323:  /* pred_mulhsuvnx8qi */
    case 2324:  /* pred_mulhvnx16qi */
    case 2325:  /* pred_mulhuvnx16qi */
    case 2326:  /* pred_mulhsuvnx16qi */
    case 2327:  /* pred_mulhvnx32qi */
    case 2328:  /* pred_mulhuvnx32qi */
    case 2329:  /* pred_mulhsuvnx32qi */
    case 2330:  /* pred_mulhvnx64qi */
    case 2331:  /* pred_mulhuvnx64qi */
    case 2332:  /* pred_mulhsuvnx64qi */
    case 2333:  /* pred_mulhvnx1hi */
    case 2334:  /* pred_mulhuvnx1hi */
    case 2335:  /* pred_mulhsuvnx1hi */
    case 2336:  /* pred_mulhvnx2hi */
    case 2337:  /* pred_mulhuvnx2hi */
    case 2338:  /* pred_mulhsuvnx2hi */
    case 2339:  /* pred_mulhvnx4hi */
    case 2340:  /* pred_mulhuvnx4hi */
    case 2341:  /* pred_mulhsuvnx4hi */
    case 2342:  /* pred_mulhvnx8hi */
    case 2343:  /* pred_mulhuvnx8hi */
    case 2344:  /* pred_mulhsuvnx8hi */
    case 2345:  /* pred_mulhvnx16hi */
    case 2346:  /* pred_mulhuvnx16hi */
    case 2347:  /* pred_mulhsuvnx16hi */
    case 2348:  /* pred_mulhvnx32hi */
    case 2349:  /* pred_mulhuvnx32hi */
    case 2350:  /* pred_mulhsuvnx32hi */
    case 2351:  /* pred_mulhvnx1si */
    case 2352:  /* pred_mulhuvnx1si */
    case 2353:  /* pred_mulhsuvnx1si */
    case 2354:  /* pred_mulhvnx2si */
    case 2355:  /* pred_mulhuvnx2si */
    case 2356:  /* pred_mulhsuvnx2si */
    case 2357:  /* pred_mulhvnx4si */
    case 2358:  /* pred_mulhuvnx4si */
    case 2359:  /* pred_mulhsuvnx4si */
    case 2360:  /* pred_mulhvnx8si */
    case 2361:  /* pred_mulhuvnx8si */
    case 2362:  /* pred_mulhsuvnx8si */
    case 2363:  /* pred_mulhvnx16si */
    case 2364:  /* pred_mulhuvnx16si */
    case 2365:  /* pred_mulhsuvnx16si */
    case 2366:  /* pred_mulhvnx1di */
    case 2367:  /* pred_mulhuvnx1di */
    case 2368:  /* pred_mulhsuvnx1di */
    case 2369:  /* pred_mulhvnx2di */
    case 2370:  /* pred_mulhuvnx2di */
    case 2371:  /* pred_mulhsuvnx2di */
    case 2372:  /* pred_mulhvnx4di */
    case 2373:  /* pred_mulhuvnx4di */
    case 2374:  /* pred_mulhsuvnx4di */
    case 2375:  /* pred_mulhvnx8di */
    case 2376:  /* pred_mulhuvnx8di */
    case 2377:  /* pred_mulhsuvnx8di */
    case 2378:  /* pred_mulhvnx1qi_scalar */
    case 2379:  /* pred_mulhuvnx1qi_scalar */
    case 2380:  /* pred_mulhsuvnx1qi_scalar */
    case 2381:  /* pred_mulhvnx2qi_scalar */
    case 2382:  /* pred_mulhuvnx2qi_scalar */
    case 2383:  /* pred_mulhsuvnx2qi_scalar */
    case 2384:  /* pred_mulhvnx4qi_scalar */
    case 2385:  /* pred_mulhuvnx4qi_scalar */
    case 2386:  /* pred_mulhsuvnx4qi_scalar */
    case 2387:  /* pred_mulhvnx8qi_scalar */
    case 2388:  /* pred_mulhuvnx8qi_scalar */
    case 2389:  /* pred_mulhsuvnx8qi_scalar */
    case 2390:  /* pred_mulhvnx16qi_scalar */
    case 2391:  /* pred_mulhuvnx16qi_scalar */
    case 2392:  /* pred_mulhsuvnx16qi_scalar */
    case 2393:  /* pred_mulhvnx32qi_scalar */
    case 2394:  /* pred_mulhuvnx32qi_scalar */
    case 2395:  /* pred_mulhsuvnx32qi_scalar */
    case 2396:  /* pred_mulhvnx64qi_scalar */
    case 2397:  /* pred_mulhuvnx64qi_scalar */
    case 2398:  /* pred_mulhsuvnx64qi_scalar */
    case 2399:  /* pred_mulhvnx1hi_scalar */
    case 2400:  /* pred_mulhuvnx1hi_scalar */
    case 2401:  /* pred_mulhsuvnx1hi_scalar */
    case 2402:  /* pred_mulhvnx2hi_scalar */
    case 2403:  /* pred_mulhuvnx2hi_scalar */
    case 2404:  /* pred_mulhsuvnx2hi_scalar */
    case 2405:  /* pred_mulhvnx4hi_scalar */
    case 2406:  /* pred_mulhuvnx4hi_scalar */
    case 2407:  /* pred_mulhsuvnx4hi_scalar */
    case 2408:  /* pred_mulhvnx8hi_scalar */
    case 2409:  /* pred_mulhuvnx8hi_scalar */
    case 2410:  /* pred_mulhsuvnx8hi_scalar */
    case 2411:  /* pred_mulhvnx16hi_scalar */
    case 2412:  /* pred_mulhuvnx16hi_scalar */
    case 2413:  /* pred_mulhsuvnx16hi_scalar */
    case 2414:  /* pred_mulhvnx32hi_scalar */
    case 2415:  /* pred_mulhuvnx32hi_scalar */
    case 2416:  /* pred_mulhsuvnx32hi_scalar */
    case 2417:  /* pred_mulhvnx1si_scalar */
    case 2418:  /* pred_mulhuvnx1si_scalar */
    case 2419:  /* pred_mulhsuvnx1si_scalar */
    case 2420:  /* pred_mulhvnx2si_scalar */
    case 2421:  /* pred_mulhuvnx2si_scalar */
    case 2422:  /* pred_mulhsuvnx2si_scalar */
    case 2423:  /* pred_mulhvnx4si_scalar */
    case 2424:  /* pred_mulhuvnx4si_scalar */
    case 2425:  /* pred_mulhsuvnx4si_scalar */
    case 2426:  /* pred_mulhvnx8si_scalar */
    case 2427:  /* pred_mulhuvnx8si_scalar */
    case 2428:  /* pred_mulhsuvnx8si_scalar */
    case 2429:  /* pred_mulhvnx16si_scalar */
    case 2430:  /* pred_mulhuvnx16si_scalar */
    case 2431:  /* pred_mulhsuvnx16si_scalar */
    case 2432:  /* *pred_mulhvnx1di_scalar */
    case 2433:  /* *pred_mulhuvnx1di_scalar */
    case 2434:  /* *pred_mulhsuvnx1di_scalar */
    case 2435:  /* *pred_mulhvnx2di_scalar */
    case 2436:  /* *pred_mulhuvnx2di_scalar */
    case 2437:  /* *pred_mulhsuvnx2di_scalar */
    case 2438:  /* *pred_mulhvnx4di_scalar */
    case 2439:  /* *pred_mulhuvnx4di_scalar */
    case 2440:  /* *pred_mulhsuvnx4di_scalar */
    case 2441:  /* *pred_mulhvnx8di_scalar */
    case 2442:  /* *pred_mulhuvnx8di_scalar */
    case 2443:  /* *pred_mulhsuvnx8di_scalar */
    case 2444:  /* *pred_mulhvnx1di_extended_scalar */
    case 2445:  /* *pred_mulhuvnx1di_extended_scalar */
    case 2446:  /* *pred_mulhsuvnx1di_extended_scalar */
    case 2447:  /* *pred_mulhvnx2di_extended_scalar */
    case 2448:  /* *pred_mulhuvnx2di_extended_scalar */
    case 2449:  /* *pred_mulhsuvnx2di_extended_scalar */
    case 2450:  /* *pred_mulhvnx4di_extended_scalar */
    case 2451:  /* *pred_mulhuvnx4di_extended_scalar */
    case 2452:  /* *pred_mulhsuvnx4di_extended_scalar */
    case 2453:  /* *pred_mulhvnx8di_extended_scalar */
    case 2454:  /* *pred_mulhuvnx8di_extended_scalar */
    case 2455:  /* *pred_mulhsuvnx8di_extended_scalar */
      return TYPE_VIMUL;

    case 1490:  /* pred_smaxvnx1qi */
    case 1491:  /* pred_umaxvnx1qi */
    case 1492:  /* pred_sminvnx1qi */
    case 1493:  /* pred_uminvnx1qi */
    case 1507:  /* pred_smaxvnx2qi */
    case 1508:  /* pred_umaxvnx2qi */
    case 1509:  /* pred_sminvnx2qi */
    case 1510:  /* pred_uminvnx2qi */
    case 1524:  /* pred_smaxvnx4qi */
    case 1525:  /* pred_umaxvnx4qi */
    case 1526:  /* pred_sminvnx4qi */
    case 1527:  /* pred_uminvnx4qi */
    case 1541:  /* pred_smaxvnx8qi */
    case 1542:  /* pred_umaxvnx8qi */
    case 1543:  /* pred_sminvnx8qi */
    case 1544:  /* pred_uminvnx8qi */
    case 1558:  /* pred_smaxvnx16qi */
    case 1559:  /* pred_umaxvnx16qi */
    case 1560:  /* pred_sminvnx16qi */
    case 1561:  /* pred_uminvnx16qi */
    case 1575:  /* pred_smaxvnx32qi */
    case 1576:  /* pred_umaxvnx32qi */
    case 1577:  /* pred_sminvnx32qi */
    case 1578:  /* pred_uminvnx32qi */
    case 1592:  /* pred_smaxvnx64qi */
    case 1593:  /* pred_umaxvnx64qi */
    case 1594:  /* pred_sminvnx64qi */
    case 1595:  /* pred_uminvnx64qi */
    case 1609:  /* pred_smaxvnx1hi */
    case 1610:  /* pred_umaxvnx1hi */
    case 1611:  /* pred_sminvnx1hi */
    case 1612:  /* pred_uminvnx1hi */
    case 1626:  /* pred_smaxvnx2hi */
    case 1627:  /* pred_umaxvnx2hi */
    case 1628:  /* pred_sminvnx2hi */
    case 1629:  /* pred_uminvnx2hi */
    case 1643:  /* pred_smaxvnx4hi */
    case 1644:  /* pred_umaxvnx4hi */
    case 1645:  /* pred_sminvnx4hi */
    case 1646:  /* pred_uminvnx4hi */
    case 1660:  /* pred_smaxvnx8hi */
    case 1661:  /* pred_umaxvnx8hi */
    case 1662:  /* pred_sminvnx8hi */
    case 1663:  /* pred_uminvnx8hi */
    case 1677:  /* pred_smaxvnx16hi */
    case 1678:  /* pred_umaxvnx16hi */
    case 1679:  /* pred_sminvnx16hi */
    case 1680:  /* pred_uminvnx16hi */
    case 1694:  /* pred_smaxvnx32hi */
    case 1695:  /* pred_umaxvnx32hi */
    case 1696:  /* pred_sminvnx32hi */
    case 1697:  /* pred_uminvnx32hi */
    case 1711:  /* pred_smaxvnx1si */
    case 1712:  /* pred_umaxvnx1si */
    case 1713:  /* pred_sminvnx1si */
    case 1714:  /* pred_uminvnx1si */
    case 1728:  /* pred_smaxvnx2si */
    case 1729:  /* pred_umaxvnx2si */
    case 1730:  /* pred_sminvnx2si */
    case 1731:  /* pred_uminvnx2si */
    case 1745:  /* pred_smaxvnx4si */
    case 1746:  /* pred_umaxvnx4si */
    case 1747:  /* pred_sminvnx4si */
    case 1748:  /* pred_uminvnx4si */
    case 1762:  /* pred_smaxvnx8si */
    case 1763:  /* pred_umaxvnx8si */
    case 1764:  /* pred_sminvnx8si */
    case 1765:  /* pred_uminvnx8si */
    case 1779:  /* pred_smaxvnx16si */
    case 1780:  /* pred_umaxvnx16si */
    case 1781:  /* pred_sminvnx16si */
    case 1782:  /* pred_uminvnx16si */
    case 1796:  /* pred_smaxvnx1di */
    case 1797:  /* pred_umaxvnx1di */
    case 1798:  /* pred_sminvnx1di */
    case 1799:  /* pred_uminvnx1di */
    case 1813:  /* pred_smaxvnx2di */
    case 1814:  /* pred_umaxvnx2di */
    case 1815:  /* pred_sminvnx2di */
    case 1816:  /* pred_uminvnx2di */
    case 1830:  /* pred_smaxvnx4di */
    case 1831:  /* pred_umaxvnx4di */
    case 1832:  /* pred_sminvnx4di */
    case 1833:  /* pred_uminvnx4di */
    case 1847:  /* pred_smaxvnx8di */
    case 1848:  /* pred_umaxvnx8di */
    case 1849:  /* pred_sminvnx8di */
    case 1850:  /* pred_uminvnx8di */
    case 1926:  /* pred_smaxvnx1qi_scalar */
    case 1927:  /* pred_umaxvnx1qi_scalar */
    case 1928:  /* pred_sminvnx1qi_scalar */
    case 1929:  /* pred_uminvnx1qi_scalar */
    case 1935:  /* pred_smaxvnx2qi_scalar */
    case 1936:  /* pred_umaxvnx2qi_scalar */
    case 1937:  /* pred_sminvnx2qi_scalar */
    case 1938:  /* pred_uminvnx2qi_scalar */
    case 1944:  /* pred_smaxvnx4qi_scalar */
    case 1945:  /* pred_umaxvnx4qi_scalar */
    case 1946:  /* pred_sminvnx4qi_scalar */
    case 1947:  /* pred_uminvnx4qi_scalar */
    case 1953:  /* pred_smaxvnx8qi_scalar */
    case 1954:  /* pred_umaxvnx8qi_scalar */
    case 1955:  /* pred_sminvnx8qi_scalar */
    case 1956:  /* pred_uminvnx8qi_scalar */
    case 1962:  /* pred_smaxvnx16qi_scalar */
    case 1963:  /* pred_umaxvnx16qi_scalar */
    case 1964:  /* pred_sminvnx16qi_scalar */
    case 1965:  /* pred_uminvnx16qi_scalar */
    case 1971:  /* pred_smaxvnx32qi_scalar */
    case 1972:  /* pred_umaxvnx32qi_scalar */
    case 1973:  /* pred_sminvnx32qi_scalar */
    case 1974:  /* pred_uminvnx32qi_scalar */
    case 1980:  /* pred_smaxvnx64qi_scalar */
    case 1981:  /* pred_umaxvnx64qi_scalar */
    case 1982:  /* pred_sminvnx64qi_scalar */
    case 1983:  /* pred_uminvnx64qi_scalar */
    case 1989:  /* pred_smaxvnx1hi_scalar */
    case 1990:  /* pred_umaxvnx1hi_scalar */
    case 1991:  /* pred_sminvnx1hi_scalar */
    case 1992:  /* pred_uminvnx1hi_scalar */
    case 1998:  /* pred_smaxvnx2hi_scalar */
    case 1999:  /* pred_umaxvnx2hi_scalar */
    case 2000:  /* pred_sminvnx2hi_scalar */
    case 2001:  /* pred_uminvnx2hi_scalar */
    case 2007:  /* pred_smaxvnx4hi_scalar */
    case 2008:  /* pred_umaxvnx4hi_scalar */
    case 2009:  /* pred_sminvnx4hi_scalar */
    case 2010:  /* pred_uminvnx4hi_scalar */
    case 2016:  /* pred_smaxvnx8hi_scalar */
    case 2017:  /* pred_umaxvnx8hi_scalar */
    case 2018:  /* pred_sminvnx8hi_scalar */
    case 2019:  /* pred_uminvnx8hi_scalar */
    case 2025:  /* pred_smaxvnx16hi_scalar */
    case 2026:  /* pred_umaxvnx16hi_scalar */
    case 2027:  /* pred_sminvnx16hi_scalar */
    case 2028:  /* pred_uminvnx16hi_scalar */
    case 2034:  /* pred_smaxvnx32hi_scalar */
    case 2035:  /* pred_umaxvnx32hi_scalar */
    case 2036:  /* pred_sminvnx32hi_scalar */
    case 2037:  /* pred_uminvnx32hi_scalar */
    case 2043:  /* pred_smaxvnx1si_scalar */
    case 2044:  /* pred_umaxvnx1si_scalar */
    case 2045:  /* pred_sminvnx1si_scalar */
    case 2046:  /* pred_uminvnx1si_scalar */
    case 2052:  /* pred_smaxvnx2si_scalar */
    case 2053:  /* pred_umaxvnx2si_scalar */
    case 2054:  /* pred_sminvnx2si_scalar */
    case 2055:  /* pred_uminvnx2si_scalar */
    case 2061:  /* pred_smaxvnx4si_scalar */
    case 2062:  /* pred_umaxvnx4si_scalar */
    case 2063:  /* pred_sminvnx4si_scalar */
    case 2064:  /* pred_uminvnx4si_scalar */
    case 2070:  /* pred_smaxvnx8si_scalar */
    case 2071:  /* pred_umaxvnx8si_scalar */
    case 2072:  /* pred_sminvnx8si_scalar */
    case 2073:  /* pred_uminvnx8si_scalar */
    case 2079:  /* pred_smaxvnx16si_scalar */
    case 2080:  /* pred_umaxvnx16si_scalar */
    case 2081:  /* pred_sminvnx16si_scalar */
    case 2082:  /* pred_uminvnx16si_scalar */
    case 2196:  /* *pred_smaxvnx1di_scalar */
    case 2197:  /* *pred_umaxvnx1di_scalar */
    case 2198:  /* *pred_sminvnx1di_scalar */
    case 2199:  /* *pred_uminvnx1di_scalar */
    case 2205:  /* *pred_smaxvnx2di_scalar */
    case 2206:  /* *pred_umaxvnx2di_scalar */
    case 2207:  /* *pred_sminvnx2di_scalar */
    case 2208:  /* *pred_uminvnx2di_scalar */
    case 2214:  /* *pred_smaxvnx4di_scalar */
    case 2215:  /* *pred_umaxvnx4di_scalar */
    case 2216:  /* *pred_sminvnx4di_scalar */
    case 2217:  /* *pred_uminvnx4di_scalar */
    case 2223:  /* *pred_smaxvnx8di_scalar */
    case 2224:  /* *pred_umaxvnx8di_scalar */
    case 2225:  /* *pred_sminvnx8di_scalar */
    case 2226:  /* *pred_uminvnx8di_scalar */
    case 2232:  /* *pred_smaxvnx1di_extended_scalar */
    case 2233:  /* *pred_umaxvnx1di_extended_scalar */
    case 2234:  /* *pred_sminvnx1di_extended_scalar */
    case 2235:  /* *pred_uminvnx1di_extended_scalar */
    case 2241:  /* *pred_smaxvnx2di_extended_scalar */
    case 2242:  /* *pred_umaxvnx2di_extended_scalar */
    case 2243:  /* *pred_sminvnx2di_extended_scalar */
    case 2244:  /* *pred_uminvnx2di_extended_scalar */
    case 2250:  /* *pred_smaxvnx4di_extended_scalar */
    case 2251:  /* *pred_umaxvnx4di_extended_scalar */
    case 2252:  /* *pred_sminvnx4di_extended_scalar */
    case 2253:  /* *pred_uminvnx4di_extended_scalar */
    case 2259:  /* *pred_smaxvnx8di_extended_scalar */
    case 2260:  /* *pred_umaxvnx8di_extended_scalar */
    case 2261:  /* *pred_sminvnx8di_extended_scalar */
    case 2262:  /* *pred_uminvnx8di_extended_scalar */
      return TYPE_VIMINMAX;

    case 3859:  /* *pred_cmpvnx1qi */
    case 3860:  /* *pred_cmpvnx2qi */
    case 3861:  /* *pred_cmpvnx4qi */
    case 3862:  /* *pred_cmpvnx8qi */
    case 3863:  /* *pred_cmpvnx16qi */
    case 3864:  /* *pred_cmpvnx32qi */
    case 3865:  /* *pred_cmpvnx64qi */
    case 3866:  /* *pred_cmpvnx1hi */
    case 3867:  /* *pred_cmpvnx2hi */
    case 3868:  /* *pred_cmpvnx4hi */
    case 3869:  /* *pred_cmpvnx8hi */
    case 3870:  /* *pred_cmpvnx16hi */
    case 3871:  /* *pred_cmpvnx32hi */
    case 3872:  /* *pred_cmpvnx1si */
    case 3873:  /* *pred_cmpvnx2si */
    case 3874:  /* *pred_cmpvnx4si */
    case 3875:  /* *pred_cmpvnx8si */
    case 3876:  /* *pred_cmpvnx16si */
    case 3877:  /* *pred_cmpvnx1di */
    case 3878:  /* *pred_cmpvnx2di */
    case 3879:  /* *pred_cmpvnx4di */
    case 3880:  /* *pred_cmpvnx8di */
    case 3881:  /* *pred_cmpvnx1qi_narrow */
    case 3882:  /* *pred_cmpvnx2qi_narrow */
    case 3883:  /* *pred_cmpvnx4qi_narrow */
    case 3884:  /* *pred_cmpvnx8qi_narrow */
    case 3885:  /* *pred_cmpvnx16qi_narrow */
    case 3886:  /* *pred_cmpvnx32qi_narrow */
    case 3887:  /* *pred_cmpvnx64qi_narrow */
    case 3888:  /* *pred_cmpvnx1hi_narrow */
    case 3889:  /* *pred_cmpvnx2hi_narrow */
    case 3890:  /* *pred_cmpvnx4hi_narrow */
    case 3891:  /* *pred_cmpvnx8hi_narrow */
    case 3892:  /* *pred_cmpvnx16hi_narrow */
    case 3893:  /* *pred_cmpvnx32hi_narrow */
    case 3894:  /* *pred_cmpvnx1si_narrow */
    case 3895:  /* *pred_cmpvnx2si_narrow */
    case 3896:  /* *pred_cmpvnx4si_narrow */
    case 3897:  /* *pred_cmpvnx8si_narrow */
    case 3898:  /* *pred_cmpvnx16si_narrow */
    case 3899:  /* *pred_cmpvnx1di_narrow */
    case 3900:  /* *pred_cmpvnx2di_narrow */
    case 3901:  /* *pred_cmpvnx4di_narrow */
    case 3902:  /* *pred_cmpvnx8di_narrow */
    case 3903:  /* *pred_ltgevnx1qi */
    case 3904:  /* *pred_ltgevnx2qi */
    case 3905:  /* *pred_ltgevnx4qi */
    case 3906:  /* *pred_ltgevnx8qi */
    case 3907:  /* *pred_ltgevnx16qi */
    case 3908:  /* *pred_ltgevnx32qi */
    case 3909:  /* *pred_ltgevnx64qi */
    case 3910:  /* *pred_ltgevnx1hi */
    case 3911:  /* *pred_ltgevnx2hi */
    case 3912:  /* *pred_ltgevnx4hi */
    case 3913:  /* *pred_ltgevnx8hi */
    case 3914:  /* *pred_ltgevnx16hi */
    case 3915:  /* *pred_ltgevnx32hi */
    case 3916:  /* *pred_ltgevnx1si */
    case 3917:  /* *pred_ltgevnx2si */
    case 3918:  /* *pred_ltgevnx4si */
    case 3919:  /* *pred_ltgevnx8si */
    case 3920:  /* *pred_ltgevnx16si */
    case 3921:  /* *pred_ltgevnx1di */
    case 3922:  /* *pred_ltgevnx2di */
    case 3923:  /* *pred_ltgevnx4di */
    case 3924:  /* *pred_ltgevnx8di */
    case 3925:  /* *pred_ltgevnx1qi_narrow */
    case 3926:  /* *pred_ltgevnx2qi_narrow */
    case 3927:  /* *pred_ltgevnx4qi_narrow */
    case 3928:  /* *pred_ltgevnx8qi_narrow */
    case 3929:  /* *pred_ltgevnx16qi_narrow */
    case 3930:  /* *pred_ltgevnx32qi_narrow */
    case 3931:  /* *pred_ltgevnx64qi_narrow */
    case 3932:  /* *pred_ltgevnx1hi_narrow */
    case 3933:  /* *pred_ltgevnx2hi_narrow */
    case 3934:  /* *pred_ltgevnx4hi_narrow */
    case 3935:  /* *pred_ltgevnx8hi_narrow */
    case 3936:  /* *pred_ltgevnx16hi_narrow */
    case 3937:  /* *pred_ltgevnx32hi_narrow */
    case 3938:  /* *pred_ltgevnx1si_narrow */
    case 3939:  /* *pred_ltgevnx2si_narrow */
    case 3940:  /* *pred_ltgevnx4si_narrow */
    case 3941:  /* *pred_ltgevnx8si_narrow */
    case 3942:  /* *pred_ltgevnx16si_narrow */
    case 3943:  /* *pred_ltgevnx1di_narrow */
    case 3944:  /* *pred_ltgevnx2di_narrow */
    case 3945:  /* *pred_ltgevnx4di_narrow */
    case 3946:  /* *pred_ltgevnx8di_narrow */
    case 3947:  /* *pred_cmpvnx1qi_scalar */
    case 3948:  /* *pred_cmpvnx2qi_scalar */
    case 3949:  /* *pred_cmpvnx4qi_scalar */
    case 3950:  /* *pred_cmpvnx8qi_scalar */
    case 3951:  /* *pred_cmpvnx16qi_scalar */
    case 3952:  /* *pred_cmpvnx32qi_scalar */
    case 3953:  /* *pred_cmpvnx64qi_scalar */
    case 3954:  /* *pred_cmpvnx1hi_scalar */
    case 3955:  /* *pred_cmpvnx2hi_scalar */
    case 3956:  /* *pred_cmpvnx4hi_scalar */
    case 3957:  /* *pred_cmpvnx8hi_scalar */
    case 3958:  /* *pred_cmpvnx16hi_scalar */
    case 3959:  /* *pred_cmpvnx32hi_scalar */
    case 3960:  /* *pred_cmpvnx1si_scalar */
    case 3961:  /* *pred_cmpvnx2si_scalar */
    case 3962:  /* *pred_cmpvnx4si_scalar */
    case 3963:  /* *pred_cmpvnx8si_scalar */
    case 3964:  /* *pred_cmpvnx16si_scalar */
    case 3965:  /* *pred_cmpvnx1qi_scalar_narrow */
    case 3966:  /* *pred_cmpvnx2qi_scalar_narrow */
    case 3967:  /* *pred_cmpvnx4qi_scalar_narrow */
    case 3968:  /* *pred_cmpvnx8qi_scalar_narrow */
    case 3969:  /* *pred_cmpvnx16qi_scalar_narrow */
    case 3970:  /* *pred_cmpvnx32qi_scalar_narrow */
    case 3971:  /* *pred_cmpvnx64qi_scalar_narrow */
    case 3972:  /* *pred_cmpvnx1hi_scalar_narrow */
    case 3973:  /* *pred_cmpvnx2hi_scalar_narrow */
    case 3974:  /* *pred_cmpvnx4hi_scalar_narrow */
    case 3975:  /* *pred_cmpvnx8hi_scalar_narrow */
    case 3976:  /* *pred_cmpvnx16hi_scalar_narrow */
    case 3977:  /* *pred_cmpvnx32hi_scalar_narrow */
    case 3978:  /* *pred_cmpvnx1si_scalar_narrow */
    case 3979:  /* *pred_cmpvnx2si_scalar_narrow */
    case 3980:  /* *pred_cmpvnx4si_scalar_narrow */
    case 3981:  /* *pred_cmpvnx8si_scalar_narrow */
    case 3982:  /* *pred_cmpvnx16si_scalar_narrow */
    case 3983:  /* *pred_eqnevnx1qi_scalar */
    case 3984:  /* *pred_eqnevnx2qi_scalar */
    case 3985:  /* *pred_eqnevnx4qi_scalar */
    case 3986:  /* *pred_eqnevnx8qi_scalar */
    case 3987:  /* *pred_eqnevnx16qi_scalar */
    case 3988:  /* *pred_eqnevnx32qi_scalar */
    case 3989:  /* *pred_eqnevnx64qi_scalar */
    case 3990:  /* *pred_eqnevnx1hi_scalar */
    case 3991:  /* *pred_eqnevnx2hi_scalar */
    case 3992:  /* *pred_eqnevnx4hi_scalar */
    case 3993:  /* *pred_eqnevnx8hi_scalar */
    case 3994:  /* *pred_eqnevnx16hi_scalar */
    case 3995:  /* *pred_eqnevnx32hi_scalar */
    case 3996:  /* *pred_eqnevnx1si_scalar */
    case 3997:  /* *pred_eqnevnx2si_scalar */
    case 3998:  /* *pred_eqnevnx4si_scalar */
    case 3999:  /* *pred_eqnevnx8si_scalar */
    case 4000:  /* *pred_eqnevnx16si_scalar */
    case 4001:  /* *pred_eqnevnx1qi_scalar_narrow */
    case 4002:  /* *pred_eqnevnx2qi_scalar_narrow */
    case 4003:  /* *pred_eqnevnx4qi_scalar_narrow */
    case 4004:  /* *pred_eqnevnx8qi_scalar_narrow */
    case 4005:  /* *pred_eqnevnx16qi_scalar_narrow */
    case 4006:  /* *pred_eqnevnx32qi_scalar_narrow */
    case 4007:  /* *pred_eqnevnx64qi_scalar_narrow */
    case 4008:  /* *pred_eqnevnx1hi_scalar_narrow */
    case 4009:  /* *pred_eqnevnx2hi_scalar_narrow */
    case 4010:  /* *pred_eqnevnx4hi_scalar_narrow */
    case 4011:  /* *pred_eqnevnx8hi_scalar_narrow */
    case 4012:  /* *pred_eqnevnx16hi_scalar_narrow */
    case 4013:  /* *pred_eqnevnx32hi_scalar_narrow */
    case 4014:  /* *pred_eqnevnx1si_scalar_narrow */
    case 4015:  /* *pred_eqnevnx2si_scalar_narrow */
    case 4016:  /* *pred_eqnevnx4si_scalar_narrow */
    case 4017:  /* *pred_eqnevnx8si_scalar_narrow */
    case 4018:  /* *pred_eqnevnx16si_scalar_narrow */
    case 4019:  /* *pred_cmpvnx1di_scalar */
    case 4020:  /* *pred_cmpvnx2di_scalar */
    case 4021:  /* *pred_cmpvnx4di_scalar */
    case 4022:  /* *pred_cmpvnx8di_scalar */
    case 4023:  /* *pred_cmpvnx1di_scalar_narrow */
    case 4024:  /* *pred_cmpvnx2di_scalar_narrow */
    case 4025:  /* *pred_cmpvnx4di_scalar_narrow */
    case 4026:  /* *pred_cmpvnx8di_scalar_narrow */
    case 4027:  /* *pred_eqnevnx1di_scalar */
    case 4028:  /* *pred_eqnevnx2di_scalar */
    case 4029:  /* *pred_eqnevnx4di_scalar */
    case 4030:  /* *pred_eqnevnx8di_scalar */
    case 4031:  /* *pred_eqnevnx1di_scalar_narrow */
    case 4032:  /* *pred_eqnevnx2di_scalar_narrow */
    case 4033:  /* *pred_eqnevnx4di_scalar_narrow */
    case 4034:  /* *pred_eqnevnx8di_scalar_narrow */
    case 4035:  /* *pred_cmpvnx1di_extended_scalar */
    case 4036:  /* *pred_cmpvnx2di_extended_scalar */
    case 4037:  /* *pred_cmpvnx4di_extended_scalar */
    case 4038:  /* *pred_cmpvnx8di_extended_scalar */
    case 4039:  /* *pred_cmpvnx1di_extended_scalar_narrow */
    case 4040:  /* *pred_cmpvnx2di_extended_scalar_narrow */
    case 4041:  /* *pred_cmpvnx4di_extended_scalar_narrow */
    case 4042:  /* *pred_cmpvnx8di_extended_scalar_narrow */
    case 4043:  /* *pred_eqnevnx1di_extended_scalar */
    case 4044:  /* *pred_eqnevnx2di_extended_scalar */
    case 4045:  /* *pred_eqnevnx4di_extended_scalar */
    case 4046:  /* *pred_eqnevnx8di_extended_scalar */
    case 4047:  /* *pred_eqnevnx1di_extended_scalar_narrow */
    case 4048:  /* *pred_eqnevnx2di_extended_scalar_narrow */
    case 4049:  /* *pred_eqnevnx4di_extended_scalar_narrow */
    case 4050:  /* *pred_eqnevnx8di_extended_scalar_narrow */
      return TYPE_VICMP;

    case 3204:  /* pred_narrow_ashrvnx1hi */
    case 3205:  /* pred_narrow_lshrvnx1hi */
    case 3206:  /* pred_narrow_ashrvnx2hi */
    case 3207:  /* pred_narrow_lshrvnx2hi */
    case 3208:  /* pred_narrow_ashrvnx4hi */
    case 3209:  /* pred_narrow_lshrvnx4hi */
    case 3210:  /* pred_narrow_ashrvnx8hi */
    case 3211:  /* pred_narrow_lshrvnx8hi */
    case 3212:  /* pred_narrow_ashrvnx16hi */
    case 3213:  /* pred_narrow_lshrvnx16hi */
    case 3214:  /* pred_narrow_ashrvnx32hi */
    case 3215:  /* pred_narrow_lshrvnx32hi */
    case 3216:  /* pred_narrow_ashrvnx1si */
    case 3217:  /* pred_narrow_lshrvnx1si */
    case 3218:  /* pred_narrow_ashrvnx2si */
    case 3219:  /* pred_narrow_lshrvnx2si */
    case 3220:  /* pred_narrow_ashrvnx4si */
    case 3221:  /* pred_narrow_lshrvnx4si */
    case 3222:  /* pred_narrow_ashrvnx8si */
    case 3223:  /* pred_narrow_lshrvnx8si */
    case 3224:  /* pred_narrow_ashrvnx16si */
    case 3225:  /* pred_narrow_lshrvnx16si */
    case 3226:  /* pred_narrow_ashrvnx1di */
    case 3227:  /* pred_narrow_lshrvnx1di */
    case 3228:  /* pred_narrow_ashrvnx2di */
    case 3229:  /* pred_narrow_lshrvnx2di */
    case 3230:  /* pred_narrow_ashrvnx4di */
    case 3231:  /* pred_narrow_lshrvnx4di */
    case 3232:  /* pred_narrow_ashrvnx8di */
    case 3233:  /* pred_narrow_lshrvnx8di */
    case 3234:  /* pred_narrow_ashrvnx1hi_scalar */
    case 3235:  /* pred_narrow_lshrvnx1hi_scalar */
    case 3236:  /* pred_narrow_ashrvnx2hi_scalar */
    case 3237:  /* pred_narrow_lshrvnx2hi_scalar */
    case 3238:  /* pred_narrow_ashrvnx4hi_scalar */
    case 3239:  /* pred_narrow_lshrvnx4hi_scalar */
    case 3240:  /* pred_narrow_ashrvnx8hi_scalar */
    case 3241:  /* pred_narrow_lshrvnx8hi_scalar */
    case 3242:  /* pred_narrow_ashrvnx16hi_scalar */
    case 3243:  /* pred_narrow_lshrvnx16hi_scalar */
    case 3244:  /* pred_narrow_ashrvnx32hi_scalar */
    case 3245:  /* pred_narrow_lshrvnx32hi_scalar */
    case 3246:  /* pred_narrow_ashrvnx1si_scalar */
    case 3247:  /* pred_narrow_lshrvnx1si_scalar */
    case 3248:  /* pred_narrow_ashrvnx2si_scalar */
    case 3249:  /* pred_narrow_lshrvnx2si_scalar */
    case 3250:  /* pred_narrow_ashrvnx4si_scalar */
    case 3251:  /* pred_narrow_lshrvnx4si_scalar */
    case 3252:  /* pred_narrow_ashrvnx8si_scalar */
    case 3253:  /* pred_narrow_lshrvnx8si_scalar */
    case 3254:  /* pred_narrow_ashrvnx16si_scalar */
    case 3255:  /* pred_narrow_lshrvnx16si_scalar */
    case 3256:  /* pred_narrow_ashrvnx1di_scalar */
    case 3257:  /* pred_narrow_lshrvnx1di_scalar */
    case 3258:  /* pred_narrow_ashrvnx2di_scalar */
    case 3259:  /* pred_narrow_lshrvnx2di_scalar */
    case 3260:  /* pred_narrow_ashrvnx4di_scalar */
    case 3261:  /* pred_narrow_lshrvnx4di_scalar */
    case 3262:  /* pred_narrow_ashrvnx8di_scalar */
    case 3263:  /* pred_narrow_lshrvnx8di_scalar */
    case 3264:  /* pred_truncvnx1hi */
    case 3265:  /* pred_truncvnx2hi */
    case 3266:  /* pred_truncvnx4hi */
    case 3267:  /* pred_truncvnx8hi */
    case 3268:  /* pred_truncvnx16hi */
    case 3269:  /* pred_truncvnx32hi */
    case 3270:  /* pred_truncvnx1si */
    case 3271:  /* pred_truncvnx2si */
    case 3272:  /* pred_truncvnx4si */
    case 3273:  /* pred_truncvnx8si */
    case 3274:  /* pred_truncvnx16si */
    case 3275:  /* pred_truncvnx1di */
    case 3276:  /* pred_truncvnx2di */
    case 3277:  /* pred_truncvnx4di */
    case 3278:  /* pred_truncvnx8di */
      return TYPE_VNSHIFT;

    case 1487:  /* pred_ashlvnx1qi */
    case 1488:  /* pred_ashrvnx1qi */
    case 1489:  /* pred_lshrvnx1qi */
    case 1504:  /* pred_ashlvnx2qi */
    case 1505:  /* pred_ashrvnx2qi */
    case 1506:  /* pred_lshrvnx2qi */
    case 1521:  /* pred_ashlvnx4qi */
    case 1522:  /* pred_ashrvnx4qi */
    case 1523:  /* pred_lshrvnx4qi */
    case 1538:  /* pred_ashlvnx8qi */
    case 1539:  /* pred_ashrvnx8qi */
    case 1540:  /* pred_lshrvnx8qi */
    case 1555:  /* pred_ashlvnx16qi */
    case 1556:  /* pred_ashrvnx16qi */
    case 1557:  /* pred_lshrvnx16qi */
    case 1572:  /* pred_ashlvnx32qi */
    case 1573:  /* pred_ashrvnx32qi */
    case 1574:  /* pred_lshrvnx32qi */
    case 1589:  /* pred_ashlvnx64qi */
    case 1590:  /* pred_ashrvnx64qi */
    case 1591:  /* pred_lshrvnx64qi */
    case 1606:  /* pred_ashlvnx1hi */
    case 1607:  /* pred_ashrvnx1hi */
    case 1608:  /* pred_lshrvnx1hi */
    case 1623:  /* pred_ashlvnx2hi */
    case 1624:  /* pred_ashrvnx2hi */
    case 1625:  /* pred_lshrvnx2hi */
    case 1640:  /* pred_ashlvnx4hi */
    case 1641:  /* pred_ashrvnx4hi */
    case 1642:  /* pred_lshrvnx4hi */
    case 1657:  /* pred_ashlvnx8hi */
    case 1658:  /* pred_ashrvnx8hi */
    case 1659:  /* pred_lshrvnx8hi */
    case 1674:  /* pred_ashlvnx16hi */
    case 1675:  /* pred_ashrvnx16hi */
    case 1676:  /* pred_lshrvnx16hi */
    case 1691:  /* pred_ashlvnx32hi */
    case 1692:  /* pred_ashrvnx32hi */
    case 1693:  /* pred_lshrvnx32hi */
    case 1708:  /* pred_ashlvnx1si */
    case 1709:  /* pred_ashrvnx1si */
    case 1710:  /* pred_lshrvnx1si */
    case 1725:  /* pred_ashlvnx2si */
    case 1726:  /* pred_ashrvnx2si */
    case 1727:  /* pred_lshrvnx2si */
    case 1742:  /* pred_ashlvnx4si */
    case 1743:  /* pred_ashrvnx4si */
    case 1744:  /* pred_lshrvnx4si */
    case 1759:  /* pred_ashlvnx8si */
    case 1760:  /* pred_ashrvnx8si */
    case 1761:  /* pred_lshrvnx8si */
    case 1776:  /* pred_ashlvnx16si */
    case 1777:  /* pred_ashrvnx16si */
    case 1778:  /* pred_lshrvnx16si */
    case 1793:  /* pred_ashlvnx1di */
    case 1794:  /* pred_ashrvnx1di */
    case 1795:  /* pred_lshrvnx1di */
    case 1810:  /* pred_ashlvnx2di */
    case 1811:  /* pred_ashrvnx2di */
    case 1812:  /* pred_lshrvnx2di */
    case 1827:  /* pred_ashlvnx4di */
    case 1828:  /* pred_ashrvnx4di */
    case 1829:  /* pred_lshrvnx4di */
    case 1844:  /* pred_ashlvnx8di */
    case 1845:  /* pred_ashrvnx8di */
    case 1846:  /* pred_lshrvnx8di */
    case 1856:  /* pred_ashlvnx1qi_scalar */
    case 1857:  /* pred_ashrvnx1qi_scalar */
    case 1858:  /* pred_lshrvnx1qi_scalar */
    case 1859:  /* pred_ashlvnx2qi_scalar */
    case 1860:  /* pred_ashrvnx2qi_scalar */
    case 1861:  /* pred_lshrvnx2qi_scalar */
    case 1862:  /* pred_ashlvnx4qi_scalar */
    case 1863:  /* pred_ashrvnx4qi_scalar */
    case 1864:  /* pred_lshrvnx4qi_scalar */
    case 1865:  /* pred_ashlvnx8qi_scalar */
    case 1866:  /* pred_ashrvnx8qi_scalar */
    case 1867:  /* pred_lshrvnx8qi_scalar */
    case 1868:  /* pred_ashlvnx16qi_scalar */
    case 1869:  /* pred_ashrvnx16qi_scalar */
    case 1870:  /* pred_lshrvnx16qi_scalar */
    case 1871:  /* pred_ashlvnx32qi_scalar */
    case 1872:  /* pred_ashrvnx32qi_scalar */
    case 1873:  /* pred_lshrvnx32qi_scalar */
    case 1874:  /* pred_ashlvnx64qi_scalar */
    case 1875:  /* pred_ashrvnx64qi_scalar */
    case 1876:  /* pred_lshrvnx64qi_scalar */
    case 1877:  /* pred_ashlvnx1hi_scalar */
    case 1878:  /* pred_ashrvnx1hi_scalar */
    case 1879:  /* pred_lshrvnx1hi_scalar */
    case 1880:  /* pred_ashlvnx2hi_scalar */
    case 1881:  /* pred_ashrvnx2hi_scalar */
    case 1882:  /* pred_lshrvnx2hi_scalar */
    case 1883:  /* pred_ashlvnx4hi_scalar */
    case 1884:  /* pred_ashrvnx4hi_scalar */
    case 1885:  /* pred_lshrvnx4hi_scalar */
    case 1886:  /* pred_ashlvnx8hi_scalar */
    case 1887:  /* pred_ashrvnx8hi_scalar */
    case 1888:  /* pred_lshrvnx8hi_scalar */
    case 1889:  /* pred_ashlvnx16hi_scalar */
    case 1890:  /* pred_ashrvnx16hi_scalar */
    case 1891:  /* pred_lshrvnx16hi_scalar */
    case 1892:  /* pred_ashlvnx32hi_scalar */
    case 1893:  /* pred_ashrvnx32hi_scalar */
    case 1894:  /* pred_lshrvnx32hi_scalar */
    case 1895:  /* pred_ashlvnx1si_scalar */
    case 1896:  /* pred_ashrvnx1si_scalar */
    case 1897:  /* pred_lshrvnx1si_scalar */
    case 1898:  /* pred_ashlvnx2si_scalar */
    case 1899:  /* pred_ashrvnx2si_scalar */
    case 1900:  /* pred_lshrvnx2si_scalar */
    case 1901:  /* pred_ashlvnx4si_scalar */
    case 1902:  /* pred_ashrvnx4si_scalar */
    case 1903:  /* pred_lshrvnx4si_scalar */
    case 1904:  /* pred_ashlvnx8si_scalar */
    case 1905:  /* pred_ashrvnx8si_scalar */
    case 1906:  /* pred_lshrvnx8si_scalar */
    case 1907:  /* pred_ashlvnx16si_scalar */
    case 1908:  /* pred_ashrvnx16si_scalar */
    case 1909:  /* pred_lshrvnx16si_scalar */
    case 1910:  /* pred_ashlvnx1di_scalar */
    case 1911:  /* pred_ashrvnx1di_scalar */
    case 1912:  /* pred_lshrvnx1di_scalar */
    case 1913:  /* pred_ashlvnx2di_scalar */
    case 1914:  /* pred_ashrvnx2di_scalar */
    case 1915:  /* pred_lshrvnx2di_scalar */
    case 1916:  /* pred_ashlvnx4di_scalar */
    case 1917:  /* pred_ashrvnx4di_scalar */
    case 1918:  /* pred_lshrvnx4di_scalar */
    case 1919:  /* pred_ashlvnx8di_scalar */
    case 1920:  /* pred_ashrvnx8di_scalar */
    case 1921:  /* pred_lshrvnx8di_scalar */
      return TYPE_VSHIFT;

    case 2456:  /* pred_adcvnx1qi */
    case 2457:  /* pred_adcvnx2qi */
    case 2458:  /* pred_adcvnx4qi */
    case 2459:  /* pred_adcvnx8qi */
    case 2460:  /* pred_adcvnx16qi */
    case 2461:  /* pred_adcvnx32qi */
    case 2462:  /* pred_adcvnx64qi */
    case 2463:  /* pred_adcvnx1hi */
    case 2464:  /* pred_adcvnx2hi */
    case 2465:  /* pred_adcvnx4hi */
    case 2466:  /* pred_adcvnx8hi */
    case 2467:  /* pred_adcvnx16hi */
    case 2468:  /* pred_adcvnx32hi */
    case 2469:  /* pred_adcvnx1si */
    case 2470:  /* pred_adcvnx2si */
    case 2471:  /* pred_adcvnx4si */
    case 2472:  /* pred_adcvnx8si */
    case 2473:  /* pred_adcvnx16si */
    case 2474:  /* pred_adcvnx1di */
    case 2475:  /* pred_adcvnx2di */
    case 2476:  /* pred_adcvnx4di */
    case 2477:  /* pred_adcvnx8di */
    case 2478:  /* pred_sbcvnx1qi */
    case 2479:  /* pred_sbcvnx2qi */
    case 2480:  /* pred_sbcvnx4qi */
    case 2481:  /* pred_sbcvnx8qi */
    case 2482:  /* pred_sbcvnx16qi */
    case 2483:  /* pred_sbcvnx32qi */
    case 2484:  /* pred_sbcvnx64qi */
    case 2485:  /* pred_sbcvnx1hi */
    case 2486:  /* pred_sbcvnx2hi */
    case 2487:  /* pred_sbcvnx4hi */
    case 2488:  /* pred_sbcvnx8hi */
    case 2489:  /* pred_sbcvnx16hi */
    case 2490:  /* pred_sbcvnx32hi */
    case 2491:  /* pred_sbcvnx1si */
    case 2492:  /* pred_sbcvnx2si */
    case 2493:  /* pred_sbcvnx4si */
    case 2494:  /* pred_sbcvnx8si */
    case 2495:  /* pred_sbcvnx16si */
    case 2496:  /* pred_sbcvnx1di */
    case 2497:  /* pred_sbcvnx2di */
    case 2498:  /* pred_sbcvnx4di */
    case 2499:  /* pred_sbcvnx8di */
    case 2500:  /* pred_adcvnx1qi_scalar */
    case 2501:  /* pred_adcvnx2qi_scalar */
    case 2502:  /* pred_adcvnx4qi_scalar */
    case 2503:  /* pred_adcvnx8qi_scalar */
    case 2504:  /* pred_adcvnx16qi_scalar */
    case 2505:  /* pred_adcvnx32qi_scalar */
    case 2506:  /* pred_adcvnx64qi_scalar */
    case 2507:  /* pred_adcvnx1hi_scalar */
    case 2508:  /* pred_adcvnx2hi_scalar */
    case 2509:  /* pred_adcvnx4hi_scalar */
    case 2510:  /* pred_adcvnx8hi_scalar */
    case 2511:  /* pred_adcvnx16hi_scalar */
    case 2512:  /* pred_adcvnx32hi_scalar */
    case 2513:  /* pred_adcvnx1si_scalar */
    case 2514:  /* pred_adcvnx2si_scalar */
    case 2515:  /* pred_adcvnx4si_scalar */
    case 2516:  /* pred_adcvnx8si_scalar */
    case 2517:  /* pred_adcvnx16si_scalar */
    case 2518:  /* pred_sbcvnx1qi_scalar */
    case 2519:  /* pred_sbcvnx2qi_scalar */
    case 2520:  /* pred_sbcvnx4qi_scalar */
    case 2521:  /* pred_sbcvnx8qi_scalar */
    case 2522:  /* pred_sbcvnx16qi_scalar */
    case 2523:  /* pred_sbcvnx32qi_scalar */
    case 2524:  /* pred_sbcvnx64qi_scalar */
    case 2525:  /* pred_sbcvnx1hi_scalar */
    case 2526:  /* pred_sbcvnx2hi_scalar */
    case 2527:  /* pred_sbcvnx4hi_scalar */
    case 2528:  /* pred_sbcvnx8hi_scalar */
    case 2529:  /* pred_sbcvnx16hi_scalar */
    case 2530:  /* pred_sbcvnx32hi_scalar */
    case 2531:  /* pred_sbcvnx1si_scalar */
    case 2532:  /* pred_sbcvnx2si_scalar */
    case 2533:  /* pred_sbcvnx4si_scalar */
    case 2534:  /* pred_sbcvnx8si_scalar */
    case 2535:  /* pred_sbcvnx16si_scalar */
    case 2536:  /* *pred_adcvnx1di_scalar */
    case 2537:  /* *pred_adcvnx2di_scalar */
    case 2538:  /* *pred_adcvnx4di_scalar */
    case 2539:  /* *pred_adcvnx8di_scalar */
    case 2540:  /* *pred_adcvnx1di_extended_scalar */
    case 2541:  /* *pred_adcvnx2di_extended_scalar */
    case 2542:  /* *pred_adcvnx4di_extended_scalar */
    case 2543:  /* *pred_adcvnx8di_extended_scalar */
    case 2544:  /* *pred_sbcvnx1di_scalar */
    case 2545:  /* *pred_sbcvnx2di_scalar */
    case 2546:  /* *pred_sbcvnx4di_scalar */
    case 2547:  /* *pred_sbcvnx8di_scalar */
    case 2548:  /* *pred_sbcvnx1di_extended_scalar */
    case 2549:  /* *pred_sbcvnx2di_extended_scalar */
    case 2550:  /* *pred_sbcvnx4di_extended_scalar */
    case 2551:  /* *pred_sbcvnx8di_extended_scalar */
    case 2552:  /* pred_madcvnx1qi */
    case 2553:  /* pred_madcvnx2qi */
    case 2554:  /* pred_madcvnx4qi */
    case 2555:  /* pred_madcvnx8qi */
    case 2556:  /* pred_madcvnx16qi */
    case 2557:  /* pred_madcvnx32qi */
    case 2558:  /* pred_madcvnx64qi */
    case 2559:  /* pred_madcvnx1hi */
    case 2560:  /* pred_madcvnx2hi */
    case 2561:  /* pred_madcvnx4hi */
    case 2562:  /* pred_madcvnx8hi */
    case 2563:  /* pred_madcvnx16hi */
    case 2564:  /* pred_madcvnx32hi */
    case 2565:  /* pred_madcvnx1si */
    case 2566:  /* pred_madcvnx2si */
    case 2567:  /* pred_madcvnx4si */
    case 2568:  /* pred_madcvnx8si */
    case 2569:  /* pred_madcvnx16si */
    case 2570:  /* pred_madcvnx1di */
    case 2571:  /* pred_madcvnx2di */
    case 2572:  /* pred_madcvnx4di */
    case 2573:  /* pred_madcvnx8di */
    case 2574:  /* pred_msbcvnx1qi */
    case 2575:  /* pred_msbcvnx2qi */
    case 2576:  /* pred_msbcvnx4qi */
    case 2577:  /* pred_msbcvnx8qi */
    case 2578:  /* pred_msbcvnx16qi */
    case 2579:  /* pred_msbcvnx32qi */
    case 2580:  /* pred_msbcvnx64qi */
    case 2581:  /* pred_msbcvnx1hi */
    case 2582:  /* pred_msbcvnx2hi */
    case 2583:  /* pred_msbcvnx4hi */
    case 2584:  /* pred_msbcvnx8hi */
    case 2585:  /* pred_msbcvnx16hi */
    case 2586:  /* pred_msbcvnx32hi */
    case 2587:  /* pred_msbcvnx1si */
    case 2588:  /* pred_msbcvnx2si */
    case 2589:  /* pred_msbcvnx4si */
    case 2590:  /* pred_msbcvnx8si */
    case 2591:  /* pred_msbcvnx16si */
    case 2592:  /* pred_msbcvnx1di */
    case 2593:  /* pred_msbcvnx2di */
    case 2594:  /* pred_msbcvnx4di */
    case 2595:  /* pred_msbcvnx8di */
    case 2596:  /* pred_madcvnx1qi_scalar */
    case 2597:  /* pred_madcvnx2qi_scalar */
    case 2598:  /* pred_madcvnx4qi_scalar */
    case 2599:  /* pred_madcvnx8qi_scalar */
    case 2600:  /* pred_madcvnx16qi_scalar */
    case 2601:  /* pred_madcvnx32qi_scalar */
    case 2602:  /* pred_madcvnx64qi_scalar */
    case 2603:  /* pred_madcvnx1hi_scalar */
    case 2604:  /* pred_madcvnx2hi_scalar */
    case 2605:  /* pred_madcvnx4hi_scalar */
    case 2606:  /* pred_madcvnx8hi_scalar */
    case 2607:  /* pred_madcvnx16hi_scalar */
    case 2608:  /* pred_madcvnx32hi_scalar */
    case 2609:  /* pred_madcvnx1si_scalar */
    case 2610:  /* pred_madcvnx2si_scalar */
    case 2611:  /* pred_madcvnx4si_scalar */
    case 2612:  /* pred_madcvnx8si_scalar */
    case 2613:  /* pred_madcvnx16si_scalar */
    case 2614:  /* pred_msbcvnx1qi_scalar */
    case 2615:  /* pred_msbcvnx2qi_scalar */
    case 2616:  /* pred_msbcvnx4qi_scalar */
    case 2617:  /* pred_msbcvnx8qi_scalar */
    case 2618:  /* pred_msbcvnx16qi_scalar */
    case 2619:  /* pred_msbcvnx32qi_scalar */
    case 2620:  /* pred_msbcvnx64qi_scalar */
    case 2621:  /* pred_msbcvnx1hi_scalar */
    case 2622:  /* pred_msbcvnx2hi_scalar */
    case 2623:  /* pred_msbcvnx4hi_scalar */
    case 2624:  /* pred_msbcvnx8hi_scalar */
    case 2625:  /* pred_msbcvnx16hi_scalar */
    case 2626:  /* pred_msbcvnx32hi_scalar */
    case 2627:  /* pred_msbcvnx1si_scalar */
    case 2628:  /* pred_msbcvnx2si_scalar */
    case 2629:  /* pred_msbcvnx4si_scalar */
    case 2630:  /* pred_msbcvnx8si_scalar */
    case 2631:  /* pred_msbcvnx16si_scalar */
    case 2632:  /* *pred_madcvnx1di_scalar */
    case 2633:  /* *pred_madcvnx2di_scalar */
    case 2634:  /* *pred_madcvnx4di_scalar */
    case 2635:  /* *pred_madcvnx8di_scalar */
    case 2636:  /* *pred_madcvnx1di_extended_scalar */
    case 2637:  /* *pred_madcvnx2di_extended_scalar */
    case 2638:  /* *pred_madcvnx4di_extended_scalar */
    case 2639:  /* *pred_madcvnx8di_extended_scalar */
    case 2640:  /* *pred_msbcvnx1di_scalar */
    case 2641:  /* *pred_msbcvnx2di_scalar */
    case 2642:  /* *pred_msbcvnx4di_scalar */
    case 2643:  /* *pred_msbcvnx8di_scalar */
    case 2644:  /* *pred_msbcvnx1di_extended_scalar */
    case 2645:  /* *pred_msbcvnx2di_extended_scalar */
    case 2646:  /* *pred_msbcvnx4di_extended_scalar */
    case 2647:  /* *pred_msbcvnx8di_extended_scalar */
    case 2648:  /* pred_madcvnx1qi_overflow */
    case 2649:  /* pred_madcvnx2qi_overflow */
    case 2650:  /* pred_madcvnx4qi_overflow */
    case 2651:  /* pred_madcvnx8qi_overflow */
    case 2652:  /* pred_madcvnx16qi_overflow */
    case 2653:  /* pred_madcvnx32qi_overflow */
    case 2654:  /* pred_madcvnx64qi_overflow */
    case 2655:  /* pred_madcvnx1hi_overflow */
    case 2656:  /* pred_madcvnx2hi_overflow */
    case 2657:  /* pred_madcvnx4hi_overflow */
    case 2658:  /* pred_madcvnx8hi_overflow */
    case 2659:  /* pred_madcvnx16hi_overflow */
    case 2660:  /* pred_madcvnx32hi_overflow */
    case 2661:  /* pred_madcvnx1si_overflow */
    case 2662:  /* pred_madcvnx2si_overflow */
    case 2663:  /* pred_madcvnx4si_overflow */
    case 2664:  /* pred_madcvnx8si_overflow */
    case 2665:  /* pred_madcvnx16si_overflow */
    case 2666:  /* pred_madcvnx1di_overflow */
    case 2667:  /* pred_madcvnx2di_overflow */
    case 2668:  /* pred_madcvnx4di_overflow */
    case 2669:  /* pred_madcvnx8di_overflow */
    case 2670:  /* pred_msbcvnx1qi_overflow */
    case 2671:  /* pred_msbcvnx2qi_overflow */
    case 2672:  /* pred_msbcvnx4qi_overflow */
    case 2673:  /* pred_msbcvnx8qi_overflow */
    case 2674:  /* pred_msbcvnx16qi_overflow */
    case 2675:  /* pred_msbcvnx32qi_overflow */
    case 2676:  /* pred_msbcvnx64qi_overflow */
    case 2677:  /* pred_msbcvnx1hi_overflow */
    case 2678:  /* pred_msbcvnx2hi_overflow */
    case 2679:  /* pred_msbcvnx4hi_overflow */
    case 2680:  /* pred_msbcvnx8hi_overflow */
    case 2681:  /* pred_msbcvnx16hi_overflow */
    case 2682:  /* pred_msbcvnx32hi_overflow */
    case 2683:  /* pred_msbcvnx1si_overflow */
    case 2684:  /* pred_msbcvnx2si_overflow */
    case 2685:  /* pred_msbcvnx4si_overflow */
    case 2686:  /* pred_msbcvnx8si_overflow */
    case 2687:  /* pred_msbcvnx16si_overflow */
    case 2688:  /* pred_msbcvnx1di_overflow */
    case 2689:  /* pred_msbcvnx2di_overflow */
    case 2690:  /* pred_msbcvnx4di_overflow */
    case 2691:  /* pred_msbcvnx8di_overflow */
    case 2692:  /* pred_madcvnx1qi_overflow_scalar */
    case 2693:  /* pred_madcvnx2qi_overflow_scalar */
    case 2694:  /* pred_madcvnx4qi_overflow_scalar */
    case 2695:  /* pred_madcvnx8qi_overflow_scalar */
    case 2696:  /* pred_madcvnx16qi_overflow_scalar */
    case 2697:  /* pred_madcvnx32qi_overflow_scalar */
    case 2698:  /* pred_madcvnx64qi_overflow_scalar */
    case 2699:  /* pred_madcvnx1hi_overflow_scalar */
    case 2700:  /* pred_madcvnx2hi_overflow_scalar */
    case 2701:  /* pred_madcvnx4hi_overflow_scalar */
    case 2702:  /* pred_madcvnx8hi_overflow_scalar */
    case 2703:  /* pred_madcvnx16hi_overflow_scalar */
    case 2704:  /* pred_madcvnx32hi_overflow_scalar */
    case 2705:  /* pred_madcvnx1si_overflow_scalar */
    case 2706:  /* pred_madcvnx2si_overflow_scalar */
    case 2707:  /* pred_madcvnx4si_overflow_scalar */
    case 2708:  /* pred_madcvnx8si_overflow_scalar */
    case 2709:  /* pred_madcvnx16si_overflow_scalar */
    case 2710:  /* pred_msbcvnx1qi_overflow_scalar */
    case 2711:  /* pred_msbcvnx2qi_overflow_scalar */
    case 2712:  /* pred_msbcvnx4qi_overflow_scalar */
    case 2713:  /* pred_msbcvnx8qi_overflow_scalar */
    case 2714:  /* pred_msbcvnx16qi_overflow_scalar */
    case 2715:  /* pred_msbcvnx32qi_overflow_scalar */
    case 2716:  /* pred_msbcvnx64qi_overflow_scalar */
    case 2717:  /* pred_msbcvnx1hi_overflow_scalar */
    case 2718:  /* pred_msbcvnx2hi_overflow_scalar */
    case 2719:  /* pred_msbcvnx4hi_overflow_scalar */
    case 2720:  /* pred_msbcvnx8hi_overflow_scalar */
    case 2721:  /* pred_msbcvnx16hi_overflow_scalar */
    case 2722:  /* pred_msbcvnx32hi_overflow_scalar */
    case 2723:  /* pred_msbcvnx1si_overflow_scalar */
    case 2724:  /* pred_msbcvnx2si_overflow_scalar */
    case 2725:  /* pred_msbcvnx4si_overflow_scalar */
    case 2726:  /* pred_msbcvnx8si_overflow_scalar */
    case 2727:  /* pred_msbcvnx16si_overflow_scalar */
    case 2728:  /* *pred_madcvnx1di_overflow_scalar */
    case 2729:  /* *pred_madcvnx2di_overflow_scalar */
    case 2730:  /* *pred_madcvnx4di_overflow_scalar */
    case 2731:  /* *pred_madcvnx8di_overflow_scalar */
    case 2732:  /* *pred_madcvnx1di_overflow_extended_scalar */
    case 2733:  /* *pred_madcvnx2di_overflow_extended_scalar */
    case 2734:  /* *pred_madcvnx4di_overflow_extended_scalar */
    case 2735:  /* *pred_madcvnx8di_overflow_extended_scalar */
    case 2736:  /* *pred_msbcvnx1di_overflow_scalar */
    case 2737:  /* *pred_msbcvnx2di_overflow_scalar */
    case 2738:  /* *pred_msbcvnx4di_overflow_scalar */
    case 2739:  /* *pred_msbcvnx8di_overflow_scalar */
    case 2740:  /* *pred_msbcvnx1di_overflow_extended_scalar */
    case 2741:  /* *pred_msbcvnx2di_overflow_extended_scalar */
    case 2742:  /* *pred_msbcvnx4di_overflow_extended_scalar */
    case 2743:  /* *pred_msbcvnx8di_overflow_extended_scalar */
      return TYPE_VICALU;

    case 2788:  /* pred_extendvnx1hi_vf2 */
    case 2789:  /* pred_zero_extendvnx1hi_vf2 */
    case 2790:  /* pred_extendvnx2hi_vf2 */
    case 2791:  /* pred_zero_extendvnx2hi_vf2 */
    case 2792:  /* pred_extendvnx4hi_vf2 */
    case 2793:  /* pred_zero_extendvnx4hi_vf2 */
    case 2794:  /* pred_extendvnx8hi_vf2 */
    case 2795:  /* pred_zero_extendvnx8hi_vf2 */
    case 2796:  /* pred_extendvnx16hi_vf2 */
    case 2797:  /* pred_zero_extendvnx16hi_vf2 */
    case 2798:  /* pred_extendvnx32hi_vf2 */
    case 2799:  /* pred_zero_extendvnx32hi_vf2 */
    case 2800:  /* pred_extendvnx1si_vf2 */
    case 2801:  /* pred_zero_extendvnx1si_vf2 */
    case 2802:  /* pred_extendvnx2si_vf2 */
    case 2803:  /* pred_zero_extendvnx2si_vf2 */
    case 2804:  /* pred_extendvnx4si_vf2 */
    case 2805:  /* pred_zero_extendvnx4si_vf2 */
    case 2806:  /* pred_extendvnx8si_vf2 */
    case 2807:  /* pred_zero_extendvnx8si_vf2 */
    case 2808:  /* pred_extendvnx16si_vf2 */
    case 2809:  /* pred_zero_extendvnx16si_vf2 */
    case 2810:  /* pred_extendvnx1di_vf2 */
    case 2811:  /* pred_zero_extendvnx1di_vf2 */
    case 2812:  /* pred_extendvnx2di_vf2 */
    case 2813:  /* pred_zero_extendvnx2di_vf2 */
    case 2814:  /* pred_extendvnx4di_vf2 */
    case 2815:  /* pred_zero_extendvnx4di_vf2 */
    case 2816:  /* pred_extendvnx8di_vf2 */
    case 2817:  /* pred_zero_extendvnx8di_vf2 */
    case 2818:  /* pred_extendvnx1si_vf4 */
    case 2819:  /* pred_zero_extendvnx1si_vf4 */
    case 2820:  /* pred_extendvnx2si_vf4 */
    case 2821:  /* pred_zero_extendvnx2si_vf4 */
    case 2822:  /* pred_extendvnx4si_vf4 */
    case 2823:  /* pred_zero_extendvnx4si_vf4 */
    case 2824:  /* pred_extendvnx8si_vf4 */
    case 2825:  /* pred_zero_extendvnx8si_vf4 */
    case 2826:  /* pred_extendvnx16si_vf4 */
    case 2827:  /* pred_zero_extendvnx16si_vf4 */
    case 2828:  /* pred_extendvnx1di_vf4 */
    case 2829:  /* pred_zero_extendvnx1di_vf4 */
    case 2830:  /* pred_extendvnx2di_vf4 */
    case 2831:  /* pred_zero_extendvnx2di_vf4 */
    case 2832:  /* pred_extendvnx4di_vf4 */
    case 2833:  /* pred_zero_extendvnx4di_vf4 */
    case 2834:  /* pred_extendvnx8di_vf4 */
    case 2835:  /* pred_zero_extendvnx8di_vf4 */
    case 2836:  /* pred_extendvnx1di_vf8 */
    case 2837:  /* pred_zero_extendvnx1di_vf8 */
    case 2838:  /* pred_extendvnx2di_vf8 */
    case 2839:  /* pred_zero_extendvnx2di_vf8 */
    case 2840:  /* pred_extendvnx4di_vf8 */
    case 2841:  /* pred_zero_extendvnx4di_vf8 */
    case 2842:  /* pred_extendvnx8di_vf8 */
    case 2843:  /* pred_zero_extendvnx8di_vf8 */
      return TYPE_VEXT;

    case 2844:  /* pred_dual_widen_addsvnx1hi */
    case 2845:  /* pred_dual_widen_subsvnx1hi */
    case 2847:  /* pred_dual_widen_adduvnx1hi */
    case 2848:  /* pred_dual_widen_subuvnx1hi */
    case 2850:  /* pred_dual_widen_addsvnx2hi */
    case 2851:  /* pred_dual_widen_subsvnx2hi */
    case 2853:  /* pred_dual_widen_adduvnx2hi */
    case 2854:  /* pred_dual_widen_subuvnx2hi */
    case 2856:  /* pred_dual_widen_addsvnx4hi */
    case 2857:  /* pred_dual_widen_subsvnx4hi */
    case 2859:  /* pred_dual_widen_adduvnx4hi */
    case 2860:  /* pred_dual_widen_subuvnx4hi */
    case 2862:  /* pred_dual_widen_addsvnx8hi */
    case 2863:  /* pred_dual_widen_subsvnx8hi */
    case 2865:  /* pred_dual_widen_adduvnx8hi */
    case 2866:  /* pred_dual_widen_subuvnx8hi */
    case 2868:  /* pred_dual_widen_addsvnx16hi */
    case 2869:  /* pred_dual_widen_subsvnx16hi */
    case 2871:  /* pred_dual_widen_adduvnx16hi */
    case 2872:  /* pred_dual_widen_subuvnx16hi */
    case 2874:  /* pred_dual_widen_addsvnx32hi */
    case 2875:  /* pred_dual_widen_subsvnx32hi */
    case 2877:  /* pred_dual_widen_adduvnx32hi */
    case 2878:  /* pred_dual_widen_subuvnx32hi */
    case 2880:  /* pred_dual_widen_addsvnx1si */
    case 2881:  /* pred_dual_widen_subsvnx1si */
    case 2883:  /* pred_dual_widen_adduvnx1si */
    case 2884:  /* pred_dual_widen_subuvnx1si */
    case 2886:  /* pred_dual_widen_addsvnx2si */
    case 2887:  /* pred_dual_widen_subsvnx2si */
    case 2889:  /* pred_dual_widen_adduvnx2si */
    case 2890:  /* pred_dual_widen_subuvnx2si */
    case 2892:  /* pred_dual_widen_addsvnx4si */
    case 2893:  /* pred_dual_widen_subsvnx4si */
    case 2895:  /* pred_dual_widen_adduvnx4si */
    case 2896:  /* pred_dual_widen_subuvnx4si */
    case 2898:  /* pred_dual_widen_addsvnx8si */
    case 2899:  /* pred_dual_widen_subsvnx8si */
    case 2901:  /* pred_dual_widen_adduvnx8si */
    case 2902:  /* pred_dual_widen_subuvnx8si */
    case 2904:  /* pred_dual_widen_addsvnx16si */
    case 2905:  /* pred_dual_widen_subsvnx16si */
    case 2907:  /* pred_dual_widen_adduvnx16si */
    case 2908:  /* pred_dual_widen_subuvnx16si */
    case 2910:  /* pred_dual_widen_addsvnx1di */
    case 2911:  /* pred_dual_widen_subsvnx1di */
    case 2913:  /* pred_dual_widen_adduvnx1di */
    case 2914:  /* pred_dual_widen_subuvnx1di */
    case 2916:  /* pred_dual_widen_addsvnx2di */
    case 2917:  /* pred_dual_widen_subsvnx2di */
    case 2919:  /* pred_dual_widen_adduvnx2di */
    case 2920:  /* pred_dual_widen_subuvnx2di */
    case 2922:  /* pred_dual_widen_addsvnx4di */
    case 2923:  /* pred_dual_widen_subsvnx4di */
    case 2925:  /* pred_dual_widen_adduvnx4di */
    case 2926:  /* pred_dual_widen_subuvnx4di */
    case 2928:  /* pred_dual_widen_addsvnx8di */
    case 2929:  /* pred_dual_widen_subsvnx8di */
    case 2931:  /* pred_dual_widen_adduvnx8di */
    case 2932:  /* pred_dual_widen_subuvnx8di */
    case 2934:  /* pred_dual_widen_addsvnx1hi_scalar */
    case 2935:  /* pred_dual_widen_subsvnx1hi_scalar */
    case 2937:  /* pred_dual_widen_adduvnx1hi_scalar */
    case 2938:  /* pred_dual_widen_subuvnx1hi_scalar */
    case 2940:  /* pred_dual_widen_addsvnx2hi_scalar */
    case 2941:  /* pred_dual_widen_subsvnx2hi_scalar */
    case 2943:  /* pred_dual_widen_adduvnx2hi_scalar */
    case 2944:  /* pred_dual_widen_subuvnx2hi_scalar */
    case 2946:  /* pred_dual_widen_addsvnx4hi_scalar */
    case 2947:  /* pred_dual_widen_subsvnx4hi_scalar */
    case 2949:  /* pred_dual_widen_adduvnx4hi_scalar */
    case 2950:  /* pred_dual_widen_subuvnx4hi_scalar */
    case 2952:  /* pred_dual_widen_addsvnx8hi_scalar */
    case 2953:  /* pred_dual_widen_subsvnx8hi_scalar */
    case 2955:  /* pred_dual_widen_adduvnx8hi_scalar */
    case 2956:  /* pred_dual_widen_subuvnx8hi_scalar */
    case 2958:  /* pred_dual_widen_addsvnx16hi_scalar */
    case 2959:  /* pred_dual_widen_subsvnx16hi_scalar */
    case 2961:  /* pred_dual_widen_adduvnx16hi_scalar */
    case 2962:  /* pred_dual_widen_subuvnx16hi_scalar */
    case 2964:  /* pred_dual_widen_addsvnx32hi_scalar */
    case 2965:  /* pred_dual_widen_subsvnx32hi_scalar */
    case 2967:  /* pred_dual_widen_adduvnx32hi_scalar */
    case 2968:  /* pred_dual_widen_subuvnx32hi_scalar */
    case 2970:  /* pred_dual_widen_addsvnx1si_scalar */
    case 2971:  /* pred_dual_widen_subsvnx1si_scalar */
    case 2973:  /* pred_dual_widen_adduvnx1si_scalar */
    case 2974:  /* pred_dual_widen_subuvnx1si_scalar */
    case 2976:  /* pred_dual_widen_addsvnx2si_scalar */
    case 2977:  /* pred_dual_widen_subsvnx2si_scalar */
    case 2979:  /* pred_dual_widen_adduvnx2si_scalar */
    case 2980:  /* pred_dual_widen_subuvnx2si_scalar */
    case 2982:  /* pred_dual_widen_addsvnx4si_scalar */
    case 2983:  /* pred_dual_widen_subsvnx4si_scalar */
    case 2985:  /* pred_dual_widen_adduvnx4si_scalar */
    case 2986:  /* pred_dual_widen_subuvnx4si_scalar */
    case 2988:  /* pred_dual_widen_addsvnx8si_scalar */
    case 2989:  /* pred_dual_widen_subsvnx8si_scalar */
    case 2991:  /* pred_dual_widen_adduvnx8si_scalar */
    case 2992:  /* pred_dual_widen_subuvnx8si_scalar */
    case 2994:  /* pred_dual_widen_addsvnx16si_scalar */
    case 2995:  /* pred_dual_widen_subsvnx16si_scalar */
    case 2997:  /* pred_dual_widen_adduvnx16si_scalar */
    case 2998:  /* pred_dual_widen_subuvnx16si_scalar */
    case 3000:  /* pred_dual_widen_addsvnx1di_scalar */
    case 3001:  /* pred_dual_widen_subsvnx1di_scalar */
    case 3003:  /* pred_dual_widen_adduvnx1di_scalar */
    case 3004:  /* pred_dual_widen_subuvnx1di_scalar */
    case 3006:  /* pred_dual_widen_addsvnx2di_scalar */
    case 3007:  /* pred_dual_widen_subsvnx2di_scalar */
    case 3009:  /* pred_dual_widen_adduvnx2di_scalar */
    case 3010:  /* pred_dual_widen_subuvnx2di_scalar */
    case 3012:  /* pred_dual_widen_addsvnx4di_scalar */
    case 3013:  /* pred_dual_widen_subsvnx4di_scalar */
    case 3015:  /* pred_dual_widen_adduvnx4di_scalar */
    case 3016:  /* pred_dual_widen_subuvnx4di_scalar */
    case 3018:  /* pred_dual_widen_addsvnx8di_scalar */
    case 3019:  /* pred_dual_widen_subsvnx8di_scalar */
    case 3021:  /* pred_dual_widen_adduvnx8di_scalar */
    case 3022:  /* pred_dual_widen_subuvnx8di_scalar */
    case 3024:  /* pred_single_widen_addsvnx1hi */
    case 3025:  /* pred_single_widen_subsvnx1hi */
    case 3026:  /* pred_single_widen_adduvnx1hi */
    case 3027:  /* pred_single_widen_subuvnx1hi */
    case 3028:  /* pred_single_widen_addsvnx2hi */
    case 3029:  /* pred_single_widen_subsvnx2hi */
    case 3030:  /* pred_single_widen_adduvnx2hi */
    case 3031:  /* pred_single_widen_subuvnx2hi */
    case 3032:  /* pred_single_widen_addsvnx4hi */
    case 3033:  /* pred_single_widen_subsvnx4hi */
    case 3034:  /* pred_single_widen_adduvnx4hi */
    case 3035:  /* pred_single_widen_subuvnx4hi */
    case 3036:  /* pred_single_widen_addsvnx8hi */
    case 3037:  /* pred_single_widen_subsvnx8hi */
    case 3038:  /* pred_single_widen_adduvnx8hi */
    case 3039:  /* pred_single_widen_subuvnx8hi */
    case 3040:  /* pred_single_widen_addsvnx16hi */
    case 3041:  /* pred_single_widen_subsvnx16hi */
    case 3042:  /* pred_single_widen_adduvnx16hi */
    case 3043:  /* pred_single_widen_subuvnx16hi */
    case 3044:  /* pred_single_widen_addsvnx32hi */
    case 3045:  /* pred_single_widen_subsvnx32hi */
    case 3046:  /* pred_single_widen_adduvnx32hi */
    case 3047:  /* pred_single_widen_subuvnx32hi */
    case 3048:  /* pred_single_widen_addsvnx1si */
    case 3049:  /* pred_single_widen_subsvnx1si */
    case 3050:  /* pred_single_widen_adduvnx1si */
    case 3051:  /* pred_single_widen_subuvnx1si */
    case 3052:  /* pred_single_widen_addsvnx2si */
    case 3053:  /* pred_single_widen_subsvnx2si */
    case 3054:  /* pred_single_widen_adduvnx2si */
    case 3055:  /* pred_single_widen_subuvnx2si */
    case 3056:  /* pred_single_widen_addsvnx4si */
    case 3057:  /* pred_single_widen_subsvnx4si */
    case 3058:  /* pred_single_widen_adduvnx4si */
    case 3059:  /* pred_single_widen_subuvnx4si */
    case 3060:  /* pred_single_widen_addsvnx8si */
    case 3061:  /* pred_single_widen_subsvnx8si */
    case 3062:  /* pred_single_widen_adduvnx8si */
    case 3063:  /* pred_single_widen_subuvnx8si */
    case 3064:  /* pred_single_widen_addsvnx16si */
    case 3065:  /* pred_single_widen_subsvnx16si */
    case 3066:  /* pred_single_widen_adduvnx16si */
    case 3067:  /* pred_single_widen_subuvnx16si */
    case 3068:  /* pred_single_widen_addsvnx1di */
    case 3069:  /* pred_single_widen_subsvnx1di */
    case 3070:  /* pred_single_widen_adduvnx1di */
    case 3071:  /* pred_single_widen_subuvnx1di */
    case 3072:  /* pred_single_widen_addsvnx2di */
    case 3073:  /* pred_single_widen_subsvnx2di */
    case 3074:  /* pred_single_widen_adduvnx2di */
    case 3075:  /* pred_single_widen_subuvnx2di */
    case 3076:  /* pred_single_widen_addsvnx4di */
    case 3077:  /* pred_single_widen_subsvnx4di */
    case 3078:  /* pred_single_widen_adduvnx4di */
    case 3079:  /* pred_single_widen_subuvnx4di */
    case 3080:  /* pred_single_widen_addsvnx8di */
    case 3081:  /* pred_single_widen_subsvnx8di */
    case 3082:  /* pred_single_widen_adduvnx8di */
    case 3083:  /* pred_single_widen_subuvnx8di */
    case 3084:  /* pred_single_widen_addsvnx1hi_scalar */
    case 3085:  /* pred_single_widen_subsvnx1hi_scalar */
    case 3086:  /* pred_single_widen_adduvnx1hi_scalar */
    case 3087:  /* pred_single_widen_subuvnx1hi_scalar */
    case 3088:  /* pred_single_widen_addsvnx2hi_scalar */
    case 3089:  /* pred_single_widen_subsvnx2hi_scalar */
    case 3090:  /* pred_single_widen_adduvnx2hi_scalar */
    case 3091:  /* pred_single_widen_subuvnx2hi_scalar */
    case 3092:  /* pred_single_widen_addsvnx4hi_scalar */
    case 3093:  /* pred_single_widen_subsvnx4hi_scalar */
    case 3094:  /* pred_single_widen_adduvnx4hi_scalar */
    case 3095:  /* pred_single_widen_subuvnx4hi_scalar */
    case 3096:  /* pred_single_widen_addsvnx8hi_scalar */
    case 3097:  /* pred_single_widen_subsvnx8hi_scalar */
    case 3098:  /* pred_single_widen_adduvnx8hi_scalar */
    case 3099:  /* pred_single_widen_subuvnx8hi_scalar */
    case 3100:  /* pred_single_widen_addsvnx16hi_scalar */
    case 3101:  /* pred_single_widen_subsvnx16hi_scalar */
    case 3102:  /* pred_single_widen_adduvnx16hi_scalar */
    case 3103:  /* pred_single_widen_subuvnx16hi_scalar */
    case 3104:  /* pred_single_widen_addsvnx32hi_scalar */
    case 3105:  /* pred_single_widen_subsvnx32hi_scalar */
    case 3106:  /* pred_single_widen_adduvnx32hi_scalar */
    case 3107:  /* pred_single_widen_subuvnx32hi_scalar */
    case 3108:  /* pred_single_widen_addsvnx1si_scalar */
    case 3109:  /* pred_single_widen_subsvnx1si_scalar */
    case 3110:  /* pred_single_widen_adduvnx1si_scalar */
    case 3111:  /* pred_single_widen_subuvnx1si_scalar */
    case 3112:  /* pred_single_widen_addsvnx2si_scalar */
    case 3113:  /* pred_single_widen_subsvnx2si_scalar */
    case 3114:  /* pred_single_widen_adduvnx2si_scalar */
    case 3115:  /* pred_single_widen_subuvnx2si_scalar */
    case 3116:  /* pred_single_widen_addsvnx4si_scalar */
    case 3117:  /* pred_single_widen_subsvnx4si_scalar */
    case 3118:  /* pred_single_widen_adduvnx4si_scalar */
    case 3119:  /* pred_single_widen_subuvnx4si_scalar */
    case 3120:  /* pred_single_widen_addsvnx8si_scalar */
    case 3121:  /* pred_single_widen_subsvnx8si_scalar */
    case 3122:  /* pred_single_widen_adduvnx8si_scalar */
    case 3123:  /* pred_single_widen_subuvnx8si_scalar */
    case 3124:  /* pred_single_widen_addsvnx16si_scalar */
    case 3125:  /* pred_single_widen_subsvnx16si_scalar */
    case 3126:  /* pred_single_widen_adduvnx16si_scalar */
    case 3127:  /* pred_single_widen_subuvnx16si_scalar */
    case 3128:  /* pred_single_widen_addsvnx1di_scalar */
    case 3129:  /* pred_single_widen_subsvnx1di_scalar */
    case 3130:  /* pred_single_widen_adduvnx1di_scalar */
    case 3131:  /* pred_single_widen_subuvnx1di_scalar */
    case 3132:  /* pred_single_widen_addsvnx2di_scalar */
    case 3133:  /* pred_single_widen_subsvnx2di_scalar */
    case 3134:  /* pred_single_widen_adduvnx2di_scalar */
    case 3135:  /* pred_single_widen_subuvnx2di_scalar */
    case 3136:  /* pred_single_widen_addsvnx4di_scalar */
    case 3137:  /* pred_single_widen_subsvnx4di_scalar */
    case 3138:  /* pred_single_widen_adduvnx4di_scalar */
    case 3139:  /* pred_single_widen_subuvnx4di_scalar */
    case 3140:  /* pred_single_widen_addsvnx8di_scalar */
    case 3141:  /* pred_single_widen_subsvnx8di_scalar */
    case 3142:  /* pred_single_widen_adduvnx8di_scalar */
    case 3143:  /* pred_single_widen_subuvnx8di_scalar */
    case 3174:  /* pred_extendvnx1hi */
    case 3175:  /* pred_zero_extendvnx1hi */
    case 3176:  /* pred_extendvnx2hi */
    case 3177:  /* pred_zero_extendvnx2hi */
    case 3178:  /* pred_extendvnx4hi */
    case 3179:  /* pred_zero_extendvnx4hi */
    case 3180:  /* pred_extendvnx8hi */
    case 3181:  /* pred_zero_extendvnx8hi */
    case 3182:  /* pred_extendvnx16hi */
    case 3183:  /* pred_zero_extendvnx16hi */
    case 3184:  /* pred_extendvnx32hi */
    case 3185:  /* pred_zero_extendvnx32hi */
    case 3186:  /* pred_extendvnx1si */
    case 3187:  /* pred_zero_extendvnx1si */
    case 3188:  /* pred_extendvnx2si */
    case 3189:  /* pred_zero_extendvnx2si */
    case 3190:  /* pred_extendvnx4si */
    case 3191:  /* pred_zero_extendvnx4si */
    case 3192:  /* pred_extendvnx8si */
    case 3193:  /* pred_zero_extendvnx8si */
    case 3194:  /* pred_extendvnx16si */
    case 3195:  /* pred_zero_extendvnx16si */
    case 3196:  /* pred_extendvnx1di */
    case 3197:  /* pred_zero_extendvnx1di */
    case 3198:  /* pred_extendvnx2di */
    case 3199:  /* pred_zero_extendvnx2di */
    case 3200:  /* pred_extendvnx4di */
    case 3201:  /* pred_zero_extendvnx4di */
    case 3202:  /* pred_extendvnx8di */
    case 3203:  /* pred_zero_extendvnx8di */
      return TYPE_VIWALU;

    case 6037:  /* pred_fault_loadvnx1qi */
    case 6038:  /* pred_fault_loadvnx2qi */
    case 6039:  /* pred_fault_loadvnx4qi */
    case 6040:  /* pred_fault_loadvnx8qi */
    case 6041:  /* pred_fault_loadvnx16qi */
    case 6042:  /* pred_fault_loadvnx32qi */
    case 6043:  /* pred_fault_loadvnx64qi */
    case 6044:  /* pred_fault_loadvnx1hi */
    case 6045:  /* pred_fault_loadvnx2hi */
    case 6046:  /* pred_fault_loadvnx4hi */
    case 6047:  /* pred_fault_loadvnx8hi */
    case 6048:  /* pred_fault_loadvnx16hi */
    case 6049:  /* pred_fault_loadvnx32hi */
    case 6050:  /* pred_fault_loadvnx1si */
    case 6051:  /* pred_fault_loadvnx2si */
    case 6052:  /* pred_fault_loadvnx4si */
    case 6053:  /* pred_fault_loadvnx8si */
    case 6054:  /* pred_fault_loadvnx16si */
    case 6055:  /* pred_fault_loadvnx1di */
    case 6056:  /* pred_fault_loadvnx2di */
    case 6057:  /* pred_fault_loadvnx4di */
    case 6058:  /* pred_fault_loadvnx8di */
    case 6059:  /* pred_fault_loadvnx1sf */
    case 6060:  /* pred_fault_loadvnx2sf */
    case 6061:  /* pred_fault_loadvnx4sf */
    case 6062:  /* pred_fault_loadvnx8sf */
    case 6063:  /* pred_fault_loadvnx16sf */
    case 6064:  /* pred_fault_loadvnx1df */
    case 6065:  /* pred_fault_loadvnx2df */
    case 6066:  /* pred_fault_loadvnx4df */
    case 6067:  /* pred_fault_loadvnx8df */
      return TYPE_VLDFF;

    case 1256:  /* pred_indexed_ostorevnx1qivnx1qi */
    case 1258:  /* pred_indexed_ostorevnx1qivnx1hi */
    case 1260:  /* pred_indexed_ostorevnx1qivnx1si */
    case 1262:  /* pred_indexed_ostorevnx1qivnx1di */
    case 1264:  /* pred_indexed_ostorevnx1hivnx1qi */
    case 1266:  /* pred_indexed_ostorevnx1hivnx1hi */
    case 1268:  /* pred_indexed_ostorevnx1hivnx1si */
    case 1270:  /* pred_indexed_ostorevnx1hivnx1di */
    case 1272:  /* pred_indexed_ostorevnx1sivnx1qi */
    case 1274:  /* pred_indexed_ostorevnx1sivnx1hi */
    case 1276:  /* pred_indexed_ostorevnx1sivnx1si */
    case 1278:  /* pred_indexed_ostorevnx1sivnx1di */
    case 1280:  /* pred_indexed_ostorevnx1divnx1qi */
    case 1282:  /* pred_indexed_ostorevnx1divnx1hi */
    case 1284:  /* pred_indexed_ostorevnx1divnx1si */
    case 1286:  /* pred_indexed_ostorevnx1divnx1di */
    case 1288:  /* pred_indexed_ostorevnx1sfvnx1qi */
    case 1290:  /* pred_indexed_ostorevnx1sfvnx1hi */
    case 1292:  /* pred_indexed_ostorevnx1sfvnx1si */
    case 1294:  /* pred_indexed_ostorevnx1sfvnx1di */
    case 1296:  /* pred_indexed_ostorevnx1dfvnx1qi */
    case 1298:  /* pred_indexed_ostorevnx1dfvnx1hi */
    case 1300:  /* pred_indexed_ostorevnx1dfvnx1si */
    case 1302:  /* pred_indexed_ostorevnx1dfvnx1di */
    case 1304:  /* pred_indexed_ostorevnx2qivnx2qi */
    case 1306:  /* pred_indexed_ostorevnx2hivnx2qi */
    case 1308:  /* pred_indexed_ostorevnx2sivnx2qi */
    case 1310:  /* pred_indexed_ostorevnx2divnx2qi */
    case 1312:  /* pred_indexed_ostorevnx2sfvnx2qi */
    case 1314:  /* pred_indexed_ostorevnx2dfvnx2qi */
    case 1316:  /* pred_indexed_ostorevnx2qivnx2hi */
    case 1318:  /* pred_indexed_ostorevnx2hivnx2hi */
    case 1320:  /* pred_indexed_ostorevnx2sivnx2hi */
    case 1322:  /* pred_indexed_ostorevnx2divnx2hi */
    case 1324:  /* pred_indexed_ostorevnx2sfvnx2hi */
    case 1326:  /* pred_indexed_ostorevnx2dfvnx2hi */
    case 1328:  /* pred_indexed_ostorevnx2qivnx2si */
    case 1330:  /* pred_indexed_ostorevnx2hivnx2si */
    case 1332:  /* pred_indexed_ostorevnx2sivnx2si */
    case 1334:  /* pred_indexed_ostorevnx2divnx2si */
    case 1336:  /* pred_indexed_ostorevnx2sfvnx2si */
    case 1338:  /* pred_indexed_ostorevnx2dfvnx2si */
    case 1340:  /* pred_indexed_ostorevnx2qivnx2di */
    case 1342:  /* pred_indexed_ostorevnx2hivnx2di */
    case 1344:  /* pred_indexed_ostorevnx2sivnx2di */
    case 1346:  /* pred_indexed_ostorevnx2divnx2di */
    case 1348:  /* pred_indexed_ostorevnx2sfvnx2di */
    case 1350:  /* pred_indexed_ostorevnx2dfvnx2di */
    case 1352:  /* pred_indexed_ostorevnx4qivnx4qi */
    case 1354:  /* pred_indexed_ostorevnx4hivnx4qi */
    case 1356:  /* pred_indexed_ostorevnx4sivnx4qi */
    case 1358:  /* pred_indexed_ostorevnx4divnx4qi */
    case 1360:  /* pred_indexed_ostorevnx4sfvnx4qi */
    case 1362:  /* pred_indexed_ostorevnx4dfvnx4qi */
    case 1364:  /* pred_indexed_ostorevnx4qivnx4hi */
    case 1366:  /* pred_indexed_ostorevnx4hivnx4hi */
    case 1368:  /* pred_indexed_ostorevnx4sivnx4hi */
    case 1370:  /* pred_indexed_ostorevnx4divnx4hi */
    case 1372:  /* pred_indexed_ostorevnx4sfvnx4hi */
    case 1374:  /* pred_indexed_ostorevnx4dfvnx4hi */
    case 1376:  /* pred_indexed_ostorevnx4qivnx4si */
    case 1378:  /* pred_indexed_ostorevnx4hivnx4si */
    case 1380:  /* pred_indexed_ostorevnx4sivnx4si */
    case 1382:  /* pred_indexed_ostorevnx4divnx4si */
    case 1384:  /* pred_indexed_ostorevnx4sfvnx4si */
    case 1386:  /* pred_indexed_ostorevnx4dfvnx4si */
    case 1388:  /* pred_indexed_ostorevnx4qivnx4di */
    case 1390:  /* pred_indexed_ostorevnx4hivnx4di */
    case 1392:  /* pred_indexed_ostorevnx4sivnx4di */
    case 1394:  /* pred_indexed_ostorevnx4divnx4di */
    case 1396:  /* pred_indexed_ostorevnx4sfvnx4di */
    case 1398:  /* pred_indexed_ostorevnx4dfvnx4di */
    case 1400:  /* pred_indexed_ostorevnx8qivnx8qi */
    case 1402:  /* pred_indexed_ostorevnx8hivnx8qi */
    case 1404:  /* pred_indexed_ostorevnx8sivnx8qi */
    case 1406:  /* pred_indexed_ostorevnx8divnx8qi */
    case 1408:  /* pred_indexed_ostorevnx8sfvnx8qi */
    case 1410:  /* pred_indexed_ostorevnx8dfvnx8qi */
    case 1412:  /* pred_indexed_ostorevnx8qivnx8hi */
    case 1414:  /* pred_indexed_ostorevnx8hivnx8hi */
    case 1416:  /* pred_indexed_ostorevnx8sivnx8hi */
    case 1418:  /* pred_indexed_ostorevnx8divnx8hi */
    case 1420:  /* pred_indexed_ostorevnx8sfvnx8hi */
    case 1422:  /* pred_indexed_ostorevnx8dfvnx8hi */
    case 1424:  /* pred_indexed_ostorevnx8qivnx8si */
    case 1426:  /* pred_indexed_ostorevnx8hivnx8si */
    case 1428:  /* pred_indexed_ostorevnx8sivnx8si */
    case 1430:  /* pred_indexed_ostorevnx8divnx8si */
    case 1432:  /* pred_indexed_ostorevnx8sfvnx8si */
    case 1434:  /* pred_indexed_ostorevnx8dfvnx8si */
    case 1436:  /* pred_indexed_ostorevnx8qivnx8di */
    case 1438:  /* pred_indexed_ostorevnx8hivnx8di */
    case 1440:  /* pred_indexed_ostorevnx8sivnx8di */
    case 1442:  /* pred_indexed_ostorevnx8divnx8di */
    case 1444:  /* pred_indexed_ostorevnx8sfvnx8di */
    case 1446:  /* pred_indexed_ostorevnx8dfvnx8di */
    case 1448:  /* pred_indexed_ostorevnx16qivnx16qi */
    case 1450:  /* pred_indexed_ostorevnx16hivnx16qi */
    case 1452:  /* pred_indexed_ostorevnx16sivnx16qi */
    case 1454:  /* pred_indexed_ostorevnx16sfvnx16qi */
    case 1456:  /* pred_indexed_ostorevnx16qivnx16hi */
    case 1458:  /* pred_indexed_ostorevnx16hivnx16hi */
    case 1460:  /* pred_indexed_ostorevnx16sivnx16hi */
    case 1462:  /* pred_indexed_ostorevnx16sfvnx16hi */
    case 1464:  /* pred_indexed_ostorevnx16qivnx16si */
    case 1466:  /* pred_indexed_ostorevnx16hivnx16si */
    case 1468:  /* pred_indexed_ostorevnx16sivnx16si */
    case 1470:  /* pred_indexed_ostorevnx16sfvnx16si */
    case 1472:  /* pred_indexed_ostorevnx32qivnx32qi */
    case 1474:  /* pred_indexed_ostorevnx32qivnx32hi */
    case 1476:  /* pred_indexed_ostorevnx32hivnx32qi */
    case 1478:  /* pred_indexed_ostorevnx32hivnx32hi */
    case 1480:  /* pred_indexed_ostorevnx64qivnx64qi */
      return TYPE_VSTOX;

    case 1257:  /* pred_indexed_ustorevnx1qivnx1qi */
    case 1259:  /* pred_indexed_ustorevnx1qivnx1hi */
    case 1261:  /* pred_indexed_ustorevnx1qivnx1si */
    case 1263:  /* pred_indexed_ustorevnx1qivnx1di */
    case 1265:  /* pred_indexed_ustorevnx1hivnx1qi */
    case 1267:  /* pred_indexed_ustorevnx1hivnx1hi */
    case 1269:  /* pred_indexed_ustorevnx1hivnx1si */
    case 1271:  /* pred_indexed_ustorevnx1hivnx1di */
    case 1273:  /* pred_indexed_ustorevnx1sivnx1qi */
    case 1275:  /* pred_indexed_ustorevnx1sivnx1hi */
    case 1277:  /* pred_indexed_ustorevnx1sivnx1si */
    case 1279:  /* pred_indexed_ustorevnx1sivnx1di */
    case 1281:  /* pred_indexed_ustorevnx1divnx1qi */
    case 1283:  /* pred_indexed_ustorevnx1divnx1hi */
    case 1285:  /* pred_indexed_ustorevnx1divnx1si */
    case 1287:  /* pred_indexed_ustorevnx1divnx1di */
    case 1289:  /* pred_indexed_ustorevnx1sfvnx1qi */
    case 1291:  /* pred_indexed_ustorevnx1sfvnx1hi */
    case 1293:  /* pred_indexed_ustorevnx1sfvnx1si */
    case 1295:  /* pred_indexed_ustorevnx1sfvnx1di */
    case 1297:  /* pred_indexed_ustorevnx1dfvnx1qi */
    case 1299:  /* pred_indexed_ustorevnx1dfvnx1hi */
    case 1301:  /* pred_indexed_ustorevnx1dfvnx1si */
    case 1303:  /* pred_indexed_ustorevnx1dfvnx1di */
    case 1305:  /* pred_indexed_ustorevnx2qivnx2qi */
    case 1307:  /* pred_indexed_ustorevnx2hivnx2qi */
    case 1309:  /* pred_indexed_ustorevnx2sivnx2qi */
    case 1311:  /* pred_indexed_ustorevnx2divnx2qi */
    case 1313:  /* pred_indexed_ustorevnx2sfvnx2qi */
    case 1315:  /* pred_indexed_ustorevnx2dfvnx2qi */
    case 1317:  /* pred_indexed_ustorevnx2qivnx2hi */
    case 1319:  /* pred_indexed_ustorevnx2hivnx2hi */
    case 1321:  /* pred_indexed_ustorevnx2sivnx2hi */
    case 1323:  /* pred_indexed_ustorevnx2divnx2hi */
    case 1325:  /* pred_indexed_ustorevnx2sfvnx2hi */
    case 1327:  /* pred_indexed_ustorevnx2dfvnx2hi */
    case 1329:  /* pred_indexed_ustorevnx2qivnx2si */
    case 1331:  /* pred_indexed_ustorevnx2hivnx2si */
    case 1333:  /* pred_indexed_ustorevnx2sivnx2si */
    case 1335:  /* pred_indexed_ustorevnx2divnx2si */
    case 1337:  /* pred_indexed_ustorevnx2sfvnx2si */
    case 1339:  /* pred_indexed_ustorevnx2dfvnx2si */
    case 1341:  /* pred_indexed_ustorevnx2qivnx2di */
    case 1343:  /* pred_indexed_ustorevnx2hivnx2di */
    case 1345:  /* pred_indexed_ustorevnx2sivnx2di */
    case 1347:  /* pred_indexed_ustorevnx2divnx2di */
    case 1349:  /* pred_indexed_ustorevnx2sfvnx2di */
    case 1351:  /* pred_indexed_ustorevnx2dfvnx2di */
    case 1353:  /* pred_indexed_ustorevnx4qivnx4qi */
    case 1355:  /* pred_indexed_ustorevnx4hivnx4qi */
    case 1357:  /* pred_indexed_ustorevnx4sivnx4qi */
    case 1359:  /* pred_indexed_ustorevnx4divnx4qi */
    case 1361:  /* pred_indexed_ustorevnx4sfvnx4qi */
    case 1363:  /* pred_indexed_ustorevnx4dfvnx4qi */
    case 1365:  /* pred_indexed_ustorevnx4qivnx4hi */
    case 1367:  /* pred_indexed_ustorevnx4hivnx4hi */
    case 1369:  /* pred_indexed_ustorevnx4sivnx4hi */
    case 1371:  /* pred_indexed_ustorevnx4divnx4hi */
    case 1373:  /* pred_indexed_ustorevnx4sfvnx4hi */
    case 1375:  /* pred_indexed_ustorevnx4dfvnx4hi */
    case 1377:  /* pred_indexed_ustorevnx4qivnx4si */
    case 1379:  /* pred_indexed_ustorevnx4hivnx4si */
    case 1381:  /* pred_indexed_ustorevnx4sivnx4si */
    case 1383:  /* pred_indexed_ustorevnx4divnx4si */
    case 1385:  /* pred_indexed_ustorevnx4sfvnx4si */
    case 1387:  /* pred_indexed_ustorevnx4dfvnx4si */
    case 1389:  /* pred_indexed_ustorevnx4qivnx4di */
    case 1391:  /* pred_indexed_ustorevnx4hivnx4di */
    case 1393:  /* pred_indexed_ustorevnx4sivnx4di */
    case 1395:  /* pred_indexed_ustorevnx4divnx4di */
    case 1397:  /* pred_indexed_ustorevnx4sfvnx4di */
    case 1399:  /* pred_indexed_ustorevnx4dfvnx4di */
    case 1401:  /* pred_indexed_ustorevnx8qivnx8qi */
    case 1403:  /* pred_indexed_ustorevnx8hivnx8qi */
    case 1405:  /* pred_indexed_ustorevnx8sivnx8qi */
    case 1407:  /* pred_indexed_ustorevnx8divnx8qi */
    case 1409:  /* pred_indexed_ustorevnx8sfvnx8qi */
    case 1411:  /* pred_indexed_ustorevnx8dfvnx8qi */
    case 1413:  /* pred_indexed_ustorevnx8qivnx8hi */
    case 1415:  /* pred_indexed_ustorevnx8hivnx8hi */
    case 1417:  /* pred_indexed_ustorevnx8sivnx8hi */
    case 1419:  /* pred_indexed_ustorevnx8divnx8hi */
    case 1421:  /* pred_indexed_ustorevnx8sfvnx8hi */
    case 1423:  /* pred_indexed_ustorevnx8dfvnx8hi */
    case 1425:  /* pred_indexed_ustorevnx8qivnx8si */
    case 1427:  /* pred_indexed_ustorevnx8hivnx8si */
    case 1429:  /* pred_indexed_ustorevnx8sivnx8si */
    case 1431:  /* pred_indexed_ustorevnx8divnx8si */
    case 1433:  /* pred_indexed_ustorevnx8sfvnx8si */
    case 1435:  /* pred_indexed_ustorevnx8dfvnx8si */
    case 1437:  /* pred_indexed_ustorevnx8qivnx8di */
    case 1439:  /* pred_indexed_ustorevnx8hivnx8di */
    case 1441:  /* pred_indexed_ustorevnx8sivnx8di */
    case 1443:  /* pred_indexed_ustorevnx8divnx8di */
    case 1445:  /* pred_indexed_ustorevnx8sfvnx8di */
    case 1447:  /* pred_indexed_ustorevnx8dfvnx8di */
    case 1449:  /* pred_indexed_ustorevnx16qivnx16qi */
    case 1451:  /* pred_indexed_ustorevnx16hivnx16qi */
    case 1453:  /* pred_indexed_ustorevnx16sivnx16qi */
    case 1455:  /* pred_indexed_ustorevnx16sfvnx16qi */
    case 1457:  /* pred_indexed_ustorevnx16qivnx16hi */
    case 1459:  /* pred_indexed_ustorevnx16hivnx16hi */
    case 1461:  /* pred_indexed_ustorevnx16sivnx16hi */
    case 1463:  /* pred_indexed_ustorevnx16sfvnx16hi */
    case 1465:  /* pred_indexed_ustorevnx16qivnx16si */
    case 1467:  /* pred_indexed_ustorevnx16hivnx16si */
    case 1469:  /* pred_indexed_ustorevnx16sivnx16si */
    case 1471:  /* pred_indexed_ustorevnx16sfvnx16si */
    case 1473:  /* pred_indexed_ustorevnx32qivnx32qi */
    case 1475:  /* pred_indexed_ustorevnx32qivnx32hi */
    case 1477:  /* pred_indexed_ustorevnx32hivnx32qi */
    case 1479:  /* pred_indexed_ustorevnx32hivnx32hi */
    case 1481:  /* pred_indexed_ustorevnx64qivnx64qi */
      return TYPE_VSTUX;

    case 1030:  /* pred_indexed_oloadvnx1qi_same_eew */
    case 1032:  /* pred_indexed_oloadvnx2qi_same_eew */
    case 1034:  /* pred_indexed_oloadvnx4qi_same_eew */
    case 1036:  /* pred_indexed_oloadvnx8qi_same_eew */
    case 1038:  /* pred_indexed_oloadvnx16qi_same_eew */
    case 1040:  /* pred_indexed_oloadvnx32qi_same_eew */
    case 1042:  /* pred_indexed_oloadvnx64qi_same_eew */
    case 1044:  /* pred_indexed_oloadvnx1hi_same_eew */
    case 1046:  /* pred_indexed_oloadvnx2hi_same_eew */
    case 1048:  /* pred_indexed_oloadvnx4hi_same_eew */
    case 1050:  /* pred_indexed_oloadvnx8hi_same_eew */
    case 1052:  /* pred_indexed_oloadvnx16hi_same_eew */
    case 1054:  /* pred_indexed_oloadvnx32hi_same_eew */
    case 1056:  /* pred_indexed_oloadvnx1si_same_eew */
    case 1058:  /* pred_indexed_oloadvnx2si_same_eew */
    case 1060:  /* pred_indexed_oloadvnx4si_same_eew */
    case 1062:  /* pred_indexed_oloadvnx8si_same_eew */
    case 1064:  /* pred_indexed_oloadvnx16si_same_eew */
    case 1066:  /* pred_indexed_oloadvnx1di_same_eew */
    case 1068:  /* pred_indexed_oloadvnx2di_same_eew */
    case 1070:  /* pred_indexed_oloadvnx4di_same_eew */
    case 1072:  /* pred_indexed_oloadvnx8di_same_eew */
    case 1074:  /* pred_indexed_oloadvnx1sf_same_eew */
    case 1076:  /* pred_indexed_oloadvnx2sf_same_eew */
    case 1078:  /* pred_indexed_oloadvnx4sf_same_eew */
    case 1080:  /* pred_indexed_oloadvnx8sf_same_eew */
    case 1082:  /* pred_indexed_oloadvnx16sf_same_eew */
    case 1084:  /* pred_indexed_oloadvnx1df_same_eew */
    case 1086:  /* pred_indexed_oloadvnx2df_same_eew */
    case 1088:  /* pred_indexed_oloadvnx4df_same_eew */
    case 1090:  /* pred_indexed_oloadvnx8df_same_eew */
    case 1092:  /* pred_indexed_oloadvnx1hi_x2_greater_eew */
    case 1094:  /* pred_indexed_oloadvnx2hi_x2_greater_eew */
    case 1096:  /* pred_indexed_oloadvnx4hi_x2_greater_eew */
    case 1098:  /* pred_indexed_oloadvnx8hi_x2_greater_eew */
    case 1100:  /* pred_indexed_oloadvnx16hi_x2_greater_eew */
    case 1102:  /* pred_indexed_oloadvnx32hi_x2_greater_eew */
    case 1104:  /* pred_indexed_oloadvnx1si_x2_greater_eew */
    case 1106:  /* pred_indexed_oloadvnx2si_x2_greater_eew */
    case 1108:  /* pred_indexed_oloadvnx4si_x2_greater_eew */
    case 1110:  /* pred_indexed_oloadvnx8si_x2_greater_eew */
    case 1112:  /* pred_indexed_oloadvnx16si_x2_greater_eew */
    case 1114:  /* pred_indexed_oloadvnx1di_x2_greater_eew */
    case 1116:  /* pred_indexed_oloadvnx2di_x2_greater_eew */
    case 1118:  /* pred_indexed_oloadvnx4di_x2_greater_eew */
    case 1120:  /* pred_indexed_oloadvnx8di_x2_greater_eew */
    case 1122:  /* pred_indexed_oloadvnx1sf_x2_greater_eew */
    case 1124:  /* pred_indexed_oloadvnx2sf_x2_greater_eew */
    case 1126:  /* pred_indexed_oloadvnx4sf_x2_greater_eew */
    case 1128:  /* pred_indexed_oloadvnx8sf_x2_greater_eew */
    case 1130:  /* pred_indexed_oloadvnx16sf_x2_greater_eew */
    case 1132:  /* pred_indexed_oloadvnx1df_x2_greater_eew */
    case 1134:  /* pred_indexed_oloadvnx2df_x2_greater_eew */
    case 1136:  /* pred_indexed_oloadvnx4df_x2_greater_eew */
    case 1138:  /* pred_indexed_oloadvnx8df_x2_greater_eew */
    case 1140:  /* pred_indexed_oloadvnx1si_x4_greater_eew */
    case 1142:  /* pred_indexed_oloadvnx2si_x4_greater_eew */
    case 1144:  /* pred_indexed_oloadvnx4si_x4_greater_eew */
    case 1146:  /* pred_indexed_oloadvnx8si_x4_greater_eew */
    case 1148:  /* pred_indexed_oloadvnx16si_x4_greater_eew */
    case 1150:  /* pred_indexed_oloadvnx1di_x4_greater_eew */
    case 1152:  /* pred_indexed_oloadvnx2di_x4_greater_eew */
    case 1154:  /* pred_indexed_oloadvnx4di_x4_greater_eew */
    case 1156:  /* pred_indexed_oloadvnx8di_x4_greater_eew */
    case 1158:  /* pred_indexed_oloadvnx1sf_x4_greater_eew */
    case 1160:  /* pred_indexed_oloadvnx2sf_x4_greater_eew */
    case 1162:  /* pred_indexed_oloadvnx4sf_x4_greater_eew */
    case 1164:  /* pred_indexed_oloadvnx8sf_x4_greater_eew */
    case 1166:  /* pred_indexed_oloadvnx16sf_x4_greater_eew */
    case 1168:  /* pred_indexed_oloadvnx1df_x4_greater_eew */
    case 1170:  /* pred_indexed_oloadvnx2df_x4_greater_eew */
    case 1172:  /* pred_indexed_oloadvnx4df_x4_greater_eew */
    case 1174:  /* pred_indexed_oloadvnx8df_x4_greater_eew */
    case 1176:  /* pred_indexed_oloadvnx1di_x8_greater_eew */
    case 1178:  /* pred_indexed_oloadvnx2di_x8_greater_eew */
    case 1180:  /* pred_indexed_oloadvnx4di_x8_greater_eew */
    case 1182:  /* pred_indexed_oloadvnx8di_x8_greater_eew */
    case 1184:  /* pred_indexed_oloadvnx1df_x8_greater_eew */
    case 1186:  /* pred_indexed_oloadvnx2df_x8_greater_eew */
    case 1188:  /* pred_indexed_oloadvnx4df_x8_greater_eew */
    case 1190:  /* pred_indexed_oloadvnx8df_x8_greater_eew */
    case 1192:  /* pred_indexed_oloadvnx1qi_x2_smaller_eew */
    case 1194:  /* pred_indexed_oloadvnx2qi_x2_smaller_eew */
    case 1196:  /* pred_indexed_oloadvnx4qi_x2_smaller_eew */
    case 1198:  /* pred_indexed_oloadvnx8qi_x2_smaller_eew */
    case 1200:  /* pred_indexed_oloadvnx16qi_x2_smaller_eew */
    case 1202:  /* pred_indexed_oloadvnx32qi_x2_smaller_eew */
    case 1204:  /* pred_indexed_oloadvnx1hi_x2_smaller_eew */
    case 1206:  /* pred_indexed_oloadvnx2hi_x2_smaller_eew */
    case 1208:  /* pred_indexed_oloadvnx4hi_x2_smaller_eew */
    case 1210:  /* pred_indexed_oloadvnx8hi_x2_smaller_eew */
    case 1212:  /* pred_indexed_oloadvnx16hi_x2_smaller_eew */
    case 1214:  /* pred_indexed_oloadvnx1si_x2_smaller_eew */
    case 1216:  /* pred_indexed_oloadvnx2si_x2_smaller_eew */
    case 1218:  /* pred_indexed_oloadvnx4si_x2_smaller_eew */
    case 1220:  /* pred_indexed_oloadvnx8si_x2_smaller_eew */
    case 1222:  /* pred_indexed_oloadvnx1sf_x2_smaller_eew */
    case 1224:  /* pred_indexed_oloadvnx2sf_x2_smaller_eew */
    case 1226:  /* pred_indexed_oloadvnx4sf_x2_smaller_eew */
    case 1228:  /* pred_indexed_oloadvnx8sf_x2_smaller_eew */
    case 1230:  /* pred_indexed_oloadvnx1qi_x4_smaller_eew */
    case 1232:  /* pred_indexed_oloadvnx2qi_x4_smaller_eew */
    case 1234:  /* pred_indexed_oloadvnx4qi_x4_smaller_eew */
    case 1236:  /* pred_indexed_oloadvnx8qi_x4_smaller_eew */
    case 1238:  /* pred_indexed_oloadvnx16qi_x4_smaller_eew */
    case 1240:  /* pred_indexed_oloadvnx1hi_x4_smaller_eew */
    case 1242:  /* pred_indexed_oloadvnx2hi_x4_smaller_eew */
    case 1244:  /* pred_indexed_oloadvnx4hi_x4_smaller_eew */
    case 1246:  /* pred_indexed_oloadvnx8hi_x4_smaller_eew */
    case 1248:  /* pred_indexed_oloadvnx1qi_x8_smaller_eew */
    case 1250:  /* pred_indexed_oloadvnx2qi_x8_smaller_eew */
    case 1252:  /* pred_indexed_oloadvnx4qi_x8_smaller_eew */
    case 1254:  /* pred_indexed_oloadvnx8qi_x8_smaller_eew */
      return TYPE_VLDOX;

    case 1031:  /* pred_indexed_uloadvnx1qi_same_eew */
    case 1033:  /* pred_indexed_uloadvnx2qi_same_eew */
    case 1035:  /* pred_indexed_uloadvnx4qi_same_eew */
    case 1037:  /* pred_indexed_uloadvnx8qi_same_eew */
    case 1039:  /* pred_indexed_uloadvnx16qi_same_eew */
    case 1041:  /* pred_indexed_uloadvnx32qi_same_eew */
    case 1043:  /* pred_indexed_uloadvnx64qi_same_eew */
    case 1045:  /* pred_indexed_uloadvnx1hi_same_eew */
    case 1047:  /* pred_indexed_uloadvnx2hi_same_eew */
    case 1049:  /* pred_indexed_uloadvnx4hi_same_eew */
    case 1051:  /* pred_indexed_uloadvnx8hi_same_eew */
    case 1053:  /* pred_indexed_uloadvnx16hi_same_eew */
    case 1055:  /* pred_indexed_uloadvnx32hi_same_eew */
    case 1057:  /* pred_indexed_uloadvnx1si_same_eew */
    case 1059:  /* pred_indexed_uloadvnx2si_same_eew */
    case 1061:  /* pred_indexed_uloadvnx4si_same_eew */
    case 1063:  /* pred_indexed_uloadvnx8si_same_eew */
    case 1065:  /* pred_indexed_uloadvnx16si_same_eew */
    case 1067:  /* pred_indexed_uloadvnx1di_same_eew */
    case 1069:  /* pred_indexed_uloadvnx2di_same_eew */
    case 1071:  /* pred_indexed_uloadvnx4di_same_eew */
    case 1073:  /* pred_indexed_uloadvnx8di_same_eew */
    case 1075:  /* pred_indexed_uloadvnx1sf_same_eew */
    case 1077:  /* pred_indexed_uloadvnx2sf_same_eew */
    case 1079:  /* pred_indexed_uloadvnx4sf_same_eew */
    case 1081:  /* pred_indexed_uloadvnx8sf_same_eew */
    case 1083:  /* pred_indexed_uloadvnx16sf_same_eew */
    case 1085:  /* pred_indexed_uloadvnx1df_same_eew */
    case 1087:  /* pred_indexed_uloadvnx2df_same_eew */
    case 1089:  /* pred_indexed_uloadvnx4df_same_eew */
    case 1091:  /* pred_indexed_uloadvnx8df_same_eew */
    case 1093:  /* pred_indexed_uloadvnx1hi_x2_greater_eew */
    case 1095:  /* pred_indexed_uloadvnx2hi_x2_greater_eew */
    case 1097:  /* pred_indexed_uloadvnx4hi_x2_greater_eew */
    case 1099:  /* pred_indexed_uloadvnx8hi_x2_greater_eew */
    case 1101:  /* pred_indexed_uloadvnx16hi_x2_greater_eew */
    case 1103:  /* pred_indexed_uloadvnx32hi_x2_greater_eew */
    case 1105:  /* pred_indexed_uloadvnx1si_x2_greater_eew */
    case 1107:  /* pred_indexed_uloadvnx2si_x2_greater_eew */
    case 1109:  /* pred_indexed_uloadvnx4si_x2_greater_eew */
    case 1111:  /* pred_indexed_uloadvnx8si_x2_greater_eew */
    case 1113:  /* pred_indexed_uloadvnx16si_x2_greater_eew */
    case 1115:  /* pred_indexed_uloadvnx1di_x2_greater_eew */
    case 1117:  /* pred_indexed_uloadvnx2di_x2_greater_eew */
    case 1119:  /* pred_indexed_uloadvnx4di_x2_greater_eew */
    case 1121:  /* pred_indexed_uloadvnx8di_x2_greater_eew */
    case 1123:  /* pred_indexed_uloadvnx1sf_x2_greater_eew */
    case 1125:  /* pred_indexed_uloadvnx2sf_x2_greater_eew */
    case 1127:  /* pred_indexed_uloadvnx4sf_x2_greater_eew */
    case 1129:  /* pred_indexed_uloadvnx8sf_x2_greater_eew */
    case 1131:  /* pred_indexed_uloadvnx16sf_x2_greater_eew */
    case 1133:  /* pred_indexed_uloadvnx1df_x2_greater_eew */
    case 1135:  /* pred_indexed_uloadvnx2df_x2_greater_eew */
    case 1137:  /* pred_indexed_uloadvnx4df_x2_greater_eew */
    case 1139:  /* pred_indexed_uloadvnx8df_x2_greater_eew */
    case 1141:  /* pred_indexed_uloadvnx1si_x4_greater_eew */
    case 1143:  /* pred_indexed_uloadvnx2si_x4_greater_eew */
    case 1145:  /* pred_indexed_uloadvnx4si_x4_greater_eew */
    case 1147:  /* pred_indexed_uloadvnx8si_x4_greater_eew */
    case 1149:  /* pred_indexed_uloadvnx16si_x4_greater_eew */
    case 1151:  /* pred_indexed_uloadvnx1di_x4_greater_eew */
    case 1153:  /* pred_indexed_uloadvnx2di_x4_greater_eew */
    case 1155:  /* pred_indexed_uloadvnx4di_x4_greater_eew */
    case 1157:  /* pred_indexed_uloadvnx8di_x4_greater_eew */
    case 1159:  /* pred_indexed_uloadvnx1sf_x4_greater_eew */
    case 1161:  /* pred_indexed_uloadvnx2sf_x4_greater_eew */
    case 1163:  /* pred_indexed_uloadvnx4sf_x4_greater_eew */
    case 1165:  /* pred_indexed_uloadvnx8sf_x4_greater_eew */
    case 1167:  /* pred_indexed_uloadvnx16sf_x4_greater_eew */
    case 1169:  /* pred_indexed_uloadvnx1df_x4_greater_eew */
    case 1171:  /* pred_indexed_uloadvnx2df_x4_greater_eew */
    case 1173:  /* pred_indexed_uloadvnx4df_x4_greater_eew */
    case 1175:  /* pred_indexed_uloadvnx8df_x4_greater_eew */
    case 1177:  /* pred_indexed_uloadvnx1di_x8_greater_eew */
    case 1179:  /* pred_indexed_uloadvnx2di_x8_greater_eew */
    case 1181:  /* pred_indexed_uloadvnx4di_x8_greater_eew */
    case 1183:  /* pred_indexed_uloadvnx8di_x8_greater_eew */
    case 1185:  /* pred_indexed_uloadvnx1df_x8_greater_eew */
    case 1187:  /* pred_indexed_uloadvnx2df_x8_greater_eew */
    case 1189:  /* pred_indexed_uloadvnx4df_x8_greater_eew */
    case 1191:  /* pred_indexed_uloadvnx8df_x8_greater_eew */
    case 1193:  /* pred_indexed_uloadvnx1qi_x2_smaller_eew */
    case 1195:  /* pred_indexed_uloadvnx2qi_x2_smaller_eew */
    case 1197:  /* pred_indexed_uloadvnx4qi_x2_smaller_eew */
    case 1199:  /* pred_indexed_uloadvnx8qi_x2_smaller_eew */
    case 1201:  /* pred_indexed_uloadvnx16qi_x2_smaller_eew */
    case 1203:  /* pred_indexed_uloadvnx32qi_x2_smaller_eew */
    case 1205:  /* pred_indexed_uloadvnx1hi_x2_smaller_eew */
    case 1207:  /* pred_indexed_uloadvnx2hi_x2_smaller_eew */
    case 1209:  /* pred_indexed_uloadvnx4hi_x2_smaller_eew */
    case 1211:  /* pred_indexed_uloadvnx8hi_x2_smaller_eew */
    case 1213:  /* pred_indexed_uloadvnx16hi_x2_smaller_eew */
    case 1215:  /* pred_indexed_uloadvnx1si_x2_smaller_eew */
    case 1217:  /* pred_indexed_uloadvnx2si_x2_smaller_eew */
    case 1219:  /* pred_indexed_uloadvnx4si_x2_smaller_eew */
    case 1221:  /* pred_indexed_uloadvnx8si_x2_smaller_eew */
    case 1223:  /* pred_indexed_uloadvnx1sf_x2_smaller_eew */
    case 1225:  /* pred_indexed_uloadvnx2sf_x2_smaller_eew */
    case 1227:  /* pred_indexed_uloadvnx4sf_x2_smaller_eew */
    case 1229:  /* pred_indexed_uloadvnx8sf_x2_smaller_eew */
    case 1231:  /* pred_indexed_uloadvnx1qi_x4_smaller_eew */
    case 1233:  /* pred_indexed_uloadvnx2qi_x4_smaller_eew */
    case 1235:  /* pred_indexed_uloadvnx4qi_x4_smaller_eew */
    case 1237:  /* pred_indexed_uloadvnx8qi_x4_smaller_eew */
    case 1239:  /* pred_indexed_uloadvnx16qi_x4_smaller_eew */
    case 1241:  /* pred_indexed_uloadvnx1hi_x4_smaller_eew */
    case 1243:  /* pred_indexed_uloadvnx2hi_x4_smaller_eew */
    case 1245:  /* pred_indexed_uloadvnx4hi_x4_smaller_eew */
    case 1247:  /* pred_indexed_uloadvnx8hi_x4_smaller_eew */
    case 1249:  /* pred_indexed_uloadvnx1qi_x8_smaller_eew */
    case 1251:  /* pred_indexed_uloadvnx2qi_x8_smaller_eew */
    case 1253:  /* pred_indexed_uloadvnx4qi_x8_smaller_eew */
    case 1255:  /* pred_indexed_uloadvnx8qi_x8_smaller_eew */
      return TYPE_VLDUX;

    case 999:  /* pred_strided_storevnx1qi */
    case 1000:  /* pred_strided_storevnx2qi */
    case 1001:  /* pred_strided_storevnx4qi */
    case 1002:  /* pred_strided_storevnx8qi */
    case 1003:  /* pred_strided_storevnx16qi */
    case 1004:  /* pred_strided_storevnx32qi */
    case 1005:  /* pred_strided_storevnx64qi */
    case 1006:  /* pred_strided_storevnx1hi */
    case 1007:  /* pred_strided_storevnx2hi */
    case 1008:  /* pred_strided_storevnx4hi */
    case 1009:  /* pred_strided_storevnx8hi */
    case 1010:  /* pred_strided_storevnx16hi */
    case 1011:  /* pred_strided_storevnx32hi */
    case 1012:  /* pred_strided_storevnx1si */
    case 1013:  /* pred_strided_storevnx2si */
    case 1014:  /* pred_strided_storevnx4si */
    case 1015:  /* pred_strided_storevnx8si */
    case 1016:  /* pred_strided_storevnx16si */
    case 1017:  /* pred_strided_storevnx1di */
    case 1018:  /* pred_strided_storevnx2di */
    case 1019:  /* pred_strided_storevnx4di */
    case 1020:  /* pred_strided_storevnx8di */
    case 1021:  /* pred_strided_storevnx1sf */
    case 1022:  /* pred_strided_storevnx2sf */
    case 1023:  /* pred_strided_storevnx4sf */
    case 1024:  /* pred_strided_storevnx8sf */
    case 1025:  /* pred_strided_storevnx16sf */
    case 1026:  /* pred_strided_storevnx1df */
    case 1027:  /* pred_strided_storevnx2df */
    case 1028:  /* pred_strided_storevnx4df */
    case 1029:  /* pred_strided_storevnx8df */
      return TYPE_VSTS;

    case 968:  /* pred_strided_loadvnx1qi */
    case 969:  /* pred_strided_loadvnx2qi */
    case 970:  /* pred_strided_loadvnx4qi */
    case 971:  /* pred_strided_loadvnx8qi */
    case 972:  /* pred_strided_loadvnx16qi */
    case 973:  /* pred_strided_loadvnx32qi */
    case 974:  /* pred_strided_loadvnx64qi */
    case 975:  /* pred_strided_loadvnx1hi */
    case 976:  /* pred_strided_loadvnx2hi */
    case 977:  /* pred_strided_loadvnx4hi */
    case 978:  /* pred_strided_loadvnx8hi */
    case 979:  /* pred_strided_loadvnx16hi */
    case 980:  /* pred_strided_loadvnx32hi */
    case 981:  /* pred_strided_loadvnx1si */
    case 982:  /* pred_strided_loadvnx2si */
    case 983:  /* pred_strided_loadvnx4si */
    case 984:  /* pred_strided_loadvnx8si */
    case 985:  /* pred_strided_loadvnx16si */
    case 986:  /* pred_strided_loadvnx1di */
    case 987:  /* pred_strided_loadvnx2di */
    case 988:  /* pred_strided_loadvnx4di */
    case 989:  /* pred_strided_loadvnx8di */
    case 990:  /* pred_strided_loadvnx1sf */
    case 991:  /* pred_strided_loadvnx2sf */
    case 992:  /* pred_strided_loadvnx4sf */
    case 993:  /* pred_strided_loadvnx8sf */
    case 994:  /* pred_strided_loadvnx16sf */
    case 995:  /* pred_strided_loadvnx1df */
    case 996:  /* pred_strided_loadvnx2df */
    case 997:  /* pred_strided_loadvnx4df */
    case 998:  /* pred_strided_loadvnx8df */
      return TYPE_VLDS;

    case 869:  /* pred_storevnx1bi */
    case 870:  /* pred_storevnx2bi */
    case 871:  /* pred_storevnx4bi */
    case 872:  /* pred_storevnx8bi */
    case 873:  /* pred_storevnx16bi */
    case 874:  /* pred_storevnx32bi */
    case 875:  /* pred_storevnx64bi */
      return TYPE_VSTM;

    case 831:  /* pred_storevnx1qi */
    case 832:  /* pred_storevnx2qi */
    case 833:  /* pred_storevnx4qi */
    case 834:  /* pred_storevnx8qi */
    case 835:  /* pred_storevnx16qi */
    case 836:  /* pred_storevnx32qi */
    case 837:  /* pred_storevnx64qi */
    case 838:  /* pred_storevnx1hi */
    case 839:  /* pred_storevnx2hi */
    case 840:  /* pred_storevnx4hi */
    case 841:  /* pred_storevnx8hi */
    case 842:  /* pred_storevnx16hi */
    case 843:  /* pred_storevnx32hi */
    case 844:  /* pred_storevnx1si */
    case 845:  /* pred_storevnx2si */
    case 846:  /* pred_storevnx4si */
    case 847:  /* pred_storevnx8si */
    case 848:  /* pred_storevnx16si */
    case 849:  /* pred_storevnx1di */
    case 850:  /* pred_storevnx2di */
    case 851:  /* pred_storevnx4di */
    case 852:  /* pred_storevnx8di */
    case 853:  /* pred_storevnx1sf */
    case 854:  /* pred_storevnx2sf */
    case 855:  /* pred_storevnx4sf */
    case 856:  /* pred_storevnx8sf */
    case 857:  /* pred_storevnx16sf */
    case 858:  /* pred_storevnx1df */
    case 859:  /* pred_storevnx2df */
    case 860:  /* pred_storevnx4df */
    case 861:  /* pred_storevnx8df */
      return TYPE_VSTE;

    case 793:  /* vsetvlsi */
    case 794:  /* vsetvldi */
    case 795:  /* vsetvl_vtype_change_only */
    case 796:  /* vsetvl_discard_resultsi */
    case 797:  /* vsetvl_discard_resultdi */
    case 798:  /* vsetvlsi_no_side_effects */
    case 799:  /* vsetvldi_no_side_effects */
      return TYPE_VSETVL;

    case 6035:  /* read_vlsi */
    case 6036:  /* read_vldi_zero_extend */
      return TYPE_RDVL;

    case 421:  /* riscv_brev8_si */
    case 422:  /* riscv_brev8_di */
    case 423:  /* riscv_zip */
    case 424:  /* riscv_unzip */
    case 425:  /* riscv_pack_sihi */
    case 426:  /* riscv_pack_sisi */
    case 427:  /* riscv_pack_dihi */
    case 428:  /* riscv_pack_disi */
    case 429:  /* riscv_packh_si */
    case 430:  /* riscv_packh_di */
    case 431:  /* riscv_packw */
    case 432:  /* riscv_clmul_si */
    case 433:  /* riscv_clmul_di */
    case 434:  /* riscv_clmulh_si */
    case 435:  /* riscv_clmulh_di */
    case 436:  /* riscv_xperm4_si */
    case 437:  /* riscv_xperm4_di */
    case 438:  /* riscv_xperm8_si */
    case 439:  /* riscv_xperm8_di */
    case 440:  /* riscv_aes32dsi */
    case 441:  /* riscv_aes32dsmi */
    case 442:  /* riscv_aes64ds */
    case 443:  /* riscv_aes64dsm */
    case 444:  /* riscv_aes64im */
    case 445:  /* riscv_aes64ks1i */
    case 446:  /* riscv_aes64ks2 */
    case 447:  /* riscv_aes32esi */
    case 448:  /* riscv_aes32esmi */
    case 449:  /* riscv_aes64es */
    case 450:  /* riscv_aes64esm */
    case 451:  /* riscv_sha256sig0_si */
    case 452:  /* riscv_sha256sig0_di */
    case 453:  /* riscv_sha256sig1_si */
    case 454:  /* riscv_sha256sig1_di */
    case 455:  /* riscv_sha256sum0_si */
    case 456:  /* riscv_sha256sum0_di */
    case 457:  /* riscv_sha256sum1_si */
    case 458:  /* riscv_sha256sum1_di */
    case 459:  /* riscv_sha512sig0h */
    case 460:  /* riscv_sha512sig0l */
    case 461:  /* riscv_sha512sig1h */
    case 462:  /* riscv_sha512sig1l */
    case 463:  /* riscv_sha512sum0r */
    case 464:  /* riscv_sha512sum1r */
    case 465:  /* riscv_sha512sig0 */
    case 466:  /* riscv_sha512sig1 */
    case 467:  /* riscv_sha512sum0 */
    case 468:  /* riscv_sha512sum1 */
    case 469:  /* riscv_sm3p0_si */
    case 470:  /* riscv_sm3p0_di */
    case 471:  /* riscv_sm3p1_si */
    case 472:  /* riscv_sm3p1_di */
    case 473:  /* riscv_sm4ed_si */
    case 474:  /* riscv_sm4ed_di */
    case 475:  /* riscv_sm4ks_si */
    case 476:  /* riscv_sm4ks_di */
      return TYPE_CRYPTO;

    case 586:  /* *th_cond_movsisi */
    case 587:  /* *th_cond_movdisi */
    case 588:  /* *th_cond_movsidi */
    case 589:  /* *th_cond_movdidi */
    case 590:  /* *th_cond_gpr_movsisi */
    case 591:  /* *th_cond_gpr_movdisi */
    case 592:  /* *th_cond_gpr_movsidi */
    case 593:  /* *th_cond_gpr_movdidi */
      return TYPE_CONDMOVE;

    case 478:  /* atomic_loadsi */
    case 479:  /* atomic_loaddi */
    case 480:  /* atomic_storesi */
    case 481:  /* atomic_storedi */
    case 482:  /* atomic_addsi */
    case 483:  /* atomic_orsi */
    case 484:  /* atomic_xorsi */
    case 485:  /* atomic_andsi */
    case 486:  /* atomic_adddi */
    case 487:  /* atomic_ordi */
    case 488:  /* atomic_xordi */
    case 489:  /* atomic_anddi */
    case 490:  /* atomic_fetch_addsi */
    case 491:  /* atomic_fetch_orsi */
    case 492:  /* atomic_fetch_xorsi */
    case 493:  /* atomic_fetch_andsi */
    case 494:  /* atomic_fetch_adddi */
    case 495:  /* atomic_fetch_ordi */
    case 496:  /* atomic_fetch_xordi */
    case 497:  /* atomic_fetch_anddi */
    case 503:  /* atomic_exchangesi */
    case 504:  /* atomic_exchangedi */
    case 506:  /* atomic_cas_value_strongsi */
    case 507:  /* atomic_cas_value_strongdi */
      return TYPE_ATOMIC;

    case 332:  /* *shNadd */
    case 333:  /* *shNadd */
    case 335:  /* *shNadduw */
    case 336:  /* *add.uw */
    case 337:  /* *slliuw */
    case 338:  /* *and_notsi */
    case 339:  /* *ior_notsi */
    case 340:  /* *and_notdi */
    case 341:  /* *ior_notdi */
    case 342:  /* *xor_notsi */
    case 343:  /* *xor_notdi */
    case 344:  /* *clzsi2 */
    case 345:  /* *ctzsi2 */
    case 346:  /* *popcountsi2 */
    case 347:  /* *clzdisi2 */
    case 348:  /* *ctzdisi2 */
    case 349:  /* *popcountdisi2 */
    case 350:  /* *clzdi2 */
    case 351:  /* *ctzdi2 */
    case 352:  /* *popcountdi2 */
    case 363:  /* *rotrsi3 */
    case 364:  /* *rotrdi3 */
    case 365:  /* *rotrsi3_sext */
    case 366:  /* rotlsi3 */
    case 367:  /* rotldi3 */
    case 368:  /* rotlsi3_sext */
    case 371:  /* *bswapsi2 */
    case 372:  /* *bswapdi2 */
    case 373:  /* sminsi3 */
    case 374:  /* uminsi3 */
    case 375:  /* smaxsi3 */
    case 376:  /* umaxsi3 */
    case 377:  /* smindi3 */
    case 378:  /* umindi3 */
    case 379:  /* smaxdi3 */
    case 380:  /* umaxdi3 */
    case 385:  /* *bsetsi */
    case 386:  /* *bsetdi */
    case 387:  /* *bsetsi_mask */
    case 388:  /* *bsetdi_mask */
    case 389:  /* *bsetsi_1 */
    case 390:  /* *bsetdi_1 */
    case 391:  /* *bsetsi_1_mask */
    case 392:  /* *bsetdi_1_mask */
    case 393:  /* *bsetisi */
    case 394:  /* *bsetidi */
    case 395:  /* *bsetidisi */
    case 396:  /* *bclrsi */
    case 397:  /* *bclrdi */
    case 398:  /* *bclrisi */
    case 399:  /* *bclridi */
    case 403:  /* *binvsi */
    case 404:  /* *binvdi */
    case 405:  /* *binvisi */
    case 406:  /* *binvidi */
    case 407:  /* *bextsi */
    case 408:  /* *bextdi */
    case 409:  /* *bextsi */
    case 410:  /* *bextdi */
    case 411:  /* *bexti */
    case 412:  /* *bexti */
    case 572:  /* *th_addslsi4 */
    case 573:  /* *th_addsldi4 */
    case 574:  /* *th_srrisi3 */
    case 575:  /* *th_srridi3 */
    case 576:  /* *th_extsi4 */
    case 577:  /* *th_extdi4 */
    case 578:  /* *th_extusi4 */
    case 579:  /* *th_extudi4 */
    case 580:  /* *th_clzsi2 */
    case 581:  /* *th_clzdi2 */
    case 582:  /* *th_revsi2 */
    case 583:  /* *th_revdi2 */
    case 584:  /* *th_tstsi3 */
    case 585:  /* *th_tstdi3 */
      return TYPE_BITMANIP;

    case 291:  /* blockage */
      return TYPE_GHOST;

    case 301:  /* nop */
      return TYPE_NOP;

    case 243:  /* *movsisicc */
    case 244:  /* *movsidicc */
    case 245:  /* *movdidicc */
      return TYPE_SFB_ALU;

    case 172:  /* auipcsi */
    case 173:  /* auipcdi */
      return TYPE_AUIPC;

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      return TYPE_MULTI;

    case 47:  /* sqrtsf2 */
    case 48:  /* sqrtdf2 */
    case 49:  /* sqrthf2 */
      return TYPE_FSQRT;

    case 107:  /* truncdfsf2 */
    case 108:  /* truncsfhf2 */
    case 109:  /* truncdfhf2 */
    case 123:  /* extendhfsf2 */
    case 124:  /* extendsfdf2 */
    case 125:  /* extendhfdf2 */
    case 128:  /* fix_truncsfsi2 */
    case 129:  /* fix_truncsfdi2 */
    case 130:  /* fix_truncdfsi2 */
    case 131:  /* fix_truncdfdi2 */
    case 132:  /* fix_trunchfsi2 */
    case 133:  /* fix_trunchfdi2 */
    case 134:  /* fixuns_truncsfsi2 */
    case 135:  /* fixuns_truncsfdi2 */
    case 136:  /* fixuns_truncdfsi2 */
    case 137:  /* fixuns_truncdfdi2 */
    case 138:  /* fixuns_trunchfsi2 */
    case 139:  /* fixuns_trunchfdi2 */
    case 140:  /* floatsisf2 */
    case 141:  /* floatdisf2 */
    case 142:  /* floatsidf2 */
    case 143:  /* floatdidf2 */
    case 144:  /* floatsihf2 */
    case 145:  /* floatdihf2 */
    case 146:  /* floatunssisf2 */
    case 147:  /* floatunsdisf2 */
    case 148:  /* floatunssidf2 */
    case 149:  /* floatunsdidf2 */
    case 150:  /* floatunssihf2 */
    case 151:  /* floatunsdihf2 */
    case 152:  /* lrintsfsi2 */
    case 153:  /* lroundsfsi2 */
    case 154:  /* lrintsfdi2 */
    case 155:  /* lroundsfdi2 */
    case 156:  /* lrintdfsi2 */
    case 157:  /* lrounddfsi2 */
    case 158:  /* lrintdfdi2 */
    case 159:  /* lrounddfdi2 */
    case 160:  /* lrinthfsi2 */
    case 161:  /* lroundhfsi2 */
    case 162:  /* lrinthfdi2 */
    case 163:  /* lroundhfdi2 */
      return TYPE_FCVT;

    case 250:  /* *cstoresfsi4 */
    case 251:  /* *cstoresfdi4 */
    case 252:  /* *cstoredfsi4 */
    case 253:  /* *cstoredfdi4 */
    case 254:  /* *cstorehfsi4 */
    case 255:  /* *cstorehfdi4 */
    case 308:  /* *riscv_fsnvsnansf2 */
    case 309:  /* *riscv_fsnvsnandf2 */
    case 310:  /* *riscv_fsnvsnanhf2 */
      return TYPE_FCMP;

    case 44:  /* divsf3 */
    case 45:  /* divdf3 */
    case 46:  /* divhf3 */
      return TYPE_FDIV;

    case 50:  /* fmasf4 */
    case 51:  /* fmadf4 */
    case 52:  /* fmahf4 */
    case 53:  /* fmssf4 */
    case 54:  /* fmsdf4 */
    case 55:  /* fmshf4 */
    case 56:  /* fnmssf4 */
    case 57:  /* fnmsdf4 */
    case 58:  /* fnmshf4 */
    case 59:  /* fnmasf4 */
    case 60:  /* fnmadf4 */
    case 61:  /* fnmahf4 */
    case 62:  /* *fmasf4 */
    case 63:  /* *fmadf4 */
    case 64:  /* *fmahf4 */
    case 65:  /* *fmssf4 */
    case 66:  /* *fmsdf4 */
    case 67:  /* *fmshf4 */
    case 68:  /* *fnmssf4 */
    case 69:  /* *fnmsdf4 */
    case 70:  /* *fnmshf4 */
    case 71:  /* *fnmasf4 */
    case 72:  /* *fnmadf4 */
    case 73:  /* *fnmahf4 */
      return TYPE_FMADD;

    case 19:  /* mulsf3 */
    case 20:  /* muldf3 */
    case 21:  /* mulhf3 */
      return TYPE_FMUL;

    case 1:  /* addsf3 */
    case 2:  /* adddf3 */
    case 3:  /* addhf3 */
    case 8:  /* subsf3 */
    case 9:  /* subdf3 */
    case 10:  /* subhf3 */
      return TYPE_FADD;

    case 74:  /* abssf2 */
    case 75:  /* absdf2 */
    case 76:  /* abshf2 */
    case 77:  /* copysignsf3 */
    case 78:  /* copysigndf3 */
    case 79:  /* copysignhf3 */
    case 80:  /* negsf2 */
    case 81:  /* negdf2 */
    case 82:  /* neghf2 */
    case 83:  /* fminsf3 */
    case 84:  /* fmindf3 */
    case 85:  /* fminhf3 */
    case 86:  /* fmaxsf3 */
    case 87:  /* fmaxdf3 */
    case 88:  /* fmaxhf3 */
    case 89:  /* sminsf3 */
    case 90:  /* smindf3 */
    case 91:  /* sminhf3 */
    case 92:  /* smaxsf3 */
    case 93:  /* smaxdf3 */
    case 94:  /* smaxhf3 */
      return TYPE_FMOVE;

    case 32:  /* divsi3 */
    case 33:  /* udivsi3 */
    case 34:  /* modsi3 */
    case 35:  /* umodsi3 */
    case 36:  /* divdi3 */
    case 37:  /* udivdi3 */
    case 38:  /* moddi3 */
    case 39:  /* umoddi3 */
    case 40:  /* *divsi3_extended */
    case 41:  /* *udivsi3_extended */
    case 42:  /* *modsi3_extended */
    case 43:  /* *umodsi3_extended */
      return TYPE_IDIV;

    case 22:  /* mulsi3 */
    case 23:  /* muldi3 */
    case 24:  /* *mulsi3_extended */
    case 25:  /* *mulsi3_extended2 */
    case 26:  /* smuldi3_highpart */
    case 27:  /* umuldi3_highpart */
    case 28:  /* usmuldi3_highpart */
    case 29:  /* smulsi3_highpart */
    case 30:  /* umulsi3_highpart */
    case 31:  /* usmulsi3_highpart */
    case 597:  /* *th_mulasi */
    case 598:  /* *th_muladi */
    case 599:  /* *th_mulawsi */
    case 600:  /* *th_mulawsi2 */
    case 601:  /* *th_maddhisi4 */
    case 602:  /* *th_sextw_maddhisi4 */
    case 603:  /* *th_mulssi */
    case 604:  /* *th_mulsdi */
    case 605:  /* *th_mulswsi */
    case 606:  /* *th_mulswsi2 */
    case 607:  /* *th_msubhisi4 */
    case 608:  /* *th_sextw_msubhisi4 */
      return TYPE_IMUL;

    case 256:  /* *seq_zero_sisi */
    case 257:  /* *seq_zero_disi */
    case 258:  /* *seq_zero_didi */
    case 259:  /* *sne_zero_sisi */
    case 260:  /* *sne_zero_disi */
    case 261:  /* *sne_zero_didi */
    case 262:  /* *sgt_sisi */
    case 263:  /* *sgtu_sisi */
    case 264:  /* *sgt_disi */
    case 265:  /* *sgtu_disi */
    case 266:  /* *sgt_didi */
    case 267:  /* *sgtu_didi */
    case 268:  /* *sge_sisi */
    case 269:  /* *sgeu_sisi */
    case 270:  /* *sge_disi */
    case 271:  /* *sgeu_disi */
    case 272:  /* *sge_didi */
    case 273:  /* *sgeu_didi */
    case 274:  /* *slt_sisi */
    case 275:  /* *sltu_sisi */
    case 276:  /* *slt_disi */
    case 277:  /* *sltu_disi */
    case 278:  /* *slt_didi */
    case 279:  /* *sltu_didi */
    case 280:  /* *sle_sisi */
    case 281:  /* *sleu_sisi */
    case 282:  /* *sle_disi */
    case 283:  /* *sleu_disi */
    case 284:  /* *sle_didi */
    case 285:  /* *sleu_didi */
      return TYPE_SLT;

    case 195:  /* ashlsi3 */
    case 196:  /* ashrsi3 */
    case 197:  /* lshrsi3 */
    case 198:  /* *ashlsi3_mask */
    case 199:  /* *ashrsi3_mask */
    case 200:  /* *lshrsi3_mask */
    case 201:  /* *ashlsi3_mask_1 */
    case 202:  /* *ashrsi3_mask_1 */
    case 203:  /* *lshrsi3_mask_1 */
    case 204:  /* ashldi3 */
    case 205:  /* ashrdi3 */
    case 206:  /* lshrdi3 */
    case 207:  /* *ashldi3_mask */
    case 208:  /* *ashrdi3_mask */
    case 209:  /* *lshrdi3_mask */
    case 210:  /* *ashldi3_mask_1 */
    case 211:  /* *ashrdi3_mask_1 */
    case 212:  /* *lshrdi3_mask_1 */
    case 213:  /* *ashlsi3_extend */
    case 214:  /* *ashrsi3_extend */
    case 215:  /* *lshrsi3_extend */
    case 216:  /* *ashlsi3_extend_mask */
    case 217:  /* *ashrsi3_extend_mask */
    case 218:  /* *lshrsi3_extend_mask */
    case 219:  /* *ashlsi3_extend_mask_1 */
    case 220:  /* *ashrsi3_extend_mask_1 */
    case 221:  /* *lshrsi3_extend_mask_1 */
    case 222:  /* *lshrsi3_zero_extend_1 */
    case 223:  /* *lshrsi3_zero_extend_2 */
    case 224:  /* *lshrsi3_zero_extend_3 */
    case 225:  /* zero_extendsidi2_shifted */
      return TYPE_SHIFT;

    case 95:  /* andsi3 */
    case 96:  /* iorsi3 */
    case 97:  /* xorsi3 */
    case 98:  /* anddi3 */
    case 99:  /* iordi3 */
    case 100:  /* xordi3 */
    case 101:  /* *andsi3_internal */
    case 102:  /* *iorsi3_internal */
    case 103:  /* *xorsi3_internal */
    case 104:  /* one_cmplsi2 */
    case 105:  /* one_cmpldi2 */
    case 106:  /* *one_cmplsi2_internal */
    case 184:  /* *xorhihi3 */
    case 185:  /* *xorsihi3 */
      return TYPE_LOGICAL;

    case 4:  /* addsi3 */
    case 5:  /* adddi3 */
    case 6:  /* *addsi3_extended */
    case 7:  /* *addsi3_extended2 */
    case 11:  /* subdi3 */
    case 12:  /* subsi3 */
    case 13:  /* *subsi3_extended */
    case 14:  /* *subsi3_extended2 */
    case 15:  /* negdi2 */
    case 16:  /* negsi2 */
    case 17:  /* *negsi2_extended */
    case 18:  /* *negsi2_extended2 */
    case 166:  /* tls_add_tp_lesi */
    case 167:  /* tls_add_tp_ledi */
    case 174:  /* *lowsi */
    case 175:  /* *lowdi */
    case 182:  /* *addhihi3 */
    case 183:  /* *addsihi3 */
      return TYPE_ARITH;

    case 612:  /* *th_mempair_store_di2 */
    case 611:  /* *th_mempair_store_si2 */
      return TYPE_STORE;

    case 614:  /* *th_mempair_load_zero_extendsidi2 */
    case 613:  /* *th_mempair_load_extendsidi2 */
    case 610:  /* *th_mempair_load_di2 */
    case 609:  /* *th_mempair_load_si2 */
    case 171:  /* got_load_tls_iedi */
    case 170:  /* got_load_tls_iesi */
    case 169:  /* got_load_tls_gddi */
    case 168:  /* got_load_tls_gdsi */
    case 165:  /* got_loaddi */
    case 164:  /* got_loadsi */
      return TYPE_LOAD;

    case 297:  /* sibcall_internal */
    case 298:  /* sibcall_value_internal */
    case 299:  /* call_internal */
    case 300:  /* call_value_internal */
      return TYPE_CALL;

    case 286:  /* jump */
    case 287:  /* indirect_jumpsi */
    case 288:  /* indirect_jumpdi */
    case 289:  /* tablejumpsi */
    case 290:  /* tablejumpdi */
    case 292:  /* simple_return */
    case 293:  /* simple_return_internal */
      return TYPE_JUMP;

    case 241:  /* *branchsi */
    case 242:  /* *branchdi */
      return TYPE_BRANCH;

    case 792:  /* *movvnx64bidi_lra */
    case 791:  /* *movvnx32bidi_lra */
    case 790:  /* *movvnx16bidi_lra */
    case 789:  /* *movvnx8bidi_lra */
    case 788:  /* *movvnx4bidi_lra */
    case 787:  /* *movvnx2bidi_lra */
    case 786:  /* *movvnx1bidi_lra */
    case 785:  /* *movvnx64bisi_lra */
    case 784:  /* *movvnx32bisi_lra */
    case 783:  /* *movvnx16bisi_lra */
    case 782:  /* *movvnx8bisi_lra */
    case 781:  /* *movvnx4bisi_lra */
    case 780:  /* *movvnx2bisi_lra */
    case 779:  /* *movvnx1bisi_lra */
    case 778:  /* *movvnx1sfdi_lra */
    case 777:  /* *movvnx1sfsi_lra */
    case 776:  /* *movvnx1sidi_lra */
    case 775:  /* *movvnx1sisi_lra */
    case 774:  /* *movvnx2hidi_lra */
    case 773:  /* *movvnx2hisi_lra */
    case 772:  /* *movvnx1hidi_lra */
    case 771:  /* *movvnx1hisi_lra */
    case 770:  /* *movvnx4qidi_lra */
    case 769:  /* *movvnx4qisi_lra */
    case 768:  /* *movvnx2qidi_lra */
    case 767:  /* *movvnx2qisi_lra */
    case 766:  /* *movvnx1qidi_lra */
    case 765:  /* *movvnx1qisi_lra */
    case 722:  /* vlmax_avldi */
    case 721:  /* vlmax_avlsi */
    case 720:  /* *vlmul_extx64vnx1qi */
    case 719:  /* *vlmul_extx32vnx1hi */
    case 718:  /* *vlmul_extx32vnx2qi */
    case 717:  /* *vlmul_extx32vnx1qi */
    case 716:  /* *vlmul_extx16vnx1sf */
    case 715:  /* *vlmul_extx16vnx1si */
    case 714:  /* *vlmul_extx16vnx2hi */
    case 713:  /* *vlmul_extx16vnx1hi */
    case 712:  /* *vlmul_extx16vnx4qi */
    case 711:  /* *vlmul_extx16vnx2qi */
    case 710:  /* *vlmul_extx16vnx1qi */
    case 709:  /* *vlmul_extx8vnx1df */
    case 708:  /* *vlmul_extx8vnx2sf */
    case 707:  /* *vlmul_extx8vnx1sf */
    case 706:  /* *vlmul_extx8vnx1di */
    case 705:  /* *vlmul_extx8vnx2si */
    case 704:  /* *vlmul_extx8vnx1si */
    case 703:  /* *vlmul_extx8vnx4hi */
    case 702:  /* *vlmul_extx8vnx2hi */
    case 701:  /* *vlmul_extx8vnx1hi */
    case 700:  /* *vlmul_extx8vnx8qi */
    case 699:  /* *vlmul_extx8vnx4qi */
    case 698:  /* *vlmul_extx8vnx2qi */
    case 697:  /* *vlmul_extx8vnx1qi */
    case 696:  /* *vlmul_extx4vnx2df */
    case 695:  /* *vlmul_extx4vnx1df */
    case 694:  /* *vlmul_extx4vnx4sf */
    case 693:  /* *vlmul_extx4vnx2sf */
    case 692:  /* *vlmul_extx4vnx1sf */
    case 691:  /* *vlmul_extx4vnx2di */
    case 690:  /* *vlmul_extx4vnx1di */
    case 689:  /* *vlmul_extx4vnx4si */
    case 688:  /* *vlmul_extx4vnx2si */
    case 687:  /* *vlmul_extx4vnx1si */
    case 686:  /* *vlmul_extx4vnx8hi */
    case 685:  /* *vlmul_extx4vnx4hi */
    case 684:  /* *vlmul_extx4vnx2hi */
    case 683:  /* *vlmul_extx4vnx1hi */
    case 682:  /* *vlmul_extx4vnx16qi */
    case 681:  /* *vlmul_extx4vnx8qi */
    case 680:  /* *vlmul_extx4vnx4qi */
    case 679:  /* *vlmul_extx4vnx2qi */
    case 678:  /* *vlmul_extx4vnx1qi */
    case 677:  /* *vlmul_extx2vnx4df */
    case 676:  /* *vlmul_extx2vnx2df */
    case 675:  /* *vlmul_extx2vnx1df */
    case 674:  /* *vlmul_extx2vnx8sf */
    case 673:  /* *vlmul_extx2vnx4sf */
    case 672:  /* *vlmul_extx2vnx2sf */
    case 671:  /* *vlmul_extx2vnx1sf */
    case 670:  /* *vlmul_extx2vnx4di */
    case 669:  /* *vlmul_extx2vnx2di */
    case 668:  /* *vlmul_extx2vnx1di */
    case 667:  /* *vlmul_extx2vnx8si */
    case 666:  /* *vlmul_extx2vnx4si */
    case 665:  /* *vlmul_extx2vnx2si */
    case 664:  /* *vlmul_extx2vnx1si */
    case 663:  /* *vlmul_extx2vnx16hi */
    case 662:  /* *vlmul_extx2vnx8hi */
    case 661:  /* *vlmul_extx2vnx4hi */
    case 660:  /* *vlmul_extx2vnx2hi */
    case 659:  /* *vlmul_extx2vnx1hi */
    case 658:  /* *vlmul_extx2vnx32qi */
    case 657:  /* *vlmul_extx2vnx16qi */
    case 656:  /* *vlmul_extx2vnx8qi */
    case 655:  /* *vlmul_extx2vnx4qi */
    case 654:  /* *vlmul_extx2vnx2qi */
    case 653:  /* *vlmul_extx2vnx1qi */
    case 652:  /* vundefinedvnx64bi */
    case 651:  /* vundefinedvnx32bi */
    case 650:  /* vundefinedvnx16bi */
    case 649:  /* vundefinedvnx8bi */
    case 648:  /* vundefinedvnx4bi */
    case 647:  /* vundefinedvnx2bi */
    case 646:  /* vundefinedvnx1bi */
    case 645:  /* vundefinedvnx8df */
    case 644:  /* vundefinedvnx4df */
    case 643:  /* vundefinedvnx2df */
    case 642:  /* vundefinedvnx1df */
    case 641:  /* vundefinedvnx16sf */
    case 640:  /* vundefinedvnx8sf */
    case 639:  /* vundefinedvnx4sf */
    case 638:  /* vundefinedvnx2sf */
    case 637:  /* vundefinedvnx1sf */
    case 636:  /* vundefinedvnx8di */
    case 635:  /* vundefinedvnx4di */
    case 634:  /* vundefinedvnx2di */
    case 633:  /* vundefinedvnx1di */
    case 632:  /* vundefinedvnx16si */
    case 631:  /* vundefinedvnx8si */
    case 630:  /* vundefinedvnx4si */
    case 629:  /* vundefinedvnx2si */
    case 628:  /* vundefinedvnx1si */
    case 627:  /* vundefinedvnx32hi */
    case 626:  /* vundefinedvnx16hi */
    case 625:  /* vundefinedvnx8hi */
    case 624:  /* vundefinedvnx4hi */
    case 623:  /* vundefinedvnx2hi */
    case 622:  /* vundefinedvnx1hi */
    case 621:  /* vundefinedvnx64qi */
    case 620:  /* vundefinedvnx32qi */
    case 619:  /* vundefinedvnx16qi */
    case 618:  /* vundefinedvnx8qi */
    case 617:  /* vundefinedvnx4qi */
    case 616:  /* vundefinedvnx2qi */
    case 615:  /* vundefinedvnx1qi */
    case 571:  /* *local_pic_store_sfhf */
    case 570:  /* *local_pic_store_sfdf */
    case 569:  /* *local_pic_store_sfsf */
    case 568:  /* *local_pic_store_sfhf */
    case 567:  /* *local_pic_store_sfdf */
    case 566:  /* *local_pic_store_sfsf */
    case 565:  /* *local_pic_store_32dhf */
    case 564:  /* *local_pic_store_32ddf */
    case 563:  /* *local_pic_store_32dsf */
    case 562:  /* *local_pic_store_32dhf */
    case 561:  /* *local_pic_store_32ddf */
    case 560:  /* *local_pic_store_32dsf */
    case 559:  /* *local_pic_storehf */
    case 558:  /* *local_pic_storedf */
    case 557:  /* *local_pic_storesf */
    case 556:  /* *local_pic_storehf */
    case 555:  /* *local_pic_storedf */
    case 554:  /* *local_pic_storesf */
    case 553:  /* *local_pic_storedi */
    case 552:  /* *local_pic_storesi */
    case 551:  /* *local_pic_storehi */
    case 550:  /* *local_pic_storeqi */
    case 549:  /* *local_pic_storedi */
    case 548:  /* *local_pic_storesi */
    case 547:  /* *local_pic_storehi */
    case 546:  /* *local_pic_storeqi */
    case 545:  /* *local_pic_load_sfhf */
    case 544:  /* *local_pic_load_sfdf */
    case 543:  /* *local_pic_load_sfsf */
    case 542:  /* *local_pic_load_32dhf */
    case 541:  /* *local_pic_load_32ddf */
    case 540:  /* *local_pic_load_32dsf */
    case 539:  /* *local_pic_load_32dhf */
    case 538:  /* *local_pic_load_32ddf */
    case 537:  /* *local_pic_load_32dsf */
    case 536:  /* *local_pic_loadhf */
    case 535:  /* *local_pic_loaddf */
    case 534:  /* *local_pic_loadsf */
    case 533:  /* *local_pic_loadhf */
    case 532:  /* *local_pic_loaddf */
    case 531:  /* *local_pic_loadsf */
    case 530:  /* *local_pic_load_usi */
    case 529:  /* *local_pic_load_usi */
    case 528:  /* *local_pic_load_usi */
    case 527:  /* *local_pic_load_uhi */
    case 526:  /* *local_pic_load_uhi */
    case 525:  /* *local_pic_load_uhi */
    case 524:  /* *local_pic_load_uqi */
    case 523:  /* *local_pic_load_uqi */
    case 522:  /* *local_pic_load_uqi */
    case 521:  /* *local_pic_load_ssi */
    case 520:  /* *local_pic_load_ssi */
    case 519:  /* *local_pic_load_ssi */
    case 518:  /* *local_pic_load_shi */
    case 517:  /* *local_pic_load_shi */
    case 516:  /* *local_pic_load_shi */
    case 515:  /* *local_pic_load_sqi */
    case 514:  /* *local_pic_load_sqi */
    case 513:  /* *local_pic_load_sqi */
    case 512:  /* *local_pic_loaddi */
    case 511:  /* *local_pic_loadsi */
    case 510:  /* *local_pic_loadhi */
    case 509:  /* *local_pic_loadqi */
    case 508:  /* subword_atomic_cas_strong */
    case 505:  /* subword_atomic_exchange_strong */
    case 502:  /* subword_atomic_fetch_strong_nand */
    case 501:  /* subword_atomic_fetch_strong_and */
    case 500:  /* subword_atomic_fetch_strong_xor */
    case 499:  /* subword_atomic_fetch_strong_or */
    case 498:  /* subword_atomic_fetch_strong_add */
    case 477:  /* mem_thread_fence_1 */
    case 420:  /* *branchdi_mask_twobits_equals_singlebit */
    case 419:  /* *branchsi_mask_twobits_equals_singlebit */
    case 418:  /* *andidi_extrabit */
    case 417:  /* *andisi_extrabit */
    case 416:  /* *xoridi_extrabit */
    case 415:  /* *ioridi_extrabit */
    case 414:  /* *xorisi_extrabit */
    case 413:  /* *iorisi_extrabit */
    case 402:  /* *bclridisi_nottwobits */
    case 401:  /* *bclridi_nottwobits */
    case 400:  /* *bclrisi_nottwobits */
    case 384:  /* *minmax */
    case 383:  /* *minmax */
    case 382:  /* *minmax */
    case 381:  /* *minmax */
    case 370:  /* orcbdi2 */
    case 369:  /* orcbsi2 */
    case 334:  /* *andi_add.uw */
    case 330:  /* riscv_prefetchi_di */
    case 329:  /* riscv_prefetchi_si */
    case 328:  /* prefetch */
    case 327:  /* riscv_zero_di */
    case 326:  /* riscv_zero_si */
    case 325:  /* riscv_inval_di */
    case 324:  /* riscv_inval_si */
    case 323:  /* riscv_flush_di */
    case 322:  /* riscv_flush_si */
    case 321:  /* riscv_clean_di */
    case 320:  /* riscv_clean_si */
    case 319:  /* stack_protect_test_di */
    case 318:  /* stack_protect_test_si */
    case 317:  /* stack_protect_set_di */
    case 316:  /* stack_protect_set_si */
    case 315:  /* stack_tiedi */
    case 314:  /* stack_tiesi */
    case 313:  /* riscv_uret */
    case 312:  /* riscv_sret */
    case 311:  /* riscv_mret */
    case 307:  /* riscv_fsflags */
    case 306:  /* riscv_frflags */
    case 305:  /* gpr_restore_return */
    case 304:  /* gpr_restore */
    case 303:  /* gpr_save */
    case 302:  /* trap */
    case 296:  /* eh_return_internal */
    case 295:  /* eh_set_lr_di */
    case 294:  /* eh_set_lr_si */
    case 249:  /* *branch_on_bit_rangedi */
    case 248:  /* *branch_on_bit_rangesi */
    case 247:  /* *branch_on_bitdi */
    case 246:  /* *branch_on_bitsi */
    case 240:  /* *branchdi_shiftedmask_equals_zero */
    case 239:  /* *branchsi_shiftedmask_equals_zero */
    case 238:  /* *branchhi_shiftedmask_equals_zero */
    case 237:  /* *branchqi_shiftedmask_equals_zero */
    case 236:  /* *branchdi_shiftedmask_equals_zero */
    case 235:  /* *branchsi_shiftedmask_equals_zero */
    case 234:  /* *branchhi_shiftedmask_equals_zero */
    case 233:  /* *branchqi_shiftedmask_equals_zero */
    case 232:  /* *branchdi_shiftedarith_equals_zero */
    case 231:  /* *branchsi_shiftedarith_equals_zero */
    case 230:  /* *branchhi_shiftedarith_equals_zero */
    case 229:  /* *branchqi_shiftedarith_equals_zero */
    case 228:  /* *branchsi_shiftedarith_equals_zero */
    case 227:  /* *branchhi_shiftedarith_equals_zero */
    case 226:  /* *branchqi_shiftedarith_equals_zero */
    case 194:  /* riscv_pause */
    case 193:  /* fence_i */
    case 192:  /* fence */
    case 177:  /* *mvconst_internal */
    case 176:  /* *mvconst_internal */
      return TYPE_UNKNOWN;

    default:
      return TYPE_VIALU;

    }
}

int
get_attr_vl_op_idx (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 5175:  /* *pred_eqnevnx8df_scalar_narrow */
    case 5174:  /* *pred_eqnevnx4df_scalar_narrow */
    case 5173:  /* *pred_eqnevnx2df_scalar_narrow */
    case 5172:  /* *pred_eqnevnx1df_scalar_narrow */
    case 5171:  /* *pred_eqnevnx16sf_scalar_narrow */
    case 5170:  /* *pred_eqnevnx8sf_scalar_narrow */
    case 5169:  /* *pred_eqnevnx4sf_scalar_narrow */
    case 5168:  /* *pred_eqnevnx2sf_scalar_narrow */
    case 5167:  /* *pred_eqnevnx1sf_scalar_narrow */
    case 5166:  /* *pred_eqnevnx8df_scalar */
    case 5165:  /* *pred_eqnevnx4df_scalar */
    case 5164:  /* *pred_eqnevnx2df_scalar */
    case 5163:  /* *pred_eqnevnx1df_scalar */
    case 5162:  /* *pred_eqnevnx16sf_scalar */
    case 5161:  /* *pred_eqnevnx8sf_scalar */
    case 5160:  /* *pred_eqnevnx4sf_scalar */
    case 5159:  /* *pred_eqnevnx2sf_scalar */
    case 5158:  /* *pred_eqnevnx1sf_scalar */
    case 5157:  /* *pred_cmpvnx8df_scalar_narrow */
    case 5156:  /* *pred_cmpvnx4df_scalar_narrow */
    case 5155:  /* *pred_cmpvnx2df_scalar_narrow */
    case 5154:  /* *pred_cmpvnx1df_scalar_narrow */
    case 5153:  /* *pred_cmpvnx16sf_scalar_narrow */
    case 5152:  /* *pred_cmpvnx8sf_scalar_narrow */
    case 5151:  /* *pred_cmpvnx4sf_scalar_narrow */
    case 5150:  /* *pred_cmpvnx2sf_scalar_narrow */
    case 5149:  /* *pred_cmpvnx1sf_scalar_narrow */
    case 5148:  /* *pred_cmpvnx8df_scalar */
    case 5147:  /* *pred_cmpvnx4df_scalar */
    case 5146:  /* *pred_cmpvnx2df_scalar */
    case 5145:  /* *pred_cmpvnx1df_scalar */
    case 5144:  /* *pred_cmpvnx16sf_scalar */
    case 5143:  /* *pred_cmpvnx8sf_scalar */
    case 5142:  /* *pred_cmpvnx4sf_scalar */
    case 5141:  /* *pred_cmpvnx2sf_scalar */
    case 5140:  /* *pred_cmpvnx1sf_scalar */
    case 5139:  /* *pred_cmpvnx8df_narrow */
    case 5138:  /* *pred_cmpvnx4df_narrow */
    case 5137:  /* *pred_cmpvnx2df_narrow */
    case 5136:  /* *pred_cmpvnx1df_narrow */
    case 5135:  /* *pred_cmpvnx16sf_narrow */
    case 5134:  /* *pred_cmpvnx8sf_narrow */
    case 5133:  /* *pred_cmpvnx4sf_narrow */
    case 5132:  /* *pred_cmpvnx2sf_narrow */
    case 5131:  /* *pred_cmpvnx1sf_narrow */
    case 5130:  /* *pred_cmpvnx8df */
    case 5129:  /* *pred_cmpvnx4df */
    case 5128:  /* *pred_cmpvnx2df */
    case 5127:  /* *pred_cmpvnx1df */
    case 5126:  /* *pred_cmpvnx16sf */
    case 5125:  /* *pred_cmpvnx8sf */
    case 5124:  /* *pred_cmpvnx4sf */
    case 5123:  /* *pred_cmpvnx2sf */
    case 5122:  /* *pred_cmpvnx1sf */
    case 4995:  /* *pred_mul_neg_subvnx8df_scalar */
    case 4994:  /* *pred_mul_neg_addvnx8df_scalar */
    case 4993:  /* *pred_mul_neg_subvnx4df_scalar */
    case 4992:  /* *pred_mul_neg_addvnx4df_scalar */
    case 4991:  /* *pred_mul_neg_subvnx2df_scalar */
    case 4990:  /* *pred_mul_neg_addvnx2df_scalar */
    case 4989:  /* *pred_mul_neg_subvnx1df_scalar */
    case 4988:  /* *pred_mul_neg_addvnx1df_scalar */
    case 4987:  /* *pred_mul_neg_subvnx16sf_scalar */
    case 4986:  /* *pred_mul_neg_addvnx16sf_scalar */
    case 4985:  /* *pred_mul_neg_subvnx8sf_scalar */
    case 4984:  /* *pred_mul_neg_addvnx8sf_scalar */
    case 4983:  /* *pred_mul_neg_subvnx4sf_scalar */
    case 4982:  /* *pred_mul_neg_addvnx4sf_scalar */
    case 4981:  /* *pred_mul_neg_subvnx2sf_scalar */
    case 4980:  /* *pred_mul_neg_addvnx2sf_scalar */
    case 4979:  /* *pred_mul_neg_subvnx1sf_scalar */
    case 4978:  /* *pred_mul_neg_addvnx1sf_scalar */
    case 4941:  /* *pred_mul_neg_subvnx8df */
    case 4940:  /* *pred_mul_neg_addvnx8df */
    case 4939:  /* *pred_mul_neg_subvnx4df */
    case 4938:  /* *pred_mul_neg_addvnx4df */
    case 4937:  /* *pred_mul_neg_subvnx2df */
    case 4936:  /* *pred_mul_neg_addvnx2df */
    case 4935:  /* *pred_mul_neg_subvnx1df */
    case 4934:  /* *pred_mul_neg_addvnx1df */
    case 4933:  /* *pred_mul_neg_subvnx16sf */
    case 4932:  /* *pred_mul_neg_addvnx16sf */
    case 4931:  /* *pred_mul_neg_subvnx8sf */
    case 4930:  /* *pred_mul_neg_addvnx8sf */
    case 4929:  /* *pred_mul_neg_subvnx4sf */
    case 4928:  /* *pred_mul_neg_addvnx4sf */
    case 4927:  /* *pred_mul_neg_subvnx2sf */
    case 4926:  /* *pred_mul_neg_addvnx2sf */
    case 4925:  /* *pred_mul_neg_subvnx1sf */
    case 4924:  /* *pred_mul_neg_addvnx1sf */
    case 4887:  /* *pred_mul_subvnx8df_scalar */
    case 4886:  /* *pred_mul_addvnx8df_scalar */
    case 4885:  /* *pred_mul_subvnx4df_scalar */
    case 4884:  /* *pred_mul_addvnx4df_scalar */
    case 4883:  /* *pred_mul_subvnx2df_scalar */
    case 4882:  /* *pred_mul_addvnx2df_scalar */
    case 4881:  /* *pred_mul_subvnx1df_scalar */
    case 4880:  /* *pred_mul_addvnx1df_scalar */
    case 4879:  /* *pred_mul_subvnx16sf_scalar */
    case 4878:  /* *pred_mul_addvnx16sf_scalar */
    case 4877:  /* *pred_mul_subvnx8sf_scalar */
    case 4876:  /* *pred_mul_addvnx8sf_scalar */
    case 4875:  /* *pred_mul_subvnx4sf_scalar */
    case 4874:  /* *pred_mul_addvnx4sf_scalar */
    case 4873:  /* *pred_mul_subvnx2sf_scalar */
    case 4872:  /* *pred_mul_addvnx2sf_scalar */
    case 4871:  /* *pred_mul_subvnx1sf_scalar */
    case 4870:  /* *pred_mul_addvnx1sf_scalar */
    case 4833:  /* *pred_mul_subvnx8df */
    case 4832:  /* *pred_mul_addvnx8df */
    case 4831:  /* *pred_mul_subvnx4df */
    case 4830:  /* *pred_mul_addvnx4df */
    case 4829:  /* *pred_mul_subvnx2df */
    case 4828:  /* *pred_mul_addvnx2df */
    case 4827:  /* *pred_mul_subvnx1df */
    case 4826:  /* *pred_mul_addvnx1df */
    case 4825:  /* *pred_mul_subvnx16sf */
    case 4824:  /* *pred_mul_addvnx16sf */
    case 4823:  /* *pred_mul_subvnx8sf */
    case 4822:  /* *pred_mul_addvnx8sf */
    case 4821:  /* *pred_mul_subvnx4sf */
    case 4820:  /* *pred_mul_addvnx4sf */
    case 4819:  /* *pred_mul_subvnx2sf */
    case 4818:  /* *pred_mul_addvnx2sf */
    case 4817:  /* *pred_mul_subvnx1sf */
    case 4816:  /* *pred_mul_addvnx1sf */
    case 4338:  /* *pred_minus_mulvnx8di_extended_scalar */
    case 4337:  /* *pred_minus_mulvnx4di_extended_scalar */
    case 4336:  /* *pred_minus_mulvnx2di_extended_scalar */
    case 4335:  /* *pred_minus_mulvnx1di_extended_scalar */
    case 4326:  /* *pred_minus_mulvnx8di_scalar */
    case 4325:  /* *pred_minus_mulvnx4di_scalar */
    case 4324:  /* *pred_minus_mulvnx2di_scalar */
    case 4323:  /* *pred_minus_mulvnx1di_scalar */
    case 4322:  /* *pred_minus_mulvnx16si_scalar */
    case 4321:  /* *pred_minus_mulvnx8si_scalar */
    case 4320:  /* *pred_minus_mulvnx4si_scalar */
    case 4319:  /* *pred_minus_mulvnx2si_scalar */
    case 4318:  /* *pred_minus_mulvnx1si_scalar */
    case 4317:  /* *pred_minus_mulvnx32hi_scalar */
    case 4316:  /* *pred_minus_mulvnx16hi_scalar */
    case 4315:  /* *pred_minus_mulvnx8hi_scalar */
    case 4314:  /* *pred_minus_mulvnx4hi_scalar */
    case 4313:  /* *pred_minus_mulvnx2hi_scalar */
    case 4312:  /* *pred_minus_mulvnx1hi_scalar */
    case 4311:  /* *pred_minus_mulvnx64qi_scalar */
    case 4310:  /* *pred_minus_mulvnx32qi_scalar */
    case 4309:  /* *pred_minus_mulvnx16qi_scalar */
    case 4308:  /* *pred_minus_mulvnx8qi_scalar */
    case 4307:  /* *pred_minus_mulvnx4qi_scalar */
    case 4306:  /* *pred_minus_mulvnx2qi_scalar */
    case 4305:  /* *pred_minus_mulvnx1qi_scalar */
    case 4260:  /* *pred_minus_mulvnx8di */
    case 4259:  /* *pred_minus_mulvnx4di */
    case 4258:  /* *pred_minus_mulvnx2di */
    case 4257:  /* *pred_minus_mulvnx1di */
    case 4256:  /* *pred_minus_mulvnx16si */
    case 4255:  /* *pred_minus_mulvnx8si */
    case 4254:  /* *pred_minus_mulvnx4si */
    case 4253:  /* *pred_minus_mulvnx2si */
    case 4252:  /* *pred_minus_mulvnx1si */
    case 4251:  /* *pred_minus_mulvnx32hi */
    case 4250:  /* *pred_minus_mulvnx16hi */
    case 4249:  /* *pred_minus_mulvnx8hi */
    case 4248:  /* *pred_minus_mulvnx4hi */
    case 4247:  /* *pred_minus_mulvnx2hi */
    case 4246:  /* *pred_minus_mulvnx1hi */
    case 4245:  /* *pred_minus_mulvnx64qi */
    case 4244:  /* *pred_minus_mulvnx32qi */
    case 4243:  /* *pred_minus_mulvnx16qi */
    case 4242:  /* *pred_minus_mulvnx8qi */
    case 4241:  /* *pred_minus_mulvnx4qi */
    case 4240:  /* *pred_minus_mulvnx2qi */
    case 4239:  /* *pred_minus_mulvnx1qi */
    case 4194:  /* *pred_mul_plusvnx8di_extended_scalar */
    case 4193:  /* *pred_mul_plusvnx4di_extended_scalar */
    case 4192:  /* *pred_mul_plusvnx2di_extended_scalar */
    case 4191:  /* *pred_mul_plusvnx1di_extended_scalar */
    case 4182:  /* *pred_mul_plusvnx8di_scalar */
    case 4181:  /* *pred_mul_plusvnx4di_scalar */
    case 4180:  /* *pred_mul_plusvnx2di_scalar */
    case 4179:  /* *pred_mul_plusvnx1di_scalar */
    case 4178:  /* *pred_mul_plusvnx16si_scalar */
    case 4177:  /* *pred_mul_plusvnx8si_scalar */
    case 4176:  /* *pred_mul_plusvnx4si_scalar */
    case 4175:  /* *pred_mul_plusvnx2si_scalar */
    case 4174:  /* *pred_mul_plusvnx1si_scalar */
    case 4173:  /* *pred_mul_plusvnx32hi_scalar */
    case 4172:  /* *pred_mul_plusvnx16hi_scalar */
    case 4171:  /* *pred_mul_plusvnx8hi_scalar */
    case 4170:  /* *pred_mul_plusvnx4hi_scalar */
    case 4169:  /* *pred_mul_plusvnx2hi_scalar */
    case 4168:  /* *pred_mul_plusvnx1hi_scalar */
    case 4167:  /* *pred_mul_plusvnx64qi_scalar */
    case 4166:  /* *pred_mul_plusvnx32qi_scalar */
    case 4165:  /* *pred_mul_plusvnx16qi_scalar */
    case 4164:  /* *pred_mul_plusvnx8qi_scalar */
    case 4163:  /* *pred_mul_plusvnx4qi_scalar */
    case 4162:  /* *pred_mul_plusvnx2qi_scalar */
    case 4161:  /* *pred_mul_plusvnx1qi_scalar */
    case 4116:  /* *pred_mul_plusvnx8di */
    case 4115:  /* *pred_mul_plusvnx4di */
    case 4114:  /* *pred_mul_plusvnx2di */
    case 4113:  /* *pred_mul_plusvnx1di */
    case 4112:  /* *pred_mul_plusvnx16si */
    case 4111:  /* *pred_mul_plusvnx8si */
    case 4110:  /* *pred_mul_plusvnx4si */
    case 4109:  /* *pred_mul_plusvnx2si */
    case 4108:  /* *pred_mul_plusvnx1si */
    case 4107:  /* *pred_mul_plusvnx32hi */
    case 4106:  /* *pred_mul_plusvnx16hi */
    case 4105:  /* *pred_mul_plusvnx8hi */
    case 4104:  /* *pred_mul_plusvnx4hi */
    case 4103:  /* *pred_mul_plusvnx2hi */
    case 4102:  /* *pred_mul_plusvnx1hi */
    case 4101:  /* *pred_mul_plusvnx64qi */
    case 4100:  /* *pred_mul_plusvnx32qi */
    case 4099:  /* *pred_mul_plusvnx16qi */
    case 4098:  /* *pred_mul_plusvnx8qi */
    case 4097:  /* *pred_mul_plusvnx4qi */
    case 4096:  /* *pred_mul_plusvnx2qi */
    case 4095:  /* *pred_mul_plusvnx1qi */
    case 4050:  /* *pred_eqnevnx8di_extended_scalar_narrow */
    case 4049:  /* *pred_eqnevnx4di_extended_scalar_narrow */
    case 4048:  /* *pred_eqnevnx2di_extended_scalar_narrow */
    case 4047:  /* *pred_eqnevnx1di_extended_scalar_narrow */
    case 4046:  /* *pred_eqnevnx8di_extended_scalar */
    case 4045:  /* *pred_eqnevnx4di_extended_scalar */
    case 4044:  /* *pred_eqnevnx2di_extended_scalar */
    case 4043:  /* *pred_eqnevnx1di_extended_scalar */
    case 4042:  /* *pred_cmpvnx8di_extended_scalar_narrow */
    case 4041:  /* *pred_cmpvnx4di_extended_scalar_narrow */
    case 4040:  /* *pred_cmpvnx2di_extended_scalar_narrow */
    case 4039:  /* *pred_cmpvnx1di_extended_scalar_narrow */
    case 4038:  /* *pred_cmpvnx8di_extended_scalar */
    case 4037:  /* *pred_cmpvnx4di_extended_scalar */
    case 4036:  /* *pred_cmpvnx2di_extended_scalar */
    case 4035:  /* *pred_cmpvnx1di_extended_scalar */
    case 4034:  /* *pred_eqnevnx8di_scalar_narrow */
    case 4033:  /* *pred_eqnevnx4di_scalar_narrow */
    case 4032:  /* *pred_eqnevnx2di_scalar_narrow */
    case 4031:  /* *pred_eqnevnx1di_scalar_narrow */
    case 4030:  /* *pred_eqnevnx8di_scalar */
    case 4029:  /* *pred_eqnevnx4di_scalar */
    case 4028:  /* *pred_eqnevnx2di_scalar */
    case 4027:  /* *pred_eqnevnx1di_scalar */
    case 4026:  /* *pred_cmpvnx8di_scalar_narrow */
    case 4025:  /* *pred_cmpvnx4di_scalar_narrow */
    case 4024:  /* *pred_cmpvnx2di_scalar_narrow */
    case 4023:  /* *pred_cmpvnx1di_scalar_narrow */
    case 4022:  /* *pred_cmpvnx8di_scalar */
    case 4021:  /* *pred_cmpvnx4di_scalar */
    case 4020:  /* *pred_cmpvnx2di_scalar */
    case 4019:  /* *pred_cmpvnx1di_scalar */
    case 4018:  /* *pred_eqnevnx16si_scalar_narrow */
    case 4017:  /* *pred_eqnevnx8si_scalar_narrow */
    case 4016:  /* *pred_eqnevnx4si_scalar_narrow */
    case 4015:  /* *pred_eqnevnx2si_scalar_narrow */
    case 4014:  /* *pred_eqnevnx1si_scalar_narrow */
    case 4013:  /* *pred_eqnevnx32hi_scalar_narrow */
    case 4012:  /* *pred_eqnevnx16hi_scalar_narrow */
    case 4011:  /* *pred_eqnevnx8hi_scalar_narrow */
    case 4010:  /* *pred_eqnevnx4hi_scalar_narrow */
    case 4009:  /* *pred_eqnevnx2hi_scalar_narrow */
    case 4008:  /* *pred_eqnevnx1hi_scalar_narrow */
    case 4007:  /* *pred_eqnevnx64qi_scalar_narrow */
    case 4006:  /* *pred_eqnevnx32qi_scalar_narrow */
    case 4005:  /* *pred_eqnevnx16qi_scalar_narrow */
    case 4004:  /* *pred_eqnevnx8qi_scalar_narrow */
    case 4003:  /* *pred_eqnevnx4qi_scalar_narrow */
    case 4002:  /* *pred_eqnevnx2qi_scalar_narrow */
    case 4001:  /* *pred_eqnevnx1qi_scalar_narrow */
    case 4000:  /* *pred_eqnevnx16si_scalar */
    case 3999:  /* *pred_eqnevnx8si_scalar */
    case 3998:  /* *pred_eqnevnx4si_scalar */
    case 3997:  /* *pred_eqnevnx2si_scalar */
    case 3996:  /* *pred_eqnevnx1si_scalar */
    case 3995:  /* *pred_eqnevnx32hi_scalar */
    case 3994:  /* *pred_eqnevnx16hi_scalar */
    case 3993:  /* *pred_eqnevnx8hi_scalar */
    case 3992:  /* *pred_eqnevnx4hi_scalar */
    case 3991:  /* *pred_eqnevnx2hi_scalar */
    case 3990:  /* *pred_eqnevnx1hi_scalar */
    case 3989:  /* *pred_eqnevnx64qi_scalar */
    case 3988:  /* *pred_eqnevnx32qi_scalar */
    case 3987:  /* *pred_eqnevnx16qi_scalar */
    case 3986:  /* *pred_eqnevnx8qi_scalar */
    case 3985:  /* *pred_eqnevnx4qi_scalar */
    case 3984:  /* *pred_eqnevnx2qi_scalar */
    case 3983:  /* *pred_eqnevnx1qi_scalar */
    case 3982:  /* *pred_cmpvnx16si_scalar_narrow */
    case 3981:  /* *pred_cmpvnx8si_scalar_narrow */
    case 3980:  /* *pred_cmpvnx4si_scalar_narrow */
    case 3979:  /* *pred_cmpvnx2si_scalar_narrow */
    case 3978:  /* *pred_cmpvnx1si_scalar_narrow */
    case 3977:  /* *pred_cmpvnx32hi_scalar_narrow */
    case 3976:  /* *pred_cmpvnx16hi_scalar_narrow */
    case 3975:  /* *pred_cmpvnx8hi_scalar_narrow */
    case 3974:  /* *pred_cmpvnx4hi_scalar_narrow */
    case 3973:  /* *pred_cmpvnx2hi_scalar_narrow */
    case 3972:  /* *pred_cmpvnx1hi_scalar_narrow */
    case 3971:  /* *pred_cmpvnx64qi_scalar_narrow */
    case 3970:  /* *pred_cmpvnx32qi_scalar_narrow */
    case 3969:  /* *pred_cmpvnx16qi_scalar_narrow */
    case 3968:  /* *pred_cmpvnx8qi_scalar_narrow */
    case 3967:  /* *pred_cmpvnx4qi_scalar_narrow */
    case 3966:  /* *pred_cmpvnx2qi_scalar_narrow */
    case 3965:  /* *pred_cmpvnx1qi_scalar_narrow */
    case 3964:  /* *pred_cmpvnx16si_scalar */
    case 3963:  /* *pred_cmpvnx8si_scalar */
    case 3962:  /* *pred_cmpvnx4si_scalar */
    case 3961:  /* *pred_cmpvnx2si_scalar */
    case 3960:  /* *pred_cmpvnx1si_scalar */
    case 3959:  /* *pred_cmpvnx32hi_scalar */
    case 3958:  /* *pred_cmpvnx16hi_scalar */
    case 3957:  /* *pred_cmpvnx8hi_scalar */
    case 3956:  /* *pred_cmpvnx4hi_scalar */
    case 3955:  /* *pred_cmpvnx2hi_scalar */
    case 3954:  /* *pred_cmpvnx1hi_scalar */
    case 3953:  /* *pred_cmpvnx64qi_scalar */
    case 3952:  /* *pred_cmpvnx32qi_scalar */
    case 3951:  /* *pred_cmpvnx16qi_scalar */
    case 3950:  /* *pred_cmpvnx8qi_scalar */
    case 3949:  /* *pred_cmpvnx4qi_scalar */
    case 3948:  /* *pred_cmpvnx2qi_scalar */
    case 3947:  /* *pred_cmpvnx1qi_scalar */
    case 3946:  /* *pred_ltgevnx8di_narrow */
    case 3945:  /* *pred_ltgevnx4di_narrow */
    case 3944:  /* *pred_ltgevnx2di_narrow */
    case 3943:  /* *pred_ltgevnx1di_narrow */
    case 3942:  /* *pred_ltgevnx16si_narrow */
    case 3941:  /* *pred_ltgevnx8si_narrow */
    case 3940:  /* *pred_ltgevnx4si_narrow */
    case 3939:  /* *pred_ltgevnx2si_narrow */
    case 3938:  /* *pred_ltgevnx1si_narrow */
    case 3937:  /* *pred_ltgevnx32hi_narrow */
    case 3936:  /* *pred_ltgevnx16hi_narrow */
    case 3935:  /* *pred_ltgevnx8hi_narrow */
    case 3934:  /* *pred_ltgevnx4hi_narrow */
    case 3933:  /* *pred_ltgevnx2hi_narrow */
    case 3932:  /* *pred_ltgevnx1hi_narrow */
    case 3931:  /* *pred_ltgevnx64qi_narrow */
    case 3930:  /* *pred_ltgevnx32qi_narrow */
    case 3929:  /* *pred_ltgevnx16qi_narrow */
    case 3928:  /* *pred_ltgevnx8qi_narrow */
    case 3927:  /* *pred_ltgevnx4qi_narrow */
    case 3926:  /* *pred_ltgevnx2qi_narrow */
    case 3925:  /* *pred_ltgevnx1qi_narrow */
    case 3924:  /* *pred_ltgevnx8di */
    case 3923:  /* *pred_ltgevnx4di */
    case 3922:  /* *pred_ltgevnx2di */
    case 3921:  /* *pred_ltgevnx1di */
    case 3920:  /* *pred_ltgevnx16si */
    case 3919:  /* *pred_ltgevnx8si */
    case 3918:  /* *pred_ltgevnx4si */
    case 3917:  /* *pred_ltgevnx2si */
    case 3916:  /* *pred_ltgevnx1si */
    case 3915:  /* *pred_ltgevnx32hi */
    case 3914:  /* *pred_ltgevnx16hi */
    case 3913:  /* *pred_ltgevnx8hi */
    case 3912:  /* *pred_ltgevnx4hi */
    case 3911:  /* *pred_ltgevnx2hi */
    case 3910:  /* *pred_ltgevnx1hi */
    case 3909:  /* *pred_ltgevnx64qi */
    case 3908:  /* *pred_ltgevnx32qi */
    case 3907:  /* *pred_ltgevnx16qi */
    case 3906:  /* *pred_ltgevnx8qi */
    case 3905:  /* *pred_ltgevnx4qi */
    case 3904:  /* *pred_ltgevnx2qi */
    case 3903:  /* *pred_ltgevnx1qi */
    case 3902:  /* *pred_cmpvnx8di_narrow */
    case 3901:  /* *pred_cmpvnx4di_narrow */
    case 3900:  /* *pred_cmpvnx2di_narrow */
    case 3899:  /* *pred_cmpvnx1di_narrow */
    case 3898:  /* *pred_cmpvnx16si_narrow */
    case 3897:  /* *pred_cmpvnx8si_narrow */
    case 3896:  /* *pred_cmpvnx4si_narrow */
    case 3895:  /* *pred_cmpvnx2si_narrow */
    case 3894:  /* *pred_cmpvnx1si_narrow */
    case 3893:  /* *pred_cmpvnx32hi_narrow */
    case 3892:  /* *pred_cmpvnx16hi_narrow */
    case 3891:  /* *pred_cmpvnx8hi_narrow */
    case 3890:  /* *pred_cmpvnx4hi_narrow */
    case 3889:  /* *pred_cmpvnx2hi_narrow */
    case 3888:  /* *pred_cmpvnx1hi_narrow */
    case 3887:  /* *pred_cmpvnx64qi_narrow */
    case 3886:  /* *pred_cmpvnx32qi_narrow */
    case 3885:  /* *pred_cmpvnx16qi_narrow */
    case 3884:  /* *pred_cmpvnx8qi_narrow */
    case 3883:  /* *pred_cmpvnx4qi_narrow */
    case 3882:  /* *pred_cmpvnx2qi_narrow */
    case 3881:  /* *pred_cmpvnx1qi_narrow */
    case 3880:  /* *pred_cmpvnx8di */
    case 3879:  /* *pred_cmpvnx4di */
    case 3878:  /* *pred_cmpvnx2di */
    case 3877:  /* *pred_cmpvnx1di */
    case 3876:  /* *pred_cmpvnx16si */
    case 3875:  /* *pred_cmpvnx8si */
    case 3874:  /* *pred_cmpvnx4si */
    case 3873:  /* *pred_cmpvnx2si */
    case 3872:  /* *pred_cmpvnx1si */
    case 3871:  /* *pred_cmpvnx32hi */
    case 3870:  /* *pred_cmpvnx16hi */
    case 3869:  /* *pred_cmpvnx8hi */
    case 3868:  /* *pred_cmpvnx4hi */
    case 3867:  /* *pred_cmpvnx2hi */
    case 3866:  /* *pred_cmpvnx1hi */
    case 3865:  /* *pred_cmpvnx64qi */
    case 3864:  /* *pred_cmpvnx32qi */
    case 3863:  /* *pred_cmpvnx16qi */
    case 3862:  /* *pred_cmpvnx8qi */
    case 3861:  /* *pred_cmpvnx4qi */
    case 3860:  /* *pred_cmpvnx2qi */
    case 3859:  /* *pred_cmpvnx1qi */
      return 6;

    case 998:  /* pred_strided_loadvnx8df */
    case 997:  /* pred_strided_loadvnx4df */
    case 996:  /* pred_strided_loadvnx2df */
    case 995:  /* pred_strided_loadvnx1df */
    case 994:  /* pred_strided_loadvnx16sf */
    case 993:  /* pred_strided_loadvnx8sf */
    case 992:  /* pred_strided_loadvnx4sf */
    case 991:  /* pred_strided_loadvnx2sf */
    case 990:  /* pred_strided_loadvnx1sf */
    case 989:  /* pred_strided_loadvnx8di */
    case 988:  /* pred_strided_loadvnx4di */
    case 987:  /* pred_strided_loadvnx2di */
    case 986:  /* pred_strided_loadvnx1di */
    case 985:  /* pred_strided_loadvnx16si */
    case 984:  /* pred_strided_loadvnx8si */
    case 983:  /* pred_strided_loadvnx4si */
    case 982:  /* pred_strided_loadvnx2si */
    case 981:  /* pred_strided_loadvnx1si */
    case 980:  /* pred_strided_loadvnx32hi */
    case 979:  /* pred_strided_loadvnx16hi */
    case 978:  /* pred_strided_loadvnx8hi */
    case 977:  /* pred_strided_loadvnx4hi */
    case 976:  /* pred_strided_loadvnx2hi */
    case 975:  /* pred_strided_loadvnx1hi */
    case 974:  /* pred_strided_loadvnx64qi */
    case 973:  /* pred_strided_loadvnx32qi */
    case 972:  /* pred_strided_loadvnx16qi */
    case 971:  /* pred_strided_loadvnx8qi */
    case 970:  /* pred_strided_loadvnx4qi */
    case 969:  /* pred_strided_loadvnx2qi */
    case 968:  /* pred_strided_loadvnx1qi */
      extract_constrain_insn_cached (insn);
      if (
#line 239 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(VECTOR_MODE_P (GET_MODE (operands[3]))))
        {
	  return 5;
        }
      else
        {
	  return 4;
        }

    case 963:  /* *pred_broadcastvnx8df */
    case 962:  /* *pred_broadcastvnx4df */
    case 961:  /* *pred_broadcastvnx2df */
    case 960:  /* *pred_broadcastvnx1df */
    case 959:  /* *pred_broadcastvnx16sf */
    case 958:  /* *pred_broadcastvnx8sf */
    case 957:  /* *pred_broadcastvnx4sf */
    case 956:  /* *pred_broadcastvnx2sf */
    case 955:  /* *pred_broadcastvnx1sf */
    case 954:  /* *pred_broadcastvnx8di */
    case 953:  /* *pred_broadcastvnx4di */
    case 952:  /* *pred_broadcastvnx2di */
    case 951:  /* *pred_broadcastvnx1di */
    case 950:  /* *pred_broadcastvnx16si */
    case 949:  /* *pred_broadcastvnx8si */
    case 948:  /* *pred_broadcastvnx4si */
    case 947:  /* *pred_broadcastvnx2si */
    case 946:  /* *pred_broadcastvnx1si */
    case 945:  /* *pred_broadcastvnx32hi */
    case 944:  /* *pred_broadcastvnx16hi */
    case 943:  /* *pred_broadcastvnx8hi */
    case 942:  /* *pred_broadcastvnx4hi */
    case 941:  /* *pred_broadcastvnx2hi */
    case 940:  /* *pred_broadcastvnx1hi */
    case 939:  /* *pred_broadcastvnx64qi */
    case 938:  /* *pred_broadcastvnx32qi */
    case 937:  /* *pred_broadcastvnx16qi */
    case 936:  /* *pred_broadcastvnx8qi */
    case 935:  /* *pred_broadcastvnx4qi */
    case 934:  /* *pred_broadcastvnx2qi */
    case 933:  /* *pred_broadcastvnx1qi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3cULL))
        {
	  return 4;
        }
      else
        {
	  if (
#line 239 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(VECTOR_MODE_P (GET_MODE (operands[3]))))
	    {
	      return 5;
	    }
	  else
	    {
	      return 4;
	    }
        }

    case 6036:  /* read_vldi_zero_extend */
    case 6035:  /* read_vlsi */
    case 5779:  /* *pred_extract_firstvnx8df */
    case 5778:  /* *pred_extract_firstvnx4df */
    case 5777:  /* *pred_extract_firstvnx2df */
    case 5776:  /* *pred_extract_firstvnx1df */
    case 5775:  /* *pred_extract_firstvnx16sf */
    case 5774:  /* *pred_extract_firstvnx8sf */
    case 5773:  /* *pred_extract_firstvnx4sf */
    case 5772:  /* *pred_extract_firstvnx2sf */
    case 5771:  /* *pred_extract_firstvnx1sf */
    case 5770:  /* pred_extract_first_truncvnx8di */
    case 5769:  /* pred_extract_first_truncvnx4di */
    case 5768:  /* pred_extract_first_truncvnx2di */
    case 5767:  /* pred_extract_first_truncvnx1di */
    case 5766:  /* *pred_extract_firstvnx8di */
    case 5765:  /* *pred_extract_firstvnx4di */
    case 5764:  /* *pred_extract_firstvnx2di */
    case 5763:  /* *pred_extract_firstvnx1di */
    case 5762:  /* *pred_extract_firstvnx16si */
    case 5761:  /* *pred_extract_firstvnx8si */
    case 5760:  /* *pred_extract_firstvnx4si */
    case 5759:  /* *pred_extract_firstvnx2si */
    case 5758:  /* *pred_extract_firstvnx1si */
    case 5757:  /* *pred_extract_firstvnx32hi */
    case 5756:  /* *pred_extract_firstvnx16hi */
    case 5755:  /* *pred_extract_firstvnx8hi */
    case 5754:  /* *pred_extract_firstvnx4hi */
    case 5753:  /* *pred_extract_firstvnx2hi */
    case 5752:  /* *pred_extract_firstvnx1hi */
    case 5751:  /* *pred_extract_firstvnx64qi */
    case 5750:  /* *pred_extract_firstvnx32qi */
    case 5749:  /* *pred_extract_firstvnx16qi */
    case 5748:  /* *pred_extract_firstvnx8qi */
    case 5747:  /* *pred_extract_firstvnx4qi */
    case 5746:  /* *pred_extract_firstvnx2qi */
    case 5745:  /* *pred_extract_firstvnx1qi */
    case 799:  /* vsetvldi_no_side_effects */
    case 798:  /* vsetvlsi_no_side_effects */
    case 797:  /* vsetvl_discard_resultdi */
    case 796:  /* vsetvl_discard_resultsi */
    case 795:  /* vsetvl_vtype_change_only */
    case 794:  /* vsetvldi */
    case 793:  /* vsetvlsi */
    case 792:  /* *movvnx64bidi_lra */
    case 791:  /* *movvnx32bidi_lra */
    case 790:  /* *movvnx16bidi_lra */
    case 789:  /* *movvnx8bidi_lra */
    case 788:  /* *movvnx4bidi_lra */
    case 787:  /* *movvnx2bidi_lra */
    case 786:  /* *movvnx1bidi_lra */
    case 785:  /* *movvnx64bisi_lra */
    case 784:  /* *movvnx32bisi_lra */
    case 783:  /* *movvnx16bisi_lra */
    case 782:  /* *movvnx8bisi_lra */
    case 781:  /* *movvnx4bisi_lra */
    case 780:  /* *movvnx2bisi_lra */
    case 779:  /* *movvnx1bisi_lra */
    case 778:  /* *movvnx1sfdi_lra */
    case 777:  /* *movvnx1sfsi_lra */
    case 776:  /* *movvnx1sidi_lra */
    case 775:  /* *movvnx1sisi_lra */
    case 774:  /* *movvnx2hidi_lra */
    case 773:  /* *movvnx2hisi_lra */
    case 772:  /* *movvnx1hidi_lra */
    case 771:  /* *movvnx1hisi_lra */
    case 770:  /* *movvnx4qidi_lra */
    case 769:  /* *movvnx4qisi_lra */
    case 768:  /* *movvnx2qidi_lra */
    case 767:  /* *movvnx2qisi_lra */
    case 766:  /* *movvnx1qidi_lra */
    case 765:  /* *movvnx1qisi_lra */
    case 764:  /* *movvnx64bi */
    case 763:  /* *movvnx32bi */
    case 762:  /* *movvnx16bi */
    case 761:  /* *movvnx8bi */
    case 760:  /* *movvnx4bi */
    case 759:  /* *movvnx2bi */
    case 758:  /* *movvnx1bi */
    case 757:  /* *movvnx1sf_fract */
    case 756:  /* *movvnx1si_fract */
    case 755:  /* *movvnx2hi_fract */
    case 754:  /* *movvnx1hi_fract */
    case 753:  /* *movvnx4qi_fract */
    case 752:  /* *movvnx2qi_fract */
    case 751:  /* *movvnx1qi_fract */
    case 750:  /* *movvnx8df_whole */
    case 749:  /* *movvnx4df_whole */
    case 748:  /* *movvnx2df_whole */
    case 747:  /* *movvnx1df_whole */
    case 746:  /* *movvnx16sf_whole */
    case 745:  /* *movvnx8sf_whole */
    case 744:  /* *movvnx4sf_whole */
    case 743:  /* *movvnx2sf_whole */
    case 742:  /* *movvnx1sf_whole */
    case 741:  /* *movvnx8di_whole */
    case 740:  /* *movvnx4di_whole */
    case 739:  /* *movvnx2di_whole */
    case 738:  /* *movvnx1di_whole */
    case 737:  /* *movvnx16si_whole */
    case 736:  /* *movvnx8si_whole */
    case 735:  /* *movvnx4si_whole */
    case 734:  /* *movvnx2si_whole */
    case 733:  /* *movvnx1si_whole */
    case 732:  /* *movvnx32hi_whole */
    case 731:  /* *movvnx16hi_whole */
    case 730:  /* *movvnx8hi_whole */
    case 729:  /* *movvnx4hi_whole */
    case 728:  /* *movvnx2hi_whole */
    case 727:  /* *movvnx64qi_whole */
    case 726:  /* *movvnx32qi_whole */
    case 725:  /* *movvnx16qi_whole */
    case 724:  /* *movvnx8qi_whole */
    case 723:  /* *movvnx4qi_whole */
    case 722:  /* vlmax_avldi */
    case 721:  /* vlmax_avlsi */
    case 720:  /* *vlmul_extx64vnx1qi */
    case 719:  /* *vlmul_extx32vnx1hi */
    case 718:  /* *vlmul_extx32vnx2qi */
    case 717:  /* *vlmul_extx32vnx1qi */
    case 716:  /* *vlmul_extx16vnx1sf */
    case 715:  /* *vlmul_extx16vnx1si */
    case 714:  /* *vlmul_extx16vnx2hi */
    case 713:  /* *vlmul_extx16vnx1hi */
    case 712:  /* *vlmul_extx16vnx4qi */
    case 711:  /* *vlmul_extx16vnx2qi */
    case 710:  /* *vlmul_extx16vnx1qi */
    case 709:  /* *vlmul_extx8vnx1df */
    case 708:  /* *vlmul_extx8vnx2sf */
    case 707:  /* *vlmul_extx8vnx1sf */
    case 706:  /* *vlmul_extx8vnx1di */
    case 705:  /* *vlmul_extx8vnx2si */
    case 704:  /* *vlmul_extx8vnx1si */
    case 703:  /* *vlmul_extx8vnx4hi */
    case 702:  /* *vlmul_extx8vnx2hi */
    case 701:  /* *vlmul_extx8vnx1hi */
    case 700:  /* *vlmul_extx8vnx8qi */
    case 699:  /* *vlmul_extx8vnx4qi */
    case 698:  /* *vlmul_extx8vnx2qi */
    case 697:  /* *vlmul_extx8vnx1qi */
    case 696:  /* *vlmul_extx4vnx2df */
    case 695:  /* *vlmul_extx4vnx1df */
    case 694:  /* *vlmul_extx4vnx4sf */
    case 693:  /* *vlmul_extx4vnx2sf */
    case 692:  /* *vlmul_extx4vnx1sf */
    case 691:  /* *vlmul_extx4vnx2di */
    case 690:  /* *vlmul_extx4vnx1di */
    case 689:  /* *vlmul_extx4vnx4si */
    case 688:  /* *vlmul_extx4vnx2si */
    case 687:  /* *vlmul_extx4vnx1si */
    case 686:  /* *vlmul_extx4vnx8hi */
    case 685:  /* *vlmul_extx4vnx4hi */
    case 684:  /* *vlmul_extx4vnx2hi */
    case 683:  /* *vlmul_extx4vnx1hi */
    case 682:  /* *vlmul_extx4vnx16qi */
    case 681:  /* *vlmul_extx4vnx8qi */
    case 680:  /* *vlmul_extx4vnx4qi */
    case 679:  /* *vlmul_extx4vnx2qi */
    case 678:  /* *vlmul_extx4vnx1qi */
    case 677:  /* *vlmul_extx2vnx4df */
    case 676:  /* *vlmul_extx2vnx2df */
    case 675:  /* *vlmul_extx2vnx1df */
    case 674:  /* *vlmul_extx2vnx8sf */
    case 673:  /* *vlmul_extx2vnx4sf */
    case 672:  /* *vlmul_extx2vnx2sf */
    case 671:  /* *vlmul_extx2vnx1sf */
    case 670:  /* *vlmul_extx2vnx4di */
    case 669:  /* *vlmul_extx2vnx2di */
    case 668:  /* *vlmul_extx2vnx1di */
    case 667:  /* *vlmul_extx2vnx8si */
    case 666:  /* *vlmul_extx2vnx4si */
    case 665:  /* *vlmul_extx2vnx2si */
    case 664:  /* *vlmul_extx2vnx1si */
    case 663:  /* *vlmul_extx2vnx16hi */
    case 662:  /* *vlmul_extx2vnx8hi */
    case 661:  /* *vlmul_extx2vnx4hi */
    case 660:  /* *vlmul_extx2vnx2hi */
    case 659:  /* *vlmul_extx2vnx1hi */
    case 658:  /* *vlmul_extx2vnx32qi */
    case 657:  /* *vlmul_extx2vnx16qi */
    case 656:  /* *vlmul_extx2vnx8qi */
    case 655:  /* *vlmul_extx2vnx4qi */
    case 654:  /* *vlmul_extx2vnx2qi */
    case 653:  /* *vlmul_extx2vnx1qi */
    case 652:  /* vundefinedvnx64bi */
    case 651:  /* vundefinedvnx32bi */
    case 650:  /* vundefinedvnx16bi */
    case 649:  /* vundefinedvnx8bi */
    case 648:  /* vundefinedvnx4bi */
    case 647:  /* vundefinedvnx2bi */
    case 646:  /* vundefinedvnx1bi */
    case 645:  /* vundefinedvnx8df */
    case 644:  /* vundefinedvnx4df */
    case 643:  /* vundefinedvnx2df */
    case 642:  /* vundefinedvnx1df */
    case 641:  /* vundefinedvnx16sf */
    case 640:  /* vundefinedvnx8sf */
    case 639:  /* vundefinedvnx4sf */
    case 638:  /* vundefinedvnx2sf */
    case 637:  /* vundefinedvnx1sf */
    case 636:  /* vundefinedvnx8di */
    case 635:  /* vundefinedvnx4di */
    case 634:  /* vundefinedvnx2di */
    case 633:  /* vundefinedvnx1di */
    case 632:  /* vundefinedvnx16si */
    case 631:  /* vundefinedvnx8si */
    case 630:  /* vundefinedvnx4si */
    case 629:  /* vundefinedvnx2si */
    case 628:  /* vundefinedvnx1si */
    case 627:  /* vundefinedvnx32hi */
    case 626:  /* vundefinedvnx16hi */
    case 625:  /* vundefinedvnx8hi */
    case 624:  /* vundefinedvnx4hi */
    case 623:  /* vundefinedvnx2hi */
    case 622:  /* vundefinedvnx1hi */
    case 621:  /* vundefinedvnx64qi */
    case 620:  /* vundefinedvnx32qi */
    case 619:  /* vundefinedvnx16qi */
    case 618:  /* vundefinedvnx8qi */
    case 617:  /* vundefinedvnx4qi */
    case 616:  /* vundefinedvnx2qi */
    case 615:  /* vundefinedvnx1qi */
    case 614:  /* *th_mempair_load_zero_extendsidi2 */
    case 613:  /* *th_mempair_load_extendsidi2 */
    case 612:  /* *th_mempair_store_di2 */
    case 611:  /* *th_mempair_store_si2 */
    case 610:  /* *th_mempair_load_di2 */
    case 609:  /* *th_mempair_load_si2 */
    case 608:  /* *th_sextw_msubhisi4 */
    case 607:  /* *th_msubhisi4 */
    case 606:  /* *th_mulswsi2 */
    case 605:  /* *th_mulswsi */
    case 604:  /* *th_mulsdi */
    case 603:  /* *th_mulssi */
    case 602:  /* *th_sextw_maddhisi4 */
    case 601:  /* *th_maddhisi4 */
    case 600:  /* *th_mulawsi2 */
    case 599:  /* *th_mulawsi */
    case 598:  /* *th_muladi */
    case 597:  /* *th_mulasi */
    case 596:  /* th_fmv_x_hw */
    case 595:  /* th_fmv_x_w */
    case 594:  /* th_fmv_hw_w_x */
    case 593:  /* *th_cond_gpr_movdidi */
    case 592:  /* *th_cond_gpr_movsidi */
    case 591:  /* *th_cond_gpr_movdisi */
    case 590:  /* *th_cond_gpr_movsisi */
    case 589:  /* *th_cond_movdidi */
    case 588:  /* *th_cond_movsidi */
    case 587:  /* *th_cond_movdisi */
    case 586:  /* *th_cond_movsisi */
    case 585:  /* *th_tstdi3 */
    case 584:  /* *th_tstsi3 */
    case 583:  /* *th_revdi2 */
    case 582:  /* *th_revsi2 */
    case 581:  /* *th_clzdi2 */
    case 580:  /* *th_clzsi2 */
    case 579:  /* *th_extudi4 */
    case 578:  /* *th_extusi4 */
    case 577:  /* *th_extdi4 */
    case 576:  /* *th_extsi4 */
    case 575:  /* *th_srridi3 */
    case 574:  /* *th_srrisi3 */
    case 573:  /* *th_addsldi4 */
    case 572:  /* *th_addslsi4 */
    case 571:  /* *local_pic_store_sfhf */
    case 570:  /* *local_pic_store_sfdf */
    case 569:  /* *local_pic_store_sfsf */
    case 568:  /* *local_pic_store_sfhf */
    case 567:  /* *local_pic_store_sfdf */
    case 566:  /* *local_pic_store_sfsf */
    case 565:  /* *local_pic_store_32dhf */
    case 564:  /* *local_pic_store_32ddf */
    case 563:  /* *local_pic_store_32dsf */
    case 562:  /* *local_pic_store_32dhf */
    case 561:  /* *local_pic_store_32ddf */
    case 560:  /* *local_pic_store_32dsf */
    case 559:  /* *local_pic_storehf */
    case 558:  /* *local_pic_storedf */
    case 557:  /* *local_pic_storesf */
    case 556:  /* *local_pic_storehf */
    case 555:  /* *local_pic_storedf */
    case 554:  /* *local_pic_storesf */
    case 553:  /* *local_pic_storedi */
    case 552:  /* *local_pic_storesi */
    case 551:  /* *local_pic_storehi */
    case 550:  /* *local_pic_storeqi */
    case 549:  /* *local_pic_storedi */
    case 548:  /* *local_pic_storesi */
    case 547:  /* *local_pic_storehi */
    case 546:  /* *local_pic_storeqi */
    case 545:  /* *local_pic_load_sfhf */
    case 544:  /* *local_pic_load_sfdf */
    case 543:  /* *local_pic_load_sfsf */
    case 542:  /* *local_pic_load_32dhf */
    case 541:  /* *local_pic_load_32ddf */
    case 540:  /* *local_pic_load_32dsf */
    case 539:  /* *local_pic_load_32dhf */
    case 538:  /* *local_pic_load_32ddf */
    case 537:  /* *local_pic_load_32dsf */
    case 536:  /* *local_pic_loadhf */
    case 535:  /* *local_pic_loaddf */
    case 534:  /* *local_pic_loadsf */
    case 533:  /* *local_pic_loadhf */
    case 532:  /* *local_pic_loaddf */
    case 531:  /* *local_pic_loadsf */
    case 530:  /* *local_pic_load_usi */
    case 529:  /* *local_pic_load_usi */
    case 528:  /* *local_pic_load_usi */
    case 527:  /* *local_pic_load_uhi */
    case 526:  /* *local_pic_load_uhi */
    case 525:  /* *local_pic_load_uhi */
    case 524:  /* *local_pic_load_uqi */
    case 523:  /* *local_pic_load_uqi */
    case 522:  /* *local_pic_load_uqi */
    case 521:  /* *local_pic_load_ssi */
    case 520:  /* *local_pic_load_ssi */
    case 519:  /* *local_pic_load_ssi */
    case 518:  /* *local_pic_load_shi */
    case 517:  /* *local_pic_load_shi */
    case 516:  /* *local_pic_load_shi */
    case 515:  /* *local_pic_load_sqi */
    case 514:  /* *local_pic_load_sqi */
    case 513:  /* *local_pic_load_sqi */
    case 512:  /* *local_pic_loaddi */
    case 511:  /* *local_pic_loadsi */
    case 510:  /* *local_pic_loadhi */
    case 509:  /* *local_pic_loadqi */
    case 508:  /* subword_atomic_cas_strong */
    case 507:  /* atomic_cas_value_strongdi */
    case 506:  /* atomic_cas_value_strongsi */
    case 505:  /* subword_atomic_exchange_strong */
    case 504:  /* atomic_exchangedi */
    case 503:  /* atomic_exchangesi */
    case 502:  /* subword_atomic_fetch_strong_nand */
    case 501:  /* subword_atomic_fetch_strong_and */
    case 500:  /* subword_atomic_fetch_strong_xor */
    case 499:  /* subword_atomic_fetch_strong_or */
    case 498:  /* subword_atomic_fetch_strong_add */
    case 497:  /* atomic_fetch_anddi */
    case 496:  /* atomic_fetch_xordi */
    case 495:  /* atomic_fetch_ordi */
    case 494:  /* atomic_fetch_adddi */
    case 493:  /* atomic_fetch_andsi */
    case 492:  /* atomic_fetch_xorsi */
    case 491:  /* atomic_fetch_orsi */
    case 490:  /* atomic_fetch_addsi */
    case 489:  /* atomic_anddi */
    case 488:  /* atomic_xordi */
    case 487:  /* atomic_ordi */
    case 486:  /* atomic_adddi */
    case 485:  /* atomic_andsi */
    case 484:  /* atomic_xorsi */
    case 483:  /* atomic_orsi */
    case 482:  /* atomic_addsi */
    case 481:  /* atomic_storedi */
    case 480:  /* atomic_storesi */
    case 479:  /* atomic_loaddi */
    case 478:  /* atomic_loadsi */
    case 477:  /* mem_thread_fence_1 */
    case 476:  /* riscv_sm4ks_di */
    case 475:  /* riscv_sm4ks_si */
    case 474:  /* riscv_sm4ed_di */
    case 473:  /* riscv_sm4ed_si */
    case 472:  /* riscv_sm3p1_di */
    case 471:  /* riscv_sm3p1_si */
    case 470:  /* riscv_sm3p0_di */
    case 469:  /* riscv_sm3p0_si */
    case 468:  /* riscv_sha512sum1 */
    case 467:  /* riscv_sha512sum0 */
    case 466:  /* riscv_sha512sig1 */
    case 465:  /* riscv_sha512sig0 */
    case 464:  /* riscv_sha512sum1r */
    case 463:  /* riscv_sha512sum0r */
    case 462:  /* riscv_sha512sig1l */
    case 461:  /* riscv_sha512sig1h */
    case 460:  /* riscv_sha512sig0l */
    case 459:  /* riscv_sha512sig0h */
    case 458:  /* riscv_sha256sum1_di */
    case 457:  /* riscv_sha256sum1_si */
    case 456:  /* riscv_sha256sum0_di */
    case 455:  /* riscv_sha256sum0_si */
    case 454:  /* riscv_sha256sig1_di */
    case 453:  /* riscv_sha256sig1_si */
    case 452:  /* riscv_sha256sig0_di */
    case 451:  /* riscv_sha256sig0_si */
    case 450:  /* riscv_aes64esm */
    case 449:  /* riscv_aes64es */
    case 448:  /* riscv_aes32esmi */
    case 447:  /* riscv_aes32esi */
    case 446:  /* riscv_aes64ks2 */
    case 445:  /* riscv_aes64ks1i */
    case 444:  /* riscv_aes64im */
    case 443:  /* riscv_aes64dsm */
    case 442:  /* riscv_aes64ds */
    case 441:  /* riscv_aes32dsmi */
    case 440:  /* riscv_aes32dsi */
    case 439:  /* riscv_xperm8_di */
    case 438:  /* riscv_xperm8_si */
    case 437:  /* riscv_xperm4_di */
    case 436:  /* riscv_xperm4_si */
    case 435:  /* riscv_clmulh_di */
    case 434:  /* riscv_clmulh_si */
    case 433:  /* riscv_clmul_di */
    case 432:  /* riscv_clmul_si */
    case 431:  /* riscv_packw */
    case 430:  /* riscv_packh_di */
    case 429:  /* riscv_packh_si */
    case 428:  /* riscv_pack_disi */
    case 427:  /* riscv_pack_dihi */
    case 426:  /* riscv_pack_sisi */
    case 425:  /* riscv_pack_sihi */
    case 424:  /* riscv_unzip */
    case 423:  /* riscv_zip */
    case 422:  /* riscv_brev8_di */
    case 421:  /* riscv_brev8_si */
    case 420:  /* *branchdi_mask_twobits_equals_singlebit */
    case 419:  /* *branchsi_mask_twobits_equals_singlebit */
    case 418:  /* *andidi_extrabit */
    case 417:  /* *andisi_extrabit */
    case 416:  /* *xoridi_extrabit */
    case 415:  /* *ioridi_extrabit */
    case 414:  /* *xorisi_extrabit */
    case 413:  /* *iorisi_extrabit */
    case 412:  /* *bexti */
    case 411:  /* *bexti */
    case 410:  /* *bextdi */
    case 409:  /* *bextsi */
    case 408:  /* *bextdi */
    case 407:  /* *bextsi */
    case 406:  /* *binvidi */
    case 405:  /* *binvisi */
    case 404:  /* *binvdi */
    case 403:  /* *binvsi */
    case 402:  /* *bclridisi_nottwobits */
    case 401:  /* *bclridi_nottwobits */
    case 400:  /* *bclrisi_nottwobits */
    case 399:  /* *bclridi */
    case 398:  /* *bclrisi */
    case 397:  /* *bclrdi */
    case 396:  /* *bclrsi */
    case 395:  /* *bsetidisi */
    case 394:  /* *bsetidi */
    case 393:  /* *bsetisi */
    case 392:  /* *bsetdi_1_mask */
    case 391:  /* *bsetsi_1_mask */
    case 390:  /* *bsetdi_1 */
    case 389:  /* *bsetsi_1 */
    case 388:  /* *bsetdi_mask */
    case 387:  /* *bsetsi_mask */
    case 386:  /* *bsetdi */
    case 385:  /* *bsetsi */
    case 384:  /* *minmax */
    case 383:  /* *minmax */
    case 382:  /* *minmax */
    case 381:  /* *minmax */
    case 380:  /* umaxdi3 */
    case 379:  /* smaxdi3 */
    case 378:  /* umindi3 */
    case 377:  /* smindi3 */
    case 376:  /* umaxsi3 */
    case 375:  /* smaxsi3 */
    case 374:  /* uminsi3 */
    case 373:  /* sminsi3 */
    case 372:  /* *bswapdi2 */
    case 371:  /* *bswapsi2 */
    case 370:  /* orcbdi2 */
    case 369:  /* orcbsi2 */
    case 368:  /* rotlsi3_sext */
    case 367:  /* rotldi3 */
    case 366:  /* rotlsi3 */
    case 365:  /* *rotrsi3_sext */
    case 364:  /* *rotrdi3 */
    case 363:  /* *rotrsi3 */
    case 362:  /* *zero_extendhidi2_zbb */
    case 361:  /* *zero_extendhisi2_zbb */
    case 360:  /* *extendhidi2_zbb */
    case 359:  /* *extendhisi2_zbb */
    case 358:  /* *extendhihi2_zbb */
    case 357:  /* *extendqidi2_zbb */
    case 356:  /* *extendqisi2_zbb */
    case 355:  /* *extendqihi2_zbb */
    case 354:  /* *zero_extendhidi2_bitmanip */
    case 353:  /* *zero_extendhisi2_bitmanip */
    case 352:  /* *popcountdi2 */
    case 351:  /* *ctzdi2 */
    case 350:  /* *clzdi2 */
    case 349:  /* *popcountdisi2 */
    case 348:  /* *ctzdisi2 */
    case 347:  /* *clzdisi2 */
    case 346:  /* *popcountsi2 */
    case 345:  /* *ctzsi2 */
    case 344:  /* *clzsi2 */
    case 343:  /* *xor_notdi */
    case 342:  /* *xor_notsi */
    case 341:  /* *ior_notdi */
    case 340:  /* *and_notdi */
    case 339:  /* *ior_notsi */
    case 338:  /* *and_notsi */
    case 337:  /* *slliuw */
    case 336:  /* *add.uw */
    case 335:  /* *shNadduw */
    case 334:  /* *andi_add.uw */
    case 333:  /* *shNadd */
    case 332:  /* *shNadd */
    case 331:  /* *zero_extendsidi2_bitmanip */
    case 330:  /* riscv_prefetchi_di */
    case 329:  /* riscv_prefetchi_si */
    case 328:  /* prefetch */
    case 327:  /* riscv_zero_di */
    case 326:  /* riscv_zero_si */
    case 325:  /* riscv_inval_di */
    case 324:  /* riscv_inval_si */
    case 323:  /* riscv_flush_di */
    case 322:  /* riscv_flush_si */
    case 321:  /* riscv_clean_di */
    case 320:  /* riscv_clean_si */
    case 319:  /* stack_protect_test_di */
    case 318:  /* stack_protect_test_si */
    case 317:  /* stack_protect_set_di */
    case 316:  /* stack_protect_set_si */
    case 315:  /* stack_tiedi */
    case 314:  /* stack_tiesi */
    case 313:  /* riscv_uret */
    case 312:  /* riscv_sret */
    case 311:  /* riscv_mret */
    case 310:  /* *riscv_fsnvsnanhf2 */
    case 309:  /* *riscv_fsnvsnandf2 */
    case 308:  /* *riscv_fsnvsnansf2 */
    case 307:  /* riscv_fsflags */
    case 306:  /* riscv_frflags */
    case 305:  /* gpr_restore_return */
    case 304:  /* gpr_restore */
    case 303:  /* gpr_save */
    case 302:  /* trap */
    case 301:  /* nop */
    case 300:  /* call_value_internal */
    case 299:  /* call_internal */
    case 298:  /* sibcall_value_internal */
    case 297:  /* sibcall_internal */
    case 296:  /* eh_return_internal */
    case 295:  /* eh_set_lr_di */
    case 294:  /* eh_set_lr_si */
    case 293:  /* simple_return_internal */
    case 292:  /* simple_return */
    case 291:  /* blockage */
    case 290:  /* tablejumpdi */
    case 289:  /* tablejumpsi */
    case 288:  /* indirect_jumpdi */
    case 287:  /* indirect_jumpsi */
    case 286:  /* jump */
    case 285:  /* *sleu_didi */
    case 284:  /* *sle_didi */
    case 283:  /* *sleu_disi */
    case 282:  /* *sle_disi */
    case 281:  /* *sleu_sisi */
    case 280:  /* *sle_sisi */
    case 279:  /* *sltu_didi */
    case 278:  /* *slt_didi */
    case 277:  /* *sltu_disi */
    case 276:  /* *slt_disi */
    case 275:  /* *sltu_sisi */
    case 274:  /* *slt_sisi */
    case 273:  /* *sgeu_didi */
    case 272:  /* *sge_didi */
    case 271:  /* *sgeu_disi */
    case 270:  /* *sge_disi */
    case 269:  /* *sgeu_sisi */
    case 268:  /* *sge_sisi */
    case 267:  /* *sgtu_didi */
    case 266:  /* *sgt_didi */
    case 265:  /* *sgtu_disi */
    case 264:  /* *sgt_disi */
    case 263:  /* *sgtu_sisi */
    case 262:  /* *sgt_sisi */
    case 261:  /* *sne_zero_didi */
    case 260:  /* *sne_zero_disi */
    case 259:  /* *sne_zero_sisi */
    case 258:  /* *seq_zero_didi */
    case 257:  /* *seq_zero_disi */
    case 256:  /* *seq_zero_sisi */
    case 255:  /* *cstorehfdi4 */
    case 254:  /* *cstorehfsi4 */
    case 253:  /* *cstoredfdi4 */
    case 252:  /* *cstoredfsi4 */
    case 251:  /* *cstoresfdi4 */
    case 250:  /* *cstoresfsi4 */
    case 249:  /* *branch_on_bit_rangedi */
    case 248:  /* *branch_on_bit_rangesi */
    case 247:  /* *branch_on_bitdi */
    case 246:  /* *branch_on_bitsi */
    case 245:  /* *movdidicc */
    case 244:  /* *movsidicc */
    case 243:  /* *movsisicc */
    case 242:  /* *branchdi */
    case 241:  /* *branchsi */
    case 240:  /* *branchdi_shiftedmask_equals_zero */
    case 239:  /* *branchsi_shiftedmask_equals_zero */
    case 238:  /* *branchhi_shiftedmask_equals_zero */
    case 237:  /* *branchqi_shiftedmask_equals_zero */
    case 236:  /* *branchdi_shiftedmask_equals_zero */
    case 235:  /* *branchsi_shiftedmask_equals_zero */
    case 234:  /* *branchhi_shiftedmask_equals_zero */
    case 233:  /* *branchqi_shiftedmask_equals_zero */
    case 232:  /* *branchdi_shiftedarith_equals_zero */
    case 231:  /* *branchsi_shiftedarith_equals_zero */
    case 230:  /* *branchhi_shiftedarith_equals_zero */
    case 229:  /* *branchqi_shiftedarith_equals_zero */
    case 228:  /* *branchsi_shiftedarith_equals_zero */
    case 227:  /* *branchhi_shiftedarith_equals_zero */
    case 226:  /* *branchqi_shiftedarith_equals_zero */
    case 225:  /* zero_extendsidi2_shifted */
    case 224:  /* *lshrsi3_zero_extend_3 */
    case 223:  /* *lshrsi3_zero_extend_2 */
    case 222:  /* *lshrsi3_zero_extend_1 */
    case 221:  /* *lshrsi3_extend_mask_1 */
    case 220:  /* *ashrsi3_extend_mask_1 */
    case 219:  /* *ashlsi3_extend_mask_1 */
    case 218:  /* *lshrsi3_extend_mask */
    case 217:  /* *ashrsi3_extend_mask */
    case 216:  /* *ashlsi3_extend_mask */
    case 215:  /* *lshrsi3_extend */
    case 214:  /* *ashrsi3_extend */
    case 213:  /* *ashlsi3_extend */
    case 212:  /* *lshrdi3_mask_1 */
    case 211:  /* *ashrdi3_mask_1 */
    case 210:  /* *ashldi3_mask_1 */
    case 209:  /* *lshrdi3_mask */
    case 208:  /* *ashrdi3_mask */
    case 207:  /* *ashldi3_mask */
    case 206:  /* lshrdi3 */
    case 205:  /* ashrdi3 */
    case 204:  /* ashldi3 */
    case 203:  /* *lshrsi3_mask_1 */
    case 202:  /* *ashrsi3_mask_1 */
    case 201:  /* *ashlsi3_mask_1 */
    case 200:  /* *lshrsi3_mask */
    case 199:  /* *ashrsi3_mask */
    case 198:  /* *ashlsi3_mask */
    case 197:  /* lshrsi3 */
    case 196:  /* ashrsi3 */
    case 195:  /* ashlsi3 */
    case 194:  /* riscv_pause */
    case 193:  /* fence_i */
    case 192:  /* fence */
    case 191:  /* *movdf_softfloat */
    case 190:  /* *movdf_hardfloat_rv64 */
    case 189:  /* *movdf_hardfloat_rv32 */
    case 188:  /* *movsf_softfloat */
    case 187:  /* *movsf_hardfloat */
    case 186:  /* *movqi_internal */
    case 185:  /* *xorsihi3 */
    case 184:  /* *xorhihi3 */
    case 183:  /* *addsihi3 */
    case 182:  /* *addhihi3 */
    case 181:  /* *movhi_internal */
    case 180:  /* *movsi_internal */
    case 179:  /* *movdi_64bit */
    case 178:  /* *movdi_32bit */
    case 177:  /* *mvconst_internal */
    case 176:  /* *mvconst_internal */
    case 175:  /* *lowdi */
    case 174:  /* *lowsi */
    case 173:  /* auipcdi */
    case 172:  /* auipcsi */
    case 171:  /* got_load_tls_iedi */
    case 170:  /* got_load_tls_iesi */
    case 169:  /* got_load_tls_gddi */
    case 168:  /* got_load_tls_gdsi */
    case 167:  /* tls_add_tp_ledi */
    case 166:  /* tls_add_tp_lesi */
    case 165:  /* got_loaddi */
    case 164:  /* got_loadsi */
    case 163:  /* lroundhfdi2 */
    case 162:  /* lrinthfdi2 */
    case 161:  /* lroundhfsi2 */
    case 160:  /* lrinthfsi2 */
    case 159:  /* lrounddfdi2 */
    case 158:  /* lrintdfdi2 */
    case 157:  /* lrounddfsi2 */
    case 156:  /* lrintdfsi2 */
    case 155:  /* lroundsfdi2 */
    case 154:  /* lrintsfdi2 */
    case 153:  /* lroundsfsi2 */
    case 152:  /* lrintsfsi2 */
    case 151:  /* floatunsdihf2 */
    case 150:  /* floatunssihf2 */
    case 149:  /* floatunsdidf2 */
    case 148:  /* floatunssidf2 */
    case 147:  /* floatunsdisf2 */
    case 146:  /* floatunssisf2 */
    case 145:  /* floatdihf2 */
    case 144:  /* floatsihf2 */
    case 143:  /* floatdidf2 */
    case 142:  /* floatsidf2 */
    case 141:  /* floatdisf2 */
    case 140:  /* floatsisf2 */
    case 139:  /* fixuns_trunchfdi2 */
    case 138:  /* fixuns_trunchfsi2 */
    case 137:  /* fixuns_truncdfdi2 */
    case 136:  /* fixuns_truncdfsi2 */
    case 135:  /* fixuns_truncsfdi2 */
    case 134:  /* fixuns_truncsfsi2 */
    case 133:  /* fix_trunchfdi2 */
    case 132:  /* fix_trunchfsi2 */
    case 131:  /* fix_truncdfdi2 */
    case 130:  /* fix_truncdfsi2 */
    case 129:  /* fix_truncsfdi2 */
    case 128:  /* fix_truncsfsi2 */
    case 127:  /* *movhf_softfloat */
    case 126:  /* *movhf_hardfloat */
    case 125:  /* extendhfdf2 */
    case 124:  /* extendsfdf2 */
    case 123:  /* extendhfsf2 */
    case 122:  /* *extendhidi2 */
    case 121:  /* *extendhisi2 */
    case 120:  /* *extendhihi2 */
    case 119:  /* *extendqidi2 */
    case 118:  /* *extendqisi2 */
    case 117:  /* *extendqihi2 */
    case 116:  /* extendsidi2 */
    case 115:  /* zero_extendqidi2 */
    case 114:  /* zero_extendqisi2 */
    case 113:  /* zero_extendqihi2 */
    case 112:  /* *zero_extendhidi2 */
    case 111:  /* *zero_extendhisi2 */
    case 110:  /* *zero_extendsidi2_internal */
    case 109:  /* truncdfhf2 */
    case 108:  /* truncsfhf2 */
    case 107:  /* truncdfsf2 */
    case 106:  /* *one_cmplsi2_internal */
    case 105:  /* one_cmpldi2 */
    case 104:  /* one_cmplsi2 */
    case 103:  /* *xorsi3_internal */
    case 102:  /* *iorsi3_internal */
    case 101:  /* *andsi3_internal */
    case 100:  /* xordi3 */
    case 99:  /* iordi3 */
    case 98:  /* anddi3 */
    case 97:  /* xorsi3 */
    case 96:  /* iorsi3 */
    case 95:  /* andsi3 */
    case 94:  /* smaxhf3 */
    case 93:  /* smaxdf3 */
    case 92:  /* smaxsf3 */
    case 91:  /* sminhf3 */
    case 90:  /* smindf3 */
    case 89:  /* sminsf3 */
    case 88:  /* fmaxhf3 */
    case 87:  /* fmaxdf3 */
    case 86:  /* fmaxsf3 */
    case 85:  /* fminhf3 */
    case 84:  /* fmindf3 */
    case 83:  /* fminsf3 */
    case 82:  /* neghf2 */
    case 81:  /* negdf2 */
    case 80:  /* negsf2 */
    case 79:  /* copysignhf3 */
    case 78:  /* copysigndf3 */
    case 77:  /* copysignsf3 */
    case 76:  /* abshf2 */
    case 75:  /* absdf2 */
    case 74:  /* abssf2 */
    case 73:  /* *fnmahf4 */
    case 72:  /* *fnmadf4 */
    case 71:  /* *fnmasf4 */
    case 70:  /* *fnmshf4 */
    case 69:  /* *fnmsdf4 */
    case 68:  /* *fnmssf4 */
    case 67:  /* *fmshf4 */
    case 66:  /* *fmsdf4 */
    case 65:  /* *fmssf4 */
    case 64:  /* *fmahf4 */
    case 63:  /* *fmadf4 */
    case 62:  /* *fmasf4 */
    case 61:  /* fnmahf4 */
    case 60:  /* fnmadf4 */
    case 59:  /* fnmasf4 */
    case 58:  /* fnmshf4 */
    case 57:  /* fnmsdf4 */
    case 56:  /* fnmssf4 */
    case 55:  /* fmshf4 */
    case 54:  /* fmsdf4 */
    case 53:  /* fmssf4 */
    case 52:  /* fmahf4 */
    case 51:  /* fmadf4 */
    case 50:  /* fmasf4 */
    case 49:  /* sqrthf2 */
    case 48:  /* sqrtdf2 */
    case 47:  /* sqrtsf2 */
    case 46:  /* divhf3 */
    case 45:  /* divdf3 */
    case 44:  /* divsf3 */
    case 43:  /* *umodsi3_extended */
    case 42:  /* *modsi3_extended */
    case 41:  /* *udivsi3_extended */
    case 40:  /* *divsi3_extended */
    case 39:  /* umoddi3 */
    case 38:  /* moddi3 */
    case 37:  /* udivdi3 */
    case 36:  /* divdi3 */
    case 35:  /* umodsi3 */
    case 34:  /* modsi3 */
    case 33:  /* udivsi3 */
    case 32:  /* divsi3 */
    case 31:  /* usmulsi3_highpart */
    case 30:  /* umulsi3_highpart */
    case 29:  /* smulsi3_highpart */
    case 28:  /* usmuldi3_highpart */
    case 27:  /* umuldi3_highpart */
    case 26:  /* smuldi3_highpart */
    case 25:  /* *mulsi3_extended2 */
    case 24:  /* *mulsi3_extended */
    case 23:  /* muldi3 */
    case 22:  /* mulsi3 */
    case 21:  /* mulhf3 */
    case 20:  /* muldf3 */
    case 19:  /* mulsf3 */
    case 18:  /* *negsi2_extended2 */
    case 17:  /* *negsi2_extended */
    case 16:  /* negsi2 */
    case 15:  /* negdi2 */
    case 14:  /* *subsi3_extended2 */
    case 13:  /* *subsi3_extended */
    case 12:  /* subsi3 */
    case 11:  /* subdi3 */
    case 10:  /* subhf3 */
    case 9:  /* subdf3 */
    case 8:  /* subsf3 */
    case 7:  /* *addsi3_extended2 */
    case 6:  /* *addsi3_extended */
    case 5:  /* adddi3 */
    case 4:  /* addsi3 */
    case 3:  /* addhf3 */
    case 2:  /* adddf3 */
    case 1:  /* addsf3 */
      return 255 /* 0xff */;

    case 4599:  /* pred_seriesvnx8di */
    case 4598:  /* pred_seriesvnx4di */
    case 4597:  /* pred_seriesvnx2di */
    case 4596:  /* pred_seriesvnx1di */
    case 4595:  /* pred_seriesvnx16si */
    case 4594:  /* pred_seriesvnx8si */
    case 4593:  /* pred_seriesvnx4si */
    case 4592:  /* pred_seriesvnx2si */
    case 4591:  /* pred_seriesvnx1si */
    case 4590:  /* pred_seriesvnx32hi */
    case 4589:  /* pred_seriesvnx16hi */
    case 4588:  /* pred_seriesvnx8hi */
    case 4587:  /* pred_seriesvnx4hi */
    case 4586:  /* pred_seriesvnx2hi */
    case 4585:  /* pred_seriesvnx1hi */
    case 4584:  /* pred_seriesvnx64qi */
    case 4583:  /* pred_seriesvnx32qi */
    case 4582:  /* pred_seriesvnx16qi */
    case 4581:  /* pred_seriesvnx8qi */
    case 4580:  /* pred_seriesvnx4qi */
    case 4579:  /* pred_seriesvnx2qi */
    case 4578:  /* pred_seriesvnx1qi */
    case 4534:  /* pred_ffsvnx64bidi */
    case 4533:  /* pred_ffsvnx32bidi */
    case 4532:  /* pred_ffsvnx16bidi */
    case 4531:  /* pred_ffsvnx8bidi */
    case 4530:  /* pred_ffsvnx4bidi */
    case 4529:  /* pred_ffsvnx2bidi */
    case 4528:  /* pred_ffsvnx1bidi */
    case 4527:  /* pred_ffsvnx64bisi */
    case 4526:  /* pred_ffsvnx32bisi */
    case 4525:  /* pred_ffsvnx16bisi */
    case 4524:  /* pred_ffsvnx8bisi */
    case 4523:  /* pred_ffsvnx4bisi */
    case 4522:  /* pred_ffsvnx2bisi */
    case 4521:  /* pred_ffsvnx1bisi */
    case 4520:  /* pred_popcountvnx64bidi */
    case 4519:  /* pred_popcountvnx32bidi */
    case 4518:  /* pred_popcountvnx16bidi */
    case 4517:  /* pred_popcountvnx8bidi */
    case 4516:  /* pred_popcountvnx4bidi */
    case 4515:  /* pred_popcountvnx2bidi */
    case 4514:  /* pred_popcountvnx1bidi */
    case 4513:  /* pred_popcountvnx64bisi */
    case 4512:  /* pred_popcountvnx32bisi */
    case 4511:  /* pred_popcountvnx16bisi */
    case 4510:  /* pred_popcountvnx8bisi */
    case 4509:  /* pred_popcountvnx4bisi */
    case 4508:  /* pred_popcountvnx2bisi */
    case 4507:  /* pred_popcountvnx1bisi */
    case 831:  /* pred_storevnx1qi */
    case 832:  /* pred_storevnx2qi */
    case 833:  /* pred_storevnx4qi */
    case 834:  /* pred_storevnx8qi */
    case 835:  /* pred_storevnx16qi */
    case 836:  /* pred_storevnx32qi */
    case 837:  /* pred_storevnx64qi */
    case 838:  /* pred_storevnx1hi */
    case 839:  /* pred_storevnx2hi */
    case 840:  /* pred_storevnx4hi */
    case 841:  /* pred_storevnx8hi */
    case 842:  /* pred_storevnx16hi */
    case 843:  /* pred_storevnx32hi */
    case 844:  /* pred_storevnx1si */
    case 845:  /* pred_storevnx2si */
    case 846:  /* pred_storevnx4si */
    case 847:  /* pred_storevnx8si */
    case 848:  /* pred_storevnx16si */
    case 849:  /* pred_storevnx1di */
    case 850:  /* pred_storevnx2di */
    case 851:  /* pred_storevnx4di */
    case 852:  /* pred_storevnx8di */
    case 853:  /* pred_storevnx1sf */
    case 854:  /* pred_storevnx2sf */
    case 855:  /* pred_storevnx4sf */
    case 856:  /* pred_storevnx8sf */
    case 857:  /* pred_storevnx16sf */
    case 858:  /* pred_storevnx1df */
    case 859:  /* pred_storevnx2df */
    case 860:  /* pred_storevnx4df */
    case 861:  /* pred_storevnx8df */
    case 869:  /* pred_storevnx1bi */
    case 870:  /* pred_storevnx2bi */
    case 871:  /* pred_storevnx4bi */
    case 872:  /* pred_storevnx8bi */
    case 873:  /* pred_storevnx16bi */
    case 874:  /* pred_storevnx32bi */
    case 875:  /* pred_storevnx64bi */
    case 2648:  /* pred_madcvnx1qi_overflow */
    case 2649:  /* pred_madcvnx2qi_overflow */
    case 2650:  /* pred_madcvnx4qi_overflow */
    case 2651:  /* pred_madcvnx8qi_overflow */
    case 2652:  /* pred_madcvnx16qi_overflow */
    case 2653:  /* pred_madcvnx32qi_overflow */
    case 2654:  /* pred_madcvnx64qi_overflow */
    case 2655:  /* pred_madcvnx1hi_overflow */
    case 2656:  /* pred_madcvnx2hi_overflow */
    case 2657:  /* pred_madcvnx4hi_overflow */
    case 2658:  /* pred_madcvnx8hi_overflow */
    case 2659:  /* pred_madcvnx16hi_overflow */
    case 2660:  /* pred_madcvnx32hi_overflow */
    case 2661:  /* pred_madcvnx1si_overflow */
    case 2662:  /* pred_madcvnx2si_overflow */
    case 2663:  /* pred_madcvnx4si_overflow */
    case 2664:  /* pred_madcvnx8si_overflow */
    case 2665:  /* pred_madcvnx16si_overflow */
    case 2666:  /* pred_madcvnx1di_overflow */
    case 2667:  /* pred_madcvnx2di_overflow */
    case 2668:  /* pred_madcvnx4di_overflow */
    case 2669:  /* pred_madcvnx8di_overflow */
    case 2670:  /* pred_msbcvnx1qi_overflow */
    case 2671:  /* pred_msbcvnx2qi_overflow */
    case 2672:  /* pred_msbcvnx4qi_overflow */
    case 2673:  /* pred_msbcvnx8qi_overflow */
    case 2674:  /* pred_msbcvnx16qi_overflow */
    case 2675:  /* pred_msbcvnx32qi_overflow */
    case 2676:  /* pred_msbcvnx64qi_overflow */
    case 2677:  /* pred_msbcvnx1hi_overflow */
    case 2678:  /* pred_msbcvnx2hi_overflow */
    case 2679:  /* pred_msbcvnx4hi_overflow */
    case 2680:  /* pred_msbcvnx8hi_overflow */
    case 2681:  /* pred_msbcvnx16hi_overflow */
    case 2682:  /* pred_msbcvnx32hi_overflow */
    case 2683:  /* pred_msbcvnx1si_overflow */
    case 2684:  /* pred_msbcvnx2si_overflow */
    case 2685:  /* pred_msbcvnx4si_overflow */
    case 2686:  /* pred_msbcvnx8si_overflow */
    case 2687:  /* pred_msbcvnx16si_overflow */
    case 2688:  /* pred_msbcvnx1di_overflow */
    case 2689:  /* pred_msbcvnx2di_overflow */
    case 2690:  /* pred_msbcvnx4di_overflow */
    case 2691:  /* pred_msbcvnx8di_overflow */
    case 2692:  /* pred_madcvnx1qi_overflow_scalar */
    case 2693:  /* pred_madcvnx2qi_overflow_scalar */
    case 2694:  /* pred_madcvnx4qi_overflow_scalar */
    case 2695:  /* pred_madcvnx8qi_overflow_scalar */
    case 2696:  /* pred_madcvnx16qi_overflow_scalar */
    case 2697:  /* pred_madcvnx32qi_overflow_scalar */
    case 2698:  /* pred_madcvnx64qi_overflow_scalar */
    case 2699:  /* pred_madcvnx1hi_overflow_scalar */
    case 2700:  /* pred_madcvnx2hi_overflow_scalar */
    case 2701:  /* pred_madcvnx4hi_overflow_scalar */
    case 2702:  /* pred_madcvnx8hi_overflow_scalar */
    case 2703:  /* pred_madcvnx16hi_overflow_scalar */
    case 2704:  /* pred_madcvnx32hi_overflow_scalar */
    case 2705:  /* pred_madcvnx1si_overflow_scalar */
    case 2706:  /* pred_madcvnx2si_overflow_scalar */
    case 2707:  /* pred_madcvnx4si_overflow_scalar */
    case 2708:  /* pred_madcvnx8si_overflow_scalar */
    case 2709:  /* pred_madcvnx16si_overflow_scalar */
    case 2710:  /* pred_msbcvnx1qi_overflow_scalar */
    case 2711:  /* pred_msbcvnx2qi_overflow_scalar */
    case 2712:  /* pred_msbcvnx4qi_overflow_scalar */
    case 2713:  /* pred_msbcvnx8qi_overflow_scalar */
    case 2714:  /* pred_msbcvnx16qi_overflow_scalar */
    case 2715:  /* pred_msbcvnx32qi_overflow_scalar */
    case 2716:  /* pred_msbcvnx64qi_overflow_scalar */
    case 2717:  /* pred_msbcvnx1hi_overflow_scalar */
    case 2718:  /* pred_msbcvnx2hi_overflow_scalar */
    case 2719:  /* pred_msbcvnx4hi_overflow_scalar */
    case 2720:  /* pred_msbcvnx8hi_overflow_scalar */
    case 2721:  /* pred_msbcvnx16hi_overflow_scalar */
    case 2722:  /* pred_msbcvnx32hi_overflow_scalar */
    case 2723:  /* pred_msbcvnx1si_overflow_scalar */
    case 2724:  /* pred_msbcvnx2si_overflow_scalar */
    case 2725:  /* pred_msbcvnx4si_overflow_scalar */
    case 2726:  /* pred_msbcvnx8si_overflow_scalar */
    case 2727:  /* pred_msbcvnx16si_overflow_scalar */
    case 2728:  /* *pred_madcvnx1di_overflow_scalar */
    case 2729:  /* *pred_madcvnx2di_overflow_scalar */
    case 2730:  /* *pred_madcvnx4di_overflow_scalar */
    case 2731:  /* *pred_madcvnx8di_overflow_scalar */
    case 2732:  /* *pred_madcvnx1di_overflow_extended_scalar */
    case 2733:  /* *pred_madcvnx2di_overflow_extended_scalar */
    case 2734:  /* *pred_madcvnx4di_overflow_extended_scalar */
    case 2735:  /* *pred_madcvnx8di_overflow_extended_scalar */
    case 2736:  /* *pred_msbcvnx1di_overflow_scalar */
    case 2737:  /* *pred_msbcvnx2di_overflow_scalar */
    case 2738:  /* *pred_msbcvnx4di_overflow_scalar */
    case 2739:  /* *pred_msbcvnx8di_overflow_scalar */
    case 2740:  /* *pred_msbcvnx1di_overflow_extended_scalar */
    case 2741:  /* *pred_msbcvnx2di_overflow_extended_scalar */
    case 2742:  /* *pred_msbcvnx4di_overflow_extended_scalar */
    case 2743:  /* *pred_msbcvnx8di_overflow_extended_scalar */
      return 3;

    case 6067:  /* pred_fault_loadvnx8df */
    case 6066:  /* pred_fault_loadvnx4df */
    case 6065:  /* pred_fault_loadvnx2df */
    case 6064:  /* pred_fault_loadvnx1df */
    case 6063:  /* pred_fault_loadvnx16sf */
    case 6062:  /* pred_fault_loadvnx8sf */
    case 6061:  /* pred_fault_loadvnx4sf */
    case 6060:  /* pred_fault_loadvnx2sf */
    case 6059:  /* pred_fault_loadvnx1sf */
    case 6058:  /* pred_fault_loadvnx8di */
    case 6057:  /* pred_fault_loadvnx4di */
    case 6056:  /* pred_fault_loadvnx2di */
    case 6055:  /* pred_fault_loadvnx1di */
    case 6054:  /* pred_fault_loadvnx16si */
    case 6053:  /* pred_fault_loadvnx8si */
    case 6052:  /* pred_fault_loadvnx4si */
    case 6051:  /* pred_fault_loadvnx2si */
    case 6050:  /* pred_fault_loadvnx1si */
    case 6049:  /* pred_fault_loadvnx32hi */
    case 6048:  /* pred_fault_loadvnx16hi */
    case 6047:  /* pred_fault_loadvnx8hi */
    case 6046:  /* pred_fault_loadvnx4hi */
    case 6045:  /* pred_fault_loadvnx2hi */
    case 6044:  /* pred_fault_loadvnx1hi */
    case 6043:  /* pred_fault_loadvnx64qi */
    case 6042:  /* pred_fault_loadvnx32qi */
    case 6041:  /* pred_fault_loadvnx16qi */
    case 6040:  /* pred_fault_loadvnx8qi */
    case 6039:  /* pred_fault_loadvnx4qi */
    case 6038:  /* pred_fault_loadvnx2qi */
    case 6037:  /* pred_fault_loadvnx1qi */
    case 6034:  /* pred_compressvnx8df */
    case 6033:  /* pred_compressvnx4df */
    case 6032:  /* pred_compressvnx2df */
    case 6031:  /* pred_compressvnx1df */
    case 6030:  /* pred_compressvnx16sf */
    case 6029:  /* pred_compressvnx8sf */
    case 6028:  /* pred_compressvnx4sf */
    case 6027:  /* pred_compressvnx2sf */
    case 6026:  /* pred_compressvnx1sf */
    case 6025:  /* pred_compressvnx8di */
    case 6024:  /* pred_compressvnx4di */
    case 6023:  /* pred_compressvnx2di */
    case 6022:  /* pred_compressvnx1di */
    case 6021:  /* pred_compressvnx16si */
    case 6020:  /* pred_compressvnx8si */
    case 6019:  /* pred_compressvnx4si */
    case 6018:  /* pred_compressvnx2si */
    case 6017:  /* pred_compressvnx1si */
    case 6016:  /* pred_compressvnx32hi */
    case 6015:  /* pred_compressvnx16hi */
    case 6014:  /* pred_compressvnx8hi */
    case 6013:  /* pred_compressvnx4hi */
    case 6012:  /* pred_compressvnx2hi */
    case 6011:  /* pred_compressvnx1hi */
    case 6010:  /* pred_compressvnx64qi */
    case 6009:  /* pred_compressvnx32qi */
    case 6008:  /* pred_compressvnx16qi */
    case 6007:  /* pred_compressvnx8qi */
    case 6006:  /* pred_compressvnx4qi */
    case 6005:  /* pred_compressvnx2qi */
    case 6004:  /* pred_compressvnx1qi */
    case 5328:  /* pred_rod_truncvnx8df */
    case 5327:  /* pred_rod_truncvnx4df */
    case 5326:  /* pred_rod_truncvnx2df */
    case 5325:  /* pred_rod_truncvnx1df */
    case 5324:  /* pred_truncvnx8df */
    case 5323:  /* pred_truncvnx4df */
    case 5322:  /* pred_truncvnx2df */
    case 5321:  /* pred_truncvnx1df */
    case 5320:  /* pred_narrow_floatunsvnx8di */
    case 5319:  /* pred_narrow_floatvnx8di */
    case 5318:  /* pred_narrow_floatunsvnx4di */
    case 5317:  /* pred_narrow_floatvnx4di */
    case 5316:  /* pred_narrow_floatunsvnx2di */
    case 5315:  /* pred_narrow_floatvnx2di */
    case 5314:  /* pred_narrow_floatunsvnx1di */
    case 5313:  /* pred_narrow_floatvnx1di */
    case 5312:  /* pred_narrow_fixuns_truncvnx8df */
    case 5311:  /* pred_narrow_fix_truncvnx8df */
    case 5310:  /* pred_narrow_fixuns_truncvnx4df */
    case 5309:  /* pred_narrow_fix_truncvnx4df */
    case 5308:  /* pred_narrow_fixuns_truncvnx2df */
    case 5307:  /* pred_narrow_fix_truncvnx2df */
    case 5306:  /* pred_narrow_fixuns_truncvnx1df */
    case 5305:  /* pred_narrow_fix_truncvnx1df */
    case 5304:  /* pred_narrow_fixuns_truncvnx16sf */
    case 5303:  /* pred_narrow_fix_truncvnx16sf */
    case 5302:  /* pred_narrow_fixuns_truncvnx8sf */
    case 5301:  /* pred_narrow_fix_truncvnx8sf */
    case 5300:  /* pred_narrow_fixuns_truncvnx4sf */
    case 5299:  /* pred_narrow_fix_truncvnx4sf */
    case 5298:  /* pred_narrow_fixuns_truncvnx2sf */
    case 5297:  /* pred_narrow_fix_truncvnx2sf */
    case 5296:  /* pred_narrow_fixuns_truncvnx1sf */
    case 5295:  /* pred_narrow_fix_truncvnx1sf */
    case 5294:  /* pred_narrow_fcvt_xu_fvnx8df */
    case 5293:  /* pred_narrow_fcvt_x_fvnx8df */
    case 5292:  /* pred_narrow_fcvt_xu_fvnx4df */
    case 5291:  /* pred_narrow_fcvt_x_fvnx4df */
    case 5290:  /* pred_narrow_fcvt_xu_fvnx2df */
    case 5289:  /* pred_narrow_fcvt_x_fvnx2df */
    case 5288:  /* pred_narrow_fcvt_xu_fvnx1df */
    case 5287:  /* pred_narrow_fcvt_x_fvnx1df */
    case 5286:  /* pred_narrow_fcvt_xu_fvnx16sf */
    case 5285:  /* pred_narrow_fcvt_x_fvnx16sf */
    case 5284:  /* pred_narrow_fcvt_xu_fvnx8sf */
    case 5283:  /* pred_narrow_fcvt_x_fvnx8sf */
    case 5282:  /* pred_narrow_fcvt_xu_fvnx4sf */
    case 5281:  /* pred_narrow_fcvt_x_fvnx4sf */
    case 5280:  /* pred_narrow_fcvt_xu_fvnx2sf */
    case 5279:  /* pred_narrow_fcvt_x_fvnx2sf */
    case 5278:  /* pred_narrow_fcvt_xu_fvnx1sf */
    case 5277:  /* pred_narrow_fcvt_x_fvnx1sf */
    case 5276:  /* pred_extendvnx8df */
    case 5275:  /* pred_extendvnx4df */
    case 5274:  /* pred_extendvnx2df */
    case 5273:  /* pred_extendvnx1df */
    case 5272:  /* pred_widen_floatunsvnx8df */
    case 5271:  /* pred_widen_floatvnx8df */
    case 5270:  /* pred_widen_floatunsvnx4df */
    case 5269:  /* pred_widen_floatvnx4df */
    case 5268:  /* pred_widen_floatunsvnx2df */
    case 5267:  /* pred_widen_floatvnx2df */
    case 5266:  /* pred_widen_floatunsvnx1df */
    case 5265:  /* pred_widen_floatvnx1df */
    case 5264:  /* pred_widen_floatunsvnx16sf */
    case 5263:  /* pred_widen_floatvnx16sf */
    case 5262:  /* pred_widen_floatunsvnx8sf */
    case 5261:  /* pred_widen_floatvnx8sf */
    case 5260:  /* pred_widen_floatunsvnx4sf */
    case 5259:  /* pred_widen_floatvnx4sf */
    case 5258:  /* pred_widen_floatunsvnx2sf */
    case 5257:  /* pred_widen_floatvnx2sf */
    case 5256:  /* pred_widen_floatunsvnx1sf */
    case 5255:  /* pred_widen_floatvnx1sf */
    case 5254:  /* pred_widen_fixuns_truncvnx8di */
    case 5253:  /* pred_widen_fix_truncvnx8di */
    case 5252:  /* pred_widen_fixuns_truncvnx4di */
    case 5251:  /* pred_widen_fix_truncvnx4di */
    case 5250:  /* pred_widen_fixuns_truncvnx2di */
    case 5249:  /* pred_widen_fix_truncvnx2di */
    case 5248:  /* pred_widen_fixuns_truncvnx1di */
    case 5247:  /* pred_widen_fix_truncvnx1di */
    case 5246:  /* pred_widen_fcvt_xu_fvnx8di */
    case 5245:  /* pred_widen_fcvt_x_fvnx8di */
    case 5244:  /* pred_widen_fcvt_xu_fvnx4di */
    case 5243:  /* pred_widen_fcvt_x_fvnx4di */
    case 5242:  /* pred_widen_fcvt_xu_fvnx2di */
    case 5241:  /* pred_widen_fcvt_x_fvnx2di */
    case 5240:  /* pred_widen_fcvt_xu_fvnx1di */
    case 5239:  /* pred_widen_fcvt_x_fvnx1di */
    case 5238:  /* pred_floatunsvnx8df */
    case 5237:  /* pred_floatvnx8df */
    case 5236:  /* pred_floatunsvnx4df */
    case 5235:  /* pred_floatvnx4df */
    case 5234:  /* pred_floatunsvnx2df */
    case 5233:  /* pred_floatvnx2df */
    case 5232:  /* pred_floatunsvnx1df */
    case 5231:  /* pred_floatvnx1df */
    case 5230:  /* pred_floatunsvnx16sf */
    case 5229:  /* pred_floatvnx16sf */
    case 5228:  /* pred_floatunsvnx8sf */
    case 5227:  /* pred_floatvnx8sf */
    case 5226:  /* pred_floatunsvnx4sf */
    case 5225:  /* pred_floatvnx4sf */
    case 5224:  /* pred_floatunsvnx2sf */
    case 5223:  /* pred_floatvnx2sf */
    case 5222:  /* pred_floatunsvnx1sf */
    case 5221:  /* pred_floatvnx1sf */
    case 5220:  /* pred_fixuns_truncvnx8df */
    case 5219:  /* pred_fix_truncvnx8df */
    case 5218:  /* pred_fixuns_truncvnx4df */
    case 5217:  /* pred_fix_truncvnx4df */
    case 5216:  /* pred_fixuns_truncvnx2df */
    case 5215:  /* pred_fix_truncvnx2df */
    case 5214:  /* pred_fixuns_truncvnx1df */
    case 5213:  /* pred_fix_truncvnx1df */
    case 5212:  /* pred_fixuns_truncvnx16sf */
    case 5211:  /* pred_fix_truncvnx16sf */
    case 5210:  /* pred_fixuns_truncvnx8sf */
    case 5209:  /* pred_fix_truncvnx8sf */
    case 5208:  /* pred_fixuns_truncvnx4sf */
    case 5207:  /* pred_fix_truncvnx4sf */
    case 5206:  /* pred_fixuns_truncvnx2sf */
    case 5205:  /* pred_fix_truncvnx2sf */
    case 5204:  /* pred_fixuns_truncvnx1sf */
    case 5203:  /* pred_fix_truncvnx1sf */
    case 5202:  /* pred_fcvt_xu_fvnx8df */
    case 5201:  /* pred_fcvt_x_fvnx8df */
    case 5200:  /* pred_fcvt_xu_fvnx4df */
    case 5199:  /* pred_fcvt_x_fvnx4df */
    case 5198:  /* pred_fcvt_xu_fvnx2df */
    case 5197:  /* pred_fcvt_x_fvnx2df */
    case 5196:  /* pred_fcvt_xu_fvnx1df */
    case 5195:  /* pred_fcvt_x_fvnx1df */
    case 5194:  /* pred_fcvt_xu_fvnx16sf */
    case 5193:  /* pred_fcvt_x_fvnx16sf */
    case 5192:  /* pred_fcvt_xu_fvnx8sf */
    case 5191:  /* pred_fcvt_x_fvnx8sf */
    case 5190:  /* pred_fcvt_xu_fvnx4sf */
    case 5189:  /* pred_fcvt_x_fvnx4sf */
    case 5188:  /* pred_fcvt_xu_fvnx2sf */
    case 5187:  /* pred_fcvt_x_fvnx2sf */
    case 5186:  /* pred_fcvt_xu_fvnx1sf */
    case 5185:  /* pred_fcvt_x_fvnx1sf */
    case 5049:  /* pred_classvnx8df */
    case 5048:  /* pred_classvnx4df */
    case 5047:  /* pred_classvnx2df */
    case 5046:  /* pred_classvnx1df */
    case 5045:  /* pred_classvnx16sf */
    case 5044:  /* pred_classvnx8sf */
    case 5043:  /* pred_classvnx4sf */
    case 5042:  /* pred_classvnx2sf */
    case 5041:  /* pred_classvnx1sf */
    case 5040:  /* pred_rec7vnx8df */
    case 5039:  /* pred_rsqrt7vnx8df */
    case 5038:  /* pred_rec7vnx4df */
    case 5037:  /* pred_rsqrt7vnx4df */
    case 5036:  /* pred_rec7vnx2df */
    case 5035:  /* pred_rsqrt7vnx2df */
    case 5034:  /* pred_rec7vnx1df */
    case 5033:  /* pred_rsqrt7vnx1df */
    case 5032:  /* pred_rec7vnx16sf */
    case 5031:  /* pred_rsqrt7vnx16sf */
    case 5030:  /* pred_rec7vnx8sf */
    case 5029:  /* pred_rsqrt7vnx8sf */
    case 5028:  /* pred_rec7vnx4sf */
    case 5027:  /* pred_rsqrt7vnx4sf */
    case 5026:  /* pred_rec7vnx2sf */
    case 5025:  /* pred_rsqrt7vnx2sf */
    case 5024:  /* pred_rec7vnx1sf */
    case 5023:  /* pred_rsqrt7vnx1sf */
    case 4577:  /* pred_iotavnx8di */
    case 4576:  /* pred_iotavnx4di */
    case 4575:  /* pred_iotavnx2di */
    case 4574:  /* pred_iotavnx1di */
    case 4573:  /* pred_iotavnx16si */
    case 4572:  /* pred_iotavnx8si */
    case 4571:  /* pred_iotavnx4si */
    case 4570:  /* pred_iotavnx2si */
    case 4569:  /* pred_iotavnx1si */
    case 4568:  /* pred_iotavnx32hi */
    case 4567:  /* pred_iotavnx16hi */
    case 4566:  /* pred_iotavnx8hi */
    case 4565:  /* pred_iotavnx4hi */
    case 4564:  /* pred_iotavnx2hi */
    case 4563:  /* pred_iotavnx1hi */
    case 4562:  /* pred_iotavnx64qi */
    case 4561:  /* pred_iotavnx32qi */
    case 4560:  /* pred_iotavnx16qi */
    case 4559:  /* pred_iotavnx8qi */
    case 4558:  /* pred_iotavnx4qi */
    case 4557:  /* pred_iotavnx2qi */
    case 4556:  /* pred_iotavnx1qi */
    case 4555:  /* pred_sofvnx64bi */
    case 4554:  /* pred_sifvnx64bi */
    case 4553:  /* pred_sbfvnx64bi */
    case 4552:  /* pred_sofvnx32bi */
    case 4551:  /* pred_sifvnx32bi */
    case 4550:  /* pred_sbfvnx32bi */
    case 4549:  /* pred_sofvnx16bi */
    case 4548:  /* pred_sifvnx16bi */
    case 4547:  /* pred_sbfvnx16bi */
    case 4546:  /* pred_sofvnx8bi */
    case 4545:  /* pred_sifvnx8bi */
    case 4544:  /* pred_sbfvnx8bi */
    case 4543:  /* pred_sofvnx4bi */
    case 4542:  /* pred_sifvnx4bi */
    case 4541:  /* pred_sbfvnx4bi */
    case 4540:  /* pred_sofvnx2bi */
    case 4539:  /* pred_sifvnx2bi */
    case 4538:  /* pred_sbfvnx2bi */
    case 4537:  /* pred_sofvnx1bi */
    case 4536:  /* pred_sifvnx1bi */
    case 4535:  /* pred_sbfvnx1bi */
    case 2843:  /* pred_zero_extendvnx8di_vf8 */
    case 2842:  /* pred_extendvnx8di_vf8 */
    case 2841:  /* pred_zero_extendvnx4di_vf8 */
    case 2840:  /* pred_extendvnx4di_vf8 */
    case 2839:  /* pred_zero_extendvnx2di_vf8 */
    case 2838:  /* pred_extendvnx2di_vf8 */
    case 2837:  /* pred_zero_extendvnx1di_vf8 */
    case 2836:  /* pred_extendvnx1di_vf8 */
    case 2835:  /* pred_zero_extendvnx8di_vf4 */
    case 2834:  /* pred_extendvnx8di_vf4 */
    case 2833:  /* pred_zero_extendvnx4di_vf4 */
    case 2832:  /* pred_extendvnx4di_vf4 */
    case 2831:  /* pred_zero_extendvnx2di_vf4 */
    case 2830:  /* pred_extendvnx2di_vf4 */
    case 2829:  /* pred_zero_extendvnx1di_vf4 */
    case 2828:  /* pred_extendvnx1di_vf4 */
    case 2827:  /* pred_zero_extendvnx16si_vf4 */
    case 2826:  /* pred_extendvnx16si_vf4 */
    case 2825:  /* pred_zero_extendvnx8si_vf4 */
    case 2824:  /* pred_extendvnx8si_vf4 */
    case 2823:  /* pred_zero_extendvnx4si_vf4 */
    case 2822:  /* pred_extendvnx4si_vf4 */
    case 2821:  /* pred_zero_extendvnx2si_vf4 */
    case 2820:  /* pred_extendvnx2si_vf4 */
    case 2819:  /* pred_zero_extendvnx1si_vf4 */
    case 2818:  /* pred_extendvnx1si_vf4 */
    case 2817:  /* pred_zero_extendvnx8di_vf2 */
    case 2816:  /* pred_extendvnx8di_vf2 */
    case 2815:  /* pred_zero_extendvnx4di_vf2 */
    case 2814:  /* pred_extendvnx4di_vf2 */
    case 2813:  /* pred_zero_extendvnx2di_vf2 */
    case 2812:  /* pred_extendvnx2di_vf2 */
    case 2811:  /* pred_zero_extendvnx1di_vf2 */
    case 2810:  /* pred_extendvnx1di_vf2 */
    case 2809:  /* pred_zero_extendvnx16si_vf2 */
    case 2808:  /* pred_extendvnx16si_vf2 */
    case 2807:  /* pred_zero_extendvnx8si_vf2 */
    case 2806:  /* pred_extendvnx8si_vf2 */
    case 2805:  /* pred_zero_extendvnx4si_vf2 */
    case 2804:  /* pred_extendvnx4si_vf2 */
    case 2803:  /* pred_zero_extendvnx2si_vf2 */
    case 2802:  /* pred_extendvnx2si_vf2 */
    case 2801:  /* pred_zero_extendvnx1si_vf2 */
    case 2800:  /* pred_extendvnx1si_vf2 */
    case 2799:  /* pred_zero_extendvnx32hi_vf2 */
    case 2798:  /* pred_extendvnx32hi_vf2 */
    case 2797:  /* pred_zero_extendvnx16hi_vf2 */
    case 2796:  /* pred_extendvnx16hi_vf2 */
    case 2795:  /* pred_zero_extendvnx8hi_vf2 */
    case 2794:  /* pred_extendvnx8hi_vf2 */
    case 2793:  /* pred_zero_extendvnx4hi_vf2 */
    case 2792:  /* pred_extendvnx4hi_vf2 */
    case 2791:  /* pred_zero_extendvnx2hi_vf2 */
    case 2790:  /* pred_extendvnx2hi_vf2 */
    case 2789:  /* pred_zero_extendvnx1hi_vf2 */
    case 2788:  /* pred_extendvnx1hi_vf2 */
    case 1481:  /* pred_indexed_ustorevnx64qivnx64qi */
    case 1480:  /* pred_indexed_ostorevnx64qivnx64qi */
    case 1479:  /* pred_indexed_ustorevnx32hivnx32hi */
    case 1478:  /* pred_indexed_ostorevnx32hivnx32hi */
    case 1477:  /* pred_indexed_ustorevnx32hivnx32qi */
    case 1476:  /* pred_indexed_ostorevnx32hivnx32qi */
    case 1475:  /* pred_indexed_ustorevnx32qivnx32hi */
    case 1474:  /* pred_indexed_ostorevnx32qivnx32hi */
    case 1473:  /* pred_indexed_ustorevnx32qivnx32qi */
    case 1472:  /* pred_indexed_ostorevnx32qivnx32qi */
    case 1471:  /* pred_indexed_ustorevnx16sfvnx16si */
    case 1470:  /* pred_indexed_ostorevnx16sfvnx16si */
    case 1469:  /* pred_indexed_ustorevnx16sivnx16si */
    case 1468:  /* pred_indexed_ostorevnx16sivnx16si */
    case 1467:  /* pred_indexed_ustorevnx16hivnx16si */
    case 1466:  /* pred_indexed_ostorevnx16hivnx16si */
    case 1465:  /* pred_indexed_ustorevnx16qivnx16si */
    case 1464:  /* pred_indexed_ostorevnx16qivnx16si */
    case 1463:  /* pred_indexed_ustorevnx16sfvnx16hi */
    case 1462:  /* pred_indexed_ostorevnx16sfvnx16hi */
    case 1461:  /* pred_indexed_ustorevnx16sivnx16hi */
    case 1460:  /* pred_indexed_ostorevnx16sivnx16hi */
    case 1459:  /* pred_indexed_ustorevnx16hivnx16hi */
    case 1458:  /* pred_indexed_ostorevnx16hivnx16hi */
    case 1457:  /* pred_indexed_ustorevnx16qivnx16hi */
    case 1456:  /* pred_indexed_ostorevnx16qivnx16hi */
    case 1455:  /* pred_indexed_ustorevnx16sfvnx16qi */
    case 1454:  /* pred_indexed_ostorevnx16sfvnx16qi */
    case 1453:  /* pred_indexed_ustorevnx16sivnx16qi */
    case 1452:  /* pred_indexed_ostorevnx16sivnx16qi */
    case 1451:  /* pred_indexed_ustorevnx16hivnx16qi */
    case 1450:  /* pred_indexed_ostorevnx16hivnx16qi */
    case 1449:  /* pred_indexed_ustorevnx16qivnx16qi */
    case 1448:  /* pred_indexed_ostorevnx16qivnx16qi */
    case 1447:  /* pred_indexed_ustorevnx8dfvnx8di */
    case 1446:  /* pred_indexed_ostorevnx8dfvnx8di */
    case 1445:  /* pred_indexed_ustorevnx8sfvnx8di */
    case 1444:  /* pred_indexed_ostorevnx8sfvnx8di */
    case 1443:  /* pred_indexed_ustorevnx8divnx8di */
    case 1442:  /* pred_indexed_ostorevnx8divnx8di */
    case 1441:  /* pred_indexed_ustorevnx8sivnx8di */
    case 1440:  /* pred_indexed_ostorevnx8sivnx8di */
    case 1439:  /* pred_indexed_ustorevnx8hivnx8di */
    case 1438:  /* pred_indexed_ostorevnx8hivnx8di */
    case 1437:  /* pred_indexed_ustorevnx8qivnx8di */
    case 1436:  /* pred_indexed_ostorevnx8qivnx8di */
    case 1435:  /* pred_indexed_ustorevnx8dfvnx8si */
    case 1434:  /* pred_indexed_ostorevnx8dfvnx8si */
    case 1433:  /* pred_indexed_ustorevnx8sfvnx8si */
    case 1432:  /* pred_indexed_ostorevnx8sfvnx8si */
    case 1431:  /* pred_indexed_ustorevnx8divnx8si */
    case 1430:  /* pred_indexed_ostorevnx8divnx8si */
    case 1429:  /* pred_indexed_ustorevnx8sivnx8si */
    case 1428:  /* pred_indexed_ostorevnx8sivnx8si */
    case 1427:  /* pred_indexed_ustorevnx8hivnx8si */
    case 1426:  /* pred_indexed_ostorevnx8hivnx8si */
    case 1425:  /* pred_indexed_ustorevnx8qivnx8si */
    case 1424:  /* pred_indexed_ostorevnx8qivnx8si */
    case 1423:  /* pred_indexed_ustorevnx8dfvnx8hi */
    case 1422:  /* pred_indexed_ostorevnx8dfvnx8hi */
    case 1421:  /* pred_indexed_ustorevnx8sfvnx8hi */
    case 1420:  /* pred_indexed_ostorevnx8sfvnx8hi */
    case 1419:  /* pred_indexed_ustorevnx8divnx8hi */
    case 1418:  /* pred_indexed_ostorevnx8divnx8hi */
    case 1417:  /* pred_indexed_ustorevnx8sivnx8hi */
    case 1416:  /* pred_indexed_ostorevnx8sivnx8hi */
    case 1415:  /* pred_indexed_ustorevnx8hivnx8hi */
    case 1414:  /* pred_indexed_ostorevnx8hivnx8hi */
    case 1413:  /* pred_indexed_ustorevnx8qivnx8hi */
    case 1412:  /* pred_indexed_ostorevnx8qivnx8hi */
    case 1411:  /* pred_indexed_ustorevnx8dfvnx8qi */
    case 1410:  /* pred_indexed_ostorevnx8dfvnx8qi */
    case 1409:  /* pred_indexed_ustorevnx8sfvnx8qi */
    case 1408:  /* pred_indexed_ostorevnx8sfvnx8qi */
    case 1407:  /* pred_indexed_ustorevnx8divnx8qi */
    case 1406:  /* pred_indexed_ostorevnx8divnx8qi */
    case 1405:  /* pred_indexed_ustorevnx8sivnx8qi */
    case 1404:  /* pred_indexed_ostorevnx8sivnx8qi */
    case 1403:  /* pred_indexed_ustorevnx8hivnx8qi */
    case 1402:  /* pred_indexed_ostorevnx8hivnx8qi */
    case 1401:  /* pred_indexed_ustorevnx8qivnx8qi */
    case 1400:  /* pred_indexed_ostorevnx8qivnx8qi */
    case 1399:  /* pred_indexed_ustorevnx4dfvnx4di */
    case 1398:  /* pred_indexed_ostorevnx4dfvnx4di */
    case 1397:  /* pred_indexed_ustorevnx4sfvnx4di */
    case 1396:  /* pred_indexed_ostorevnx4sfvnx4di */
    case 1395:  /* pred_indexed_ustorevnx4divnx4di */
    case 1394:  /* pred_indexed_ostorevnx4divnx4di */
    case 1393:  /* pred_indexed_ustorevnx4sivnx4di */
    case 1392:  /* pred_indexed_ostorevnx4sivnx4di */
    case 1391:  /* pred_indexed_ustorevnx4hivnx4di */
    case 1390:  /* pred_indexed_ostorevnx4hivnx4di */
    case 1389:  /* pred_indexed_ustorevnx4qivnx4di */
    case 1388:  /* pred_indexed_ostorevnx4qivnx4di */
    case 1387:  /* pred_indexed_ustorevnx4dfvnx4si */
    case 1386:  /* pred_indexed_ostorevnx4dfvnx4si */
    case 1385:  /* pred_indexed_ustorevnx4sfvnx4si */
    case 1384:  /* pred_indexed_ostorevnx4sfvnx4si */
    case 1383:  /* pred_indexed_ustorevnx4divnx4si */
    case 1382:  /* pred_indexed_ostorevnx4divnx4si */
    case 1381:  /* pred_indexed_ustorevnx4sivnx4si */
    case 1380:  /* pred_indexed_ostorevnx4sivnx4si */
    case 1379:  /* pred_indexed_ustorevnx4hivnx4si */
    case 1378:  /* pred_indexed_ostorevnx4hivnx4si */
    case 1377:  /* pred_indexed_ustorevnx4qivnx4si */
    case 1376:  /* pred_indexed_ostorevnx4qivnx4si */
    case 1375:  /* pred_indexed_ustorevnx4dfvnx4hi */
    case 1374:  /* pred_indexed_ostorevnx4dfvnx4hi */
    case 1373:  /* pred_indexed_ustorevnx4sfvnx4hi */
    case 1372:  /* pred_indexed_ostorevnx4sfvnx4hi */
    case 1371:  /* pred_indexed_ustorevnx4divnx4hi */
    case 1370:  /* pred_indexed_ostorevnx4divnx4hi */
    case 1369:  /* pred_indexed_ustorevnx4sivnx4hi */
    case 1368:  /* pred_indexed_ostorevnx4sivnx4hi */
    case 1367:  /* pred_indexed_ustorevnx4hivnx4hi */
    case 1366:  /* pred_indexed_ostorevnx4hivnx4hi */
    case 1365:  /* pred_indexed_ustorevnx4qivnx4hi */
    case 1364:  /* pred_indexed_ostorevnx4qivnx4hi */
    case 1363:  /* pred_indexed_ustorevnx4dfvnx4qi */
    case 1362:  /* pred_indexed_ostorevnx4dfvnx4qi */
    case 1361:  /* pred_indexed_ustorevnx4sfvnx4qi */
    case 1360:  /* pred_indexed_ostorevnx4sfvnx4qi */
    case 1359:  /* pred_indexed_ustorevnx4divnx4qi */
    case 1358:  /* pred_indexed_ostorevnx4divnx4qi */
    case 1357:  /* pred_indexed_ustorevnx4sivnx4qi */
    case 1356:  /* pred_indexed_ostorevnx4sivnx4qi */
    case 1355:  /* pred_indexed_ustorevnx4hivnx4qi */
    case 1354:  /* pred_indexed_ostorevnx4hivnx4qi */
    case 1353:  /* pred_indexed_ustorevnx4qivnx4qi */
    case 1352:  /* pred_indexed_ostorevnx4qivnx4qi */
    case 1351:  /* pred_indexed_ustorevnx2dfvnx2di */
    case 1350:  /* pred_indexed_ostorevnx2dfvnx2di */
    case 1349:  /* pred_indexed_ustorevnx2sfvnx2di */
    case 1348:  /* pred_indexed_ostorevnx2sfvnx2di */
    case 1347:  /* pred_indexed_ustorevnx2divnx2di */
    case 1346:  /* pred_indexed_ostorevnx2divnx2di */
    case 1345:  /* pred_indexed_ustorevnx2sivnx2di */
    case 1344:  /* pred_indexed_ostorevnx2sivnx2di */
    case 1343:  /* pred_indexed_ustorevnx2hivnx2di */
    case 1342:  /* pred_indexed_ostorevnx2hivnx2di */
    case 1341:  /* pred_indexed_ustorevnx2qivnx2di */
    case 1340:  /* pred_indexed_ostorevnx2qivnx2di */
    case 1339:  /* pred_indexed_ustorevnx2dfvnx2si */
    case 1338:  /* pred_indexed_ostorevnx2dfvnx2si */
    case 1337:  /* pred_indexed_ustorevnx2sfvnx2si */
    case 1336:  /* pred_indexed_ostorevnx2sfvnx2si */
    case 1335:  /* pred_indexed_ustorevnx2divnx2si */
    case 1334:  /* pred_indexed_ostorevnx2divnx2si */
    case 1333:  /* pred_indexed_ustorevnx2sivnx2si */
    case 1332:  /* pred_indexed_ostorevnx2sivnx2si */
    case 1331:  /* pred_indexed_ustorevnx2hivnx2si */
    case 1330:  /* pred_indexed_ostorevnx2hivnx2si */
    case 1329:  /* pred_indexed_ustorevnx2qivnx2si */
    case 1328:  /* pred_indexed_ostorevnx2qivnx2si */
    case 1327:  /* pred_indexed_ustorevnx2dfvnx2hi */
    case 1326:  /* pred_indexed_ostorevnx2dfvnx2hi */
    case 1325:  /* pred_indexed_ustorevnx2sfvnx2hi */
    case 1324:  /* pred_indexed_ostorevnx2sfvnx2hi */
    case 1323:  /* pred_indexed_ustorevnx2divnx2hi */
    case 1322:  /* pred_indexed_ostorevnx2divnx2hi */
    case 1321:  /* pred_indexed_ustorevnx2sivnx2hi */
    case 1320:  /* pred_indexed_ostorevnx2sivnx2hi */
    case 1319:  /* pred_indexed_ustorevnx2hivnx2hi */
    case 1318:  /* pred_indexed_ostorevnx2hivnx2hi */
    case 1317:  /* pred_indexed_ustorevnx2qivnx2hi */
    case 1316:  /* pred_indexed_ostorevnx2qivnx2hi */
    case 1315:  /* pred_indexed_ustorevnx2dfvnx2qi */
    case 1314:  /* pred_indexed_ostorevnx2dfvnx2qi */
    case 1313:  /* pred_indexed_ustorevnx2sfvnx2qi */
    case 1312:  /* pred_indexed_ostorevnx2sfvnx2qi */
    case 1311:  /* pred_indexed_ustorevnx2divnx2qi */
    case 1310:  /* pred_indexed_ostorevnx2divnx2qi */
    case 1309:  /* pred_indexed_ustorevnx2sivnx2qi */
    case 1308:  /* pred_indexed_ostorevnx2sivnx2qi */
    case 1307:  /* pred_indexed_ustorevnx2hivnx2qi */
    case 1306:  /* pred_indexed_ostorevnx2hivnx2qi */
    case 1305:  /* pred_indexed_ustorevnx2qivnx2qi */
    case 1304:  /* pred_indexed_ostorevnx2qivnx2qi */
    case 1303:  /* pred_indexed_ustorevnx1dfvnx1di */
    case 1302:  /* pred_indexed_ostorevnx1dfvnx1di */
    case 1301:  /* pred_indexed_ustorevnx1dfvnx1si */
    case 1300:  /* pred_indexed_ostorevnx1dfvnx1si */
    case 1299:  /* pred_indexed_ustorevnx1dfvnx1hi */
    case 1298:  /* pred_indexed_ostorevnx1dfvnx1hi */
    case 1297:  /* pred_indexed_ustorevnx1dfvnx1qi */
    case 1296:  /* pred_indexed_ostorevnx1dfvnx1qi */
    case 1295:  /* pred_indexed_ustorevnx1sfvnx1di */
    case 1294:  /* pred_indexed_ostorevnx1sfvnx1di */
    case 1293:  /* pred_indexed_ustorevnx1sfvnx1si */
    case 1292:  /* pred_indexed_ostorevnx1sfvnx1si */
    case 1291:  /* pred_indexed_ustorevnx1sfvnx1hi */
    case 1290:  /* pred_indexed_ostorevnx1sfvnx1hi */
    case 1289:  /* pred_indexed_ustorevnx1sfvnx1qi */
    case 1288:  /* pred_indexed_ostorevnx1sfvnx1qi */
    case 1287:  /* pred_indexed_ustorevnx1divnx1di */
    case 1286:  /* pred_indexed_ostorevnx1divnx1di */
    case 1285:  /* pred_indexed_ustorevnx1divnx1si */
    case 1284:  /* pred_indexed_ostorevnx1divnx1si */
    case 1283:  /* pred_indexed_ustorevnx1divnx1hi */
    case 1282:  /* pred_indexed_ostorevnx1divnx1hi */
    case 1281:  /* pred_indexed_ustorevnx1divnx1qi */
    case 1280:  /* pred_indexed_ostorevnx1divnx1qi */
    case 1279:  /* pred_indexed_ustorevnx1sivnx1di */
    case 1278:  /* pred_indexed_ostorevnx1sivnx1di */
    case 1277:  /* pred_indexed_ustorevnx1sivnx1si */
    case 1276:  /* pred_indexed_ostorevnx1sivnx1si */
    case 1275:  /* pred_indexed_ustorevnx1sivnx1hi */
    case 1274:  /* pred_indexed_ostorevnx1sivnx1hi */
    case 1273:  /* pred_indexed_ustorevnx1sivnx1qi */
    case 1272:  /* pred_indexed_ostorevnx1sivnx1qi */
    case 1271:  /* pred_indexed_ustorevnx1hivnx1di */
    case 1270:  /* pred_indexed_ostorevnx1hivnx1di */
    case 1269:  /* pred_indexed_ustorevnx1hivnx1si */
    case 1268:  /* pred_indexed_ostorevnx1hivnx1si */
    case 1267:  /* pred_indexed_ustorevnx1hivnx1hi */
    case 1266:  /* pred_indexed_ostorevnx1hivnx1hi */
    case 1265:  /* pred_indexed_ustorevnx1hivnx1qi */
    case 1264:  /* pred_indexed_ostorevnx1hivnx1qi */
    case 1263:  /* pred_indexed_ustorevnx1qivnx1di */
    case 1262:  /* pred_indexed_ostorevnx1qivnx1di */
    case 1261:  /* pred_indexed_ustorevnx1qivnx1si */
    case 1260:  /* pred_indexed_ostorevnx1qivnx1si */
    case 1259:  /* pred_indexed_ustorevnx1qivnx1hi */
    case 1258:  /* pred_indexed_ostorevnx1qivnx1hi */
    case 1257:  /* pred_indexed_ustorevnx1qivnx1qi */
    case 1256:  /* pred_indexed_ostorevnx1qivnx1qi */
    case 1029:  /* pred_strided_storevnx8df */
    case 1028:  /* pred_strided_storevnx4df */
    case 1027:  /* pred_strided_storevnx2df */
    case 1026:  /* pred_strided_storevnx1df */
    case 1025:  /* pred_strided_storevnx16sf */
    case 1024:  /* pred_strided_storevnx8sf */
    case 1023:  /* pred_strided_storevnx4sf */
    case 1022:  /* pred_strided_storevnx2sf */
    case 1021:  /* pred_strided_storevnx1sf */
    case 1020:  /* pred_strided_storevnx8di */
    case 1019:  /* pred_strided_storevnx4di */
    case 1018:  /* pred_strided_storevnx2di */
    case 1017:  /* pred_strided_storevnx1di */
    case 1016:  /* pred_strided_storevnx16si */
    case 1015:  /* pred_strided_storevnx8si */
    case 1014:  /* pred_strided_storevnx4si */
    case 1013:  /* pred_strided_storevnx2si */
    case 1012:  /* pred_strided_storevnx1si */
    case 1011:  /* pred_strided_storevnx32hi */
    case 1010:  /* pred_strided_storevnx16hi */
    case 1009:  /* pred_strided_storevnx8hi */
    case 1008:  /* pred_strided_storevnx4hi */
    case 1007:  /* pred_strided_storevnx2hi */
    case 1006:  /* pred_strided_storevnx1hi */
    case 1005:  /* pred_strided_storevnx64qi */
    case 1004:  /* pred_strided_storevnx32qi */
    case 1003:  /* pred_strided_storevnx16qi */
    case 1002:  /* pred_strided_storevnx8qi */
    case 1001:  /* pred_strided_storevnx4qi */
    case 1000:  /* pred_strided_storevnx2qi */
    case 999:  /* pred_strided_storevnx1qi */
    case 967:  /* *pred_broadcastvnx8di_extended_scalar */
    case 966:  /* *pred_broadcastvnx4di_extended_scalar */
    case 965:  /* *pred_broadcastvnx2di_extended_scalar */
    case 964:  /* *pred_broadcastvnx1di_extended_scalar */
    case 868:  /* pred_movvnx64bi */
    case 867:  /* pred_movvnx32bi */
    case 866:  /* pred_movvnx16bi */
    case 865:  /* pred_movvnx8bi */
    case 864:  /* pred_movvnx4bi */
    case 863:  /* pred_movvnx2bi */
    case 862:  /* pred_movvnx1bi */
    case 830:  /* pred_movvnx8df */
    case 829:  /* pred_movvnx4df */
    case 828:  /* pred_movvnx2df */
    case 827:  /* pred_movvnx1df */
    case 826:  /* pred_movvnx16sf */
    case 825:  /* pred_movvnx8sf */
    case 824:  /* pred_movvnx4sf */
    case 823:  /* pred_movvnx2sf */
    case 822:  /* pred_movvnx1sf */
    case 821:  /* pred_movvnx8di */
    case 820:  /* pred_movvnx4di */
    case 819:  /* pred_movvnx2di */
    case 818:  /* pred_movvnx1di */
    case 817:  /* pred_movvnx16si */
    case 816:  /* pred_movvnx8si */
    case 815:  /* pred_movvnx4si */
    case 814:  /* pred_movvnx2si */
    case 813:  /* pred_movvnx1si */
    case 812:  /* pred_movvnx32hi */
    case 811:  /* pred_movvnx16hi */
    case 810:  /* pred_movvnx8hi */
    case 809:  /* pred_movvnx4hi */
    case 808:  /* pred_movvnx2hi */
    case 807:  /* pred_movvnx1hi */
    case 806:  /* pred_movvnx64qi */
    case 805:  /* pred_movvnx32qi */
    case 804:  /* pred_movvnx16qi */
    case 803:  /* pred_movvnx8qi */
    case 802:  /* pred_movvnx4qi */
    case 801:  /* pred_movvnx2qi */
    case 800:  /* pred_movvnx1qi */
    case 2552:  /* pred_madcvnx1qi */
    case 2553:  /* pred_madcvnx2qi */
    case 2554:  /* pred_madcvnx4qi */
    case 2555:  /* pred_madcvnx8qi */
    case 2556:  /* pred_madcvnx16qi */
    case 2557:  /* pred_madcvnx32qi */
    case 2558:  /* pred_madcvnx64qi */
    case 2559:  /* pred_madcvnx1hi */
    case 2560:  /* pred_madcvnx2hi */
    case 2561:  /* pred_madcvnx4hi */
    case 2562:  /* pred_madcvnx8hi */
    case 2563:  /* pred_madcvnx16hi */
    case 2564:  /* pred_madcvnx32hi */
    case 2565:  /* pred_madcvnx1si */
    case 2566:  /* pred_madcvnx2si */
    case 2567:  /* pred_madcvnx4si */
    case 2568:  /* pred_madcvnx8si */
    case 2569:  /* pred_madcvnx16si */
    case 2570:  /* pred_madcvnx1di */
    case 2571:  /* pred_madcvnx2di */
    case 2572:  /* pred_madcvnx4di */
    case 2573:  /* pred_madcvnx8di */
    case 2574:  /* pred_msbcvnx1qi */
    case 2575:  /* pred_msbcvnx2qi */
    case 2576:  /* pred_msbcvnx4qi */
    case 2577:  /* pred_msbcvnx8qi */
    case 2578:  /* pred_msbcvnx16qi */
    case 2579:  /* pred_msbcvnx32qi */
    case 2580:  /* pred_msbcvnx64qi */
    case 2581:  /* pred_msbcvnx1hi */
    case 2582:  /* pred_msbcvnx2hi */
    case 2583:  /* pred_msbcvnx4hi */
    case 2584:  /* pred_msbcvnx8hi */
    case 2585:  /* pred_msbcvnx16hi */
    case 2586:  /* pred_msbcvnx32hi */
    case 2587:  /* pred_msbcvnx1si */
    case 2588:  /* pred_msbcvnx2si */
    case 2589:  /* pred_msbcvnx4si */
    case 2590:  /* pred_msbcvnx8si */
    case 2591:  /* pred_msbcvnx16si */
    case 2592:  /* pred_msbcvnx1di */
    case 2593:  /* pred_msbcvnx2di */
    case 2594:  /* pred_msbcvnx4di */
    case 2595:  /* pred_msbcvnx8di */
    case 2596:  /* pred_madcvnx1qi_scalar */
    case 2597:  /* pred_madcvnx2qi_scalar */
    case 2598:  /* pred_madcvnx4qi_scalar */
    case 2599:  /* pred_madcvnx8qi_scalar */
    case 2600:  /* pred_madcvnx16qi_scalar */
    case 2601:  /* pred_madcvnx32qi_scalar */
    case 2602:  /* pred_madcvnx64qi_scalar */
    case 2603:  /* pred_madcvnx1hi_scalar */
    case 2604:  /* pred_madcvnx2hi_scalar */
    case 2605:  /* pred_madcvnx4hi_scalar */
    case 2606:  /* pred_madcvnx8hi_scalar */
    case 2607:  /* pred_madcvnx16hi_scalar */
    case 2608:  /* pred_madcvnx32hi_scalar */
    case 2609:  /* pred_madcvnx1si_scalar */
    case 2610:  /* pred_madcvnx2si_scalar */
    case 2611:  /* pred_madcvnx4si_scalar */
    case 2612:  /* pred_madcvnx8si_scalar */
    case 2613:  /* pred_madcvnx16si_scalar */
    case 2614:  /* pred_msbcvnx1qi_scalar */
    case 2615:  /* pred_msbcvnx2qi_scalar */
    case 2616:  /* pred_msbcvnx4qi_scalar */
    case 2617:  /* pred_msbcvnx8qi_scalar */
    case 2618:  /* pred_msbcvnx16qi_scalar */
    case 2619:  /* pred_msbcvnx32qi_scalar */
    case 2620:  /* pred_msbcvnx64qi_scalar */
    case 2621:  /* pred_msbcvnx1hi_scalar */
    case 2622:  /* pred_msbcvnx2hi_scalar */
    case 2623:  /* pred_msbcvnx4hi_scalar */
    case 2624:  /* pred_msbcvnx8hi_scalar */
    case 2625:  /* pred_msbcvnx16hi_scalar */
    case 2626:  /* pred_msbcvnx32hi_scalar */
    case 2627:  /* pred_msbcvnx1si_scalar */
    case 2628:  /* pred_msbcvnx2si_scalar */
    case 2629:  /* pred_msbcvnx4si_scalar */
    case 2630:  /* pred_msbcvnx8si_scalar */
    case 2631:  /* pred_msbcvnx16si_scalar */
    case 2632:  /* *pred_madcvnx1di_scalar */
    case 2633:  /* *pred_madcvnx2di_scalar */
    case 2634:  /* *pred_madcvnx4di_scalar */
    case 2635:  /* *pred_madcvnx8di_scalar */
    case 2636:  /* *pred_madcvnx1di_extended_scalar */
    case 2637:  /* *pred_madcvnx2di_extended_scalar */
    case 2638:  /* *pred_madcvnx4di_extended_scalar */
    case 2639:  /* *pred_madcvnx8di_extended_scalar */
    case 2640:  /* *pred_msbcvnx1di_scalar */
    case 2641:  /* *pred_msbcvnx2di_scalar */
    case 2642:  /* *pred_msbcvnx4di_scalar */
    case 2643:  /* *pred_msbcvnx8di_scalar */
    case 2644:  /* *pred_msbcvnx1di_extended_scalar */
    case 2645:  /* *pred_msbcvnx2di_extended_scalar */
    case 2646:  /* *pred_msbcvnx4di_extended_scalar */
    case 2647:  /* *pred_msbcvnx8di_extended_scalar */
    case 2744:  /* pred_negvnx1qi */
    case 2745:  /* pred_one_cmplvnx1qi */
    case 2746:  /* pred_negvnx2qi */
    case 2747:  /* pred_one_cmplvnx2qi */
    case 2748:  /* pred_negvnx4qi */
    case 2749:  /* pred_one_cmplvnx4qi */
    case 2750:  /* pred_negvnx8qi */
    case 2751:  /* pred_one_cmplvnx8qi */
    case 2752:  /* pred_negvnx16qi */
    case 2753:  /* pred_one_cmplvnx16qi */
    case 2754:  /* pred_negvnx32qi */
    case 2755:  /* pred_one_cmplvnx32qi */
    case 2756:  /* pred_negvnx64qi */
    case 2757:  /* pred_one_cmplvnx64qi */
    case 2758:  /* pred_negvnx1hi */
    case 2759:  /* pred_one_cmplvnx1hi */
    case 2760:  /* pred_negvnx2hi */
    case 2761:  /* pred_one_cmplvnx2hi */
    case 2762:  /* pred_negvnx4hi */
    case 2763:  /* pred_one_cmplvnx4hi */
    case 2764:  /* pred_negvnx8hi */
    case 2765:  /* pred_one_cmplvnx8hi */
    case 2766:  /* pred_negvnx16hi */
    case 2767:  /* pred_one_cmplvnx16hi */
    case 2768:  /* pred_negvnx32hi */
    case 2769:  /* pred_one_cmplvnx32hi */
    case 2770:  /* pred_negvnx1si */
    case 2771:  /* pred_one_cmplvnx1si */
    case 2772:  /* pred_negvnx2si */
    case 2773:  /* pred_one_cmplvnx2si */
    case 2774:  /* pred_negvnx4si */
    case 2775:  /* pred_one_cmplvnx4si */
    case 2776:  /* pred_negvnx8si */
    case 2777:  /* pred_one_cmplvnx8si */
    case 2778:  /* pred_negvnx16si */
    case 2779:  /* pred_one_cmplvnx16si */
    case 2780:  /* pred_negvnx1di */
    case 2781:  /* pred_one_cmplvnx1di */
    case 2782:  /* pred_negvnx2di */
    case 2783:  /* pred_one_cmplvnx2di */
    case 2784:  /* pred_negvnx4di */
    case 2785:  /* pred_one_cmplvnx4di */
    case 2786:  /* pred_negvnx8di */
    case 2787:  /* pred_one_cmplvnx8di */
    case 3174:  /* pred_extendvnx1hi */
    case 3175:  /* pred_zero_extendvnx1hi */
    case 3176:  /* pred_extendvnx2hi */
    case 3177:  /* pred_zero_extendvnx2hi */
    case 3178:  /* pred_extendvnx4hi */
    case 3179:  /* pred_zero_extendvnx4hi */
    case 3180:  /* pred_extendvnx8hi */
    case 3181:  /* pred_zero_extendvnx8hi */
    case 3182:  /* pred_extendvnx16hi */
    case 3183:  /* pred_zero_extendvnx16hi */
    case 3184:  /* pred_extendvnx32hi */
    case 3185:  /* pred_zero_extendvnx32hi */
    case 3186:  /* pred_extendvnx1si */
    case 3187:  /* pred_zero_extendvnx1si */
    case 3188:  /* pred_extendvnx2si */
    case 3189:  /* pred_zero_extendvnx2si */
    case 3190:  /* pred_extendvnx4si */
    case 3191:  /* pred_zero_extendvnx4si */
    case 3192:  /* pred_extendvnx8si */
    case 3193:  /* pred_zero_extendvnx8si */
    case 3194:  /* pred_extendvnx16si */
    case 3195:  /* pred_zero_extendvnx16si */
    case 3196:  /* pred_extendvnx1di */
    case 3197:  /* pred_zero_extendvnx1di */
    case 3198:  /* pred_extendvnx2di */
    case 3199:  /* pred_zero_extendvnx2di */
    case 3200:  /* pred_extendvnx4di */
    case 3201:  /* pred_zero_extendvnx4di */
    case 3202:  /* pred_extendvnx8di */
    case 3203:  /* pred_zero_extendvnx8di */
    case 3264:  /* pred_truncvnx1hi */
    case 3265:  /* pred_truncvnx2hi */
    case 3266:  /* pred_truncvnx4hi */
    case 3267:  /* pred_truncvnx8hi */
    case 3268:  /* pred_truncvnx16hi */
    case 3269:  /* pred_truncvnx32hi */
    case 3270:  /* pred_truncvnx1si */
    case 3271:  /* pred_truncvnx2si */
    case 3272:  /* pred_truncvnx4si */
    case 3273:  /* pred_truncvnx8si */
    case 3274:  /* pred_truncvnx16si */
    case 3275:  /* pred_truncvnx1di */
    case 3276:  /* pred_truncvnx2di */
    case 3277:  /* pred_truncvnx4di */
    case 3278:  /* pred_truncvnx8di */
    case 4500:  /* pred_notvnx1bi */
    case 4501:  /* pred_notvnx2bi */
    case 4502:  /* pred_notvnx4bi */
    case 4503:  /* pred_notvnx8bi */
    case 4504:  /* pred_notvnx16bi */
    case 4505:  /* pred_notvnx32bi */
    case 4506:  /* pred_notvnx64bi */
    case 4996:  /* pred_negvnx1sf */
    case 4997:  /* pred_absvnx1sf */
    case 4998:  /* pred_sqrtvnx1sf */
    case 4999:  /* pred_negvnx2sf */
    case 5000:  /* pred_absvnx2sf */
    case 5001:  /* pred_sqrtvnx2sf */
    case 5002:  /* pred_negvnx4sf */
    case 5003:  /* pred_absvnx4sf */
    case 5004:  /* pred_sqrtvnx4sf */
    case 5005:  /* pred_negvnx8sf */
    case 5006:  /* pred_absvnx8sf */
    case 5007:  /* pred_sqrtvnx8sf */
    case 5008:  /* pred_negvnx16sf */
    case 5009:  /* pred_absvnx16sf */
    case 5010:  /* pred_sqrtvnx16sf */
    case 5011:  /* pred_negvnx1df */
    case 5012:  /* pred_absvnx1df */
    case 5013:  /* pred_sqrtvnx1df */
    case 5014:  /* pred_negvnx2df */
    case 5015:  /* pred_absvnx2df */
    case 5016:  /* pred_sqrtvnx2df */
    case 5017:  /* pred_negvnx4df */
    case 5018:  /* pred_absvnx4df */
    case 5019:  /* pred_sqrtvnx4df */
    case 5020:  /* pred_negvnx8df */
    case 5021:  /* pred_absvnx8df */
    case 5022:  /* pred_sqrtvnx8df */
      return 4;

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      extract_constrain_insn_cached (insn);
      if (((cached_type = get_attr_type (insn)) == TYPE_VLDE) || (cached_type == TYPE_VSTE) || (cached_type == TYPE_VIMOV) || (cached_type == TYPE_VFMOV) || (cached_type == TYPE_VLDM) || (cached_type == TYPE_VSTM) || (cached_type == TYPE_VMALU) || (cached_type == TYPE_VSTS) || (cached_type == TYPE_VSTUX) || (cached_type == TYPE_VSTOX) || (cached_type == TYPE_VEXT) || (cached_type == TYPE_VMSFS) || (cached_type == TYPE_VMIOTA) || (cached_type == TYPE_VFSQRT) || (cached_type == TYPE_VFRECP) || (cached_type == TYPE_VFCVTITOF) || (cached_type == TYPE_VLDFF) || (cached_type == TYPE_VFCVTFTOI) || (cached_type == TYPE_VFWCVTITOF) || (cached_type == TYPE_VFWCVTFTOI) || (cached_type == TYPE_VFWCVTFTOF) || (cached_type == TYPE_VFNCVTITOF) || (cached_type == TYPE_VFNCVTFTOI) || (cached_type == TYPE_VFNCVTFTOF) || (cached_type == TYPE_VFCLASS) || (cached_type == TYPE_VIMOVXV) || (cached_type == TYPE_VFMOVFV) || (cached_type == TYPE_VCOMPRESS))
        {
	  return 4;
        }
      else if (cached_type == TYPE_VLDS)
        {
	  if (
#line 239 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(VECTOR_MODE_P (GET_MODE (operands[3]))))
	    {
	      return 5;
	    }
	  else
	    {
	      return 4;
	    }
        }
      else if ((cached_type == TYPE_VLDUX) || (cached_type == TYPE_VLDOX) || (cached_type == TYPE_VIALU) || (cached_type == TYPE_VSHIFT) || (cached_type == TYPE_VIMINMAX) || (cached_type == TYPE_VIMUL) || (cached_type == TYPE_VIDIV) || (cached_type == TYPE_VSALU) || (cached_type == TYPE_VIWALU) || (cached_type == TYPE_VIWMUL) || (cached_type == TYPE_VNSHIFT) || (cached_type == TYPE_VIMERGE) || (cached_type == TYPE_VAALU) || (cached_type == TYPE_VSMUL) || (cached_type == TYPE_VSSHIFT) || (cached_type == TYPE_VNCLIP) || (cached_type == TYPE_VFALU) || (cached_type == TYPE_VFMUL) || (cached_type == TYPE_VFMINMAX) || (cached_type == TYPE_VFDIV) || (cached_type == TYPE_VFWALU) || (cached_type == TYPE_VFWMUL) || (cached_type == TYPE_VFSGNJ) || (cached_type == TYPE_VFMERGE) || (cached_type == TYPE_VIRED) || (cached_type == TYPE_VIWRED) || (cached_type == TYPE_VFREDU) || (cached_type == TYPE_VFREDO) || (cached_type == TYPE_VFWREDU) || (cached_type == TYPE_VFWREDO) || (cached_type == TYPE_VSLIDEUP) || (cached_type == TYPE_VSLIDEDOWN) || (cached_type == TYPE_VISLIDE1UP) || (cached_type == TYPE_VISLIDE1DOWN) || (cached_type == TYPE_VFSLIDE1UP) || (cached_type == TYPE_VFSLIDE1DOWN) || (cached_type == TYPE_VGATHER) || (cached_type == TYPE_VIWMULADD) || (cached_type == TYPE_VFWMULADD))
        {
	  return 5;
        }
      else if ((cached_type == TYPE_VICMP) || (cached_type == TYPE_VIMULADD) || (cached_type == TYPE_VFCMP) || (cached_type == TYPE_VFMULADD))
        {
	  return 6;
        }
      else if ((cached_type == TYPE_VMPOP) || (cached_type == TYPE_VMFFS) || (cached_type == TYPE_VMIDX))
        {
	  return 3;
        }
      else
        {
	  return 255 /* 0xff */;
        }

    default:
      return 5;

    }
}

int
get_attr_vlmul (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_mode cached_mode ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 6044:  /* pred_fault_loadvnx1hi */
    case 6011:  /* pred_compressvnx1hi */
    case 5980:  /* pred_gatherei16vnx1hi */
    case 5950:  /* pred_gathervnx1hi_scalar */
    case 5919:  /* pred_gathervnx1hi */
    case 5857:  /* pred_slide1downvnx1hi */
    case 5856:  /* pred_slide1upvnx1hi */
    case 5795:  /* pred_slidedownvnx1hi */
    case 5794:  /* pred_slideupvnx1hi */
    case 5752:  /* *pred_extract_firstvnx1hi */
    case 5674:  /* pred_widen_reduc_plusuvnx1hivnx1si */
    case 5673:  /* pred_widen_reduc_plusvnx1hivnx1si */
    case 5640:  /* pred_widen_reduc_plusuvnx1hivnx2si */
    case 5639:  /* pred_widen_reduc_plusvnx1hivnx2si */
    case 5560:  /* pred_reduc_xorvnx1hivnx2hi */
    case 5559:  /* pred_reduc_orvnx1hivnx2hi */
    case 5558:  /* pred_reduc_andvnx1hivnx2hi */
    case 5557:  /* pred_reduc_minvnx1hivnx2hi */
    case 5556:  /* pred_reduc_minuvnx1hivnx2hi */
    case 5555:  /* pred_reduc_maxvnx1hivnx2hi */
    case 5554:  /* pred_reduc_maxuvnx1hivnx2hi */
    case 5553:  /* pred_reduc_sumvnx1hivnx2hi */
    case 5392:  /* pred_reduc_xorvnx1hivnx4hi */
    case 5391:  /* pred_reduc_orvnx1hivnx4hi */
    case 5390:  /* pred_reduc_andvnx1hivnx4hi */
    case 5389:  /* pred_reduc_minvnx1hivnx4hi */
    case 5388:  /* pred_reduc_minuvnx1hivnx4hi */
    case 5387:  /* pred_reduc_maxvnx1hivnx4hi */
    case 5386:  /* pred_reduc_maxuvnx1hivnx4hi */
    case 5385:  /* pred_reduc_sumvnx1hivnx4hi */
    case 5296:  /* pred_narrow_fixuns_truncvnx1sf */
    case 5295:  /* pred_narrow_fix_truncvnx1sf */
    case 5278:  /* pred_narrow_fcvt_xu_fvnx1sf */
    case 5277:  /* pred_narrow_fcvt_x_fvnx1sf */
    case 5256:  /* pred_widen_floatunsvnx1sf */
    case 5255:  /* pred_widen_floatvnx1sf */
    case 4585:  /* pred_seriesvnx1hi */
    case 4563:  /* pred_iotavnx1hi */
    case 4435:  /* pred_widen_mul_plususvnx1si_scalar */
    case 4420:  /* pred_widen_mul_plussuvnx1si_scalar */
    case 4405:  /* pred_widen_mul_plussuvnx1si */
    case 4382:  /* pred_widen_mul_plusuvnx1si_scalar */
    case 4381:  /* pred_widen_mul_plussvnx1si_scalar */
    case 4352:  /* pred_widen_mul_plusuvnx1si */
    case 4351:  /* pred_widen_mul_plussvnx1si */
    case 4312:  /* *pred_minus_mulvnx1hi_scalar */
    case 4290:  /* *pred_nmsacvnx1hi_scalar */
    case 4268:  /* *pred_nmsubvnx1hi_scalar */
    case 4246:  /* *pred_minus_mulvnx1hi */
    case 4224:  /* *pred_nmsacvnx1hi */
    case 4202:  /* *pred_nmsubvnx1hi */
    case 4168:  /* *pred_mul_plusvnx1hi_scalar */
    case 4146:  /* *pred_maccvnx1hi_scalar */
    case 4124:  /* *pred_maddvnx1hi_scalar */
    case 4102:  /* *pred_mul_plusvnx1hi */
    case 4080:  /* *pred_maccvnx1hi */
    case 4058:  /* *pred_maddvnx1hi */
    case 4008:  /* *pred_eqnevnx1hi_scalar_narrow */
    case 3990:  /* *pred_eqnevnx1hi_scalar */
    case 3972:  /* *pred_cmpvnx1hi_scalar_narrow */
    case 3954:  /* *pred_cmpvnx1hi_scalar */
    case 3932:  /* *pred_ltgevnx1hi_narrow */
    case 3910:  /* *pred_ltgevnx1hi */
    case 3888:  /* *pred_cmpvnx1hi_narrow */
    case 3866:  /* *pred_cmpvnx1hi */
    case 3842:  /* pred_narrow_clipuvnx1si_scalar */
    case 3841:  /* pred_narrow_clipvnx1si_scalar */
    case 3812:  /* pred_narrow_clipuvnx1si */
    case 3811:  /* pred_narrow_clipvnx1si */
    case 3730:  /* pred_ssravnx1hi_scalar */
    case 3729:  /* pred_ssrlvnx1hi_scalar */
    case 3664:  /* pred_smulvnx1hi_scalar */
    case 3663:  /* pred_asubvnx1hi_scalar */
    case 3662:  /* pred_asubuvnx1hi_scalar */
    case 3661:  /* pred_aaddvnx1hi_scalar */
    case 3660:  /* pred_aadduvnx1hi_scalar */
    case 3526:  /* pred_ssravnx1hi */
    case 3525:  /* pred_ssrlvnx1hi */
    case 3524:  /* pred_smulvnx1hi */
    case 3523:  /* pred_asubvnx1hi */
    case 3522:  /* pred_asubuvnx1hi */
    case 3521:  /* pred_aaddvnx1hi */
    case 3520:  /* pred_aadduvnx1hi */
    case 3418:  /* pred_ussubvnx1hi_scalar */
    case 3417:  /* pred_sssubvnx1hi_scalar */
    case 3382:  /* pred_usaddvnx1hi_scalar */
    case 3381:  /* pred_ssaddvnx1hi_scalar */
    case 3310:  /* pred_ussubvnx1hi */
    case 3309:  /* pred_usaddvnx1hi */
    case 3308:  /* pred_sssubvnx1hi */
    case 3307:  /* pred_ssaddvnx1hi */
    case 3270:  /* pred_truncvnx1si */
    case 3247:  /* pred_narrow_lshrvnx1si_scalar */
    case 3246:  /* pred_narrow_ashrvnx1si_scalar */
    case 3217:  /* pred_narrow_lshrvnx1si */
    case 3216:  /* pred_narrow_ashrvnx1si */
    case 3187:  /* pred_zero_extendvnx1si */
    case 3186:  /* pred_extendvnx1si */
    case 3165:  /* pred_widen_mulsuvnx1si_scalar */
    case 3150:  /* pred_widen_mulsuvnx1si */
    case 3111:  /* pred_single_widen_subuvnx1si_scalar */
    case 3110:  /* pred_single_widen_adduvnx1si_scalar */
    case 3109:  /* pred_single_widen_subsvnx1si_scalar */
    case 3108:  /* pred_single_widen_addsvnx1si_scalar */
    case 3051:  /* pred_single_widen_subuvnx1si */
    case 3050:  /* pred_single_widen_adduvnx1si */
    case 3049:  /* pred_single_widen_subsvnx1si */
    case 3048:  /* pred_single_widen_addsvnx1si */
    case 2975:  /* pred_dual_widen_muluvnx1si_scalar */
    case 2974:  /* pred_dual_widen_subuvnx1si_scalar */
    case 2973:  /* pred_dual_widen_adduvnx1si_scalar */
    case 2972:  /* pred_dual_widen_mulsvnx1si_scalar */
    case 2971:  /* pred_dual_widen_subsvnx1si_scalar */
    case 2970:  /* pred_dual_widen_addsvnx1si_scalar */
    case 2885:  /* pred_dual_widen_muluvnx1si */
    case 2884:  /* pred_dual_widen_subuvnx1si */
    case 2883:  /* pred_dual_widen_adduvnx1si */
    case 2882:  /* pred_dual_widen_mulsvnx1si */
    case 2881:  /* pred_dual_widen_subsvnx1si */
    case 2880:  /* pred_dual_widen_addsvnx1si */
    case 2789:  /* pred_zero_extendvnx1hi_vf2 */
    case 2788:  /* pred_extendvnx1hi_vf2 */
    case 2759:  /* pred_one_cmplvnx1hi */
    case 2758:  /* pred_negvnx1hi */
    case 2717:  /* pred_msbcvnx1hi_overflow_scalar */
    case 2699:  /* pred_madcvnx1hi_overflow_scalar */
    case 2677:  /* pred_msbcvnx1hi_overflow */
    case 2655:  /* pred_madcvnx1hi_overflow */
    case 2621:  /* pred_msbcvnx1hi_scalar */
    case 2603:  /* pred_madcvnx1hi_scalar */
    case 2581:  /* pred_msbcvnx1hi */
    case 2559:  /* pred_madcvnx1hi */
    case 2525:  /* pred_sbcvnx1hi_scalar */
    case 2507:  /* pred_adcvnx1hi_scalar */
    case 2485:  /* pred_sbcvnx1hi */
    case 2463:  /* pred_adcvnx1hi */
    case 2401:  /* pred_mulhsuvnx1hi_scalar */
    case 2400:  /* pred_mulhuvnx1hi_scalar */
    case 2399:  /* pred_mulhvnx1hi_scalar */
    case 2335:  /* pred_mulhsuvnx1hi */
    case 2334:  /* pred_mulhuvnx1hi */
    case 2333:  /* pred_mulhvnx1hi */
    case 2181:  /* pred_subvnx1hi_reverse_scalar */
    case 2123:  /* pred_umodvnx1hi_scalar */
    case 2122:  /* pred_modvnx1hi_scalar */
    case 2121:  /* pred_udivvnx1hi_scalar */
    case 2120:  /* pred_divvnx1hi_scalar */
    case 2119:  /* pred_subvnx1hi_scalar */
    case 1993:  /* pred_mulvnx1hi_scalar */
    case 1992:  /* pred_uminvnx1hi_scalar */
    case 1991:  /* pred_sminvnx1hi_scalar */
    case 1990:  /* pred_umaxvnx1hi_scalar */
    case 1989:  /* pred_smaxvnx1hi_scalar */
    case 1988:  /* pred_xorvnx1hi_scalar */
    case 1987:  /* pred_iorvnx1hi_scalar */
    case 1986:  /* pred_andvnx1hi_scalar */
    case 1985:  /* pred_addvnx1hi_scalar */
    case 1879:  /* pred_lshrvnx1hi_scalar */
    case 1878:  /* pred_ashrvnx1hi_scalar */
    case 1877:  /* pred_ashlvnx1hi_scalar */
    case 1617:  /* pred_umodvnx1hi */
    case 1616:  /* pred_modvnx1hi */
    case 1615:  /* pred_udivvnx1hi */
    case 1614:  /* pred_divvnx1hi */
    case 1613:  /* pred_mulvnx1hi */
    case 1612:  /* pred_uminvnx1hi */
    case 1611:  /* pred_sminvnx1hi */
    case 1610:  /* pred_umaxvnx1hi */
    case 1609:  /* pred_smaxvnx1hi */
    case 1608:  /* pred_lshrvnx1hi */
    case 1607:  /* pred_ashrvnx1hi */
    case 1606:  /* pred_ashlvnx1hi */
    case 1605:  /* pred_xorvnx1hi */
    case 1604:  /* pred_iorvnx1hi */
    case 1603:  /* pred_andvnx1hi */
    case 1602:  /* pred_subvnx1hi */
    case 1601:  /* pred_addvnx1hi */
    case 1271:  /* pred_indexed_ustorevnx1hivnx1di */
    case 1270:  /* pred_indexed_ostorevnx1hivnx1di */
    case 1269:  /* pred_indexed_ustorevnx1hivnx1si */
    case 1268:  /* pred_indexed_ostorevnx1hivnx1si */
    case 1267:  /* pred_indexed_ustorevnx1hivnx1hi */
    case 1266:  /* pred_indexed_ostorevnx1hivnx1hi */
    case 1265:  /* pred_indexed_ustorevnx1hivnx1qi */
    case 1264:  /* pred_indexed_ostorevnx1hivnx1qi */
    case 1241:  /* pred_indexed_uloadvnx1hi_x4_smaller_eew */
    case 1240:  /* pred_indexed_oloadvnx1hi_x4_smaller_eew */
    case 1205:  /* pred_indexed_uloadvnx1hi_x2_smaller_eew */
    case 1204:  /* pred_indexed_oloadvnx1hi_x2_smaller_eew */
    case 1093:  /* pred_indexed_uloadvnx1hi_x2_greater_eew */
    case 1092:  /* pred_indexed_oloadvnx1hi_x2_greater_eew */
    case 1045:  /* pred_indexed_uloadvnx1hi_same_eew */
    case 1044:  /* pred_indexed_oloadvnx1hi_same_eew */
    case 1006:  /* pred_strided_storevnx1hi */
    case 975:  /* pred_strided_loadvnx1hi */
    case 940:  /* *pred_broadcastvnx1hi */
    case 914:  /* pred_mergevnx1hi_scalar */
    case 883:  /* pred_mergevnx1hi */
    case 838:  /* pred_storevnx1hi */
    case 807:  /* pred_movvnx1hi */
    case 754:  /* *movvnx1hi_fract */
      extract_constrain_insn_cached (insn);
      return 
#line 114 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx1HImode));

    case 6038:  /* pred_fault_loadvnx2qi */
    case 6005:  /* pred_compressvnx2qi */
    case 5975:  /* pred_gatherei16vnx2qi */
    case 5944:  /* pred_gathervnx2qi_scalar */
    case 5913:  /* pred_gathervnx2qi */
    case 5845:  /* pred_slide1downvnx2qi */
    case 5844:  /* pred_slide1upvnx2qi */
    case 5783:  /* pred_slidedownvnx2qi */
    case 5782:  /* pred_slideupvnx2qi */
    case 5746:  /* *pred_extract_firstvnx2qi */
    case 5664:  /* pred_widen_reduc_plusuvnx2qivnx2hi */
    case 5663:  /* pred_widen_reduc_plusvnx2qivnx2hi */
    case 5628:  /* pred_widen_reduc_plusuvnx2qivnx4hi */
    case 5627:  /* pred_widen_reduc_plusvnx2qivnx4hi */
    case 5520:  /* pred_reduc_xorvnx2qivnx4qi */
    case 5519:  /* pred_reduc_orvnx2qivnx4qi */
    case 5518:  /* pred_reduc_andvnx2qivnx4qi */
    case 5517:  /* pred_reduc_minvnx2qivnx4qi */
    case 5516:  /* pred_reduc_minuvnx2qivnx4qi */
    case 5515:  /* pred_reduc_maxvnx2qivnx4qi */
    case 5514:  /* pred_reduc_maxuvnx2qivnx4qi */
    case 5513:  /* pred_reduc_sumvnx2qivnx4qi */
    case 5344:  /* pred_reduc_xorvnx2qivnx8qi */
    case 5343:  /* pred_reduc_orvnx2qivnx8qi */
    case 5342:  /* pred_reduc_andvnx2qivnx8qi */
    case 5341:  /* pred_reduc_minvnx2qivnx8qi */
    case 5340:  /* pred_reduc_minuvnx2qivnx8qi */
    case 5339:  /* pred_reduc_maxvnx2qivnx8qi */
    case 5338:  /* pred_reduc_maxuvnx2qivnx8qi */
    case 5337:  /* pred_reduc_sumvnx2qivnx8qi */
    case 4579:  /* pred_seriesvnx2qi */
    case 4557:  /* pred_iotavnx2qi */
    case 4540:  /* pred_sofvnx2bi */
    case 4539:  /* pred_sifvnx2bi */
    case 4538:  /* pred_sbfvnx2bi */
    case 4529:  /* pred_ffsvnx2bidi */
    case 4522:  /* pred_ffsvnx2bisi */
    case 4515:  /* pred_popcountvnx2bidi */
    case 4508:  /* pred_popcountvnx2bisi */
    case 4501:  /* pred_notvnx2bi */
    case 4489:  /* pred_iornotvnx2bi */
    case 4488:  /* pred_andnotvnx2bi */
    case 4470:  /* pred_nxorvnx2bi */
    case 4469:  /* pred_niorvnx2bi */
    case 4468:  /* pred_nandvnx2bi */
    case 4449:  /* pred_xorvnx2bi */
    case 4448:  /* pred_iorvnx2bi */
    case 4447:  /* pred_andvnx2bi */
    case 4430:  /* pred_widen_mul_plususvnx2hi_scalar */
    case 4415:  /* pred_widen_mul_plussuvnx2hi_scalar */
    case 4400:  /* pred_widen_mul_plussuvnx2hi */
    case 4372:  /* pred_widen_mul_plusuvnx2hi_scalar */
    case 4371:  /* pred_widen_mul_plussvnx2hi_scalar */
    case 4342:  /* pred_widen_mul_plusuvnx2hi */
    case 4341:  /* pred_widen_mul_plussvnx2hi */
    case 4306:  /* *pred_minus_mulvnx2qi_scalar */
    case 4284:  /* *pred_nmsacvnx2qi_scalar */
    case 4262:  /* *pred_nmsubvnx2qi_scalar */
    case 4240:  /* *pred_minus_mulvnx2qi */
    case 4218:  /* *pred_nmsacvnx2qi */
    case 4196:  /* *pred_nmsubvnx2qi */
    case 4162:  /* *pred_mul_plusvnx2qi_scalar */
    case 4140:  /* *pred_maccvnx2qi_scalar */
    case 4118:  /* *pred_maddvnx2qi_scalar */
    case 4096:  /* *pred_mul_plusvnx2qi */
    case 4074:  /* *pred_maccvnx2qi */
    case 4052:  /* *pred_maddvnx2qi */
    case 4002:  /* *pred_eqnevnx2qi_scalar_narrow */
    case 3984:  /* *pred_eqnevnx2qi_scalar */
    case 3966:  /* *pred_cmpvnx2qi_scalar_narrow */
    case 3948:  /* *pred_cmpvnx2qi_scalar */
    case 3926:  /* *pred_ltgevnx2qi_narrow */
    case 3904:  /* *pred_ltgevnx2qi */
    case 3882:  /* *pred_cmpvnx2qi_narrow */
    case 3860:  /* *pred_cmpvnx2qi */
    case 3832:  /* pred_narrow_clipuvnx2hi_scalar */
    case 3831:  /* pred_narrow_clipvnx2hi_scalar */
    case 3802:  /* pred_narrow_clipuvnx2hi */
    case 3801:  /* pred_narrow_clipvnx2hi */
    case 3718:  /* pred_ssravnx2qi_scalar */
    case 3717:  /* pred_ssrlvnx2qi_scalar */
    case 3634:  /* pred_smulvnx2qi_scalar */
    case 3633:  /* pred_asubvnx2qi_scalar */
    case 3632:  /* pred_asubuvnx2qi_scalar */
    case 3631:  /* pred_aaddvnx2qi_scalar */
    case 3630:  /* pred_aadduvnx2qi_scalar */
    case 3484:  /* pred_ssravnx2qi */
    case 3483:  /* pred_ssrlvnx2qi */
    case 3482:  /* pred_smulvnx2qi */
    case 3481:  /* pred_asubvnx2qi */
    case 3480:  /* pred_asubuvnx2qi */
    case 3479:  /* pred_aaddvnx2qi */
    case 3478:  /* pred_aadduvnx2qi */
    case 3406:  /* pred_ussubvnx2qi_scalar */
    case 3405:  /* pred_sssubvnx2qi_scalar */
    case 3370:  /* pred_usaddvnx2qi_scalar */
    case 3369:  /* pred_ssaddvnx2qi_scalar */
    case 3286:  /* pred_ussubvnx2qi */
    case 3285:  /* pred_usaddvnx2qi */
    case 3284:  /* pred_sssubvnx2qi */
    case 3283:  /* pred_ssaddvnx2qi */
    case 3265:  /* pred_truncvnx2hi */
    case 3237:  /* pred_narrow_lshrvnx2hi_scalar */
    case 3236:  /* pred_narrow_ashrvnx2hi_scalar */
    case 3207:  /* pred_narrow_lshrvnx2hi */
    case 3206:  /* pred_narrow_ashrvnx2hi */
    case 3177:  /* pred_zero_extendvnx2hi */
    case 3176:  /* pred_extendvnx2hi */
    case 3160:  /* pred_widen_mulsuvnx2hi_scalar */
    case 3145:  /* pred_widen_mulsuvnx2hi */
    case 3091:  /* pred_single_widen_subuvnx2hi_scalar */
    case 3090:  /* pred_single_widen_adduvnx2hi_scalar */
    case 3089:  /* pred_single_widen_subsvnx2hi_scalar */
    case 3088:  /* pred_single_widen_addsvnx2hi_scalar */
    case 3031:  /* pred_single_widen_subuvnx2hi */
    case 3030:  /* pred_single_widen_adduvnx2hi */
    case 3029:  /* pred_single_widen_subsvnx2hi */
    case 3028:  /* pred_single_widen_addsvnx2hi */
    case 2945:  /* pred_dual_widen_muluvnx2hi_scalar */
    case 2944:  /* pred_dual_widen_subuvnx2hi_scalar */
    case 2943:  /* pred_dual_widen_adduvnx2hi_scalar */
    case 2942:  /* pred_dual_widen_mulsvnx2hi_scalar */
    case 2941:  /* pred_dual_widen_subsvnx2hi_scalar */
    case 2940:  /* pred_dual_widen_addsvnx2hi_scalar */
    case 2855:  /* pred_dual_widen_muluvnx2hi */
    case 2854:  /* pred_dual_widen_subuvnx2hi */
    case 2853:  /* pred_dual_widen_adduvnx2hi */
    case 2852:  /* pred_dual_widen_mulsvnx2hi */
    case 2851:  /* pred_dual_widen_subsvnx2hi */
    case 2850:  /* pred_dual_widen_addsvnx2hi */
    case 2747:  /* pred_one_cmplvnx2qi */
    case 2746:  /* pred_negvnx2qi */
    case 2711:  /* pred_msbcvnx2qi_overflow_scalar */
    case 2693:  /* pred_madcvnx2qi_overflow_scalar */
    case 2671:  /* pred_msbcvnx2qi_overflow */
    case 2649:  /* pred_madcvnx2qi_overflow */
    case 2615:  /* pred_msbcvnx2qi_scalar */
    case 2597:  /* pred_madcvnx2qi_scalar */
    case 2575:  /* pred_msbcvnx2qi */
    case 2553:  /* pred_madcvnx2qi */
    case 2519:  /* pred_sbcvnx2qi_scalar */
    case 2501:  /* pred_adcvnx2qi_scalar */
    case 2479:  /* pred_sbcvnx2qi */
    case 2457:  /* pred_adcvnx2qi */
    case 2383:  /* pred_mulhsuvnx2qi_scalar */
    case 2382:  /* pred_mulhuvnx2qi_scalar */
    case 2381:  /* pred_mulhvnx2qi_scalar */
    case 2317:  /* pred_mulhsuvnx2qi */
    case 2316:  /* pred_mulhuvnx2qi */
    case 2315:  /* pred_mulhvnx2qi */
    case 2175:  /* pred_subvnx2qi_reverse_scalar */
    case 2093:  /* pred_umodvnx2qi_scalar */
    case 2092:  /* pred_modvnx2qi_scalar */
    case 2091:  /* pred_udivvnx2qi_scalar */
    case 2090:  /* pred_divvnx2qi_scalar */
    case 2089:  /* pred_subvnx2qi_scalar */
    case 1939:  /* pred_mulvnx2qi_scalar */
    case 1938:  /* pred_uminvnx2qi_scalar */
    case 1937:  /* pred_sminvnx2qi_scalar */
    case 1936:  /* pred_umaxvnx2qi_scalar */
    case 1935:  /* pred_smaxvnx2qi_scalar */
    case 1934:  /* pred_xorvnx2qi_scalar */
    case 1933:  /* pred_iorvnx2qi_scalar */
    case 1932:  /* pred_andvnx2qi_scalar */
    case 1931:  /* pred_addvnx2qi_scalar */
    case 1861:  /* pred_lshrvnx2qi_scalar */
    case 1860:  /* pred_ashrvnx2qi_scalar */
    case 1859:  /* pred_ashlvnx2qi_scalar */
    case 1515:  /* pred_umodvnx2qi */
    case 1514:  /* pred_modvnx2qi */
    case 1513:  /* pred_udivvnx2qi */
    case 1512:  /* pred_divvnx2qi */
    case 1511:  /* pred_mulvnx2qi */
    case 1510:  /* pred_uminvnx2qi */
    case 1509:  /* pred_sminvnx2qi */
    case 1508:  /* pred_umaxvnx2qi */
    case 1507:  /* pred_smaxvnx2qi */
    case 1506:  /* pred_lshrvnx2qi */
    case 1505:  /* pred_ashrvnx2qi */
    case 1504:  /* pred_ashlvnx2qi */
    case 1503:  /* pred_xorvnx2qi */
    case 1502:  /* pred_iorvnx2qi */
    case 1501:  /* pred_andvnx2qi */
    case 1500:  /* pred_subvnx2qi */
    case 1499:  /* pred_addvnx2qi */
    case 1341:  /* pred_indexed_ustorevnx2qivnx2di */
    case 1340:  /* pred_indexed_ostorevnx2qivnx2di */
    case 1329:  /* pred_indexed_ustorevnx2qivnx2si */
    case 1328:  /* pred_indexed_ostorevnx2qivnx2si */
    case 1317:  /* pred_indexed_ustorevnx2qivnx2hi */
    case 1316:  /* pred_indexed_ostorevnx2qivnx2hi */
    case 1305:  /* pred_indexed_ustorevnx2qivnx2qi */
    case 1304:  /* pred_indexed_ostorevnx2qivnx2qi */
    case 1251:  /* pred_indexed_uloadvnx2qi_x8_smaller_eew */
    case 1250:  /* pred_indexed_oloadvnx2qi_x8_smaller_eew */
    case 1233:  /* pred_indexed_uloadvnx2qi_x4_smaller_eew */
    case 1232:  /* pred_indexed_oloadvnx2qi_x4_smaller_eew */
    case 1195:  /* pred_indexed_uloadvnx2qi_x2_smaller_eew */
    case 1194:  /* pred_indexed_oloadvnx2qi_x2_smaller_eew */
    case 1033:  /* pred_indexed_uloadvnx2qi_same_eew */
    case 1032:  /* pred_indexed_oloadvnx2qi_same_eew */
    case 1000:  /* pred_strided_storevnx2qi */
    case 969:  /* pred_strided_loadvnx2qi */
    case 934:  /* *pred_broadcastvnx2qi */
    case 908:  /* pred_mergevnx2qi_scalar */
    case 877:  /* pred_mergevnx2qi */
    case 870:  /* pred_storevnx2bi */
    case 863:  /* pred_movvnx2bi */
    case 832:  /* pred_storevnx2qi */
    case 801:  /* pred_movvnx2qi */
    case 759:  /* *movvnx2bi */
    case 752:  /* *movvnx2qi_fract */
      extract_constrain_insn_cached (insn);
      return 
#line 102 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx2QImode));

    case 6037:  /* pred_fault_loadvnx1qi */
    case 6004:  /* pred_compressvnx1qi */
    case 5974:  /* pred_gatherei16vnx1qi */
    case 5943:  /* pred_gathervnx1qi_scalar */
    case 5912:  /* pred_gathervnx1qi */
    case 5843:  /* pred_slide1downvnx1qi */
    case 5842:  /* pred_slide1upvnx1qi */
    case 5781:  /* pred_slidedownvnx1qi */
    case 5780:  /* pred_slideupvnx1qi */
    case 5745:  /* *pred_extract_firstvnx1qi */
    case 5662:  /* pred_widen_reduc_plusuvnx1qivnx2hi */
    case 5661:  /* pred_widen_reduc_plusvnx1qivnx2hi */
    case 5626:  /* pred_widen_reduc_plusuvnx1qivnx4hi */
    case 5625:  /* pred_widen_reduc_plusvnx1qivnx4hi */
    case 5512:  /* pred_reduc_xorvnx1qivnx4qi */
    case 5511:  /* pred_reduc_orvnx1qivnx4qi */
    case 5510:  /* pred_reduc_andvnx1qivnx4qi */
    case 5509:  /* pred_reduc_minvnx1qivnx4qi */
    case 5508:  /* pred_reduc_minuvnx1qivnx4qi */
    case 5507:  /* pred_reduc_maxvnx1qivnx4qi */
    case 5506:  /* pred_reduc_maxuvnx1qivnx4qi */
    case 5505:  /* pred_reduc_sumvnx1qivnx4qi */
    case 5336:  /* pred_reduc_xorvnx1qivnx8qi */
    case 5335:  /* pred_reduc_orvnx1qivnx8qi */
    case 5334:  /* pred_reduc_andvnx1qivnx8qi */
    case 5333:  /* pred_reduc_minvnx1qivnx8qi */
    case 5332:  /* pred_reduc_minuvnx1qivnx8qi */
    case 5331:  /* pred_reduc_maxvnx1qivnx8qi */
    case 5330:  /* pred_reduc_maxuvnx1qivnx8qi */
    case 5329:  /* pred_reduc_sumvnx1qivnx8qi */
    case 4578:  /* pred_seriesvnx1qi */
    case 4556:  /* pred_iotavnx1qi */
    case 4537:  /* pred_sofvnx1bi */
    case 4536:  /* pred_sifvnx1bi */
    case 4535:  /* pred_sbfvnx1bi */
    case 4528:  /* pred_ffsvnx1bidi */
    case 4521:  /* pred_ffsvnx1bisi */
    case 4514:  /* pred_popcountvnx1bidi */
    case 4507:  /* pred_popcountvnx1bisi */
    case 4500:  /* pred_notvnx1bi */
    case 4487:  /* pred_iornotvnx1bi */
    case 4486:  /* pred_andnotvnx1bi */
    case 4467:  /* pred_nxorvnx1bi */
    case 4466:  /* pred_niorvnx1bi */
    case 4465:  /* pred_nandvnx1bi */
    case 4446:  /* pred_xorvnx1bi */
    case 4445:  /* pred_iorvnx1bi */
    case 4444:  /* pred_andvnx1bi */
    case 4429:  /* pred_widen_mul_plususvnx1hi_scalar */
    case 4414:  /* pred_widen_mul_plussuvnx1hi_scalar */
    case 4399:  /* pred_widen_mul_plussuvnx1hi */
    case 4370:  /* pred_widen_mul_plusuvnx1hi_scalar */
    case 4369:  /* pred_widen_mul_plussvnx1hi_scalar */
    case 4340:  /* pred_widen_mul_plusuvnx1hi */
    case 4339:  /* pred_widen_mul_plussvnx1hi */
    case 4305:  /* *pred_minus_mulvnx1qi_scalar */
    case 4283:  /* *pred_nmsacvnx1qi_scalar */
    case 4261:  /* *pred_nmsubvnx1qi_scalar */
    case 4239:  /* *pred_minus_mulvnx1qi */
    case 4217:  /* *pred_nmsacvnx1qi */
    case 4195:  /* *pred_nmsubvnx1qi */
    case 4161:  /* *pred_mul_plusvnx1qi_scalar */
    case 4139:  /* *pred_maccvnx1qi_scalar */
    case 4117:  /* *pred_maddvnx1qi_scalar */
    case 4095:  /* *pred_mul_plusvnx1qi */
    case 4073:  /* *pred_maccvnx1qi */
    case 4051:  /* *pred_maddvnx1qi */
    case 4001:  /* *pred_eqnevnx1qi_scalar_narrow */
    case 3983:  /* *pred_eqnevnx1qi_scalar */
    case 3965:  /* *pred_cmpvnx1qi_scalar_narrow */
    case 3947:  /* *pred_cmpvnx1qi_scalar */
    case 3925:  /* *pred_ltgevnx1qi_narrow */
    case 3903:  /* *pred_ltgevnx1qi */
    case 3881:  /* *pred_cmpvnx1qi_narrow */
    case 3859:  /* *pred_cmpvnx1qi */
    case 3830:  /* pred_narrow_clipuvnx1hi_scalar */
    case 3829:  /* pred_narrow_clipvnx1hi_scalar */
    case 3800:  /* pred_narrow_clipuvnx1hi */
    case 3799:  /* pred_narrow_clipvnx1hi */
    case 3716:  /* pred_ssravnx1qi_scalar */
    case 3715:  /* pred_ssrlvnx1qi_scalar */
    case 3629:  /* pred_smulvnx1qi_scalar */
    case 3628:  /* pred_asubvnx1qi_scalar */
    case 3627:  /* pred_asubuvnx1qi_scalar */
    case 3626:  /* pred_aaddvnx1qi_scalar */
    case 3625:  /* pred_aadduvnx1qi_scalar */
    case 3477:  /* pred_ssravnx1qi */
    case 3476:  /* pred_ssrlvnx1qi */
    case 3475:  /* pred_smulvnx1qi */
    case 3474:  /* pred_asubvnx1qi */
    case 3473:  /* pred_asubuvnx1qi */
    case 3472:  /* pred_aaddvnx1qi */
    case 3471:  /* pred_aadduvnx1qi */
    case 3404:  /* pred_ussubvnx1qi_scalar */
    case 3403:  /* pred_sssubvnx1qi_scalar */
    case 3368:  /* pred_usaddvnx1qi_scalar */
    case 3367:  /* pred_ssaddvnx1qi_scalar */
    case 3282:  /* pred_ussubvnx1qi */
    case 3281:  /* pred_usaddvnx1qi */
    case 3280:  /* pred_sssubvnx1qi */
    case 3279:  /* pred_ssaddvnx1qi */
    case 3264:  /* pred_truncvnx1hi */
    case 3235:  /* pred_narrow_lshrvnx1hi_scalar */
    case 3234:  /* pred_narrow_ashrvnx1hi_scalar */
    case 3205:  /* pred_narrow_lshrvnx1hi */
    case 3204:  /* pred_narrow_ashrvnx1hi */
    case 3175:  /* pred_zero_extendvnx1hi */
    case 3174:  /* pred_extendvnx1hi */
    case 3159:  /* pred_widen_mulsuvnx1hi_scalar */
    case 3144:  /* pred_widen_mulsuvnx1hi */
    case 3087:  /* pred_single_widen_subuvnx1hi_scalar */
    case 3086:  /* pred_single_widen_adduvnx1hi_scalar */
    case 3085:  /* pred_single_widen_subsvnx1hi_scalar */
    case 3084:  /* pred_single_widen_addsvnx1hi_scalar */
    case 3027:  /* pred_single_widen_subuvnx1hi */
    case 3026:  /* pred_single_widen_adduvnx1hi */
    case 3025:  /* pred_single_widen_subsvnx1hi */
    case 3024:  /* pred_single_widen_addsvnx1hi */
    case 2939:  /* pred_dual_widen_muluvnx1hi_scalar */
    case 2938:  /* pred_dual_widen_subuvnx1hi_scalar */
    case 2937:  /* pred_dual_widen_adduvnx1hi_scalar */
    case 2936:  /* pred_dual_widen_mulsvnx1hi_scalar */
    case 2935:  /* pred_dual_widen_subsvnx1hi_scalar */
    case 2934:  /* pred_dual_widen_addsvnx1hi_scalar */
    case 2849:  /* pred_dual_widen_muluvnx1hi */
    case 2848:  /* pred_dual_widen_subuvnx1hi */
    case 2847:  /* pred_dual_widen_adduvnx1hi */
    case 2846:  /* pred_dual_widen_mulsvnx1hi */
    case 2845:  /* pred_dual_widen_subsvnx1hi */
    case 2844:  /* pred_dual_widen_addsvnx1hi */
    case 2745:  /* pred_one_cmplvnx1qi */
    case 2744:  /* pred_negvnx1qi */
    case 2710:  /* pred_msbcvnx1qi_overflow_scalar */
    case 2692:  /* pred_madcvnx1qi_overflow_scalar */
    case 2670:  /* pred_msbcvnx1qi_overflow */
    case 2648:  /* pred_madcvnx1qi_overflow */
    case 2614:  /* pred_msbcvnx1qi_scalar */
    case 2596:  /* pred_madcvnx1qi_scalar */
    case 2574:  /* pred_msbcvnx1qi */
    case 2552:  /* pred_madcvnx1qi */
    case 2518:  /* pred_sbcvnx1qi_scalar */
    case 2500:  /* pred_adcvnx1qi_scalar */
    case 2478:  /* pred_sbcvnx1qi */
    case 2456:  /* pred_adcvnx1qi */
    case 2380:  /* pred_mulhsuvnx1qi_scalar */
    case 2379:  /* pred_mulhuvnx1qi_scalar */
    case 2378:  /* pred_mulhvnx1qi_scalar */
    case 2314:  /* pred_mulhsuvnx1qi */
    case 2313:  /* pred_mulhuvnx1qi */
    case 2312:  /* pred_mulhvnx1qi */
    case 2174:  /* pred_subvnx1qi_reverse_scalar */
    case 2088:  /* pred_umodvnx1qi_scalar */
    case 2087:  /* pred_modvnx1qi_scalar */
    case 2086:  /* pred_udivvnx1qi_scalar */
    case 2085:  /* pred_divvnx1qi_scalar */
    case 2084:  /* pred_subvnx1qi_scalar */
    case 1930:  /* pred_mulvnx1qi_scalar */
    case 1929:  /* pred_uminvnx1qi_scalar */
    case 1928:  /* pred_sminvnx1qi_scalar */
    case 1927:  /* pred_umaxvnx1qi_scalar */
    case 1926:  /* pred_smaxvnx1qi_scalar */
    case 1925:  /* pred_xorvnx1qi_scalar */
    case 1924:  /* pred_iorvnx1qi_scalar */
    case 1923:  /* pred_andvnx1qi_scalar */
    case 1922:  /* pred_addvnx1qi_scalar */
    case 1858:  /* pred_lshrvnx1qi_scalar */
    case 1857:  /* pred_ashrvnx1qi_scalar */
    case 1856:  /* pred_ashlvnx1qi_scalar */
    case 1498:  /* pred_umodvnx1qi */
    case 1497:  /* pred_modvnx1qi */
    case 1496:  /* pred_udivvnx1qi */
    case 1495:  /* pred_divvnx1qi */
    case 1494:  /* pred_mulvnx1qi */
    case 1493:  /* pred_uminvnx1qi */
    case 1492:  /* pred_sminvnx1qi */
    case 1491:  /* pred_umaxvnx1qi */
    case 1490:  /* pred_smaxvnx1qi */
    case 1489:  /* pred_lshrvnx1qi */
    case 1488:  /* pred_ashrvnx1qi */
    case 1487:  /* pred_ashlvnx1qi */
    case 1486:  /* pred_xorvnx1qi */
    case 1485:  /* pred_iorvnx1qi */
    case 1484:  /* pred_andvnx1qi */
    case 1483:  /* pred_subvnx1qi */
    case 1482:  /* pred_addvnx1qi */
    case 1263:  /* pred_indexed_ustorevnx1qivnx1di */
    case 1262:  /* pred_indexed_ostorevnx1qivnx1di */
    case 1261:  /* pred_indexed_ustorevnx1qivnx1si */
    case 1260:  /* pred_indexed_ostorevnx1qivnx1si */
    case 1259:  /* pred_indexed_ustorevnx1qivnx1hi */
    case 1258:  /* pred_indexed_ostorevnx1qivnx1hi */
    case 1257:  /* pred_indexed_ustorevnx1qivnx1qi */
    case 1256:  /* pred_indexed_ostorevnx1qivnx1qi */
    case 1249:  /* pred_indexed_uloadvnx1qi_x8_smaller_eew */
    case 1248:  /* pred_indexed_oloadvnx1qi_x8_smaller_eew */
    case 1231:  /* pred_indexed_uloadvnx1qi_x4_smaller_eew */
    case 1230:  /* pred_indexed_oloadvnx1qi_x4_smaller_eew */
    case 1193:  /* pred_indexed_uloadvnx1qi_x2_smaller_eew */
    case 1192:  /* pred_indexed_oloadvnx1qi_x2_smaller_eew */
    case 1031:  /* pred_indexed_uloadvnx1qi_same_eew */
    case 1030:  /* pred_indexed_oloadvnx1qi_same_eew */
    case 999:  /* pred_strided_storevnx1qi */
    case 968:  /* pred_strided_loadvnx1qi */
    case 933:  /* *pred_broadcastvnx1qi */
    case 907:  /* pred_mergevnx1qi_scalar */
    case 876:  /* pred_mergevnx1qi */
    case 869:  /* pred_storevnx1bi */
    case 862:  /* pred_movvnx1bi */
    case 831:  /* pred_storevnx1qi */
    case 800:  /* pred_movvnx1qi */
    case 758:  /* *movvnx1bi */
    case 751:  /* *movvnx1qi_fract */
      extract_constrain_insn_cached (insn);
      return 
#line 100 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx1QImode));

    case 6067:  /* pred_fault_loadvnx8df */
    case 6058:  /* pred_fault_loadvnx8di */
    case 6034:  /* pred_compressvnx8df */
    case 6025:  /* pred_compressvnx8di */
    case 6003:  /* pred_gatherei16vnx8df */
    case 5994:  /* pred_gatherei16vnx8di */
    case 5973:  /* pred_gathervnx8df_scalar */
    case 5964:  /* pred_gathervnx8di_scalar */
    case 5942:  /* pred_gathervnx8df */
    case 5933:  /* pred_gathervnx8di */
    case 5911:  /* pred_slide1downvnx8df */
    case 5910:  /* pred_slide1upvnx8df */
    case 5893:  /* *pred_slide1downvnx8di_extended */
    case 5892:  /* *pred_slide1upvnx8di_extended */
    case 5885:  /* *pred_slide1downvnx8di */
    case 5884:  /* *pred_slide1upvnx8di */
    case 5841:  /* pred_slidedownvnx8df */
    case 5840:  /* pred_slideupvnx8df */
    case 5823:  /* pred_slidedownvnx8di */
    case 5822:  /* pred_slideupvnx8di */
    case 5779:  /* *pred_extract_firstvnx8df */
    case 5770:  /* pred_extract_first_truncvnx8di */
    case 5766:  /* *pred_extract_firstvnx8di */
    case 5726:  /* pred_reduc_plusuvnx8dfvnx1df */
    case 5725:  /* pred_reduc_plusovnx8dfvnx1df */
    case 5700:  /* pred_reduc_minvnx8dfvnx1df */
    case 5699:  /* pred_reduc_maxvnx8dfvnx1df */
    case 5504:  /* pred_reduc_xorvnx8divnx1DI */
    case 5503:  /* pred_reduc_orvnx8divnx1DI */
    case 5502:  /* pred_reduc_andvnx8divnx1DI */
    case 5501:  /* pred_reduc_minvnx8divnx1DI */
    case 5500:  /* pred_reduc_minuvnx8divnx1DI */
    case 5499:  /* pred_reduc_maxvnx8divnx1DI */
    case 5498:  /* pred_reduc_maxuvnx8divnx1DI */
    case 5497:  /* pred_reduc_sumvnx8divnx1DI */
    case 5238:  /* pred_floatunsvnx8df */
    case 5237:  /* pred_floatvnx8df */
    case 5220:  /* pred_fixuns_truncvnx8df */
    case 5219:  /* pred_fix_truncvnx8df */
    case 5202:  /* pred_fcvt_xu_fvnx8df */
    case 5201:  /* pred_fcvt_x_fvnx8df */
    case 5184:  /* pred_mergevnx8df_scalar */
    case 5175:  /* *pred_eqnevnx8df_scalar_narrow */
    case 5166:  /* *pred_eqnevnx8df_scalar */
    case 5157:  /* *pred_cmpvnx8df_scalar_narrow */
    case 5148:  /* *pred_cmpvnx8df_scalar */
    case 5139:  /* *pred_cmpvnx8df_narrow */
    case 5130:  /* *pred_cmpvnx8df */
    case 5049:  /* pred_classvnx8df */
    case 5040:  /* pred_rec7vnx8df */
    case 5039:  /* pred_rsqrt7vnx8df */
    case 5022:  /* pred_sqrtvnx8df */
    case 5021:  /* pred_absvnx8df */
    case 5020:  /* pred_negvnx8df */
    case 4995:  /* *pred_mul_neg_subvnx8df_scalar */
    case 4994:  /* *pred_mul_neg_addvnx8df_scalar */
    case 4977:  /* *pred_nmaccvnx8df_scalar */
    case 4976:  /* *pred_nmsacvnx8df_scalar */
    case 4959:  /* *pred_nmaddvnx8df_scalar */
    case 4958:  /* *pred_nmsubvnx8df_scalar */
    case 4941:  /* *pred_mul_neg_subvnx8df */
    case 4940:  /* *pred_mul_neg_addvnx8df */
    case 4923:  /* *pred_nmaccvnx8df */
    case 4922:  /* *pred_nmsacvnx8df */
    case 4905:  /* *pred_nmaddvnx8df */
    case 4904:  /* *pred_nmsubvnx8df */
    case 4887:  /* *pred_mul_subvnx8df_scalar */
    case 4886:  /* *pred_mul_addvnx8df_scalar */
    case 4869:  /* *pred_msacvnx8df_scalar */
    case 4868:  /* *pred_maccvnx8df_scalar */
    case 4851:  /* *pred_msubvnx8df_scalar */
    case 4850:  /* *pred_maddvnx8df_scalar */
    case 4833:  /* *pred_mul_subvnx8df */
    case 4832:  /* *pred_mul_addvnx8df */
    case 4815:  /* *pred_msacvnx8df */
    case 4814:  /* *pred_maccvnx8df */
    case 4797:  /* *pred_msubvnx8df */
    case 4796:  /* *pred_maddvnx8df */
    case 4779:  /* pred_xorsignvnx8df_scalar */
    case 4778:  /* pred_ncopysignvnx8df_scalar */
    case 4777:  /* pred_copysignvnx8df_scalar */
    case 4752:  /* pred_xorsignvnx8df */
    case 4751:  /* pred_ncopysignvnx8df */
    case 4750:  /* pred_copysignvnx8df */
    case 4725:  /* pred_divvnx8df_reverse_scalar */
    case 4724:  /* pred_subvnx8df_reverse_scalar */
    case 4707:  /* pred_divvnx8df_scalar */
    case 4706:  /* pred_subvnx8df_scalar */
    case 4689:  /* pred_sminvnx8df_scalar */
    case 4688:  /* pred_smaxvnx8df_scalar */
    case 4687:  /* pred_mulvnx8df_scalar */
    case 4686:  /* pred_addvnx8df_scalar */
    case 4653:  /* pred_divvnx8df */
    case 4652:  /* pred_subvnx8df */
    case 4651:  /* pred_sminvnx8df */
    case 4650:  /* pred_smaxvnx8df */
    case 4649:  /* pred_mulvnx8df */
    case 4648:  /* pred_addvnx8df */
    case 4599:  /* pred_seriesvnx8di */
    case 4577:  /* pred_iotavnx8di */
    case 4338:  /* *pred_minus_mulvnx8di_extended_scalar */
    case 4334:  /* *pred_nmsacvnx8di_extended_scalar */
    case 4330:  /* *pred_nmsubvnx8di_extended_scalar */
    case 4326:  /* *pred_minus_mulvnx8di_scalar */
    case 4304:  /* *pred_nmsacvnx8di_scalar */
    case 4282:  /* *pred_nmsubvnx8di_scalar */
    case 4260:  /* *pred_minus_mulvnx8di */
    case 4238:  /* *pred_nmsacvnx8di */
    case 4216:  /* *pred_nmsubvnx8di */
    case 4194:  /* *pred_mul_plusvnx8di_extended_scalar */
    case 4190:  /* *pred_maccvnx8di_extended_scalar */
    case 4186:  /* *pred_maddvnx8di_extended_scalar */
    case 4182:  /* *pred_mul_plusvnx8di_scalar */
    case 4160:  /* *pred_maccvnx8di_scalar */
    case 4138:  /* *pred_maddvnx8di_scalar */
    case 4116:  /* *pred_mul_plusvnx8di */
    case 4094:  /* *pred_maccvnx8di */
    case 4072:  /* *pred_maddvnx8di */
    case 4050:  /* *pred_eqnevnx8di_extended_scalar_narrow */
    case 4046:  /* *pred_eqnevnx8di_extended_scalar */
    case 4042:  /* *pred_cmpvnx8di_extended_scalar_narrow */
    case 4038:  /* *pred_cmpvnx8di_extended_scalar */
    case 4034:  /* *pred_eqnevnx8di_scalar_narrow */
    case 4030:  /* *pred_eqnevnx8di_scalar */
    case 4026:  /* *pred_cmpvnx8di_scalar_narrow */
    case 4022:  /* *pred_cmpvnx8di_scalar */
    case 3946:  /* *pred_ltgevnx8di_narrow */
    case 3924:  /* *pred_ltgevnx8di */
    case 3902:  /* *pred_cmpvnx8di_narrow */
    case 3880:  /* *pred_cmpvnx8di */
    case 3798:  /* *pred_smulvnx8di_extended_scalar */
    case 3797:  /* *pred_asubvnx8di_extended_scalar */
    case 3796:  /* *pred_asubuvnx8di_extended_scalar */
    case 3795:  /* *pred_aaddvnx8di_extended_scalar */
    case 3794:  /* *pred_aadduvnx8di_extended_scalar */
    case 3778:  /* *pred_smulvnx8di_scalar */
    case 3777:  /* *pred_asubvnx8di_scalar */
    case 3776:  /* *pred_asubuvnx8di_scalar */
    case 3775:  /* *pred_aaddvnx8di_scalar */
    case 3774:  /* *pred_aadduvnx8di_scalar */
    case 3758:  /* pred_ssravnx8di_scalar */
    case 3757:  /* pred_ssrlvnx8di_scalar */
    case 3624:  /* pred_ssravnx8di */
    case 3623:  /* pred_ssrlvnx8di */
    case 3622:  /* pred_smulvnx8di */
    case 3621:  /* pred_asubvnx8di */
    case 3620:  /* pred_asubuvnx8di */
    case 3619:  /* pred_aaddvnx8di */
    case 3618:  /* pred_aadduvnx8di */
    case 3470:  /* *pred_ussubvnx8di_extended_scalar */
    case 3469:  /* *pred_sssubvnx8di_extended_scalar */
    case 3462:  /* *pred_ussubvnx8di_scalar */
    case 3461:  /* *pred_sssubvnx8di_scalar */
    case 3454:  /* *pred_usaddvnx8di_extended_scalar */
    case 3453:  /* *pred_ssaddvnx8di_extended_scalar */
    case 3446:  /* *pred_usaddvnx8di_scalar */
    case 3445:  /* *pred_ssaddvnx8di_scalar */
    case 3366:  /* pred_ussubvnx8di */
    case 3365:  /* pred_usaddvnx8di */
    case 3364:  /* pred_sssubvnx8di */
    case 3363:  /* pred_ssaddvnx8di */
    case 2843:  /* pred_zero_extendvnx8di_vf8 */
    case 2842:  /* pred_extendvnx8di_vf8 */
    case 2835:  /* pred_zero_extendvnx8di_vf4 */
    case 2834:  /* pred_extendvnx8di_vf4 */
    case 2817:  /* pred_zero_extendvnx8di_vf2 */
    case 2816:  /* pred_extendvnx8di_vf2 */
    case 2787:  /* pred_one_cmplvnx8di */
    case 2786:  /* pred_negvnx8di */
    case 2743:  /* *pred_msbcvnx8di_overflow_extended_scalar */
    case 2739:  /* *pred_msbcvnx8di_overflow_scalar */
    case 2735:  /* *pred_madcvnx8di_overflow_extended_scalar */
    case 2731:  /* *pred_madcvnx8di_overflow_scalar */
    case 2691:  /* pred_msbcvnx8di_overflow */
    case 2669:  /* pred_madcvnx8di_overflow */
    case 2647:  /* *pred_msbcvnx8di_extended_scalar */
    case 2643:  /* *pred_msbcvnx8di_scalar */
    case 2639:  /* *pred_madcvnx8di_extended_scalar */
    case 2635:  /* *pred_madcvnx8di_scalar */
    case 2595:  /* pred_msbcvnx8di */
    case 2573:  /* pred_madcvnx8di */
    case 2551:  /* *pred_sbcvnx8di_extended_scalar */
    case 2547:  /* *pred_sbcvnx8di_scalar */
    case 2543:  /* *pred_adcvnx8di_extended_scalar */
    case 2539:  /* *pred_adcvnx8di_scalar */
    case 2499:  /* pred_sbcvnx8di */
    case 2477:  /* pred_adcvnx8di */
    case 2455:  /* *pred_mulhsuvnx8di_extended_scalar */
    case 2454:  /* *pred_mulhuvnx8di_extended_scalar */
    case 2453:  /* *pred_mulhvnx8di_extended_scalar */
    case 2443:  /* *pred_mulhsuvnx8di_scalar */
    case 2442:  /* *pred_mulhuvnx8di_scalar */
    case 2441:  /* *pred_mulhvnx8di_scalar */
    case 2377:  /* pred_mulhsuvnx8di */
    case 2376:  /* pred_mulhuvnx8di */
    case 2375:  /* pred_mulhvnx8di */
    case 2311:  /* *pred_subvnx8di_extended_reverse_scalar */
    case 2307:  /* *pred_subvnx8di_reverse_scalar */
    case 2303:  /* *pred_umodvnx8di_extended_scalar */
    case 2302:  /* *pred_modvnx8di_extended_scalar */
    case 2301:  /* *pred_udivvnx8di_extended_scalar */
    case 2300:  /* *pred_divvnx8di_extended_scalar */
    case 2299:  /* *pred_subvnx8di_extended_scalar */
    case 2283:  /* *pred_umodvnx8di_scalar */
    case 2282:  /* *pred_modvnx8di_scalar */
    case 2281:  /* *pred_udivvnx8di_scalar */
    case 2280:  /* *pred_divvnx8di_scalar */
    case 2279:  /* *pred_subvnx8di_scalar */
    case 2263:  /* *pred_mulvnx8di_extended_scalar */
    case 2262:  /* *pred_uminvnx8di_extended_scalar */
    case 2261:  /* *pred_sminvnx8di_extended_scalar */
    case 2260:  /* *pred_umaxvnx8di_extended_scalar */
    case 2259:  /* *pred_smaxvnx8di_extended_scalar */
    case 2258:  /* *pred_xorvnx8di_extended_scalar */
    case 2257:  /* *pred_iorvnx8di_extended_scalar */
    case 2256:  /* *pred_andvnx8di_extended_scalar */
    case 2255:  /* *pred_addvnx8di_extended_scalar */
    case 2227:  /* *pred_mulvnx8di_scalar */
    case 2226:  /* *pred_uminvnx8di_scalar */
    case 2225:  /* *pred_sminvnx8di_scalar */
    case 2224:  /* *pred_umaxvnx8di_scalar */
    case 2223:  /* *pred_smaxvnx8di_scalar */
    case 2222:  /* *pred_xorvnx8di_scalar */
    case 2221:  /* *pred_iorvnx8di_scalar */
    case 2220:  /* *pred_andvnx8di_scalar */
    case 2219:  /* *pred_addvnx8di_scalar */
    case 1921:  /* pred_lshrvnx8di_scalar */
    case 1920:  /* pred_ashrvnx8di_scalar */
    case 1919:  /* pred_ashlvnx8di_scalar */
    case 1855:  /* pred_umodvnx8di */
    case 1854:  /* pred_modvnx8di */
    case 1853:  /* pred_udivvnx8di */
    case 1852:  /* pred_divvnx8di */
    case 1851:  /* pred_mulvnx8di */
    case 1850:  /* pred_uminvnx8di */
    case 1849:  /* pred_sminvnx8di */
    case 1848:  /* pred_umaxvnx8di */
    case 1847:  /* pred_smaxvnx8di */
    case 1846:  /* pred_lshrvnx8di */
    case 1845:  /* pred_ashrvnx8di */
    case 1844:  /* pred_ashlvnx8di */
    case 1843:  /* pred_xorvnx8di */
    case 1842:  /* pred_iorvnx8di */
    case 1841:  /* pred_andvnx8di */
    case 1840:  /* pred_subvnx8di */
    case 1839:  /* pred_addvnx8di */
    case 1447:  /* pred_indexed_ustorevnx8dfvnx8di */
    case 1446:  /* pred_indexed_ostorevnx8dfvnx8di */
    case 1443:  /* pred_indexed_ustorevnx8divnx8di */
    case 1442:  /* pred_indexed_ostorevnx8divnx8di */
    case 1435:  /* pred_indexed_ustorevnx8dfvnx8si */
    case 1434:  /* pred_indexed_ostorevnx8dfvnx8si */
    case 1431:  /* pred_indexed_ustorevnx8divnx8si */
    case 1430:  /* pred_indexed_ostorevnx8divnx8si */
    case 1423:  /* pred_indexed_ustorevnx8dfvnx8hi */
    case 1422:  /* pred_indexed_ostorevnx8dfvnx8hi */
    case 1419:  /* pred_indexed_ustorevnx8divnx8hi */
    case 1418:  /* pred_indexed_ostorevnx8divnx8hi */
    case 1411:  /* pred_indexed_ustorevnx8dfvnx8qi */
    case 1410:  /* pred_indexed_ostorevnx8dfvnx8qi */
    case 1407:  /* pred_indexed_ustorevnx8divnx8qi */
    case 1406:  /* pred_indexed_ostorevnx8divnx8qi */
    case 1191:  /* pred_indexed_uloadvnx8df_x8_greater_eew */
    case 1190:  /* pred_indexed_oloadvnx8df_x8_greater_eew */
    case 1183:  /* pred_indexed_uloadvnx8di_x8_greater_eew */
    case 1182:  /* pred_indexed_oloadvnx8di_x8_greater_eew */
    case 1175:  /* pred_indexed_uloadvnx8df_x4_greater_eew */
    case 1174:  /* pred_indexed_oloadvnx8df_x4_greater_eew */
    case 1157:  /* pred_indexed_uloadvnx8di_x4_greater_eew */
    case 1156:  /* pred_indexed_oloadvnx8di_x4_greater_eew */
    case 1139:  /* pred_indexed_uloadvnx8df_x2_greater_eew */
    case 1138:  /* pred_indexed_oloadvnx8df_x2_greater_eew */
    case 1121:  /* pred_indexed_uloadvnx8di_x2_greater_eew */
    case 1120:  /* pred_indexed_oloadvnx8di_x2_greater_eew */
    case 1091:  /* pred_indexed_uloadvnx8df_same_eew */
    case 1090:  /* pred_indexed_oloadvnx8df_same_eew */
    case 1073:  /* pred_indexed_uloadvnx8di_same_eew */
    case 1072:  /* pred_indexed_oloadvnx8di_same_eew */
    case 1029:  /* pred_strided_storevnx8df */
    case 1020:  /* pred_strided_storevnx8di */
    case 998:  /* pred_strided_loadvnx8df */
    case 989:  /* pred_strided_loadvnx8di */
    case 967:  /* *pred_broadcastvnx8di_extended_scalar */
    case 963:  /* *pred_broadcastvnx8df */
    case 954:  /* *pred_broadcastvnx8di */
    case 932:  /* *pred_mergevnx8di_extended_scalar */
    case 928:  /* *pred_mergevnx8di_scalar */
    case 906:  /* pred_mergevnx8df */
    case 897:  /* pred_mergevnx8di */
    case 861:  /* pred_storevnx8df */
    case 852:  /* pred_storevnx8di */
    case 830:  /* pred_movvnx8df */
    case 821:  /* pred_movvnx8di */
    case 750:  /* *movvnx8df_whole */
    case 741:  /* *movvnx8di_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 142 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx8DImode));

    case 6066:  /* pred_fault_loadvnx4df */
    case 6057:  /* pred_fault_loadvnx4di */
    case 6033:  /* pred_compressvnx4df */
    case 6024:  /* pred_compressvnx4di */
    case 6002:  /* pred_gatherei16vnx4df */
    case 5993:  /* pred_gatherei16vnx4di */
    case 5972:  /* pred_gathervnx4df_scalar */
    case 5963:  /* pred_gathervnx4di_scalar */
    case 5941:  /* pred_gathervnx4df */
    case 5932:  /* pred_gathervnx4di */
    case 5909:  /* pred_slide1downvnx4df */
    case 5908:  /* pred_slide1upvnx4df */
    case 5891:  /* *pred_slide1downvnx4di_extended */
    case 5890:  /* *pred_slide1upvnx4di_extended */
    case 5883:  /* *pred_slide1downvnx4di */
    case 5882:  /* *pred_slide1upvnx4di */
    case 5839:  /* pred_slidedownvnx4df */
    case 5838:  /* pred_slideupvnx4df */
    case 5821:  /* pred_slidedownvnx4di */
    case 5820:  /* pred_slideupvnx4di */
    case 5778:  /* *pred_extract_firstvnx4df */
    case 5769:  /* pred_extract_first_truncvnx4di */
    case 5765:  /* *pred_extract_firstvnx4di */
    case 5724:  /* pred_reduc_plusuvnx4dfvnx1df */
    case 5723:  /* pred_reduc_plusovnx4dfvnx1df */
    case 5698:  /* pred_reduc_minvnx4dfvnx1df */
    case 5697:  /* pred_reduc_maxvnx4dfvnx1df */
    case 5496:  /* pred_reduc_xorvnx4divnx1DI */
    case 5495:  /* pred_reduc_orvnx4divnx1DI */
    case 5494:  /* pred_reduc_andvnx4divnx1DI */
    case 5493:  /* pred_reduc_minvnx4divnx1DI */
    case 5492:  /* pred_reduc_minuvnx4divnx1DI */
    case 5491:  /* pred_reduc_maxvnx4divnx1DI */
    case 5490:  /* pred_reduc_maxuvnx4divnx1DI */
    case 5489:  /* pred_reduc_sumvnx4divnx1DI */
    case 5236:  /* pred_floatunsvnx4df */
    case 5235:  /* pred_floatvnx4df */
    case 5218:  /* pred_fixuns_truncvnx4df */
    case 5217:  /* pred_fix_truncvnx4df */
    case 5200:  /* pred_fcvt_xu_fvnx4df */
    case 5199:  /* pred_fcvt_x_fvnx4df */
    case 5183:  /* pred_mergevnx4df_scalar */
    case 5174:  /* *pred_eqnevnx4df_scalar_narrow */
    case 5165:  /* *pred_eqnevnx4df_scalar */
    case 5156:  /* *pred_cmpvnx4df_scalar_narrow */
    case 5147:  /* *pred_cmpvnx4df_scalar */
    case 5138:  /* *pred_cmpvnx4df_narrow */
    case 5129:  /* *pred_cmpvnx4df */
    case 5048:  /* pred_classvnx4df */
    case 5038:  /* pred_rec7vnx4df */
    case 5037:  /* pred_rsqrt7vnx4df */
    case 5019:  /* pred_sqrtvnx4df */
    case 5018:  /* pred_absvnx4df */
    case 5017:  /* pred_negvnx4df */
    case 4993:  /* *pred_mul_neg_subvnx4df_scalar */
    case 4992:  /* *pred_mul_neg_addvnx4df_scalar */
    case 4975:  /* *pred_nmaccvnx4df_scalar */
    case 4974:  /* *pred_nmsacvnx4df_scalar */
    case 4957:  /* *pred_nmaddvnx4df_scalar */
    case 4956:  /* *pred_nmsubvnx4df_scalar */
    case 4939:  /* *pred_mul_neg_subvnx4df */
    case 4938:  /* *pred_mul_neg_addvnx4df */
    case 4921:  /* *pred_nmaccvnx4df */
    case 4920:  /* *pred_nmsacvnx4df */
    case 4903:  /* *pred_nmaddvnx4df */
    case 4902:  /* *pred_nmsubvnx4df */
    case 4885:  /* *pred_mul_subvnx4df_scalar */
    case 4884:  /* *pred_mul_addvnx4df_scalar */
    case 4867:  /* *pred_msacvnx4df_scalar */
    case 4866:  /* *pred_maccvnx4df_scalar */
    case 4849:  /* *pred_msubvnx4df_scalar */
    case 4848:  /* *pred_maddvnx4df_scalar */
    case 4831:  /* *pred_mul_subvnx4df */
    case 4830:  /* *pred_mul_addvnx4df */
    case 4813:  /* *pred_msacvnx4df */
    case 4812:  /* *pred_maccvnx4df */
    case 4795:  /* *pred_msubvnx4df */
    case 4794:  /* *pred_maddvnx4df */
    case 4776:  /* pred_xorsignvnx4df_scalar */
    case 4775:  /* pred_ncopysignvnx4df_scalar */
    case 4774:  /* pred_copysignvnx4df_scalar */
    case 4749:  /* pred_xorsignvnx4df */
    case 4748:  /* pred_ncopysignvnx4df */
    case 4747:  /* pred_copysignvnx4df */
    case 4723:  /* pred_divvnx4df_reverse_scalar */
    case 4722:  /* pred_subvnx4df_reverse_scalar */
    case 4705:  /* pred_divvnx4df_scalar */
    case 4704:  /* pred_subvnx4df_scalar */
    case 4685:  /* pred_sminvnx4df_scalar */
    case 4684:  /* pred_smaxvnx4df_scalar */
    case 4683:  /* pred_mulvnx4df_scalar */
    case 4682:  /* pred_addvnx4df_scalar */
    case 4647:  /* pred_divvnx4df */
    case 4646:  /* pred_subvnx4df */
    case 4645:  /* pred_sminvnx4df */
    case 4644:  /* pred_smaxvnx4df */
    case 4643:  /* pred_mulvnx4df */
    case 4642:  /* pred_addvnx4df */
    case 4598:  /* pred_seriesvnx4di */
    case 4576:  /* pred_iotavnx4di */
    case 4337:  /* *pred_minus_mulvnx4di_extended_scalar */
    case 4333:  /* *pred_nmsacvnx4di_extended_scalar */
    case 4329:  /* *pred_nmsubvnx4di_extended_scalar */
    case 4325:  /* *pred_minus_mulvnx4di_scalar */
    case 4303:  /* *pred_nmsacvnx4di_scalar */
    case 4281:  /* *pred_nmsubvnx4di_scalar */
    case 4259:  /* *pred_minus_mulvnx4di */
    case 4237:  /* *pred_nmsacvnx4di */
    case 4215:  /* *pred_nmsubvnx4di */
    case 4193:  /* *pred_mul_plusvnx4di_extended_scalar */
    case 4189:  /* *pred_maccvnx4di_extended_scalar */
    case 4185:  /* *pred_maddvnx4di_extended_scalar */
    case 4181:  /* *pred_mul_plusvnx4di_scalar */
    case 4159:  /* *pred_maccvnx4di_scalar */
    case 4137:  /* *pred_maddvnx4di_scalar */
    case 4115:  /* *pred_mul_plusvnx4di */
    case 4093:  /* *pred_maccvnx4di */
    case 4071:  /* *pred_maddvnx4di */
    case 4049:  /* *pred_eqnevnx4di_extended_scalar_narrow */
    case 4045:  /* *pred_eqnevnx4di_extended_scalar */
    case 4041:  /* *pred_cmpvnx4di_extended_scalar_narrow */
    case 4037:  /* *pred_cmpvnx4di_extended_scalar */
    case 4033:  /* *pred_eqnevnx4di_scalar_narrow */
    case 4029:  /* *pred_eqnevnx4di_scalar */
    case 4025:  /* *pred_cmpvnx4di_scalar_narrow */
    case 4021:  /* *pred_cmpvnx4di_scalar */
    case 3945:  /* *pred_ltgevnx4di_narrow */
    case 3923:  /* *pred_ltgevnx4di */
    case 3901:  /* *pred_cmpvnx4di_narrow */
    case 3879:  /* *pred_cmpvnx4di */
    case 3793:  /* *pred_smulvnx4di_extended_scalar */
    case 3792:  /* *pred_asubvnx4di_extended_scalar */
    case 3791:  /* *pred_asubuvnx4di_extended_scalar */
    case 3790:  /* *pred_aaddvnx4di_extended_scalar */
    case 3789:  /* *pred_aadduvnx4di_extended_scalar */
    case 3773:  /* *pred_smulvnx4di_scalar */
    case 3772:  /* *pred_asubvnx4di_scalar */
    case 3771:  /* *pred_asubuvnx4di_scalar */
    case 3770:  /* *pred_aaddvnx4di_scalar */
    case 3769:  /* *pred_aadduvnx4di_scalar */
    case 3756:  /* pred_ssravnx4di_scalar */
    case 3755:  /* pred_ssrlvnx4di_scalar */
    case 3617:  /* pred_ssravnx4di */
    case 3616:  /* pred_ssrlvnx4di */
    case 3615:  /* pred_smulvnx4di */
    case 3614:  /* pred_asubvnx4di */
    case 3613:  /* pred_asubuvnx4di */
    case 3612:  /* pred_aaddvnx4di */
    case 3611:  /* pred_aadduvnx4di */
    case 3468:  /* *pred_ussubvnx4di_extended_scalar */
    case 3467:  /* *pred_sssubvnx4di_extended_scalar */
    case 3460:  /* *pred_ussubvnx4di_scalar */
    case 3459:  /* *pred_sssubvnx4di_scalar */
    case 3452:  /* *pred_usaddvnx4di_extended_scalar */
    case 3451:  /* *pred_ssaddvnx4di_extended_scalar */
    case 3444:  /* *pred_usaddvnx4di_scalar */
    case 3443:  /* *pred_ssaddvnx4di_scalar */
    case 3362:  /* pred_ussubvnx4di */
    case 3361:  /* pred_usaddvnx4di */
    case 3360:  /* pred_sssubvnx4di */
    case 3359:  /* pred_ssaddvnx4di */
    case 2841:  /* pred_zero_extendvnx4di_vf8 */
    case 2840:  /* pred_extendvnx4di_vf8 */
    case 2833:  /* pred_zero_extendvnx4di_vf4 */
    case 2832:  /* pred_extendvnx4di_vf4 */
    case 2815:  /* pred_zero_extendvnx4di_vf2 */
    case 2814:  /* pred_extendvnx4di_vf2 */
    case 2785:  /* pred_one_cmplvnx4di */
    case 2784:  /* pred_negvnx4di */
    case 2742:  /* *pred_msbcvnx4di_overflow_extended_scalar */
    case 2738:  /* *pred_msbcvnx4di_overflow_scalar */
    case 2734:  /* *pred_madcvnx4di_overflow_extended_scalar */
    case 2730:  /* *pred_madcvnx4di_overflow_scalar */
    case 2690:  /* pred_msbcvnx4di_overflow */
    case 2668:  /* pred_madcvnx4di_overflow */
    case 2646:  /* *pred_msbcvnx4di_extended_scalar */
    case 2642:  /* *pred_msbcvnx4di_scalar */
    case 2638:  /* *pred_madcvnx4di_extended_scalar */
    case 2634:  /* *pred_madcvnx4di_scalar */
    case 2594:  /* pred_msbcvnx4di */
    case 2572:  /* pred_madcvnx4di */
    case 2550:  /* *pred_sbcvnx4di_extended_scalar */
    case 2546:  /* *pred_sbcvnx4di_scalar */
    case 2542:  /* *pred_adcvnx4di_extended_scalar */
    case 2538:  /* *pred_adcvnx4di_scalar */
    case 2498:  /* pred_sbcvnx4di */
    case 2476:  /* pred_adcvnx4di */
    case 2452:  /* *pred_mulhsuvnx4di_extended_scalar */
    case 2451:  /* *pred_mulhuvnx4di_extended_scalar */
    case 2450:  /* *pred_mulhvnx4di_extended_scalar */
    case 2440:  /* *pred_mulhsuvnx4di_scalar */
    case 2439:  /* *pred_mulhuvnx4di_scalar */
    case 2438:  /* *pred_mulhvnx4di_scalar */
    case 2374:  /* pred_mulhsuvnx4di */
    case 2373:  /* pred_mulhuvnx4di */
    case 2372:  /* pred_mulhvnx4di */
    case 2310:  /* *pred_subvnx4di_extended_reverse_scalar */
    case 2306:  /* *pred_subvnx4di_reverse_scalar */
    case 2298:  /* *pred_umodvnx4di_extended_scalar */
    case 2297:  /* *pred_modvnx4di_extended_scalar */
    case 2296:  /* *pred_udivvnx4di_extended_scalar */
    case 2295:  /* *pred_divvnx4di_extended_scalar */
    case 2294:  /* *pred_subvnx4di_extended_scalar */
    case 2278:  /* *pred_umodvnx4di_scalar */
    case 2277:  /* *pred_modvnx4di_scalar */
    case 2276:  /* *pred_udivvnx4di_scalar */
    case 2275:  /* *pred_divvnx4di_scalar */
    case 2274:  /* *pred_subvnx4di_scalar */
    case 2254:  /* *pred_mulvnx4di_extended_scalar */
    case 2253:  /* *pred_uminvnx4di_extended_scalar */
    case 2252:  /* *pred_sminvnx4di_extended_scalar */
    case 2251:  /* *pred_umaxvnx4di_extended_scalar */
    case 2250:  /* *pred_smaxvnx4di_extended_scalar */
    case 2249:  /* *pred_xorvnx4di_extended_scalar */
    case 2248:  /* *pred_iorvnx4di_extended_scalar */
    case 2247:  /* *pred_andvnx4di_extended_scalar */
    case 2246:  /* *pred_addvnx4di_extended_scalar */
    case 2218:  /* *pred_mulvnx4di_scalar */
    case 2217:  /* *pred_uminvnx4di_scalar */
    case 2216:  /* *pred_sminvnx4di_scalar */
    case 2215:  /* *pred_umaxvnx4di_scalar */
    case 2214:  /* *pred_smaxvnx4di_scalar */
    case 2213:  /* *pred_xorvnx4di_scalar */
    case 2212:  /* *pred_iorvnx4di_scalar */
    case 2211:  /* *pred_andvnx4di_scalar */
    case 2210:  /* *pred_addvnx4di_scalar */
    case 1918:  /* pred_lshrvnx4di_scalar */
    case 1917:  /* pred_ashrvnx4di_scalar */
    case 1916:  /* pred_ashlvnx4di_scalar */
    case 1838:  /* pred_umodvnx4di */
    case 1837:  /* pred_modvnx4di */
    case 1836:  /* pred_udivvnx4di */
    case 1835:  /* pred_divvnx4di */
    case 1834:  /* pred_mulvnx4di */
    case 1833:  /* pred_uminvnx4di */
    case 1832:  /* pred_sminvnx4di */
    case 1831:  /* pred_umaxvnx4di */
    case 1830:  /* pred_smaxvnx4di */
    case 1829:  /* pred_lshrvnx4di */
    case 1828:  /* pred_ashrvnx4di */
    case 1827:  /* pred_ashlvnx4di */
    case 1826:  /* pred_xorvnx4di */
    case 1825:  /* pred_iorvnx4di */
    case 1824:  /* pred_andvnx4di */
    case 1823:  /* pred_subvnx4di */
    case 1822:  /* pred_addvnx4di */
    case 1399:  /* pred_indexed_ustorevnx4dfvnx4di */
    case 1398:  /* pred_indexed_ostorevnx4dfvnx4di */
    case 1395:  /* pred_indexed_ustorevnx4divnx4di */
    case 1394:  /* pred_indexed_ostorevnx4divnx4di */
    case 1387:  /* pred_indexed_ustorevnx4dfvnx4si */
    case 1386:  /* pred_indexed_ostorevnx4dfvnx4si */
    case 1383:  /* pred_indexed_ustorevnx4divnx4si */
    case 1382:  /* pred_indexed_ostorevnx4divnx4si */
    case 1375:  /* pred_indexed_ustorevnx4dfvnx4hi */
    case 1374:  /* pred_indexed_ostorevnx4dfvnx4hi */
    case 1371:  /* pred_indexed_ustorevnx4divnx4hi */
    case 1370:  /* pred_indexed_ostorevnx4divnx4hi */
    case 1363:  /* pred_indexed_ustorevnx4dfvnx4qi */
    case 1362:  /* pred_indexed_ostorevnx4dfvnx4qi */
    case 1359:  /* pred_indexed_ustorevnx4divnx4qi */
    case 1358:  /* pred_indexed_ostorevnx4divnx4qi */
    case 1189:  /* pred_indexed_uloadvnx4df_x8_greater_eew */
    case 1188:  /* pred_indexed_oloadvnx4df_x8_greater_eew */
    case 1181:  /* pred_indexed_uloadvnx4di_x8_greater_eew */
    case 1180:  /* pred_indexed_oloadvnx4di_x8_greater_eew */
    case 1173:  /* pred_indexed_uloadvnx4df_x4_greater_eew */
    case 1172:  /* pred_indexed_oloadvnx4df_x4_greater_eew */
    case 1155:  /* pred_indexed_uloadvnx4di_x4_greater_eew */
    case 1154:  /* pred_indexed_oloadvnx4di_x4_greater_eew */
    case 1137:  /* pred_indexed_uloadvnx4df_x2_greater_eew */
    case 1136:  /* pred_indexed_oloadvnx4df_x2_greater_eew */
    case 1119:  /* pred_indexed_uloadvnx4di_x2_greater_eew */
    case 1118:  /* pred_indexed_oloadvnx4di_x2_greater_eew */
    case 1089:  /* pred_indexed_uloadvnx4df_same_eew */
    case 1088:  /* pred_indexed_oloadvnx4df_same_eew */
    case 1071:  /* pred_indexed_uloadvnx4di_same_eew */
    case 1070:  /* pred_indexed_oloadvnx4di_same_eew */
    case 1028:  /* pred_strided_storevnx4df */
    case 1019:  /* pred_strided_storevnx4di */
    case 997:  /* pred_strided_loadvnx4df */
    case 988:  /* pred_strided_loadvnx4di */
    case 966:  /* *pred_broadcastvnx4di_extended_scalar */
    case 962:  /* *pred_broadcastvnx4df */
    case 953:  /* *pred_broadcastvnx4di */
    case 931:  /* *pred_mergevnx4di_extended_scalar */
    case 927:  /* *pred_mergevnx4di_scalar */
    case 905:  /* pred_mergevnx4df */
    case 896:  /* pred_mergevnx4di */
    case 860:  /* pred_storevnx4df */
    case 851:  /* pred_storevnx4di */
    case 829:  /* pred_movvnx4df */
    case 820:  /* pred_movvnx4di */
    case 749:  /* *movvnx4df_whole */
    case 740:  /* *movvnx4di_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 140 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx4DImode));

    case 6065:  /* pred_fault_loadvnx2df */
    case 6056:  /* pred_fault_loadvnx2di */
    case 6032:  /* pred_compressvnx2df */
    case 6023:  /* pred_compressvnx2di */
    case 6001:  /* pred_gatherei16vnx2df */
    case 5992:  /* pred_gatherei16vnx2di */
    case 5971:  /* pred_gathervnx2df_scalar */
    case 5962:  /* pred_gathervnx2di_scalar */
    case 5940:  /* pred_gathervnx2df */
    case 5931:  /* pred_gathervnx2di */
    case 5907:  /* pred_slide1downvnx2df */
    case 5906:  /* pred_slide1upvnx2df */
    case 5889:  /* *pred_slide1downvnx2di_extended */
    case 5888:  /* *pred_slide1upvnx2di_extended */
    case 5881:  /* *pred_slide1downvnx2di */
    case 5880:  /* *pred_slide1upvnx2di */
    case 5837:  /* pred_slidedownvnx2df */
    case 5836:  /* pred_slideupvnx2df */
    case 5819:  /* pred_slidedownvnx2di */
    case 5818:  /* pred_slideupvnx2di */
    case 5777:  /* *pred_extract_firstvnx2df */
    case 5768:  /* pred_extract_first_truncvnx2di */
    case 5764:  /* *pred_extract_firstvnx2di */
    case 5722:  /* pred_reduc_plusuvnx2dfvnx1df */
    case 5721:  /* pred_reduc_plusovnx2dfvnx1df */
    case 5696:  /* pred_reduc_minvnx2dfvnx1df */
    case 5695:  /* pred_reduc_maxvnx2dfvnx1df */
    case 5488:  /* pred_reduc_xorvnx2divnx1DI */
    case 5487:  /* pred_reduc_orvnx2divnx1DI */
    case 5486:  /* pred_reduc_andvnx2divnx1DI */
    case 5485:  /* pred_reduc_minvnx2divnx1DI */
    case 5484:  /* pred_reduc_minuvnx2divnx1DI */
    case 5483:  /* pred_reduc_maxvnx2divnx1DI */
    case 5482:  /* pred_reduc_maxuvnx2divnx1DI */
    case 5481:  /* pred_reduc_sumvnx2divnx1DI */
    case 5234:  /* pred_floatunsvnx2df */
    case 5233:  /* pred_floatvnx2df */
    case 5216:  /* pred_fixuns_truncvnx2df */
    case 5215:  /* pred_fix_truncvnx2df */
    case 5198:  /* pred_fcvt_xu_fvnx2df */
    case 5197:  /* pred_fcvt_x_fvnx2df */
    case 5182:  /* pred_mergevnx2df_scalar */
    case 5173:  /* *pred_eqnevnx2df_scalar_narrow */
    case 5164:  /* *pred_eqnevnx2df_scalar */
    case 5155:  /* *pred_cmpvnx2df_scalar_narrow */
    case 5146:  /* *pred_cmpvnx2df_scalar */
    case 5137:  /* *pred_cmpvnx2df_narrow */
    case 5128:  /* *pred_cmpvnx2df */
    case 5047:  /* pred_classvnx2df */
    case 5036:  /* pred_rec7vnx2df */
    case 5035:  /* pred_rsqrt7vnx2df */
    case 5016:  /* pred_sqrtvnx2df */
    case 5015:  /* pred_absvnx2df */
    case 5014:  /* pred_negvnx2df */
    case 4991:  /* *pred_mul_neg_subvnx2df_scalar */
    case 4990:  /* *pred_mul_neg_addvnx2df_scalar */
    case 4973:  /* *pred_nmaccvnx2df_scalar */
    case 4972:  /* *pred_nmsacvnx2df_scalar */
    case 4955:  /* *pred_nmaddvnx2df_scalar */
    case 4954:  /* *pred_nmsubvnx2df_scalar */
    case 4937:  /* *pred_mul_neg_subvnx2df */
    case 4936:  /* *pred_mul_neg_addvnx2df */
    case 4919:  /* *pred_nmaccvnx2df */
    case 4918:  /* *pred_nmsacvnx2df */
    case 4901:  /* *pred_nmaddvnx2df */
    case 4900:  /* *pred_nmsubvnx2df */
    case 4883:  /* *pred_mul_subvnx2df_scalar */
    case 4882:  /* *pred_mul_addvnx2df_scalar */
    case 4865:  /* *pred_msacvnx2df_scalar */
    case 4864:  /* *pred_maccvnx2df_scalar */
    case 4847:  /* *pred_msubvnx2df_scalar */
    case 4846:  /* *pred_maddvnx2df_scalar */
    case 4829:  /* *pred_mul_subvnx2df */
    case 4828:  /* *pred_mul_addvnx2df */
    case 4811:  /* *pred_msacvnx2df */
    case 4810:  /* *pred_maccvnx2df */
    case 4793:  /* *pred_msubvnx2df */
    case 4792:  /* *pred_maddvnx2df */
    case 4773:  /* pred_xorsignvnx2df_scalar */
    case 4772:  /* pred_ncopysignvnx2df_scalar */
    case 4771:  /* pred_copysignvnx2df_scalar */
    case 4746:  /* pred_xorsignvnx2df */
    case 4745:  /* pred_ncopysignvnx2df */
    case 4744:  /* pred_copysignvnx2df */
    case 4721:  /* pred_divvnx2df_reverse_scalar */
    case 4720:  /* pred_subvnx2df_reverse_scalar */
    case 4703:  /* pred_divvnx2df_scalar */
    case 4702:  /* pred_subvnx2df_scalar */
    case 4681:  /* pred_sminvnx2df_scalar */
    case 4680:  /* pred_smaxvnx2df_scalar */
    case 4679:  /* pred_mulvnx2df_scalar */
    case 4678:  /* pred_addvnx2df_scalar */
    case 4641:  /* pred_divvnx2df */
    case 4640:  /* pred_subvnx2df */
    case 4639:  /* pred_sminvnx2df */
    case 4638:  /* pred_smaxvnx2df */
    case 4637:  /* pred_mulvnx2df */
    case 4636:  /* pred_addvnx2df */
    case 4597:  /* pred_seriesvnx2di */
    case 4575:  /* pred_iotavnx2di */
    case 4336:  /* *pred_minus_mulvnx2di_extended_scalar */
    case 4332:  /* *pred_nmsacvnx2di_extended_scalar */
    case 4328:  /* *pred_nmsubvnx2di_extended_scalar */
    case 4324:  /* *pred_minus_mulvnx2di_scalar */
    case 4302:  /* *pred_nmsacvnx2di_scalar */
    case 4280:  /* *pred_nmsubvnx2di_scalar */
    case 4258:  /* *pred_minus_mulvnx2di */
    case 4236:  /* *pred_nmsacvnx2di */
    case 4214:  /* *pred_nmsubvnx2di */
    case 4192:  /* *pred_mul_plusvnx2di_extended_scalar */
    case 4188:  /* *pred_maccvnx2di_extended_scalar */
    case 4184:  /* *pred_maddvnx2di_extended_scalar */
    case 4180:  /* *pred_mul_plusvnx2di_scalar */
    case 4158:  /* *pred_maccvnx2di_scalar */
    case 4136:  /* *pred_maddvnx2di_scalar */
    case 4114:  /* *pred_mul_plusvnx2di */
    case 4092:  /* *pred_maccvnx2di */
    case 4070:  /* *pred_maddvnx2di */
    case 4048:  /* *pred_eqnevnx2di_extended_scalar_narrow */
    case 4044:  /* *pred_eqnevnx2di_extended_scalar */
    case 4040:  /* *pred_cmpvnx2di_extended_scalar_narrow */
    case 4036:  /* *pred_cmpvnx2di_extended_scalar */
    case 4032:  /* *pred_eqnevnx2di_scalar_narrow */
    case 4028:  /* *pred_eqnevnx2di_scalar */
    case 4024:  /* *pred_cmpvnx2di_scalar_narrow */
    case 4020:  /* *pred_cmpvnx2di_scalar */
    case 3944:  /* *pred_ltgevnx2di_narrow */
    case 3922:  /* *pred_ltgevnx2di */
    case 3900:  /* *pred_cmpvnx2di_narrow */
    case 3878:  /* *pred_cmpvnx2di */
    case 3788:  /* *pred_smulvnx2di_extended_scalar */
    case 3787:  /* *pred_asubvnx2di_extended_scalar */
    case 3786:  /* *pred_asubuvnx2di_extended_scalar */
    case 3785:  /* *pred_aaddvnx2di_extended_scalar */
    case 3784:  /* *pred_aadduvnx2di_extended_scalar */
    case 3768:  /* *pred_smulvnx2di_scalar */
    case 3767:  /* *pred_asubvnx2di_scalar */
    case 3766:  /* *pred_asubuvnx2di_scalar */
    case 3765:  /* *pred_aaddvnx2di_scalar */
    case 3764:  /* *pred_aadduvnx2di_scalar */
    case 3754:  /* pred_ssravnx2di_scalar */
    case 3753:  /* pred_ssrlvnx2di_scalar */
    case 3610:  /* pred_ssravnx2di */
    case 3609:  /* pred_ssrlvnx2di */
    case 3608:  /* pred_smulvnx2di */
    case 3607:  /* pred_asubvnx2di */
    case 3606:  /* pred_asubuvnx2di */
    case 3605:  /* pred_aaddvnx2di */
    case 3604:  /* pred_aadduvnx2di */
    case 3466:  /* *pred_ussubvnx2di_extended_scalar */
    case 3465:  /* *pred_sssubvnx2di_extended_scalar */
    case 3458:  /* *pred_ussubvnx2di_scalar */
    case 3457:  /* *pred_sssubvnx2di_scalar */
    case 3450:  /* *pred_usaddvnx2di_extended_scalar */
    case 3449:  /* *pred_ssaddvnx2di_extended_scalar */
    case 3442:  /* *pred_usaddvnx2di_scalar */
    case 3441:  /* *pred_ssaddvnx2di_scalar */
    case 3358:  /* pred_ussubvnx2di */
    case 3357:  /* pred_usaddvnx2di */
    case 3356:  /* pred_sssubvnx2di */
    case 3355:  /* pred_ssaddvnx2di */
    case 2839:  /* pred_zero_extendvnx2di_vf8 */
    case 2838:  /* pred_extendvnx2di_vf8 */
    case 2831:  /* pred_zero_extendvnx2di_vf4 */
    case 2830:  /* pred_extendvnx2di_vf4 */
    case 2813:  /* pred_zero_extendvnx2di_vf2 */
    case 2812:  /* pred_extendvnx2di_vf2 */
    case 2783:  /* pred_one_cmplvnx2di */
    case 2782:  /* pred_negvnx2di */
    case 2741:  /* *pred_msbcvnx2di_overflow_extended_scalar */
    case 2737:  /* *pred_msbcvnx2di_overflow_scalar */
    case 2733:  /* *pred_madcvnx2di_overflow_extended_scalar */
    case 2729:  /* *pred_madcvnx2di_overflow_scalar */
    case 2689:  /* pred_msbcvnx2di_overflow */
    case 2667:  /* pred_madcvnx2di_overflow */
    case 2645:  /* *pred_msbcvnx2di_extended_scalar */
    case 2641:  /* *pred_msbcvnx2di_scalar */
    case 2637:  /* *pred_madcvnx2di_extended_scalar */
    case 2633:  /* *pred_madcvnx2di_scalar */
    case 2593:  /* pred_msbcvnx2di */
    case 2571:  /* pred_madcvnx2di */
    case 2549:  /* *pred_sbcvnx2di_extended_scalar */
    case 2545:  /* *pred_sbcvnx2di_scalar */
    case 2541:  /* *pred_adcvnx2di_extended_scalar */
    case 2537:  /* *pred_adcvnx2di_scalar */
    case 2497:  /* pred_sbcvnx2di */
    case 2475:  /* pred_adcvnx2di */
    case 2449:  /* *pred_mulhsuvnx2di_extended_scalar */
    case 2448:  /* *pred_mulhuvnx2di_extended_scalar */
    case 2447:  /* *pred_mulhvnx2di_extended_scalar */
    case 2437:  /* *pred_mulhsuvnx2di_scalar */
    case 2436:  /* *pred_mulhuvnx2di_scalar */
    case 2435:  /* *pred_mulhvnx2di_scalar */
    case 2371:  /* pred_mulhsuvnx2di */
    case 2370:  /* pred_mulhuvnx2di */
    case 2369:  /* pred_mulhvnx2di */
    case 2309:  /* *pred_subvnx2di_extended_reverse_scalar */
    case 2305:  /* *pred_subvnx2di_reverse_scalar */
    case 2293:  /* *pred_umodvnx2di_extended_scalar */
    case 2292:  /* *pred_modvnx2di_extended_scalar */
    case 2291:  /* *pred_udivvnx2di_extended_scalar */
    case 2290:  /* *pred_divvnx2di_extended_scalar */
    case 2289:  /* *pred_subvnx2di_extended_scalar */
    case 2273:  /* *pred_umodvnx2di_scalar */
    case 2272:  /* *pred_modvnx2di_scalar */
    case 2271:  /* *pred_udivvnx2di_scalar */
    case 2270:  /* *pred_divvnx2di_scalar */
    case 2269:  /* *pred_subvnx2di_scalar */
    case 2245:  /* *pred_mulvnx2di_extended_scalar */
    case 2244:  /* *pred_uminvnx2di_extended_scalar */
    case 2243:  /* *pred_sminvnx2di_extended_scalar */
    case 2242:  /* *pred_umaxvnx2di_extended_scalar */
    case 2241:  /* *pred_smaxvnx2di_extended_scalar */
    case 2240:  /* *pred_xorvnx2di_extended_scalar */
    case 2239:  /* *pred_iorvnx2di_extended_scalar */
    case 2238:  /* *pred_andvnx2di_extended_scalar */
    case 2237:  /* *pred_addvnx2di_extended_scalar */
    case 2209:  /* *pred_mulvnx2di_scalar */
    case 2208:  /* *pred_uminvnx2di_scalar */
    case 2207:  /* *pred_sminvnx2di_scalar */
    case 2206:  /* *pred_umaxvnx2di_scalar */
    case 2205:  /* *pred_smaxvnx2di_scalar */
    case 2204:  /* *pred_xorvnx2di_scalar */
    case 2203:  /* *pred_iorvnx2di_scalar */
    case 2202:  /* *pred_andvnx2di_scalar */
    case 2201:  /* *pred_addvnx2di_scalar */
    case 1915:  /* pred_lshrvnx2di_scalar */
    case 1914:  /* pred_ashrvnx2di_scalar */
    case 1913:  /* pred_ashlvnx2di_scalar */
    case 1821:  /* pred_umodvnx2di */
    case 1820:  /* pred_modvnx2di */
    case 1819:  /* pred_udivvnx2di */
    case 1818:  /* pred_divvnx2di */
    case 1817:  /* pred_mulvnx2di */
    case 1816:  /* pred_uminvnx2di */
    case 1815:  /* pred_sminvnx2di */
    case 1814:  /* pred_umaxvnx2di */
    case 1813:  /* pred_smaxvnx2di */
    case 1812:  /* pred_lshrvnx2di */
    case 1811:  /* pred_ashrvnx2di */
    case 1810:  /* pred_ashlvnx2di */
    case 1809:  /* pred_xorvnx2di */
    case 1808:  /* pred_iorvnx2di */
    case 1807:  /* pred_andvnx2di */
    case 1806:  /* pred_subvnx2di */
    case 1805:  /* pred_addvnx2di */
    case 1351:  /* pred_indexed_ustorevnx2dfvnx2di */
    case 1350:  /* pred_indexed_ostorevnx2dfvnx2di */
    case 1347:  /* pred_indexed_ustorevnx2divnx2di */
    case 1346:  /* pred_indexed_ostorevnx2divnx2di */
    case 1339:  /* pred_indexed_ustorevnx2dfvnx2si */
    case 1338:  /* pred_indexed_ostorevnx2dfvnx2si */
    case 1335:  /* pred_indexed_ustorevnx2divnx2si */
    case 1334:  /* pred_indexed_ostorevnx2divnx2si */
    case 1327:  /* pred_indexed_ustorevnx2dfvnx2hi */
    case 1326:  /* pred_indexed_ostorevnx2dfvnx2hi */
    case 1323:  /* pred_indexed_ustorevnx2divnx2hi */
    case 1322:  /* pred_indexed_ostorevnx2divnx2hi */
    case 1315:  /* pred_indexed_ustorevnx2dfvnx2qi */
    case 1314:  /* pred_indexed_ostorevnx2dfvnx2qi */
    case 1311:  /* pred_indexed_ustorevnx2divnx2qi */
    case 1310:  /* pred_indexed_ostorevnx2divnx2qi */
    case 1187:  /* pred_indexed_uloadvnx2df_x8_greater_eew */
    case 1186:  /* pred_indexed_oloadvnx2df_x8_greater_eew */
    case 1179:  /* pred_indexed_uloadvnx2di_x8_greater_eew */
    case 1178:  /* pred_indexed_oloadvnx2di_x8_greater_eew */
    case 1171:  /* pred_indexed_uloadvnx2df_x4_greater_eew */
    case 1170:  /* pred_indexed_oloadvnx2df_x4_greater_eew */
    case 1153:  /* pred_indexed_uloadvnx2di_x4_greater_eew */
    case 1152:  /* pred_indexed_oloadvnx2di_x4_greater_eew */
    case 1135:  /* pred_indexed_uloadvnx2df_x2_greater_eew */
    case 1134:  /* pred_indexed_oloadvnx2df_x2_greater_eew */
    case 1117:  /* pred_indexed_uloadvnx2di_x2_greater_eew */
    case 1116:  /* pred_indexed_oloadvnx2di_x2_greater_eew */
    case 1087:  /* pred_indexed_uloadvnx2df_same_eew */
    case 1086:  /* pred_indexed_oloadvnx2df_same_eew */
    case 1069:  /* pred_indexed_uloadvnx2di_same_eew */
    case 1068:  /* pred_indexed_oloadvnx2di_same_eew */
    case 1027:  /* pred_strided_storevnx2df */
    case 1018:  /* pred_strided_storevnx2di */
    case 996:  /* pred_strided_loadvnx2df */
    case 987:  /* pred_strided_loadvnx2di */
    case 965:  /* *pred_broadcastvnx2di_extended_scalar */
    case 961:  /* *pred_broadcastvnx2df */
    case 952:  /* *pred_broadcastvnx2di */
    case 930:  /* *pred_mergevnx2di_extended_scalar */
    case 926:  /* *pred_mergevnx2di_scalar */
    case 904:  /* pred_mergevnx2df */
    case 895:  /* pred_mergevnx2di */
    case 859:  /* pred_storevnx2df */
    case 850:  /* pred_storevnx2di */
    case 828:  /* pred_movvnx2df */
    case 819:  /* pred_movvnx2di */
    case 748:  /* *movvnx2df_whole */
    case 739:  /* *movvnx2di_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 138 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx2DImode));

    case 6064:  /* pred_fault_loadvnx1df */
    case 6055:  /* pred_fault_loadvnx1di */
    case 6031:  /* pred_compressvnx1df */
    case 6022:  /* pred_compressvnx1di */
    case 6000:  /* pred_gatherei16vnx1df */
    case 5991:  /* pred_gatherei16vnx1di */
    case 5970:  /* pred_gathervnx1df_scalar */
    case 5961:  /* pred_gathervnx1di_scalar */
    case 5939:  /* pred_gathervnx1df */
    case 5930:  /* pred_gathervnx1di */
    case 5905:  /* pred_slide1downvnx1df */
    case 5904:  /* pred_slide1upvnx1df */
    case 5887:  /* *pred_slide1downvnx1di_extended */
    case 5886:  /* *pred_slide1upvnx1di_extended */
    case 5879:  /* *pred_slide1downvnx1di */
    case 5878:  /* *pred_slide1upvnx1di */
    case 5835:  /* pred_slidedownvnx1df */
    case 5834:  /* pred_slideupvnx1df */
    case 5817:  /* pred_slidedownvnx1di */
    case 5816:  /* pred_slideupvnx1di */
    case 5776:  /* *pred_extract_firstvnx1df */
    case 5767:  /* pred_extract_first_truncvnx1di */
    case 5763:  /* *pred_extract_firstvnx1di */
    case 5720:  /* pred_reduc_plusuvnx1dfvnx1df */
    case 5719:  /* pred_reduc_plusovnx1dfvnx1df */
    case 5694:  /* pred_reduc_minvnx1dfvnx1df */
    case 5693:  /* pred_reduc_maxvnx1dfvnx1df */
    case 5480:  /* pred_reduc_xorvnx1divnx1DI */
    case 5479:  /* pred_reduc_orvnx1divnx1DI */
    case 5478:  /* pred_reduc_andvnx1divnx1DI */
    case 5477:  /* pred_reduc_minvnx1divnx1DI */
    case 5476:  /* pred_reduc_minuvnx1divnx1DI */
    case 5475:  /* pred_reduc_maxvnx1divnx1DI */
    case 5474:  /* pred_reduc_maxuvnx1divnx1DI */
    case 5473:  /* pred_reduc_sumvnx1divnx1DI */
    case 5232:  /* pred_floatunsvnx1df */
    case 5231:  /* pred_floatvnx1df */
    case 5214:  /* pred_fixuns_truncvnx1df */
    case 5213:  /* pred_fix_truncvnx1df */
    case 5196:  /* pred_fcvt_xu_fvnx1df */
    case 5195:  /* pred_fcvt_x_fvnx1df */
    case 5181:  /* pred_mergevnx1df_scalar */
    case 5172:  /* *pred_eqnevnx1df_scalar_narrow */
    case 5163:  /* *pred_eqnevnx1df_scalar */
    case 5154:  /* *pred_cmpvnx1df_scalar_narrow */
    case 5145:  /* *pred_cmpvnx1df_scalar */
    case 5136:  /* *pred_cmpvnx1df_narrow */
    case 5127:  /* *pred_cmpvnx1df */
    case 5046:  /* pred_classvnx1df */
    case 5034:  /* pred_rec7vnx1df */
    case 5033:  /* pred_rsqrt7vnx1df */
    case 5013:  /* pred_sqrtvnx1df */
    case 5012:  /* pred_absvnx1df */
    case 5011:  /* pred_negvnx1df */
    case 4989:  /* *pred_mul_neg_subvnx1df_scalar */
    case 4988:  /* *pred_mul_neg_addvnx1df_scalar */
    case 4971:  /* *pred_nmaccvnx1df_scalar */
    case 4970:  /* *pred_nmsacvnx1df_scalar */
    case 4953:  /* *pred_nmaddvnx1df_scalar */
    case 4952:  /* *pred_nmsubvnx1df_scalar */
    case 4935:  /* *pred_mul_neg_subvnx1df */
    case 4934:  /* *pred_mul_neg_addvnx1df */
    case 4917:  /* *pred_nmaccvnx1df */
    case 4916:  /* *pred_nmsacvnx1df */
    case 4899:  /* *pred_nmaddvnx1df */
    case 4898:  /* *pred_nmsubvnx1df */
    case 4881:  /* *pred_mul_subvnx1df_scalar */
    case 4880:  /* *pred_mul_addvnx1df_scalar */
    case 4863:  /* *pred_msacvnx1df_scalar */
    case 4862:  /* *pred_maccvnx1df_scalar */
    case 4845:  /* *pred_msubvnx1df_scalar */
    case 4844:  /* *pred_maddvnx1df_scalar */
    case 4827:  /* *pred_mul_subvnx1df */
    case 4826:  /* *pred_mul_addvnx1df */
    case 4809:  /* *pred_msacvnx1df */
    case 4808:  /* *pred_maccvnx1df */
    case 4791:  /* *pred_msubvnx1df */
    case 4790:  /* *pred_maddvnx1df */
    case 4770:  /* pred_xorsignvnx1df_scalar */
    case 4769:  /* pred_ncopysignvnx1df_scalar */
    case 4768:  /* pred_copysignvnx1df_scalar */
    case 4743:  /* pred_xorsignvnx1df */
    case 4742:  /* pred_ncopysignvnx1df */
    case 4741:  /* pred_copysignvnx1df */
    case 4719:  /* pred_divvnx1df_reverse_scalar */
    case 4718:  /* pred_subvnx1df_reverse_scalar */
    case 4701:  /* pred_divvnx1df_scalar */
    case 4700:  /* pred_subvnx1df_scalar */
    case 4677:  /* pred_sminvnx1df_scalar */
    case 4676:  /* pred_smaxvnx1df_scalar */
    case 4675:  /* pred_mulvnx1df_scalar */
    case 4674:  /* pred_addvnx1df_scalar */
    case 4635:  /* pred_divvnx1df */
    case 4634:  /* pred_subvnx1df */
    case 4633:  /* pred_sminvnx1df */
    case 4632:  /* pred_smaxvnx1df */
    case 4631:  /* pred_mulvnx1df */
    case 4630:  /* pred_addvnx1df */
    case 4596:  /* pred_seriesvnx1di */
    case 4574:  /* pred_iotavnx1di */
    case 4335:  /* *pred_minus_mulvnx1di_extended_scalar */
    case 4331:  /* *pred_nmsacvnx1di_extended_scalar */
    case 4327:  /* *pred_nmsubvnx1di_extended_scalar */
    case 4323:  /* *pred_minus_mulvnx1di_scalar */
    case 4301:  /* *pred_nmsacvnx1di_scalar */
    case 4279:  /* *pred_nmsubvnx1di_scalar */
    case 4257:  /* *pred_minus_mulvnx1di */
    case 4235:  /* *pred_nmsacvnx1di */
    case 4213:  /* *pred_nmsubvnx1di */
    case 4191:  /* *pred_mul_plusvnx1di_extended_scalar */
    case 4187:  /* *pred_maccvnx1di_extended_scalar */
    case 4183:  /* *pred_maddvnx1di_extended_scalar */
    case 4179:  /* *pred_mul_plusvnx1di_scalar */
    case 4157:  /* *pred_maccvnx1di_scalar */
    case 4135:  /* *pred_maddvnx1di_scalar */
    case 4113:  /* *pred_mul_plusvnx1di */
    case 4091:  /* *pred_maccvnx1di */
    case 4069:  /* *pred_maddvnx1di */
    case 4047:  /* *pred_eqnevnx1di_extended_scalar_narrow */
    case 4043:  /* *pred_eqnevnx1di_extended_scalar */
    case 4039:  /* *pred_cmpvnx1di_extended_scalar_narrow */
    case 4035:  /* *pred_cmpvnx1di_extended_scalar */
    case 4031:  /* *pred_eqnevnx1di_scalar_narrow */
    case 4027:  /* *pred_eqnevnx1di_scalar */
    case 4023:  /* *pred_cmpvnx1di_scalar_narrow */
    case 4019:  /* *pred_cmpvnx1di_scalar */
    case 3943:  /* *pred_ltgevnx1di_narrow */
    case 3921:  /* *pred_ltgevnx1di */
    case 3899:  /* *pred_cmpvnx1di_narrow */
    case 3877:  /* *pred_cmpvnx1di */
    case 3783:  /* *pred_smulvnx1di_extended_scalar */
    case 3782:  /* *pred_asubvnx1di_extended_scalar */
    case 3781:  /* *pred_asubuvnx1di_extended_scalar */
    case 3780:  /* *pred_aaddvnx1di_extended_scalar */
    case 3779:  /* *pred_aadduvnx1di_extended_scalar */
    case 3763:  /* *pred_smulvnx1di_scalar */
    case 3762:  /* *pred_asubvnx1di_scalar */
    case 3761:  /* *pred_asubuvnx1di_scalar */
    case 3760:  /* *pred_aaddvnx1di_scalar */
    case 3759:  /* *pred_aadduvnx1di_scalar */
    case 3752:  /* pred_ssravnx1di_scalar */
    case 3751:  /* pred_ssrlvnx1di_scalar */
    case 3603:  /* pred_ssravnx1di */
    case 3602:  /* pred_ssrlvnx1di */
    case 3601:  /* pred_smulvnx1di */
    case 3600:  /* pred_asubvnx1di */
    case 3599:  /* pred_asubuvnx1di */
    case 3598:  /* pred_aaddvnx1di */
    case 3597:  /* pred_aadduvnx1di */
    case 3464:  /* *pred_ussubvnx1di_extended_scalar */
    case 3463:  /* *pred_sssubvnx1di_extended_scalar */
    case 3456:  /* *pred_ussubvnx1di_scalar */
    case 3455:  /* *pred_sssubvnx1di_scalar */
    case 3448:  /* *pred_usaddvnx1di_extended_scalar */
    case 3447:  /* *pred_ssaddvnx1di_extended_scalar */
    case 3440:  /* *pred_usaddvnx1di_scalar */
    case 3439:  /* *pred_ssaddvnx1di_scalar */
    case 3354:  /* pred_ussubvnx1di */
    case 3353:  /* pred_usaddvnx1di */
    case 3352:  /* pred_sssubvnx1di */
    case 3351:  /* pred_ssaddvnx1di */
    case 2837:  /* pred_zero_extendvnx1di_vf8 */
    case 2836:  /* pred_extendvnx1di_vf8 */
    case 2829:  /* pred_zero_extendvnx1di_vf4 */
    case 2828:  /* pred_extendvnx1di_vf4 */
    case 2811:  /* pred_zero_extendvnx1di_vf2 */
    case 2810:  /* pred_extendvnx1di_vf2 */
    case 2781:  /* pred_one_cmplvnx1di */
    case 2780:  /* pred_negvnx1di */
    case 2740:  /* *pred_msbcvnx1di_overflow_extended_scalar */
    case 2736:  /* *pred_msbcvnx1di_overflow_scalar */
    case 2732:  /* *pred_madcvnx1di_overflow_extended_scalar */
    case 2728:  /* *pred_madcvnx1di_overflow_scalar */
    case 2688:  /* pred_msbcvnx1di_overflow */
    case 2666:  /* pred_madcvnx1di_overflow */
    case 2644:  /* *pred_msbcvnx1di_extended_scalar */
    case 2640:  /* *pred_msbcvnx1di_scalar */
    case 2636:  /* *pred_madcvnx1di_extended_scalar */
    case 2632:  /* *pred_madcvnx1di_scalar */
    case 2592:  /* pred_msbcvnx1di */
    case 2570:  /* pred_madcvnx1di */
    case 2548:  /* *pred_sbcvnx1di_extended_scalar */
    case 2544:  /* *pred_sbcvnx1di_scalar */
    case 2540:  /* *pred_adcvnx1di_extended_scalar */
    case 2536:  /* *pred_adcvnx1di_scalar */
    case 2496:  /* pred_sbcvnx1di */
    case 2474:  /* pred_adcvnx1di */
    case 2446:  /* *pred_mulhsuvnx1di_extended_scalar */
    case 2445:  /* *pred_mulhuvnx1di_extended_scalar */
    case 2444:  /* *pred_mulhvnx1di_extended_scalar */
    case 2434:  /* *pred_mulhsuvnx1di_scalar */
    case 2433:  /* *pred_mulhuvnx1di_scalar */
    case 2432:  /* *pred_mulhvnx1di_scalar */
    case 2368:  /* pred_mulhsuvnx1di */
    case 2367:  /* pred_mulhuvnx1di */
    case 2366:  /* pred_mulhvnx1di */
    case 2308:  /* *pred_subvnx1di_extended_reverse_scalar */
    case 2304:  /* *pred_subvnx1di_reverse_scalar */
    case 2288:  /* *pred_umodvnx1di_extended_scalar */
    case 2287:  /* *pred_modvnx1di_extended_scalar */
    case 2286:  /* *pred_udivvnx1di_extended_scalar */
    case 2285:  /* *pred_divvnx1di_extended_scalar */
    case 2284:  /* *pred_subvnx1di_extended_scalar */
    case 2268:  /* *pred_umodvnx1di_scalar */
    case 2267:  /* *pred_modvnx1di_scalar */
    case 2266:  /* *pred_udivvnx1di_scalar */
    case 2265:  /* *pred_divvnx1di_scalar */
    case 2264:  /* *pred_subvnx1di_scalar */
    case 2236:  /* *pred_mulvnx1di_extended_scalar */
    case 2235:  /* *pred_uminvnx1di_extended_scalar */
    case 2234:  /* *pred_sminvnx1di_extended_scalar */
    case 2233:  /* *pred_umaxvnx1di_extended_scalar */
    case 2232:  /* *pred_smaxvnx1di_extended_scalar */
    case 2231:  /* *pred_xorvnx1di_extended_scalar */
    case 2230:  /* *pred_iorvnx1di_extended_scalar */
    case 2229:  /* *pred_andvnx1di_extended_scalar */
    case 2228:  /* *pred_addvnx1di_extended_scalar */
    case 2200:  /* *pred_mulvnx1di_scalar */
    case 2199:  /* *pred_uminvnx1di_scalar */
    case 2198:  /* *pred_sminvnx1di_scalar */
    case 2197:  /* *pred_umaxvnx1di_scalar */
    case 2196:  /* *pred_smaxvnx1di_scalar */
    case 2195:  /* *pred_xorvnx1di_scalar */
    case 2194:  /* *pred_iorvnx1di_scalar */
    case 2193:  /* *pred_andvnx1di_scalar */
    case 2192:  /* *pred_addvnx1di_scalar */
    case 1912:  /* pred_lshrvnx1di_scalar */
    case 1911:  /* pred_ashrvnx1di_scalar */
    case 1910:  /* pred_ashlvnx1di_scalar */
    case 1804:  /* pred_umodvnx1di */
    case 1803:  /* pred_modvnx1di */
    case 1802:  /* pred_udivvnx1di */
    case 1801:  /* pred_divvnx1di */
    case 1800:  /* pred_mulvnx1di */
    case 1799:  /* pred_uminvnx1di */
    case 1798:  /* pred_sminvnx1di */
    case 1797:  /* pred_umaxvnx1di */
    case 1796:  /* pred_smaxvnx1di */
    case 1795:  /* pred_lshrvnx1di */
    case 1794:  /* pred_ashrvnx1di */
    case 1793:  /* pred_ashlvnx1di */
    case 1792:  /* pred_xorvnx1di */
    case 1791:  /* pred_iorvnx1di */
    case 1790:  /* pred_andvnx1di */
    case 1789:  /* pred_subvnx1di */
    case 1788:  /* pred_addvnx1di */
    case 1303:  /* pred_indexed_ustorevnx1dfvnx1di */
    case 1302:  /* pred_indexed_ostorevnx1dfvnx1di */
    case 1301:  /* pred_indexed_ustorevnx1dfvnx1si */
    case 1300:  /* pred_indexed_ostorevnx1dfvnx1si */
    case 1299:  /* pred_indexed_ustorevnx1dfvnx1hi */
    case 1298:  /* pred_indexed_ostorevnx1dfvnx1hi */
    case 1297:  /* pred_indexed_ustorevnx1dfvnx1qi */
    case 1296:  /* pred_indexed_ostorevnx1dfvnx1qi */
    case 1287:  /* pred_indexed_ustorevnx1divnx1di */
    case 1286:  /* pred_indexed_ostorevnx1divnx1di */
    case 1285:  /* pred_indexed_ustorevnx1divnx1si */
    case 1284:  /* pred_indexed_ostorevnx1divnx1si */
    case 1283:  /* pred_indexed_ustorevnx1divnx1hi */
    case 1282:  /* pred_indexed_ostorevnx1divnx1hi */
    case 1281:  /* pred_indexed_ustorevnx1divnx1qi */
    case 1280:  /* pred_indexed_ostorevnx1divnx1qi */
    case 1185:  /* pred_indexed_uloadvnx1df_x8_greater_eew */
    case 1184:  /* pred_indexed_oloadvnx1df_x8_greater_eew */
    case 1177:  /* pred_indexed_uloadvnx1di_x8_greater_eew */
    case 1176:  /* pred_indexed_oloadvnx1di_x8_greater_eew */
    case 1169:  /* pred_indexed_uloadvnx1df_x4_greater_eew */
    case 1168:  /* pred_indexed_oloadvnx1df_x4_greater_eew */
    case 1151:  /* pred_indexed_uloadvnx1di_x4_greater_eew */
    case 1150:  /* pred_indexed_oloadvnx1di_x4_greater_eew */
    case 1133:  /* pred_indexed_uloadvnx1df_x2_greater_eew */
    case 1132:  /* pred_indexed_oloadvnx1df_x2_greater_eew */
    case 1115:  /* pred_indexed_uloadvnx1di_x2_greater_eew */
    case 1114:  /* pred_indexed_oloadvnx1di_x2_greater_eew */
    case 1085:  /* pred_indexed_uloadvnx1df_same_eew */
    case 1084:  /* pred_indexed_oloadvnx1df_same_eew */
    case 1067:  /* pred_indexed_uloadvnx1di_same_eew */
    case 1066:  /* pred_indexed_oloadvnx1di_same_eew */
    case 1026:  /* pred_strided_storevnx1df */
    case 1017:  /* pred_strided_storevnx1di */
    case 995:  /* pred_strided_loadvnx1df */
    case 986:  /* pred_strided_loadvnx1di */
    case 964:  /* *pred_broadcastvnx1di_extended_scalar */
    case 960:  /* *pred_broadcastvnx1df */
    case 951:  /* *pred_broadcastvnx1di */
    case 929:  /* *pred_mergevnx1di_extended_scalar */
    case 925:  /* *pred_mergevnx1di_scalar */
    case 903:  /* pred_mergevnx1df */
    case 894:  /* pred_mergevnx1di */
    case 858:  /* pred_storevnx1df */
    case 849:  /* pred_storevnx1di */
    case 827:  /* pred_movvnx1df */
    case 818:  /* pred_movvnx1di */
    case 747:  /* *movvnx1df_whole */
    case 738:  /* *movvnx1di_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 136 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx1DImode));

    case 6063:  /* pred_fault_loadvnx16sf */
    case 6054:  /* pred_fault_loadvnx16si */
    case 6030:  /* pred_compressvnx16sf */
    case 6021:  /* pred_compressvnx16si */
    case 5999:  /* pred_gatherei16vnx16sf */
    case 5990:  /* pred_gatherei16vnx16si */
    case 5969:  /* pred_gathervnx16sf_scalar */
    case 5960:  /* pred_gathervnx16si_scalar */
    case 5938:  /* pred_gathervnx16sf */
    case 5929:  /* pred_gathervnx16si */
    case 5903:  /* pred_slide1downvnx16sf */
    case 5902:  /* pred_slide1upvnx16sf */
    case 5877:  /* pred_slide1downvnx16si */
    case 5876:  /* pred_slide1upvnx16si */
    case 5833:  /* pred_slidedownvnx16sf */
    case 5832:  /* pred_slideupvnx16sf */
    case 5815:  /* pred_slidedownvnx16si */
    case 5814:  /* pred_slideupvnx16si */
    case 5775:  /* *pred_extract_firstvnx16sf */
    case 5762:  /* *pred_extract_firstvnx16si */
    case 5744:  /* pred_widen_reduc_plusuvnx16sfvnx1df */
    case 5743:  /* pred_widen_reduc_plusovnx16sfvnx1df */
    case 5718:  /* pred_reduc_plusuvnx16sfvnx2sf */
    case 5717:  /* pred_reduc_plusovnx16sfvnx2sf */
    case 5692:  /* pred_reduc_minvnx16sfvnx2sf */
    case 5691:  /* pred_reduc_maxvnx16sfvnx2sf */
    case 5660:  /* pred_widen_reduc_plusuvnx16sivnx2di */
    case 5659:  /* pred_widen_reduc_plusvnx16sivnx2di */
    case 5472:  /* pred_reduc_xorvnx16sivnx2si */
    case 5471:  /* pred_reduc_orvnx16sivnx2si */
    case 5470:  /* pred_reduc_andvnx16sivnx2si */
    case 5469:  /* pred_reduc_minvnx16sivnx2si */
    case 5468:  /* pred_reduc_minuvnx16sivnx2si */
    case 5467:  /* pred_reduc_maxvnx16sivnx2si */
    case 5466:  /* pred_reduc_maxuvnx16sivnx2si */
    case 5465:  /* pred_reduc_sumvnx16sivnx2si */
    case 5230:  /* pred_floatunsvnx16sf */
    case 5229:  /* pred_floatvnx16sf */
    case 5212:  /* pred_fixuns_truncvnx16sf */
    case 5211:  /* pred_fix_truncvnx16sf */
    case 5194:  /* pred_fcvt_xu_fvnx16sf */
    case 5193:  /* pred_fcvt_x_fvnx16sf */
    case 5180:  /* pred_mergevnx16sf_scalar */
    case 5171:  /* *pred_eqnevnx16sf_scalar_narrow */
    case 5162:  /* *pred_eqnevnx16sf_scalar */
    case 5153:  /* *pred_cmpvnx16sf_scalar_narrow */
    case 5144:  /* *pred_cmpvnx16sf_scalar */
    case 5135:  /* *pred_cmpvnx16sf_narrow */
    case 5126:  /* *pred_cmpvnx16sf */
    case 5045:  /* pred_classvnx16sf */
    case 5032:  /* pred_rec7vnx16sf */
    case 5031:  /* pred_rsqrt7vnx16sf */
    case 5010:  /* pred_sqrtvnx16sf */
    case 5009:  /* pred_absvnx16sf */
    case 5008:  /* pred_negvnx16sf */
    case 4987:  /* *pred_mul_neg_subvnx16sf_scalar */
    case 4986:  /* *pred_mul_neg_addvnx16sf_scalar */
    case 4969:  /* *pred_nmaccvnx16sf_scalar */
    case 4968:  /* *pred_nmsacvnx16sf_scalar */
    case 4951:  /* *pred_nmaddvnx16sf_scalar */
    case 4950:  /* *pred_nmsubvnx16sf_scalar */
    case 4933:  /* *pred_mul_neg_subvnx16sf */
    case 4932:  /* *pred_mul_neg_addvnx16sf */
    case 4915:  /* *pred_nmaccvnx16sf */
    case 4914:  /* *pred_nmsacvnx16sf */
    case 4897:  /* *pred_nmaddvnx16sf */
    case 4896:  /* *pred_nmsubvnx16sf */
    case 4879:  /* *pred_mul_subvnx16sf_scalar */
    case 4878:  /* *pred_mul_addvnx16sf_scalar */
    case 4861:  /* *pred_msacvnx16sf_scalar */
    case 4860:  /* *pred_maccvnx16sf_scalar */
    case 4843:  /* *pred_msubvnx16sf_scalar */
    case 4842:  /* *pred_maddvnx16sf_scalar */
    case 4825:  /* *pred_mul_subvnx16sf */
    case 4824:  /* *pred_mul_addvnx16sf */
    case 4807:  /* *pred_msacvnx16sf */
    case 4806:  /* *pred_maccvnx16sf */
    case 4789:  /* *pred_msubvnx16sf */
    case 4788:  /* *pred_maddvnx16sf */
    case 4767:  /* pred_xorsignvnx16sf_scalar */
    case 4766:  /* pred_ncopysignvnx16sf_scalar */
    case 4765:  /* pred_copysignvnx16sf_scalar */
    case 4740:  /* pred_xorsignvnx16sf */
    case 4739:  /* pred_ncopysignvnx16sf */
    case 4738:  /* pred_copysignvnx16sf */
    case 4717:  /* pred_divvnx16sf_reverse_scalar */
    case 4716:  /* pred_subvnx16sf_reverse_scalar */
    case 4699:  /* pred_divvnx16sf_scalar */
    case 4698:  /* pred_subvnx16sf_scalar */
    case 4673:  /* pred_sminvnx16sf_scalar */
    case 4672:  /* pred_smaxvnx16sf_scalar */
    case 4671:  /* pred_mulvnx16sf_scalar */
    case 4670:  /* pred_addvnx16sf_scalar */
    case 4629:  /* pred_divvnx16sf */
    case 4628:  /* pred_subvnx16sf */
    case 4627:  /* pred_sminvnx16sf */
    case 4626:  /* pred_smaxvnx16sf */
    case 4625:  /* pred_mulvnx16sf */
    case 4624:  /* pred_addvnx16sf */
    case 4595:  /* pred_seriesvnx16si */
    case 4573:  /* pred_iotavnx16si */
    case 4322:  /* *pred_minus_mulvnx16si_scalar */
    case 4300:  /* *pred_nmsacvnx16si_scalar */
    case 4278:  /* *pred_nmsubvnx16si_scalar */
    case 4256:  /* *pred_minus_mulvnx16si */
    case 4234:  /* *pred_nmsacvnx16si */
    case 4212:  /* *pred_nmsubvnx16si */
    case 4178:  /* *pred_mul_plusvnx16si_scalar */
    case 4156:  /* *pred_maccvnx16si_scalar */
    case 4134:  /* *pred_maddvnx16si_scalar */
    case 4112:  /* *pred_mul_plusvnx16si */
    case 4090:  /* *pred_maccvnx16si */
    case 4068:  /* *pred_maddvnx16si */
    case 4018:  /* *pred_eqnevnx16si_scalar_narrow */
    case 4000:  /* *pred_eqnevnx16si_scalar */
    case 3982:  /* *pred_cmpvnx16si_scalar_narrow */
    case 3964:  /* *pred_cmpvnx16si_scalar */
    case 3942:  /* *pred_ltgevnx16si_narrow */
    case 3920:  /* *pred_ltgevnx16si */
    case 3898:  /* *pred_cmpvnx16si_narrow */
    case 3876:  /* *pred_cmpvnx16si */
    case 3750:  /* pred_ssravnx16si_scalar */
    case 3749:  /* pred_ssrlvnx16si_scalar */
    case 3714:  /* pred_smulvnx16si_scalar */
    case 3713:  /* pred_asubvnx16si_scalar */
    case 3712:  /* pred_asubuvnx16si_scalar */
    case 3711:  /* pred_aaddvnx16si_scalar */
    case 3710:  /* pred_aadduvnx16si_scalar */
    case 3596:  /* pred_ssravnx16si */
    case 3595:  /* pred_ssrlvnx16si */
    case 3594:  /* pred_smulvnx16si */
    case 3593:  /* pred_asubvnx16si */
    case 3592:  /* pred_asubuvnx16si */
    case 3591:  /* pred_aaddvnx16si */
    case 3590:  /* pred_aadduvnx16si */
    case 3438:  /* pred_ussubvnx16si_scalar */
    case 3437:  /* pred_sssubvnx16si_scalar */
    case 3402:  /* pred_usaddvnx16si_scalar */
    case 3401:  /* pred_ssaddvnx16si_scalar */
    case 3350:  /* pred_ussubvnx16si */
    case 3349:  /* pred_usaddvnx16si */
    case 3348:  /* pred_sssubvnx16si */
    case 3347:  /* pred_ssaddvnx16si */
    case 2827:  /* pred_zero_extendvnx16si_vf4 */
    case 2826:  /* pred_extendvnx16si_vf4 */
    case 2809:  /* pred_zero_extendvnx16si_vf2 */
    case 2808:  /* pred_extendvnx16si_vf2 */
    case 2779:  /* pred_one_cmplvnx16si */
    case 2778:  /* pred_negvnx16si */
    case 2727:  /* pred_msbcvnx16si_overflow_scalar */
    case 2709:  /* pred_madcvnx16si_overflow_scalar */
    case 2687:  /* pred_msbcvnx16si_overflow */
    case 2665:  /* pred_madcvnx16si_overflow */
    case 2631:  /* pred_msbcvnx16si_scalar */
    case 2613:  /* pred_madcvnx16si_scalar */
    case 2591:  /* pred_msbcvnx16si */
    case 2569:  /* pred_madcvnx16si */
    case 2535:  /* pred_sbcvnx16si_scalar */
    case 2517:  /* pred_adcvnx16si_scalar */
    case 2495:  /* pred_sbcvnx16si */
    case 2473:  /* pred_adcvnx16si */
    case 2431:  /* pred_mulhsuvnx16si_scalar */
    case 2430:  /* pred_mulhuvnx16si_scalar */
    case 2429:  /* pred_mulhvnx16si_scalar */
    case 2365:  /* pred_mulhsuvnx16si */
    case 2364:  /* pred_mulhuvnx16si */
    case 2363:  /* pred_mulhvnx16si */
    case 2191:  /* pred_subvnx16si_reverse_scalar */
    case 2173:  /* pred_umodvnx16si_scalar */
    case 2172:  /* pred_modvnx16si_scalar */
    case 2171:  /* pred_udivvnx16si_scalar */
    case 2170:  /* pred_divvnx16si_scalar */
    case 2169:  /* pred_subvnx16si_scalar */
    case 2083:  /* pred_mulvnx16si_scalar */
    case 2082:  /* pred_uminvnx16si_scalar */
    case 2081:  /* pred_sminvnx16si_scalar */
    case 2080:  /* pred_umaxvnx16si_scalar */
    case 2079:  /* pred_smaxvnx16si_scalar */
    case 2078:  /* pred_xorvnx16si_scalar */
    case 2077:  /* pred_iorvnx16si_scalar */
    case 2076:  /* pred_andvnx16si_scalar */
    case 2075:  /* pred_addvnx16si_scalar */
    case 1909:  /* pred_lshrvnx16si_scalar */
    case 1908:  /* pred_ashrvnx16si_scalar */
    case 1907:  /* pred_ashlvnx16si_scalar */
    case 1787:  /* pred_umodvnx16si */
    case 1786:  /* pred_modvnx16si */
    case 1785:  /* pred_udivvnx16si */
    case 1784:  /* pred_divvnx16si */
    case 1783:  /* pred_mulvnx16si */
    case 1782:  /* pred_uminvnx16si */
    case 1781:  /* pred_sminvnx16si */
    case 1780:  /* pred_umaxvnx16si */
    case 1779:  /* pred_smaxvnx16si */
    case 1778:  /* pred_lshrvnx16si */
    case 1777:  /* pred_ashrvnx16si */
    case 1776:  /* pred_ashlvnx16si */
    case 1775:  /* pred_xorvnx16si */
    case 1774:  /* pred_iorvnx16si */
    case 1773:  /* pred_andvnx16si */
    case 1772:  /* pred_subvnx16si */
    case 1771:  /* pred_addvnx16si */
    case 1471:  /* pred_indexed_ustorevnx16sfvnx16si */
    case 1470:  /* pred_indexed_ostorevnx16sfvnx16si */
    case 1469:  /* pred_indexed_ustorevnx16sivnx16si */
    case 1468:  /* pred_indexed_ostorevnx16sivnx16si */
    case 1463:  /* pred_indexed_ustorevnx16sfvnx16hi */
    case 1462:  /* pred_indexed_ostorevnx16sfvnx16hi */
    case 1461:  /* pred_indexed_ustorevnx16sivnx16hi */
    case 1460:  /* pred_indexed_ostorevnx16sivnx16hi */
    case 1455:  /* pred_indexed_ustorevnx16sfvnx16qi */
    case 1454:  /* pred_indexed_ostorevnx16sfvnx16qi */
    case 1453:  /* pred_indexed_ustorevnx16sivnx16qi */
    case 1452:  /* pred_indexed_ostorevnx16sivnx16qi */
    case 1167:  /* pred_indexed_uloadvnx16sf_x4_greater_eew */
    case 1166:  /* pred_indexed_oloadvnx16sf_x4_greater_eew */
    case 1149:  /* pred_indexed_uloadvnx16si_x4_greater_eew */
    case 1148:  /* pred_indexed_oloadvnx16si_x4_greater_eew */
    case 1131:  /* pred_indexed_uloadvnx16sf_x2_greater_eew */
    case 1130:  /* pred_indexed_oloadvnx16sf_x2_greater_eew */
    case 1113:  /* pred_indexed_uloadvnx16si_x2_greater_eew */
    case 1112:  /* pred_indexed_oloadvnx16si_x2_greater_eew */
    case 1083:  /* pred_indexed_uloadvnx16sf_same_eew */
    case 1082:  /* pred_indexed_oloadvnx16sf_same_eew */
    case 1065:  /* pred_indexed_uloadvnx16si_same_eew */
    case 1064:  /* pred_indexed_oloadvnx16si_same_eew */
    case 1025:  /* pred_strided_storevnx16sf */
    case 1016:  /* pred_strided_storevnx16si */
    case 994:  /* pred_strided_loadvnx16sf */
    case 985:  /* pred_strided_loadvnx16si */
    case 959:  /* *pred_broadcastvnx16sf */
    case 950:  /* *pred_broadcastvnx16si */
    case 924:  /* pred_mergevnx16si_scalar */
    case 902:  /* pred_mergevnx16sf */
    case 893:  /* pred_mergevnx16si */
    case 857:  /* pred_storevnx16sf */
    case 848:  /* pred_storevnx16si */
    case 826:  /* pred_movvnx16sf */
    case 817:  /* pred_movvnx16si */
    case 746:  /* *movvnx16sf_whole */
    case 737:  /* *movvnx16si_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 134 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx16SImode));

    case 6062:  /* pred_fault_loadvnx8sf */
    case 6053:  /* pred_fault_loadvnx8si */
    case 6029:  /* pred_compressvnx8sf */
    case 6020:  /* pred_compressvnx8si */
    case 5998:  /* pred_gatherei16vnx8sf */
    case 5989:  /* pred_gatherei16vnx8si */
    case 5968:  /* pred_gathervnx8sf_scalar */
    case 5959:  /* pred_gathervnx8si_scalar */
    case 5937:  /* pred_gathervnx8sf */
    case 5928:  /* pred_gathervnx8si */
    case 5901:  /* pred_slide1downvnx8sf */
    case 5900:  /* pred_slide1upvnx8sf */
    case 5875:  /* pred_slide1downvnx8si */
    case 5874:  /* pred_slide1upvnx8si */
    case 5831:  /* pred_slidedownvnx8sf */
    case 5830:  /* pred_slideupvnx8sf */
    case 5813:  /* pred_slidedownvnx8si */
    case 5812:  /* pred_slideupvnx8si */
    case 5774:  /* *pred_extract_firstvnx8sf */
    case 5761:  /* *pred_extract_firstvnx8si */
    case 5742:  /* pred_widen_reduc_plusuvnx8sfvnx1df */
    case 5741:  /* pred_widen_reduc_plusovnx8sfvnx1df */
    case 5734:  /* pred_reduc_plusuvnx8sfvnx1sf */
    case 5733:  /* pred_reduc_plusovnx8sfvnx1sf */
    case 5716:  /* pred_reduc_plusuvnx8sfvnx2sf */
    case 5715:  /* pred_reduc_plusovnx8sfvnx2sf */
    case 5708:  /* pred_reduc_minvnx8sfvnx1sf */
    case 5707:  /* pred_reduc_maxvnx8sfvnx1sf */
    case 5690:  /* pred_reduc_minvnx8sfvnx2sf */
    case 5689:  /* pred_reduc_maxvnx8sfvnx2sf */
    case 5658:  /* pred_widen_reduc_plusuvnx8sivnx2di */
    case 5657:  /* pred_widen_reduc_plusvnx8sivnx2di */
    case 5624:  /* pred_reduc_xorvnx8sivnx1si */
    case 5623:  /* pred_reduc_orvnx8sivnx1si */
    case 5622:  /* pred_reduc_andvnx8sivnx1si */
    case 5621:  /* pred_reduc_minvnx8sivnx1si */
    case 5620:  /* pred_reduc_minuvnx8sivnx1si */
    case 5619:  /* pred_reduc_maxvnx8sivnx1si */
    case 5618:  /* pred_reduc_maxuvnx8sivnx1si */
    case 5617:  /* pred_reduc_sumvnx8sivnx1si */
    case 5464:  /* pred_reduc_xorvnx8sivnx2si */
    case 5463:  /* pred_reduc_orvnx8sivnx2si */
    case 5462:  /* pred_reduc_andvnx8sivnx2si */
    case 5461:  /* pred_reduc_minvnx8sivnx2si */
    case 5460:  /* pred_reduc_minuvnx8sivnx2si */
    case 5459:  /* pred_reduc_maxvnx8sivnx2si */
    case 5458:  /* pred_reduc_maxuvnx8sivnx2si */
    case 5457:  /* pred_reduc_sumvnx8sivnx2si */
    case 5328:  /* pred_rod_truncvnx8df */
    case 5324:  /* pred_truncvnx8df */
    case 5320:  /* pred_narrow_floatunsvnx8di */
    case 5319:  /* pred_narrow_floatvnx8di */
    case 5312:  /* pred_narrow_fixuns_truncvnx8df */
    case 5311:  /* pred_narrow_fix_truncvnx8df */
    case 5294:  /* pred_narrow_fcvt_xu_fvnx8df */
    case 5293:  /* pred_narrow_fcvt_x_fvnx8df */
    case 5276:  /* pred_extendvnx8df */
    case 5272:  /* pred_widen_floatunsvnx8df */
    case 5271:  /* pred_widen_floatvnx8df */
    case 5254:  /* pred_widen_fixuns_truncvnx8di */
    case 5253:  /* pred_widen_fix_truncvnx8di */
    case 5246:  /* pred_widen_fcvt_xu_fvnx8di */
    case 5245:  /* pred_widen_fcvt_x_fvnx8di */
    case 5228:  /* pred_floatunsvnx8sf */
    case 5227:  /* pred_floatvnx8sf */
    case 5210:  /* pred_fixuns_truncvnx8sf */
    case 5209:  /* pred_fix_truncvnx8sf */
    case 5192:  /* pred_fcvt_xu_fvnx8sf */
    case 5191:  /* pred_fcvt_x_fvnx8sf */
    case 5179:  /* pred_mergevnx8sf_scalar */
    case 5170:  /* *pred_eqnevnx8sf_scalar_narrow */
    case 5161:  /* *pred_eqnevnx8sf_scalar */
    case 5152:  /* *pred_cmpvnx8sf_scalar_narrow */
    case 5143:  /* *pred_cmpvnx8sf_scalar */
    case 5134:  /* *pred_cmpvnx8sf_narrow */
    case 5125:  /* *pred_cmpvnx8sf */
    case 5121:  /* pred_widen_mul_neg_subvnx8df_scalar */
    case 5120:  /* pred_widen_mul_neg_addvnx8df_scalar */
    case 5113:  /* pred_widen_mul_neg_subvnx8df */
    case 5112:  /* pred_widen_mul_neg_addvnx8df */
    case 5105:  /* pred_widen_mul_subvnx8df_scalar */
    case 5104:  /* pred_widen_mul_addvnx8df_scalar */
    case 5097:  /* pred_widen_mul_subvnx8df */
    case 5096:  /* pred_widen_mul_addvnx8df */
    case 5089:  /* pred_single_widen_subvnx8df_scalar */
    case 5088:  /* pred_single_widen_addvnx8df_scalar */
    case 5081:  /* pred_single_widen_subvnx8df */
    case 5080:  /* pred_single_widen_addvnx8df */
    case 5073:  /* pred_dual_widen_mulvnx8df_scalar */
    case 5072:  /* pred_dual_widen_subvnx8df_scalar */
    case 5071:  /* pred_dual_widen_addvnx8df_scalar */
    case 5061:  /* pred_dual_widen_mulvnx8df */
    case 5060:  /* pred_dual_widen_subvnx8df */
    case 5059:  /* pred_dual_widen_addvnx8df */
    case 5044:  /* pred_classvnx8sf */
    case 5030:  /* pred_rec7vnx8sf */
    case 5029:  /* pred_rsqrt7vnx8sf */
    case 5007:  /* pred_sqrtvnx8sf */
    case 5006:  /* pred_absvnx8sf */
    case 5005:  /* pred_negvnx8sf */
    case 4985:  /* *pred_mul_neg_subvnx8sf_scalar */
    case 4984:  /* *pred_mul_neg_addvnx8sf_scalar */
    case 4967:  /* *pred_nmaccvnx8sf_scalar */
    case 4966:  /* *pred_nmsacvnx8sf_scalar */
    case 4949:  /* *pred_nmaddvnx8sf_scalar */
    case 4948:  /* *pred_nmsubvnx8sf_scalar */
    case 4931:  /* *pred_mul_neg_subvnx8sf */
    case 4930:  /* *pred_mul_neg_addvnx8sf */
    case 4913:  /* *pred_nmaccvnx8sf */
    case 4912:  /* *pred_nmsacvnx8sf */
    case 4895:  /* *pred_nmaddvnx8sf */
    case 4894:  /* *pred_nmsubvnx8sf */
    case 4877:  /* *pred_mul_subvnx8sf_scalar */
    case 4876:  /* *pred_mul_addvnx8sf_scalar */
    case 4859:  /* *pred_msacvnx8sf_scalar */
    case 4858:  /* *pred_maccvnx8sf_scalar */
    case 4841:  /* *pred_msubvnx8sf_scalar */
    case 4840:  /* *pred_maddvnx8sf_scalar */
    case 4823:  /* *pred_mul_subvnx8sf */
    case 4822:  /* *pred_mul_addvnx8sf */
    case 4805:  /* *pred_msacvnx8sf */
    case 4804:  /* *pred_maccvnx8sf */
    case 4787:  /* *pred_msubvnx8sf */
    case 4786:  /* *pred_maddvnx8sf */
    case 4764:  /* pred_xorsignvnx8sf_scalar */
    case 4763:  /* pred_ncopysignvnx8sf_scalar */
    case 4762:  /* pred_copysignvnx8sf_scalar */
    case 4737:  /* pred_xorsignvnx8sf */
    case 4736:  /* pred_ncopysignvnx8sf */
    case 4735:  /* pred_copysignvnx8sf */
    case 4715:  /* pred_divvnx8sf_reverse_scalar */
    case 4714:  /* pred_subvnx8sf_reverse_scalar */
    case 4697:  /* pred_divvnx8sf_scalar */
    case 4696:  /* pred_subvnx8sf_scalar */
    case 4669:  /* pred_sminvnx8sf_scalar */
    case 4668:  /* pred_smaxvnx8sf_scalar */
    case 4667:  /* pred_mulvnx8sf_scalar */
    case 4666:  /* pred_addvnx8sf_scalar */
    case 4623:  /* pred_divvnx8sf */
    case 4622:  /* pred_subvnx8sf */
    case 4621:  /* pred_sminvnx8sf */
    case 4620:  /* pred_smaxvnx8sf */
    case 4619:  /* pred_mulvnx8sf */
    case 4618:  /* pred_addvnx8sf */
    case 4594:  /* pred_seriesvnx8si */
    case 4572:  /* pred_iotavnx8si */
    case 4443:  /* pred_widen_mul_plususvnx8di_scalar */
    case 4428:  /* pred_widen_mul_plussuvnx8di_scalar */
    case 4413:  /* pred_widen_mul_plussuvnx8di */
    case 4398:  /* pred_widen_mul_plusuvnx8di_scalar */
    case 4397:  /* pred_widen_mul_plussvnx8di_scalar */
    case 4368:  /* pred_widen_mul_plusuvnx8di */
    case 4367:  /* pred_widen_mul_plussvnx8di */
    case 4321:  /* *pred_minus_mulvnx8si_scalar */
    case 4299:  /* *pred_nmsacvnx8si_scalar */
    case 4277:  /* *pred_nmsubvnx8si_scalar */
    case 4255:  /* *pred_minus_mulvnx8si */
    case 4233:  /* *pred_nmsacvnx8si */
    case 4211:  /* *pred_nmsubvnx8si */
    case 4177:  /* *pred_mul_plusvnx8si_scalar */
    case 4155:  /* *pred_maccvnx8si_scalar */
    case 4133:  /* *pred_maddvnx8si_scalar */
    case 4111:  /* *pred_mul_plusvnx8si */
    case 4089:  /* *pred_maccvnx8si */
    case 4067:  /* *pred_maddvnx8si */
    case 4017:  /* *pred_eqnevnx8si_scalar_narrow */
    case 3999:  /* *pred_eqnevnx8si_scalar */
    case 3981:  /* *pred_cmpvnx8si_scalar_narrow */
    case 3963:  /* *pred_cmpvnx8si_scalar */
    case 3941:  /* *pred_ltgevnx8si_narrow */
    case 3919:  /* *pred_ltgevnx8si */
    case 3897:  /* *pred_cmpvnx8si_narrow */
    case 3875:  /* *pred_cmpvnx8si */
    case 3858:  /* pred_narrow_clipuvnx8di_scalar */
    case 3857:  /* pred_narrow_clipvnx8di_scalar */
    case 3828:  /* pred_narrow_clipuvnx8di */
    case 3827:  /* pred_narrow_clipvnx8di */
    case 3748:  /* pred_ssravnx8si_scalar */
    case 3747:  /* pred_ssrlvnx8si_scalar */
    case 3709:  /* pred_smulvnx8si_scalar */
    case 3708:  /* pred_asubvnx8si_scalar */
    case 3707:  /* pred_asubuvnx8si_scalar */
    case 3706:  /* pred_aaddvnx8si_scalar */
    case 3705:  /* pred_aadduvnx8si_scalar */
    case 3589:  /* pred_ssravnx8si */
    case 3588:  /* pred_ssrlvnx8si */
    case 3587:  /* pred_smulvnx8si */
    case 3586:  /* pred_asubvnx8si */
    case 3585:  /* pred_asubuvnx8si */
    case 3584:  /* pred_aaddvnx8si */
    case 3583:  /* pred_aadduvnx8si */
    case 3436:  /* pred_ussubvnx8si_scalar */
    case 3435:  /* pred_sssubvnx8si_scalar */
    case 3400:  /* pred_usaddvnx8si_scalar */
    case 3399:  /* pred_ssaddvnx8si_scalar */
    case 3346:  /* pred_ussubvnx8si */
    case 3345:  /* pred_usaddvnx8si */
    case 3344:  /* pred_sssubvnx8si */
    case 3343:  /* pred_ssaddvnx8si */
    case 3278:  /* pred_truncvnx8di */
    case 3263:  /* pred_narrow_lshrvnx8di_scalar */
    case 3262:  /* pred_narrow_ashrvnx8di_scalar */
    case 3233:  /* pred_narrow_lshrvnx8di */
    case 3232:  /* pred_narrow_ashrvnx8di */
    case 3203:  /* pred_zero_extendvnx8di */
    case 3202:  /* pred_extendvnx8di */
    case 3173:  /* pred_widen_mulsuvnx8di_scalar */
    case 3158:  /* pred_widen_mulsuvnx8di */
    case 3143:  /* pred_single_widen_subuvnx8di_scalar */
    case 3142:  /* pred_single_widen_adduvnx8di_scalar */
    case 3141:  /* pred_single_widen_subsvnx8di_scalar */
    case 3140:  /* pred_single_widen_addsvnx8di_scalar */
    case 3083:  /* pred_single_widen_subuvnx8di */
    case 3082:  /* pred_single_widen_adduvnx8di */
    case 3081:  /* pred_single_widen_subsvnx8di */
    case 3080:  /* pred_single_widen_addsvnx8di */
    case 3023:  /* pred_dual_widen_muluvnx8di_scalar */
    case 3022:  /* pred_dual_widen_subuvnx8di_scalar */
    case 3021:  /* pred_dual_widen_adduvnx8di_scalar */
    case 3020:  /* pred_dual_widen_mulsvnx8di_scalar */
    case 3019:  /* pred_dual_widen_subsvnx8di_scalar */
    case 3018:  /* pred_dual_widen_addsvnx8di_scalar */
    case 2933:  /* pred_dual_widen_muluvnx8di */
    case 2932:  /* pred_dual_widen_subuvnx8di */
    case 2931:  /* pred_dual_widen_adduvnx8di */
    case 2930:  /* pred_dual_widen_mulsvnx8di */
    case 2929:  /* pred_dual_widen_subsvnx8di */
    case 2928:  /* pred_dual_widen_addsvnx8di */
    case 2825:  /* pred_zero_extendvnx8si_vf4 */
    case 2824:  /* pred_extendvnx8si_vf4 */
    case 2807:  /* pred_zero_extendvnx8si_vf2 */
    case 2806:  /* pred_extendvnx8si_vf2 */
    case 2777:  /* pred_one_cmplvnx8si */
    case 2776:  /* pred_negvnx8si */
    case 2726:  /* pred_msbcvnx8si_overflow_scalar */
    case 2708:  /* pred_madcvnx8si_overflow_scalar */
    case 2686:  /* pred_msbcvnx8si_overflow */
    case 2664:  /* pred_madcvnx8si_overflow */
    case 2630:  /* pred_msbcvnx8si_scalar */
    case 2612:  /* pred_madcvnx8si_scalar */
    case 2590:  /* pred_msbcvnx8si */
    case 2568:  /* pred_madcvnx8si */
    case 2534:  /* pred_sbcvnx8si_scalar */
    case 2516:  /* pred_adcvnx8si_scalar */
    case 2494:  /* pred_sbcvnx8si */
    case 2472:  /* pred_adcvnx8si */
    case 2428:  /* pred_mulhsuvnx8si_scalar */
    case 2427:  /* pred_mulhuvnx8si_scalar */
    case 2426:  /* pred_mulhvnx8si_scalar */
    case 2362:  /* pred_mulhsuvnx8si */
    case 2361:  /* pred_mulhuvnx8si */
    case 2360:  /* pred_mulhvnx8si */
    case 2190:  /* pred_subvnx8si_reverse_scalar */
    case 2168:  /* pred_umodvnx8si_scalar */
    case 2167:  /* pred_modvnx8si_scalar */
    case 2166:  /* pred_udivvnx8si_scalar */
    case 2165:  /* pred_divvnx8si_scalar */
    case 2164:  /* pred_subvnx8si_scalar */
    case 2074:  /* pred_mulvnx8si_scalar */
    case 2073:  /* pred_uminvnx8si_scalar */
    case 2072:  /* pred_sminvnx8si_scalar */
    case 2071:  /* pred_umaxvnx8si_scalar */
    case 2070:  /* pred_smaxvnx8si_scalar */
    case 2069:  /* pred_xorvnx8si_scalar */
    case 2068:  /* pred_iorvnx8si_scalar */
    case 2067:  /* pred_andvnx8si_scalar */
    case 2066:  /* pred_addvnx8si_scalar */
    case 1906:  /* pred_lshrvnx8si_scalar */
    case 1905:  /* pred_ashrvnx8si_scalar */
    case 1904:  /* pred_ashlvnx8si_scalar */
    case 1770:  /* pred_umodvnx8si */
    case 1769:  /* pred_modvnx8si */
    case 1768:  /* pred_udivvnx8si */
    case 1767:  /* pred_divvnx8si */
    case 1766:  /* pred_mulvnx8si */
    case 1765:  /* pred_uminvnx8si */
    case 1764:  /* pred_sminvnx8si */
    case 1763:  /* pred_umaxvnx8si */
    case 1762:  /* pred_smaxvnx8si */
    case 1761:  /* pred_lshrvnx8si */
    case 1760:  /* pred_ashrvnx8si */
    case 1759:  /* pred_ashlvnx8si */
    case 1758:  /* pred_xorvnx8si */
    case 1757:  /* pred_iorvnx8si */
    case 1756:  /* pred_andvnx8si */
    case 1755:  /* pred_subvnx8si */
    case 1754:  /* pred_addvnx8si */
    case 1445:  /* pred_indexed_ustorevnx8sfvnx8di */
    case 1444:  /* pred_indexed_ostorevnx8sfvnx8di */
    case 1441:  /* pred_indexed_ustorevnx8sivnx8di */
    case 1440:  /* pred_indexed_ostorevnx8sivnx8di */
    case 1433:  /* pred_indexed_ustorevnx8sfvnx8si */
    case 1432:  /* pred_indexed_ostorevnx8sfvnx8si */
    case 1429:  /* pred_indexed_ustorevnx8sivnx8si */
    case 1428:  /* pred_indexed_ostorevnx8sivnx8si */
    case 1421:  /* pred_indexed_ustorevnx8sfvnx8hi */
    case 1420:  /* pred_indexed_ostorevnx8sfvnx8hi */
    case 1417:  /* pred_indexed_ustorevnx8sivnx8hi */
    case 1416:  /* pred_indexed_ostorevnx8sivnx8hi */
    case 1409:  /* pred_indexed_ustorevnx8sfvnx8qi */
    case 1408:  /* pred_indexed_ostorevnx8sfvnx8qi */
    case 1405:  /* pred_indexed_ustorevnx8sivnx8qi */
    case 1404:  /* pred_indexed_ostorevnx8sivnx8qi */
    case 1229:  /* pred_indexed_uloadvnx8sf_x2_smaller_eew */
    case 1228:  /* pred_indexed_oloadvnx8sf_x2_smaller_eew */
    case 1221:  /* pred_indexed_uloadvnx8si_x2_smaller_eew */
    case 1220:  /* pred_indexed_oloadvnx8si_x2_smaller_eew */
    case 1165:  /* pred_indexed_uloadvnx8sf_x4_greater_eew */
    case 1164:  /* pred_indexed_oloadvnx8sf_x4_greater_eew */
    case 1147:  /* pred_indexed_uloadvnx8si_x4_greater_eew */
    case 1146:  /* pred_indexed_oloadvnx8si_x4_greater_eew */
    case 1129:  /* pred_indexed_uloadvnx8sf_x2_greater_eew */
    case 1128:  /* pred_indexed_oloadvnx8sf_x2_greater_eew */
    case 1111:  /* pred_indexed_uloadvnx8si_x2_greater_eew */
    case 1110:  /* pred_indexed_oloadvnx8si_x2_greater_eew */
    case 1081:  /* pred_indexed_uloadvnx8sf_same_eew */
    case 1080:  /* pred_indexed_oloadvnx8sf_same_eew */
    case 1063:  /* pred_indexed_uloadvnx8si_same_eew */
    case 1062:  /* pred_indexed_oloadvnx8si_same_eew */
    case 1024:  /* pred_strided_storevnx8sf */
    case 1015:  /* pred_strided_storevnx8si */
    case 993:  /* pred_strided_loadvnx8sf */
    case 984:  /* pred_strided_loadvnx8si */
    case 958:  /* *pred_broadcastvnx8sf */
    case 949:  /* *pred_broadcastvnx8si */
    case 923:  /* pred_mergevnx8si_scalar */
    case 901:  /* pred_mergevnx8sf */
    case 892:  /* pred_mergevnx8si */
    case 856:  /* pred_storevnx8sf */
    case 847:  /* pred_storevnx8si */
    case 825:  /* pred_movvnx8sf */
    case 816:  /* pred_movvnx8si */
    case 745:  /* *movvnx8sf_whole */
    case 736:  /* *movvnx8si_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 132 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx8SImode));

    case 6061:  /* pred_fault_loadvnx4sf */
    case 6052:  /* pred_fault_loadvnx4si */
    case 6028:  /* pred_compressvnx4sf */
    case 6019:  /* pred_compressvnx4si */
    case 5997:  /* pred_gatherei16vnx4sf */
    case 5988:  /* pred_gatherei16vnx4si */
    case 5967:  /* pred_gathervnx4sf_scalar */
    case 5958:  /* pred_gathervnx4si_scalar */
    case 5936:  /* pred_gathervnx4sf */
    case 5927:  /* pred_gathervnx4si */
    case 5899:  /* pred_slide1downvnx4sf */
    case 5898:  /* pred_slide1upvnx4sf */
    case 5873:  /* pred_slide1downvnx4si */
    case 5872:  /* pred_slide1upvnx4si */
    case 5829:  /* pred_slidedownvnx4sf */
    case 5828:  /* pred_slideupvnx4sf */
    case 5811:  /* pred_slidedownvnx4si */
    case 5810:  /* pred_slideupvnx4si */
    case 5773:  /* *pred_extract_firstvnx4sf */
    case 5760:  /* *pred_extract_firstvnx4si */
    case 5740:  /* pred_widen_reduc_plusuvnx4sfvnx1df */
    case 5739:  /* pred_widen_reduc_plusovnx4sfvnx1df */
    case 5732:  /* pred_reduc_plusuvnx4sfvnx1sf */
    case 5731:  /* pred_reduc_plusovnx4sfvnx1sf */
    case 5714:  /* pred_reduc_plusuvnx4sfvnx2sf */
    case 5713:  /* pred_reduc_plusovnx4sfvnx2sf */
    case 5706:  /* pred_reduc_minvnx4sfvnx1sf */
    case 5705:  /* pred_reduc_maxvnx4sfvnx1sf */
    case 5688:  /* pred_reduc_minvnx4sfvnx2sf */
    case 5687:  /* pred_reduc_maxvnx4sfvnx2sf */
    case 5656:  /* pred_widen_reduc_plusuvnx4sivnx2di */
    case 5655:  /* pred_widen_reduc_plusvnx4sivnx2di */
    case 5616:  /* pred_reduc_xorvnx4sivnx1si */
    case 5615:  /* pred_reduc_orvnx4sivnx1si */
    case 5614:  /* pred_reduc_andvnx4sivnx1si */
    case 5613:  /* pred_reduc_minvnx4sivnx1si */
    case 5612:  /* pred_reduc_minuvnx4sivnx1si */
    case 5611:  /* pred_reduc_maxvnx4sivnx1si */
    case 5610:  /* pred_reduc_maxuvnx4sivnx1si */
    case 5609:  /* pred_reduc_sumvnx4sivnx1si */
    case 5456:  /* pred_reduc_xorvnx4sivnx2si */
    case 5455:  /* pred_reduc_orvnx4sivnx2si */
    case 5454:  /* pred_reduc_andvnx4sivnx2si */
    case 5453:  /* pred_reduc_minvnx4sivnx2si */
    case 5452:  /* pred_reduc_minuvnx4sivnx2si */
    case 5451:  /* pred_reduc_maxvnx4sivnx2si */
    case 5450:  /* pred_reduc_maxuvnx4sivnx2si */
    case 5449:  /* pred_reduc_sumvnx4sivnx2si */
    case 5327:  /* pred_rod_truncvnx4df */
    case 5323:  /* pred_truncvnx4df */
    case 5318:  /* pred_narrow_floatunsvnx4di */
    case 5317:  /* pred_narrow_floatvnx4di */
    case 5310:  /* pred_narrow_fixuns_truncvnx4df */
    case 5309:  /* pred_narrow_fix_truncvnx4df */
    case 5292:  /* pred_narrow_fcvt_xu_fvnx4df */
    case 5291:  /* pred_narrow_fcvt_x_fvnx4df */
    case 5275:  /* pred_extendvnx4df */
    case 5270:  /* pred_widen_floatunsvnx4df */
    case 5269:  /* pred_widen_floatvnx4df */
    case 5252:  /* pred_widen_fixuns_truncvnx4di */
    case 5251:  /* pred_widen_fix_truncvnx4di */
    case 5244:  /* pred_widen_fcvt_xu_fvnx4di */
    case 5243:  /* pred_widen_fcvt_x_fvnx4di */
    case 5226:  /* pred_floatunsvnx4sf */
    case 5225:  /* pred_floatvnx4sf */
    case 5208:  /* pred_fixuns_truncvnx4sf */
    case 5207:  /* pred_fix_truncvnx4sf */
    case 5190:  /* pred_fcvt_xu_fvnx4sf */
    case 5189:  /* pred_fcvt_x_fvnx4sf */
    case 5178:  /* pred_mergevnx4sf_scalar */
    case 5169:  /* *pred_eqnevnx4sf_scalar_narrow */
    case 5160:  /* *pred_eqnevnx4sf_scalar */
    case 5151:  /* *pred_cmpvnx4sf_scalar_narrow */
    case 5142:  /* *pred_cmpvnx4sf_scalar */
    case 5133:  /* *pred_cmpvnx4sf_narrow */
    case 5124:  /* *pred_cmpvnx4sf */
    case 5119:  /* pred_widen_mul_neg_subvnx4df_scalar */
    case 5118:  /* pred_widen_mul_neg_addvnx4df_scalar */
    case 5111:  /* pred_widen_mul_neg_subvnx4df */
    case 5110:  /* pred_widen_mul_neg_addvnx4df */
    case 5103:  /* pred_widen_mul_subvnx4df_scalar */
    case 5102:  /* pred_widen_mul_addvnx4df_scalar */
    case 5095:  /* pred_widen_mul_subvnx4df */
    case 5094:  /* pred_widen_mul_addvnx4df */
    case 5087:  /* pred_single_widen_subvnx4df_scalar */
    case 5086:  /* pred_single_widen_addvnx4df_scalar */
    case 5079:  /* pred_single_widen_subvnx4df */
    case 5078:  /* pred_single_widen_addvnx4df */
    case 5070:  /* pred_dual_widen_mulvnx4df_scalar */
    case 5069:  /* pred_dual_widen_subvnx4df_scalar */
    case 5068:  /* pred_dual_widen_addvnx4df_scalar */
    case 5058:  /* pred_dual_widen_mulvnx4df */
    case 5057:  /* pred_dual_widen_subvnx4df */
    case 5056:  /* pred_dual_widen_addvnx4df */
    case 5043:  /* pred_classvnx4sf */
    case 5028:  /* pred_rec7vnx4sf */
    case 5027:  /* pred_rsqrt7vnx4sf */
    case 5004:  /* pred_sqrtvnx4sf */
    case 5003:  /* pred_absvnx4sf */
    case 5002:  /* pred_negvnx4sf */
    case 4983:  /* *pred_mul_neg_subvnx4sf_scalar */
    case 4982:  /* *pred_mul_neg_addvnx4sf_scalar */
    case 4965:  /* *pred_nmaccvnx4sf_scalar */
    case 4964:  /* *pred_nmsacvnx4sf_scalar */
    case 4947:  /* *pred_nmaddvnx4sf_scalar */
    case 4946:  /* *pred_nmsubvnx4sf_scalar */
    case 4929:  /* *pred_mul_neg_subvnx4sf */
    case 4928:  /* *pred_mul_neg_addvnx4sf */
    case 4911:  /* *pred_nmaccvnx4sf */
    case 4910:  /* *pred_nmsacvnx4sf */
    case 4893:  /* *pred_nmaddvnx4sf */
    case 4892:  /* *pred_nmsubvnx4sf */
    case 4875:  /* *pred_mul_subvnx4sf_scalar */
    case 4874:  /* *pred_mul_addvnx4sf_scalar */
    case 4857:  /* *pred_msacvnx4sf_scalar */
    case 4856:  /* *pred_maccvnx4sf_scalar */
    case 4839:  /* *pred_msubvnx4sf_scalar */
    case 4838:  /* *pred_maddvnx4sf_scalar */
    case 4821:  /* *pred_mul_subvnx4sf */
    case 4820:  /* *pred_mul_addvnx4sf */
    case 4803:  /* *pred_msacvnx4sf */
    case 4802:  /* *pred_maccvnx4sf */
    case 4785:  /* *pred_msubvnx4sf */
    case 4784:  /* *pred_maddvnx4sf */
    case 4761:  /* pred_xorsignvnx4sf_scalar */
    case 4760:  /* pred_ncopysignvnx4sf_scalar */
    case 4759:  /* pred_copysignvnx4sf_scalar */
    case 4734:  /* pred_xorsignvnx4sf */
    case 4733:  /* pred_ncopysignvnx4sf */
    case 4732:  /* pred_copysignvnx4sf */
    case 4713:  /* pred_divvnx4sf_reverse_scalar */
    case 4712:  /* pred_subvnx4sf_reverse_scalar */
    case 4695:  /* pred_divvnx4sf_scalar */
    case 4694:  /* pred_subvnx4sf_scalar */
    case 4665:  /* pred_sminvnx4sf_scalar */
    case 4664:  /* pred_smaxvnx4sf_scalar */
    case 4663:  /* pred_mulvnx4sf_scalar */
    case 4662:  /* pred_addvnx4sf_scalar */
    case 4617:  /* pred_divvnx4sf */
    case 4616:  /* pred_subvnx4sf */
    case 4615:  /* pred_sminvnx4sf */
    case 4614:  /* pred_smaxvnx4sf */
    case 4613:  /* pred_mulvnx4sf */
    case 4612:  /* pred_addvnx4sf */
    case 4593:  /* pred_seriesvnx4si */
    case 4571:  /* pred_iotavnx4si */
    case 4442:  /* pred_widen_mul_plususvnx4di_scalar */
    case 4427:  /* pred_widen_mul_plussuvnx4di_scalar */
    case 4412:  /* pred_widen_mul_plussuvnx4di */
    case 4396:  /* pred_widen_mul_plusuvnx4di_scalar */
    case 4395:  /* pred_widen_mul_plussvnx4di_scalar */
    case 4366:  /* pred_widen_mul_plusuvnx4di */
    case 4365:  /* pred_widen_mul_plussvnx4di */
    case 4320:  /* *pred_minus_mulvnx4si_scalar */
    case 4298:  /* *pred_nmsacvnx4si_scalar */
    case 4276:  /* *pred_nmsubvnx4si_scalar */
    case 4254:  /* *pred_minus_mulvnx4si */
    case 4232:  /* *pred_nmsacvnx4si */
    case 4210:  /* *pred_nmsubvnx4si */
    case 4176:  /* *pred_mul_plusvnx4si_scalar */
    case 4154:  /* *pred_maccvnx4si_scalar */
    case 4132:  /* *pred_maddvnx4si_scalar */
    case 4110:  /* *pred_mul_plusvnx4si */
    case 4088:  /* *pred_maccvnx4si */
    case 4066:  /* *pred_maddvnx4si */
    case 4016:  /* *pred_eqnevnx4si_scalar_narrow */
    case 3998:  /* *pred_eqnevnx4si_scalar */
    case 3980:  /* *pred_cmpvnx4si_scalar_narrow */
    case 3962:  /* *pred_cmpvnx4si_scalar */
    case 3940:  /* *pred_ltgevnx4si_narrow */
    case 3918:  /* *pred_ltgevnx4si */
    case 3896:  /* *pred_cmpvnx4si_narrow */
    case 3874:  /* *pred_cmpvnx4si */
    case 3856:  /* pred_narrow_clipuvnx4di_scalar */
    case 3855:  /* pred_narrow_clipvnx4di_scalar */
    case 3826:  /* pred_narrow_clipuvnx4di */
    case 3825:  /* pred_narrow_clipvnx4di */
    case 3746:  /* pred_ssravnx4si_scalar */
    case 3745:  /* pred_ssrlvnx4si_scalar */
    case 3704:  /* pred_smulvnx4si_scalar */
    case 3703:  /* pred_asubvnx4si_scalar */
    case 3702:  /* pred_asubuvnx4si_scalar */
    case 3701:  /* pred_aaddvnx4si_scalar */
    case 3700:  /* pred_aadduvnx4si_scalar */
    case 3582:  /* pred_ssravnx4si */
    case 3581:  /* pred_ssrlvnx4si */
    case 3580:  /* pred_smulvnx4si */
    case 3579:  /* pred_asubvnx4si */
    case 3578:  /* pred_asubuvnx4si */
    case 3577:  /* pred_aaddvnx4si */
    case 3576:  /* pred_aadduvnx4si */
    case 3434:  /* pred_ussubvnx4si_scalar */
    case 3433:  /* pred_sssubvnx4si_scalar */
    case 3398:  /* pred_usaddvnx4si_scalar */
    case 3397:  /* pred_ssaddvnx4si_scalar */
    case 3342:  /* pred_ussubvnx4si */
    case 3341:  /* pred_usaddvnx4si */
    case 3340:  /* pred_sssubvnx4si */
    case 3339:  /* pred_ssaddvnx4si */
    case 3277:  /* pred_truncvnx4di */
    case 3261:  /* pred_narrow_lshrvnx4di_scalar */
    case 3260:  /* pred_narrow_ashrvnx4di_scalar */
    case 3231:  /* pred_narrow_lshrvnx4di */
    case 3230:  /* pred_narrow_ashrvnx4di */
    case 3201:  /* pred_zero_extendvnx4di */
    case 3200:  /* pred_extendvnx4di */
    case 3172:  /* pred_widen_mulsuvnx4di_scalar */
    case 3157:  /* pred_widen_mulsuvnx4di */
    case 3139:  /* pred_single_widen_subuvnx4di_scalar */
    case 3138:  /* pred_single_widen_adduvnx4di_scalar */
    case 3137:  /* pred_single_widen_subsvnx4di_scalar */
    case 3136:  /* pred_single_widen_addsvnx4di_scalar */
    case 3079:  /* pred_single_widen_subuvnx4di */
    case 3078:  /* pred_single_widen_adduvnx4di */
    case 3077:  /* pred_single_widen_subsvnx4di */
    case 3076:  /* pred_single_widen_addsvnx4di */
    case 3017:  /* pred_dual_widen_muluvnx4di_scalar */
    case 3016:  /* pred_dual_widen_subuvnx4di_scalar */
    case 3015:  /* pred_dual_widen_adduvnx4di_scalar */
    case 3014:  /* pred_dual_widen_mulsvnx4di_scalar */
    case 3013:  /* pred_dual_widen_subsvnx4di_scalar */
    case 3012:  /* pred_dual_widen_addsvnx4di_scalar */
    case 2927:  /* pred_dual_widen_muluvnx4di */
    case 2926:  /* pred_dual_widen_subuvnx4di */
    case 2925:  /* pred_dual_widen_adduvnx4di */
    case 2924:  /* pred_dual_widen_mulsvnx4di */
    case 2923:  /* pred_dual_widen_subsvnx4di */
    case 2922:  /* pred_dual_widen_addsvnx4di */
    case 2823:  /* pred_zero_extendvnx4si_vf4 */
    case 2822:  /* pred_extendvnx4si_vf4 */
    case 2805:  /* pred_zero_extendvnx4si_vf2 */
    case 2804:  /* pred_extendvnx4si_vf2 */
    case 2775:  /* pred_one_cmplvnx4si */
    case 2774:  /* pred_negvnx4si */
    case 2725:  /* pred_msbcvnx4si_overflow_scalar */
    case 2707:  /* pred_madcvnx4si_overflow_scalar */
    case 2685:  /* pred_msbcvnx4si_overflow */
    case 2663:  /* pred_madcvnx4si_overflow */
    case 2629:  /* pred_msbcvnx4si_scalar */
    case 2611:  /* pred_madcvnx4si_scalar */
    case 2589:  /* pred_msbcvnx4si */
    case 2567:  /* pred_madcvnx4si */
    case 2533:  /* pred_sbcvnx4si_scalar */
    case 2515:  /* pred_adcvnx4si_scalar */
    case 2493:  /* pred_sbcvnx4si */
    case 2471:  /* pred_adcvnx4si */
    case 2425:  /* pred_mulhsuvnx4si_scalar */
    case 2424:  /* pred_mulhuvnx4si_scalar */
    case 2423:  /* pred_mulhvnx4si_scalar */
    case 2359:  /* pred_mulhsuvnx4si */
    case 2358:  /* pred_mulhuvnx4si */
    case 2357:  /* pred_mulhvnx4si */
    case 2189:  /* pred_subvnx4si_reverse_scalar */
    case 2163:  /* pred_umodvnx4si_scalar */
    case 2162:  /* pred_modvnx4si_scalar */
    case 2161:  /* pred_udivvnx4si_scalar */
    case 2160:  /* pred_divvnx4si_scalar */
    case 2159:  /* pred_subvnx4si_scalar */
    case 2065:  /* pred_mulvnx4si_scalar */
    case 2064:  /* pred_uminvnx4si_scalar */
    case 2063:  /* pred_sminvnx4si_scalar */
    case 2062:  /* pred_umaxvnx4si_scalar */
    case 2061:  /* pred_smaxvnx4si_scalar */
    case 2060:  /* pred_xorvnx4si_scalar */
    case 2059:  /* pred_iorvnx4si_scalar */
    case 2058:  /* pred_andvnx4si_scalar */
    case 2057:  /* pred_addvnx4si_scalar */
    case 1903:  /* pred_lshrvnx4si_scalar */
    case 1902:  /* pred_ashrvnx4si_scalar */
    case 1901:  /* pred_ashlvnx4si_scalar */
    case 1753:  /* pred_umodvnx4si */
    case 1752:  /* pred_modvnx4si */
    case 1751:  /* pred_udivvnx4si */
    case 1750:  /* pred_divvnx4si */
    case 1749:  /* pred_mulvnx4si */
    case 1748:  /* pred_uminvnx4si */
    case 1747:  /* pred_sminvnx4si */
    case 1746:  /* pred_umaxvnx4si */
    case 1745:  /* pred_smaxvnx4si */
    case 1744:  /* pred_lshrvnx4si */
    case 1743:  /* pred_ashrvnx4si */
    case 1742:  /* pred_ashlvnx4si */
    case 1741:  /* pred_xorvnx4si */
    case 1740:  /* pred_iorvnx4si */
    case 1739:  /* pred_andvnx4si */
    case 1738:  /* pred_subvnx4si */
    case 1737:  /* pred_addvnx4si */
    case 1397:  /* pred_indexed_ustorevnx4sfvnx4di */
    case 1396:  /* pred_indexed_ostorevnx4sfvnx4di */
    case 1393:  /* pred_indexed_ustorevnx4sivnx4di */
    case 1392:  /* pred_indexed_ostorevnx4sivnx4di */
    case 1385:  /* pred_indexed_ustorevnx4sfvnx4si */
    case 1384:  /* pred_indexed_ostorevnx4sfvnx4si */
    case 1381:  /* pred_indexed_ustorevnx4sivnx4si */
    case 1380:  /* pred_indexed_ostorevnx4sivnx4si */
    case 1373:  /* pred_indexed_ustorevnx4sfvnx4hi */
    case 1372:  /* pred_indexed_ostorevnx4sfvnx4hi */
    case 1369:  /* pred_indexed_ustorevnx4sivnx4hi */
    case 1368:  /* pred_indexed_ostorevnx4sivnx4hi */
    case 1361:  /* pred_indexed_ustorevnx4sfvnx4qi */
    case 1360:  /* pred_indexed_ostorevnx4sfvnx4qi */
    case 1357:  /* pred_indexed_ustorevnx4sivnx4qi */
    case 1356:  /* pred_indexed_ostorevnx4sivnx4qi */
    case 1227:  /* pred_indexed_uloadvnx4sf_x2_smaller_eew */
    case 1226:  /* pred_indexed_oloadvnx4sf_x2_smaller_eew */
    case 1219:  /* pred_indexed_uloadvnx4si_x2_smaller_eew */
    case 1218:  /* pred_indexed_oloadvnx4si_x2_smaller_eew */
    case 1163:  /* pred_indexed_uloadvnx4sf_x4_greater_eew */
    case 1162:  /* pred_indexed_oloadvnx4sf_x4_greater_eew */
    case 1145:  /* pred_indexed_uloadvnx4si_x4_greater_eew */
    case 1144:  /* pred_indexed_oloadvnx4si_x4_greater_eew */
    case 1127:  /* pred_indexed_uloadvnx4sf_x2_greater_eew */
    case 1126:  /* pred_indexed_oloadvnx4sf_x2_greater_eew */
    case 1109:  /* pred_indexed_uloadvnx4si_x2_greater_eew */
    case 1108:  /* pred_indexed_oloadvnx4si_x2_greater_eew */
    case 1079:  /* pred_indexed_uloadvnx4sf_same_eew */
    case 1078:  /* pred_indexed_oloadvnx4sf_same_eew */
    case 1061:  /* pred_indexed_uloadvnx4si_same_eew */
    case 1060:  /* pred_indexed_oloadvnx4si_same_eew */
    case 1023:  /* pred_strided_storevnx4sf */
    case 1014:  /* pred_strided_storevnx4si */
    case 992:  /* pred_strided_loadvnx4sf */
    case 983:  /* pred_strided_loadvnx4si */
    case 957:  /* *pred_broadcastvnx4sf */
    case 948:  /* *pred_broadcastvnx4si */
    case 922:  /* pred_mergevnx4si_scalar */
    case 900:  /* pred_mergevnx4sf */
    case 891:  /* pred_mergevnx4si */
    case 855:  /* pred_storevnx4sf */
    case 846:  /* pred_storevnx4si */
    case 824:  /* pred_movvnx4sf */
    case 815:  /* pred_movvnx4si */
    case 744:  /* *movvnx4sf_whole */
    case 735:  /* *movvnx4si_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 130 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx4SImode));

    case 6060:  /* pred_fault_loadvnx2sf */
    case 6051:  /* pred_fault_loadvnx2si */
    case 6027:  /* pred_compressvnx2sf */
    case 6018:  /* pred_compressvnx2si */
    case 5996:  /* pred_gatherei16vnx2sf */
    case 5987:  /* pred_gatherei16vnx2si */
    case 5966:  /* pred_gathervnx2sf_scalar */
    case 5957:  /* pred_gathervnx2si_scalar */
    case 5935:  /* pred_gathervnx2sf */
    case 5926:  /* pred_gathervnx2si */
    case 5897:  /* pred_slide1downvnx2sf */
    case 5896:  /* pred_slide1upvnx2sf */
    case 5871:  /* pred_slide1downvnx2si */
    case 5870:  /* pred_slide1upvnx2si */
    case 5827:  /* pred_slidedownvnx2sf */
    case 5826:  /* pred_slideupvnx2sf */
    case 5809:  /* pred_slidedownvnx2si */
    case 5808:  /* pred_slideupvnx2si */
    case 5772:  /* *pred_extract_firstvnx2sf */
    case 5759:  /* *pred_extract_firstvnx2si */
    case 5738:  /* pred_widen_reduc_plusuvnx2sfvnx1df */
    case 5737:  /* pred_widen_reduc_plusovnx2sfvnx1df */
    case 5730:  /* pred_reduc_plusuvnx2sfvnx1sf */
    case 5729:  /* pred_reduc_plusovnx2sfvnx1sf */
    case 5712:  /* pred_reduc_plusuvnx2sfvnx2sf */
    case 5711:  /* pred_reduc_plusovnx2sfvnx2sf */
    case 5704:  /* pred_reduc_minvnx2sfvnx1sf */
    case 5703:  /* pred_reduc_maxvnx2sfvnx1sf */
    case 5686:  /* pred_reduc_minvnx2sfvnx2sf */
    case 5685:  /* pred_reduc_maxvnx2sfvnx2sf */
    case 5654:  /* pred_widen_reduc_plusuvnx2sivnx2di */
    case 5653:  /* pred_widen_reduc_plusvnx2sivnx2di */
    case 5608:  /* pred_reduc_xorvnx2sivnx1si */
    case 5607:  /* pred_reduc_orvnx2sivnx1si */
    case 5606:  /* pred_reduc_andvnx2sivnx1si */
    case 5605:  /* pred_reduc_minvnx2sivnx1si */
    case 5604:  /* pred_reduc_minuvnx2sivnx1si */
    case 5603:  /* pred_reduc_maxvnx2sivnx1si */
    case 5602:  /* pred_reduc_maxuvnx2sivnx1si */
    case 5601:  /* pred_reduc_sumvnx2sivnx1si */
    case 5448:  /* pred_reduc_xorvnx2sivnx2si */
    case 5447:  /* pred_reduc_orvnx2sivnx2si */
    case 5446:  /* pred_reduc_andvnx2sivnx2si */
    case 5445:  /* pred_reduc_minvnx2sivnx2si */
    case 5444:  /* pred_reduc_minuvnx2sivnx2si */
    case 5443:  /* pred_reduc_maxvnx2sivnx2si */
    case 5442:  /* pred_reduc_maxuvnx2sivnx2si */
    case 5441:  /* pred_reduc_sumvnx2sivnx2si */
    case 5326:  /* pred_rod_truncvnx2df */
    case 5322:  /* pred_truncvnx2df */
    case 5316:  /* pred_narrow_floatunsvnx2di */
    case 5315:  /* pred_narrow_floatvnx2di */
    case 5308:  /* pred_narrow_fixuns_truncvnx2df */
    case 5307:  /* pred_narrow_fix_truncvnx2df */
    case 5290:  /* pred_narrow_fcvt_xu_fvnx2df */
    case 5289:  /* pred_narrow_fcvt_x_fvnx2df */
    case 5274:  /* pred_extendvnx2df */
    case 5268:  /* pred_widen_floatunsvnx2df */
    case 5267:  /* pred_widen_floatvnx2df */
    case 5250:  /* pred_widen_fixuns_truncvnx2di */
    case 5249:  /* pred_widen_fix_truncvnx2di */
    case 5242:  /* pred_widen_fcvt_xu_fvnx2di */
    case 5241:  /* pred_widen_fcvt_x_fvnx2di */
    case 5224:  /* pred_floatunsvnx2sf */
    case 5223:  /* pred_floatvnx2sf */
    case 5206:  /* pred_fixuns_truncvnx2sf */
    case 5205:  /* pred_fix_truncvnx2sf */
    case 5188:  /* pred_fcvt_xu_fvnx2sf */
    case 5187:  /* pred_fcvt_x_fvnx2sf */
    case 5177:  /* pred_mergevnx2sf_scalar */
    case 5168:  /* *pred_eqnevnx2sf_scalar_narrow */
    case 5159:  /* *pred_eqnevnx2sf_scalar */
    case 5150:  /* *pred_cmpvnx2sf_scalar_narrow */
    case 5141:  /* *pred_cmpvnx2sf_scalar */
    case 5132:  /* *pred_cmpvnx2sf_narrow */
    case 5123:  /* *pred_cmpvnx2sf */
    case 5117:  /* pred_widen_mul_neg_subvnx2df_scalar */
    case 5116:  /* pred_widen_mul_neg_addvnx2df_scalar */
    case 5109:  /* pred_widen_mul_neg_subvnx2df */
    case 5108:  /* pred_widen_mul_neg_addvnx2df */
    case 5101:  /* pred_widen_mul_subvnx2df_scalar */
    case 5100:  /* pred_widen_mul_addvnx2df_scalar */
    case 5093:  /* pred_widen_mul_subvnx2df */
    case 5092:  /* pred_widen_mul_addvnx2df */
    case 5085:  /* pred_single_widen_subvnx2df_scalar */
    case 5084:  /* pred_single_widen_addvnx2df_scalar */
    case 5077:  /* pred_single_widen_subvnx2df */
    case 5076:  /* pred_single_widen_addvnx2df */
    case 5067:  /* pred_dual_widen_mulvnx2df_scalar */
    case 5066:  /* pred_dual_widen_subvnx2df_scalar */
    case 5065:  /* pred_dual_widen_addvnx2df_scalar */
    case 5055:  /* pred_dual_widen_mulvnx2df */
    case 5054:  /* pred_dual_widen_subvnx2df */
    case 5053:  /* pred_dual_widen_addvnx2df */
    case 5042:  /* pred_classvnx2sf */
    case 5026:  /* pred_rec7vnx2sf */
    case 5025:  /* pred_rsqrt7vnx2sf */
    case 5001:  /* pred_sqrtvnx2sf */
    case 5000:  /* pred_absvnx2sf */
    case 4999:  /* pred_negvnx2sf */
    case 4981:  /* *pred_mul_neg_subvnx2sf_scalar */
    case 4980:  /* *pred_mul_neg_addvnx2sf_scalar */
    case 4963:  /* *pred_nmaccvnx2sf_scalar */
    case 4962:  /* *pred_nmsacvnx2sf_scalar */
    case 4945:  /* *pred_nmaddvnx2sf_scalar */
    case 4944:  /* *pred_nmsubvnx2sf_scalar */
    case 4927:  /* *pred_mul_neg_subvnx2sf */
    case 4926:  /* *pred_mul_neg_addvnx2sf */
    case 4909:  /* *pred_nmaccvnx2sf */
    case 4908:  /* *pred_nmsacvnx2sf */
    case 4891:  /* *pred_nmaddvnx2sf */
    case 4890:  /* *pred_nmsubvnx2sf */
    case 4873:  /* *pred_mul_subvnx2sf_scalar */
    case 4872:  /* *pred_mul_addvnx2sf_scalar */
    case 4855:  /* *pred_msacvnx2sf_scalar */
    case 4854:  /* *pred_maccvnx2sf_scalar */
    case 4837:  /* *pred_msubvnx2sf_scalar */
    case 4836:  /* *pred_maddvnx2sf_scalar */
    case 4819:  /* *pred_mul_subvnx2sf */
    case 4818:  /* *pred_mul_addvnx2sf */
    case 4801:  /* *pred_msacvnx2sf */
    case 4800:  /* *pred_maccvnx2sf */
    case 4783:  /* *pred_msubvnx2sf */
    case 4782:  /* *pred_maddvnx2sf */
    case 4758:  /* pred_xorsignvnx2sf_scalar */
    case 4757:  /* pred_ncopysignvnx2sf_scalar */
    case 4756:  /* pred_copysignvnx2sf_scalar */
    case 4731:  /* pred_xorsignvnx2sf */
    case 4730:  /* pred_ncopysignvnx2sf */
    case 4729:  /* pred_copysignvnx2sf */
    case 4711:  /* pred_divvnx2sf_reverse_scalar */
    case 4710:  /* pred_subvnx2sf_reverse_scalar */
    case 4693:  /* pred_divvnx2sf_scalar */
    case 4692:  /* pred_subvnx2sf_scalar */
    case 4661:  /* pred_sminvnx2sf_scalar */
    case 4660:  /* pred_smaxvnx2sf_scalar */
    case 4659:  /* pred_mulvnx2sf_scalar */
    case 4658:  /* pred_addvnx2sf_scalar */
    case 4611:  /* pred_divvnx2sf */
    case 4610:  /* pred_subvnx2sf */
    case 4609:  /* pred_sminvnx2sf */
    case 4608:  /* pred_smaxvnx2sf */
    case 4607:  /* pred_mulvnx2sf */
    case 4606:  /* pred_addvnx2sf */
    case 4592:  /* pred_seriesvnx2si */
    case 4570:  /* pred_iotavnx2si */
    case 4441:  /* pred_widen_mul_plususvnx2di_scalar */
    case 4426:  /* pred_widen_mul_plussuvnx2di_scalar */
    case 4411:  /* pred_widen_mul_plussuvnx2di */
    case 4394:  /* pred_widen_mul_plusuvnx2di_scalar */
    case 4393:  /* pred_widen_mul_plussvnx2di_scalar */
    case 4364:  /* pred_widen_mul_plusuvnx2di */
    case 4363:  /* pred_widen_mul_plussvnx2di */
    case 4319:  /* *pred_minus_mulvnx2si_scalar */
    case 4297:  /* *pred_nmsacvnx2si_scalar */
    case 4275:  /* *pred_nmsubvnx2si_scalar */
    case 4253:  /* *pred_minus_mulvnx2si */
    case 4231:  /* *pred_nmsacvnx2si */
    case 4209:  /* *pred_nmsubvnx2si */
    case 4175:  /* *pred_mul_plusvnx2si_scalar */
    case 4153:  /* *pred_maccvnx2si_scalar */
    case 4131:  /* *pred_maddvnx2si_scalar */
    case 4109:  /* *pred_mul_plusvnx2si */
    case 4087:  /* *pred_maccvnx2si */
    case 4065:  /* *pred_maddvnx2si */
    case 4015:  /* *pred_eqnevnx2si_scalar_narrow */
    case 3997:  /* *pred_eqnevnx2si_scalar */
    case 3979:  /* *pred_cmpvnx2si_scalar_narrow */
    case 3961:  /* *pred_cmpvnx2si_scalar */
    case 3939:  /* *pred_ltgevnx2si_narrow */
    case 3917:  /* *pred_ltgevnx2si */
    case 3895:  /* *pred_cmpvnx2si_narrow */
    case 3873:  /* *pred_cmpvnx2si */
    case 3854:  /* pred_narrow_clipuvnx2di_scalar */
    case 3853:  /* pred_narrow_clipvnx2di_scalar */
    case 3824:  /* pred_narrow_clipuvnx2di */
    case 3823:  /* pred_narrow_clipvnx2di */
    case 3744:  /* pred_ssravnx2si_scalar */
    case 3743:  /* pred_ssrlvnx2si_scalar */
    case 3699:  /* pred_smulvnx2si_scalar */
    case 3698:  /* pred_asubvnx2si_scalar */
    case 3697:  /* pred_asubuvnx2si_scalar */
    case 3696:  /* pred_aaddvnx2si_scalar */
    case 3695:  /* pred_aadduvnx2si_scalar */
    case 3575:  /* pred_ssravnx2si */
    case 3574:  /* pred_ssrlvnx2si */
    case 3573:  /* pred_smulvnx2si */
    case 3572:  /* pred_asubvnx2si */
    case 3571:  /* pred_asubuvnx2si */
    case 3570:  /* pred_aaddvnx2si */
    case 3569:  /* pred_aadduvnx2si */
    case 3432:  /* pred_ussubvnx2si_scalar */
    case 3431:  /* pred_sssubvnx2si_scalar */
    case 3396:  /* pred_usaddvnx2si_scalar */
    case 3395:  /* pred_ssaddvnx2si_scalar */
    case 3338:  /* pred_ussubvnx2si */
    case 3337:  /* pred_usaddvnx2si */
    case 3336:  /* pred_sssubvnx2si */
    case 3335:  /* pred_ssaddvnx2si */
    case 3276:  /* pred_truncvnx2di */
    case 3259:  /* pred_narrow_lshrvnx2di_scalar */
    case 3258:  /* pred_narrow_ashrvnx2di_scalar */
    case 3229:  /* pred_narrow_lshrvnx2di */
    case 3228:  /* pred_narrow_ashrvnx2di */
    case 3199:  /* pred_zero_extendvnx2di */
    case 3198:  /* pred_extendvnx2di */
    case 3171:  /* pred_widen_mulsuvnx2di_scalar */
    case 3156:  /* pred_widen_mulsuvnx2di */
    case 3135:  /* pred_single_widen_subuvnx2di_scalar */
    case 3134:  /* pred_single_widen_adduvnx2di_scalar */
    case 3133:  /* pred_single_widen_subsvnx2di_scalar */
    case 3132:  /* pred_single_widen_addsvnx2di_scalar */
    case 3075:  /* pred_single_widen_subuvnx2di */
    case 3074:  /* pred_single_widen_adduvnx2di */
    case 3073:  /* pred_single_widen_subsvnx2di */
    case 3072:  /* pred_single_widen_addsvnx2di */
    case 3011:  /* pred_dual_widen_muluvnx2di_scalar */
    case 3010:  /* pred_dual_widen_subuvnx2di_scalar */
    case 3009:  /* pred_dual_widen_adduvnx2di_scalar */
    case 3008:  /* pred_dual_widen_mulsvnx2di_scalar */
    case 3007:  /* pred_dual_widen_subsvnx2di_scalar */
    case 3006:  /* pred_dual_widen_addsvnx2di_scalar */
    case 2921:  /* pred_dual_widen_muluvnx2di */
    case 2920:  /* pred_dual_widen_subuvnx2di */
    case 2919:  /* pred_dual_widen_adduvnx2di */
    case 2918:  /* pred_dual_widen_mulsvnx2di */
    case 2917:  /* pred_dual_widen_subsvnx2di */
    case 2916:  /* pred_dual_widen_addsvnx2di */
    case 2821:  /* pred_zero_extendvnx2si_vf4 */
    case 2820:  /* pred_extendvnx2si_vf4 */
    case 2803:  /* pred_zero_extendvnx2si_vf2 */
    case 2802:  /* pred_extendvnx2si_vf2 */
    case 2773:  /* pred_one_cmplvnx2si */
    case 2772:  /* pred_negvnx2si */
    case 2724:  /* pred_msbcvnx2si_overflow_scalar */
    case 2706:  /* pred_madcvnx2si_overflow_scalar */
    case 2684:  /* pred_msbcvnx2si_overflow */
    case 2662:  /* pred_madcvnx2si_overflow */
    case 2628:  /* pred_msbcvnx2si_scalar */
    case 2610:  /* pred_madcvnx2si_scalar */
    case 2588:  /* pred_msbcvnx2si */
    case 2566:  /* pred_madcvnx2si */
    case 2532:  /* pred_sbcvnx2si_scalar */
    case 2514:  /* pred_adcvnx2si_scalar */
    case 2492:  /* pred_sbcvnx2si */
    case 2470:  /* pred_adcvnx2si */
    case 2422:  /* pred_mulhsuvnx2si_scalar */
    case 2421:  /* pred_mulhuvnx2si_scalar */
    case 2420:  /* pred_mulhvnx2si_scalar */
    case 2356:  /* pred_mulhsuvnx2si */
    case 2355:  /* pred_mulhuvnx2si */
    case 2354:  /* pred_mulhvnx2si */
    case 2188:  /* pred_subvnx2si_reverse_scalar */
    case 2158:  /* pred_umodvnx2si_scalar */
    case 2157:  /* pred_modvnx2si_scalar */
    case 2156:  /* pred_udivvnx2si_scalar */
    case 2155:  /* pred_divvnx2si_scalar */
    case 2154:  /* pred_subvnx2si_scalar */
    case 2056:  /* pred_mulvnx2si_scalar */
    case 2055:  /* pred_uminvnx2si_scalar */
    case 2054:  /* pred_sminvnx2si_scalar */
    case 2053:  /* pred_umaxvnx2si_scalar */
    case 2052:  /* pred_smaxvnx2si_scalar */
    case 2051:  /* pred_xorvnx2si_scalar */
    case 2050:  /* pred_iorvnx2si_scalar */
    case 2049:  /* pred_andvnx2si_scalar */
    case 2048:  /* pred_addvnx2si_scalar */
    case 1900:  /* pred_lshrvnx2si_scalar */
    case 1899:  /* pred_ashrvnx2si_scalar */
    case 1898:  /* pred_ashlvnx2si_scalar */
    case 1736:  /* pred_umodvnx2si */
    case 1735:  /* pred_modvnx2si */
    case 1734:  /* pred_udivvnx2si */
    case 1733:  /* pred_divvnx2si */
    case 1732:  /* pred_mulvnx2si */
    case 1731:  /* pred_uminvnx2si */
    case 1730:  /* pred_sminvnx2si */
    case 1729:  /* pred_umaxvnx2si */
    case 1728:  /* pred_smaxvnx2si */
    case 1727:  /* pred_lshrvnx2si */
    case 1726:  /* pred_ashrvnx2si */
    case 1725:  /* pred_ashlvnx2si */
    case 1724:  /* pred_xorvnx2si */
    case 1723:  /* pred_iorvnx2si */
    case 1722:  /* pred_andvnx2si */
    case 1721:  /* pred_subvnx2si */
    case 1720:  /* pred_addvnx2si */
    case 1349:  /* pred_indexed_ustorevnx2sfvnx2di */
    case 1348:  /* pred_indexed_ostorevnx2sfvnx2di */
    case 1345:  /* pred_indexed_ustorevnx2sivnx2di */
    case 1344:  /* pred_indexed_ostorevnx2sivnx2di */
    case 1337:  /* pred_indexed_ustorevnx2sfvnx2si */
    case 1336:  /* pred_indexed_ostorevnx2sfvnx2si */
    case 1333:  /* pred_indexed_ustorevnx2sivnx2si */
    case 1332:  /* pred_indexed_ostorevnx2sivnx2si */
    case 1325:  /* pred_indexed_ustorevnx2sfvnx2hi */
    case 1324:  /* pred_indexed_ostorevnx2sfvnx2hi */
    case 1321:  /* pred_indexed_ustorevnx2sivnx2hi */
    case 1320:  /* pred_indexed_ostorevnx2sivnx2hi */
    case 1313:  /* pred_indexed_ustorevnx2sfvnx2qi */
    case 1312:  /* pred_indexed_ostorevnx2sfvnx2qi */
    case 1309:  /* pred_indexed_ustorevnx2sivnx2qi */
    case 1308:  /* pred_indexed_ostorevnx2sivnx2qi */
    case 1225:  /* pred_indexed_uloadvnx2sf_x2_smaller_eew */
    case 1224:  /* pred_indexed_oloadvnx2sf_x2_smaller_eew */
    case 1217:  /* pred_indexed_uloadvnx2si_x2_smaller_eew */
    case 1216:  /* pred_indexed_oloadvnx2si_x2_smaller_eew */
    case 1161:  /* pred_indexed_uloadvnx2sf_x4_greater_eew */
    case 1160:  /* pred_indexed_oloadvnx2sf_x4_greater_eew */
    case 1143:  /* pred_indexed_uloadvnx2si_x4_greater_eew */
    case 1142:  /* pred_indexed_oloadvnx2si_x4_greater_eew */
    case 1125:  /* pred_indexed_uloadvnx2sf_x2_greater_eew */
    case 1124:  /* pred_indexed_oloadvnx2sf_x2_greater_eew */
    case 1107:  /* pred_indexed_uloadvnx2si_x2_greater_eew */
    case 1106:  /* pred_indexed_oloadvnx2si_x2_greater_eew */
    case 1077:  /* pred_indexed_uloadvnx2sf_same_eew */
    case 1076:  /* pred_indexed_oloadvnx2sf_same_eew */
    case 1059:  /* pred_indexed_uloadvnx2si_same_eew */
    case 1058:  /* pred_indexed_oloadvnx2si_same_eew */
    case 1022:  /* pred_strided_storevnx2sf */
    case 1013:  /* pred_strided_storevnx2si */
    case 991:  /* pred_strided_loadvnx2sf */
    case 982:  /* pred_strided_loadvnx2si */
    case 956:  /* *pred_broadcastvnx2sf */
    case 947:  /* *pred_broadcastvnx2si */
    case 921:  /* pred_mergevnx2si_scalar */
    case 899:  /* pred_mergevnx2sf */
    case 890:  /* pred_mergevnx2si */
    case 854:  /* pred_storevnx2sf */
    case 845:  /* pred_storevnx2si */
    case 823:  /* pred_movvnx2sf */
    case 814:  /* pred_movvnx2si */
    case 743:  /* *movvnx2sf_whole */
    case 734:  /* *movvnx2si_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 128 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx2SImode));

    case 6059:  /* pred_fault_loadvnx1sf */
    case 6050:  /* pred_fault_loadvnx1si */
    case 6026:  /* pred_compressvnx1sf */
    case 6017:  /* pred_compressvnx1si */
    case 5995:  /* pred_gatherei16vnx1sf */
    case 5986:  /* pred_gatherei16vnx1si */
    case 5965:  /* pred_gathervnx1sf_scalar */
    case 5956:  /* pred_gathervnx1si_scalar */
    case 5934:  /* pred_gathervnx1sf */
    case 5925:  /* pred_gathervnx1si */
    case 5895:  /* pred_slide1downvnx1sf */
    case 5894:  /* pred_slide1upvnx1sf */
    case 5869:  /* pred_slide1downvnx1si */
    case 5868:  /* pred_slide1upvnx1si */
    case 5825:  /* pred_slidedownvnx1sf */
    case 5824:  /* pred_slideupvnx1sf */
    case 5807:  /* pred_slidedownvnx1si */
    case 5806:  /* pred_slideupvnx1si */
    case 5771:  /* *pred_extract_firstvnx1sf */
    case 5758:  /* *pred_extract_firstvnx1si */
    case 5736:  /* pred_widen_reduc_plusuvnx1sfvnx1df */
    case 5735:  /* pred_widen_reduc_plusovnx1sfvnx1df */
    case 5728:  /* pred_reduc_plusuvnx1sfvnx1sf */
    case 5727:  /* pred_reduc_plusovnx1sfvnx1sf */
    case 5710:  /* pred_reduc_plusuvnx1sfvnx2sf */
    case 5709:  /* pred_reduc_plusovnx1sfvnx2sf */
    case 5702:  /* pred_reduc_minvnx1sfvnx1sf */
    case 5701:  /* pred_reduc_maxvnx1sfvnx1sf */
    case 5684:  /* pred_reduc_minvnx1sfvnx2sf */
    case 5683:  /* pred_reduc_maxvnx1sfvnx2sf */
    case 5652:  /* pred_widen_reduc_plusuvnx1sivnx2di */
    case 5651:  /* pred_widen_reduc_plusvnx1sivnx2di */
    case 5600:  /* pred_reduc_xorvnx1sivnx1si */
    case 5599:  /* pred_reduc_orvnx1sivnx1si */
    case 5598:  /* pred_reduc_andvnx1sivnx1si */
    case 5597:  /* pred_reduc_minvnx1sivnx1si */
    case 5596:  /* pred_reduc_minuvnx1sivnx1si */
    case 5595:  /* pred_reduc_maxvnx1sivnx1si */
    case 5594:  /* pred_reduc_maxuvnx1sivnx1si */
    case 5593:  /* pred_reduc_sumvnx1sivnx1si */
    case 5440:  /* pred_reduc_xorvnx1sivnx2si */
    case 5439:  /* pred_reduc_orvnx1sivnx2si */
    case 5438:  /* pred_reduc_andvnx1sivnx2si */
    case 5437:  /* pred_reduc_minvnx1sivnx2si */
    case 5436:  /* pred_reduc_minuvnx1sivnx2si */
    case 5435:  /* pred_reduc_maxvnx1sivnx2si */
    case 5434:  /* pred_reduc_maxuvnx1sivnx2si */
    case 5433:  /* pred_reduc_sumvnx1sivnx2si */
    case 5325:  /* pred_rod_truncvnx1df */
    case 5321:  /* pred_truncvnx1df */
    case 5314:  /* pred_narrow_floatunsvnx1di */
    case 5313:  /* pred_narrow_floatvnx1di */
    case 5306:  /* pred_narrow_fixuns_truncvnx1df */
    case 5305:  /* pred_narrow_fix_truncvnx1df */
    case 5288:  /* pred_narrow_fcvt_xu_fvnx1df */
    case 5287:  /* pred_narrow_fcvt_x_fvnx1df */
    case 5273:  /* pred_extendvnx1df */
    case 5266:  /* pred_widen_floatunsvnx1df */
    case 5265:  /* pred_widen_floatvnx1df */
    case 5248:  /* pred_widen_fixuns_truncvnx1di */
    case 5247:  /* pred_widen_fix_truncvnx1di */
    case 5240:  /* pred_widen_fcvt_xu_fvnx1di */
    case 5239:  /* pred_widen_fcvt_x_fvnx1di */
    case 5222:  /* pred_floatunsvnx1sf */
    case 5221:  /* pred_floatvnx1sf */
    case 5204:  /* pred_fixuns_truncvnx1sf */
    case 5203:  /* pred_fix_truncvnx1sf */
    case 5186:  /* pred_fcvt_xu_fvnx1sf */
    case 5185:  /* pred_fcvt_x_fvnx1sf */
    case 5176:  /* pred_mergevnx1sf_scalar */
    case 5167:  /* *pred_eqnevnx1sf_scalar_narrow */
    case 5158:  /* *pred_eqnevnx1sf_scalar */
    case 5149:  /* *pred_cmpvnx1sf_scalar_narrow */
    case 5140:  /* *pred_cmpvnx1sf_scalar */
    case 5131:  /* *pred_cmpvnx1sf_narrow */
    case 5122:  /* *pred_cmpvnx1sf */
    case 5115:  /* pred_widen_mul_neg_subvnx1df_scalar */
    case 5114:  /* pred_widen_mul_neg_addvnx1df_scalar */
    case 5107:  /* pred_widen_mul_neg_subvnx1df */
    case 5106:  /* pred_widen_mul_neg_addvnx1df */
    case 5099:  /* pred_widen_mul_subvnx1df_scalar */
    case 5098:  /* pred_widen_mul_addvnx1df_scalar */
    case 5091:  /* pred_widen_mul_subvnx1df */
    case 5090:  /* pred_widen_mul_addvnx1df */
    case 5083:  /* pred_single_widen_subvnx1df_scalar */
    case 5082:  /* pred_single_widen_addvnx1df_scalar */
    case 5075:  /* pred_single_widen_subvnx1df */
    case 5074:  /* pred_single_widen_addvnx1df */
    case 5064:  /* pred_dual_widen_mulvnx1df_scalar */
    case 5063:  /* pred_dual_widen_subvnx1df_scalar */
    case 5062:  /* pred_dual_widen_addvnx1df_scalar */
    case 5052:  /* pred_dual_widen_mulvnx1df */
    case 5051:  /* pred_dual_widen_subvnx1df */
    case 5050:  /* pred_dual_widen_addvnx1df */
    case 5041:  /* pred_classvnx1sf */
    case 5024:  /* pred_rec7vnx1sf */
    case 5023:  /* pred_rsqrt7vnx1sf */
    case 4998:  /* pred_sqrtvnx1sf */
    case 4997:  /* pred_absvnx1sf */
    case 4996:  /* pred_negvnx1sf */
    case 4979:  /* *pred_mul_neg_subvnx1sf_scalar */
    case 4978:  /* *pred_mul_neg_addvnx1sf_scalar */
    case 4961:  /* *pred_nmaccvnx1sf_scalar */
    case 4960:  /* *pred_nmsacvnx1sf_scalar */
    case 4943:  /* *pred_nmaddvnx1sf_scalar */
    case 4942:  /* *pred_nmsubvnx1sf_scalar */
    case 4925:  /* *pred_mul_neg_subvnx1sf */
    case 4924:  /* *pred_mul_neg_addvnx1sf */
    case 4907:  /* *pred_nmaccvnx1sf */
    case 4906:  /* *pred_nmsacvnx1sf */
    case 4889:  /* *pred_nmaddvnx1sf */
    case 4888:  /* *pred_nmsubvnx1sf */
    case 4871:  /* *pred_mul_subvnx1sf_scalar */
    case 4870:  /* *pred_mul_addvnx1sf_scalar */
    case 4853:  /* *pred_msacvnx1sf_scalar */
    case 4852:  /* *pred_maccvnx1sf_scalar */
    case 4835:  /* *pred_msubvnx1sf_scalar */
    case 4834:  /* *pred_maddvnx1sf_scalar */
    case 4817:  /* *pred_mul_subvnx1sf */
    case 4816:  /* *pred_mul_addvnx1sf */
    case 4799:  /* *pred_msacvnx1sf */
    case 4798:  /* *pred_maccvnx1sf */
    case 4781:  /* *pred_msubvnx1sf */
    case 4780:  /* *pred_maddvnx1sf */
    case 4755:  /* pred_xorsignvnx1sf_scalar */
    case 4754:  /* pred_ncopysignvnx1sf_scalar */
    case 4753:  /* pred_copysignvnx1sf_scalar */
    case 4728:  /* pred_xorsignvnx1sf */
    case 4727:  /* pred_ncopysignvnx1sf */
    case 4726:  /* pred_copysignvnx1sf */
    case 4709:  /* pred_divvnx1sf_reverse_scalar */
    case 4708:  /* pred_subvnx1sf_reverse_scalar */
    case 4691:  /* pred_divvnx1sf_scalar */
    case 4690:  /* pred_subvnx1sf_scalar */
    case 4657:  /* pred_sminvnx1sf_scalar */
    case 4656:  /* pred_smaxvnx1sf_scalar */
    case 4655:  /* pred_mulvnx1sf_scalar */
    case 4654:  /* pred_addvnx1sf_scalar */
    case 4605:  /* pred_divvnx1sf */
    case 4604:  /* pred_subvnx1sf */
    case 4603:  /* pred_sminvnx1sf */
    case 4602:  /* pred_smaxvnx1sf */
    case 4601:  /* pred_mulvnx1sf */
    case 4600:  /* pred_addvnx1sf */
    case 4591:  /* pred_seriesvnx1si */
    case 4569:  /* pred_iotavnx1si */
    case 4440:  /* pred_widen_mul_plususvnx1di_scalar */
    case 4425:  /* pred_widen_mul_plussuvnx1di_scalar */
    case 4410:  /* pred_widen_mul_plussuvnx1di */
    case 4392:  /* pred_widen_mul_plusuvnx1di_scalar */
    case 4391:  /* pred_widen_mul_plussvnx1di_scalar */
    case 4362:  /* pred_widen_mul_plusuvnx1di */
    case 4361:  /* pred_widen_mul_plussvnx1di */
    case 4318:  /* *pred_minus_mulvnx1si_scalar */
    case 4296:  /* *pred_nmsacvnx1si_scalar */
    case 4274:  /* *pred_nmsubvnx1si_scalar */
    case 4252:  /* *pred_minus_mulvnx1si */
    case 4230:  /* *pred_nmsacvnx1si */
    case 4208:  /* *pred_nmsubvnx1si */
    case 4174:  /* *pred_mul_plusvnx1si_scalar */
    case 4152:  /* *pred_maccvnx1si_scalar */
    case 4130:  /* *pred_maddvnx1si_scalar */
    case 4108:  /* *pred_mul_plusvnx1si */
    case 4086:  /* *pred_maccvnx1si */
    case 4064:  /* *pred_maddvnx1si */
    case 4014:  /* *pred_eqnevnx1si_scalar_narrow */
    case 3996:  /* *pred_eqnevnx1si_scalar */
    case 3978:  /* *pred_cmpvnx1si_scalar_narrow */
    case 3960:  /* *pred_cmpvnx1si_scalar */
    case 3938:  /* *pred_ltgevnx1si_narrow */
    case 3916:  /* *pred_ltgevnx1si */
    case 3894:  /* *pred_cmpvnx1si_narrow */
    case 3872:  /* *pred_cmpvnx1si */
    case 3852:  /* pred_narrow_clipuvnx1di_scalar */
    case 3851:  /* pred_narrow_clipvnx1di_scalar */
    case 3822:  /* pred_narrow_clipuvnx1di */
    case 3821:  /* pred_narrow_clipvnx1di */
    case 3742:  /* pred_ssravnx1si_scalar */
    case 3741:  /* pred_ssrlvnx1si_scalar */
    case 3694:  /* pred_smulvnx1si_scalar */
    case 3693:  /* pred_asubvnx1si_scalar */
    case 3692:  /* pred_asubuvnx1si_scalar */
    case 3691:  /* pred_aaddvnx1si_scalar */
    case 3690:  /* pred_aadduvnx1si_scalar */
    case 3568:  /* pred_ssravnx1si */
    case 3567:  /* pred_ssrlvnx1si */
    case 3566:  /* pred_smulvnx1si */
    case 3565:  /* pred_asubvnx1si */
    case 3564:  /* pred_asubuvnx1si */
    case 3563:  /* pred_aaddvnx1si */
    case 3562:  /* pred_aadduvnx1si */
    case 3430:  /* pred_ussubvnx1si_scalar */
    case 3429:  /* pred_sssubvnx1si_scalar */
    case 3394:  /* pred_usaddvnx1si_scalar */
    case 3393:  /* pred_ssaddvnx1si_scalar */
    case 3334:  /* pred_ussubvnx1si */
    case 3333:  /* pred_usaddvnx1si */
    case 3332:  /* pred_sssubvnx1si */
    case 3331:  /* pred_ssaddvnx1si */
    case 3275:  /* pred_truncvnx1di */
    case 3257:  /* pred_narrow_lshrvnx1di_scalar */
    case 3256:  /* pred_narrow_ashrvnx1di_scalar */
    case 3227:  /* pred_narrow_lshrvnx1di */
    case 3226:  /* pred_narrow_ashrvnx1di */
    case 3197:  /* pred_zero_extendvnx1di */
    case 3196:  /* pred_extendvnx1di */
    case 3170:  /* pred_widen_mulsuvnx1di_scalar */
    case 3155:  /* pred_widen_mulsuvnx1di */
    case 3131:  /* pred_single_widen_subuvnx1di_scalar */
    case 3130:  /* pred_single_widen_adduvnx1di_scalar */
    case 3129:  /* pred_single_widen_subsvnx1di_scalar */
    case 3128:  /* pred_single_widen_addsvnx1di_scalar */
    case 3071:  /* pred_single_widen_subuvnx1di */
    case 3070:  /* pred_single_widen_adduvnx1di */
    case 3069:  /* pred_single_widen_subsvnx1di */
    case 3068:  /* pred_single_widen_addsvnx1di */
    case 3005:  /* pred_dual_widen_muluvnx1di_scalar */
    case 3004:  /* pred_dual_widen_subuvnx1di_scalar */
    case 3003:  /* pred_dual_widen_adduvnx1di_scalar */
    case 3002:  /* pred_dual_widen_mulsvnx1di_scalar */
    case 3001:  /* pred_dual_widen_subsvnx1di_scalar */
    case 3000:  /* pred_dual_widen_addsvnx1di_scalar */
    case 2915:  /* pred_dual_widen_muluvnx1di */
    case 2914:  /* pred_dual_widen_subuvnx1di */
    case 2913:  /* pred_dual_widen_adduvnx1di */
    case 2912:  /* pred_dual_widen_mulsvnx1di */
    case 2911:  /* pred_dual_widen_subsvnx1di */
    case 2910:  /* pred_dual_widen_addsvnx1di */
    case 2819:  /* pred_zero_extendvnx1si_vf4 */
    case 2818:  /* pred_extendvnx1si_vf4 */
    case 2801:  /* pred_zero_extendvnx1si_vf2 */
    case 2800:  /* pred_extendvnx1si_vf2 */
    case 2771:  /* pred_one_cmplvnx1si */
    case 2770:  /* pred_negvnx1si */
    case 2723:  /* pred_msbcvnx1si_overflow_scalar */
    case 2705:  /* pred_madcvnx1si_overflow_scalar */
    case 2683:  /* pred_msbcvnx1si_overflow */
    case 2661:  /* pred_madcvnx1si_overflow */
    case 2627:  /* pred_msbcvnx1si_scalar */
    case 2609:  /* pred_madcvnx1si_scalar */
    case 2587:  /* pred_msbcvnx1si */
    case 2565:  /* pred_madcvnx1si */
    case 2531:  /* pred_sbcvnx1si_scalar */
    case 2513:  /* pred_adcvnx1si_scalar */
    case 2491:  /* pred_sbcvnx1si */
    case 2469:  /* pred_adcvnx1si */
    case 2419:  /* pred_mulhsuvnx1si_scalar */
    case 2418:  /* pred_mulhuvnx1si_scalar */
    case 2417:  /* pred_mulhvnx1si_scalar */
    case 2353:  /* pred_mulhsuvnx1si */
    case 2352:  /* pred_mulhuvnx1si */
    case 2351:  /* pred_mulhvnx1si */
    case 2187:  /* pred_subvnx1si_reverse_scalar */
    case 2153:  /* pred_umodvnx1si_scalar */
    case 2152:  /* pred_modvnx1si_scalar */
    case 2151:  /* pred_udivvnx1si_scalar */
    case 2150:  /* pred_divvnx1si_scalar */
    case 2149:  /* pred_subvnx1si_scalar */
    case 2047:  /* pred_mulvnx1si_scalar */
    case 2046:  /* pred_uminvnx1si_scalar */
    case 2045:  /* pred_sminvnx1si_scalar */
    case 2044:  /* pred_umaxvnx1si_scalar */
    case 2043:  /* pred_smaxvnx1si_scalar */
    case 2042:  /* pred_xorvnx1si_scalar */
    case 2041:  /* pred_iorvnx1si_scalar */
    case 2040:  /* pred_andvnx1si_scalar */
    case 2039:  /* pred_addvnx1si_scalar */
    case 1897:  /* pred_lshrvnx1si_scalar */
    case 1896:  /* pred_ashrvnx1si_scalar */
    case 1895:  /* pred_ashlvnx1si_scalar */
    case 1719:  /* pred_umodvnx1si */
    case 1718:  /* pred_modvnx1si */
    case 1717:  /* pred_udivvnx1si */
    case 1716:  /* pred_divvnx1si */
    case 1715:  /* pred_mulvnx1si */
    case 1714:  /* pred_uminvnx1si */
    case 1713:  /* pred_sminvnx1si */
    case 1712:  /* pred_umaxvnx1si */
    case 1711:  /* pred_smaxvnx1si */
    case 1710:  /* pred_lshrvnx1si */
    case 1709:  /* pred_ashrvnx1si */
    case 1708:  /* pred_ashlvnx1si */
    case 1707:  /* pred_xorvnx1si */
    case 1706:  /* pred_iorvnx1si */
    case 1705:  /* pred_andvnx1si */
    case 1704:  /* pred_subvnx1si */
    case 1703:  /* pred_addvnx1si */
    case 1295:  /* pred_indexed_ustorevnx1sfvnx1di */
    case 1294:  /* pred_indexed_ostorevnx1sfvnx1di */
    case 1293:  /* pred_indexed_ustorevnx1sfvnx1si */
    case 1292:  /* pred_indexed_ostorevnx1sfvnx1si */
    case 1291:  /* pred_indexed_ustorevnx1sfvnx1hi */
    case 1290:  /* pred_indexed_ostorevnx1sfvnx1hi */
    case 1289:  /* pred_indexed_ustorevnx1sfvnx1qi */
    case 1288:  /* pred_indexed_ostorevnx1sfvnx1qi */
    case 1279:  /* pred_indexed_ustorevnx1sivnx1di */
    case 1278:  /* pred_indexed_ostorevnx1sivnx1di */
    case 1277:  /* pred_indexed_ustorevnx1sivnx1si */
    case 1276:  /* pred_indexed_ostorevnx1sivnx1si */
    case 1275:  /* pred_indexed_ustorevnx1sivnx1hi */
    case 1274:  /* pred_indexed_ostorevnx1sivnx1hi */
    case 1273:  /* pred_indexed_ustorevnx1sivnx1qi */
    case 1272:  /* pred_indexed_ostorevnx1sivnx1qi */
    case 1223:  /* pred_indexed_uloadvnx1sf_x2_smaller_eew */
    case 1222:  /* pred_indexed_oloadvnx1sf_x2_smaller_eew */
    case 1215:  /* pred_indexed_uloadvnx1si_x2_smaller_eew */
    case 1214:  /* pred_indexed_oloadvnx1si_x2_smaller_eew */
    case 1159:  /* pred_indexed_uloadvnx1sf_x4_greater_eew */
    case 1158:  /* pred_indexed_oloadvnx1sf_x4_greater_eew */
    case 1141:  /* pred_indexed_uloadvnx1si_x4_greater_eew */
    case 1140:  /* pred_indexed_oloadvnx1si_x4_greater_eew */
    case 1123:  /* pred_indexed_uloadvnx1sf_x2_greater_eew */
    case 1122:  /* pred_indexed_oloadvnx1sf_x2_greater_eew */
    case 1105:  /* pred_indexed_uloadvnx1si_x2_greater_eew */
    case 1104:  /* pred_indexed_oloadvnx1si_x2_greater_eew */
    case 1075:  /* pred_indexed_uloadvnx1sf_same_eew */
    case 1074:  /* pred_indexed_oloadvnx1sf_same_eew */
    case 1057:  /* pred_indexed_uloadvnx1si_same_eew */
    case 1056:  /* pred_indexed_oloadvnx1si_same_eew */
    case 1021:  /* pred_strided_storevnx1sf */
    case 1012:  /* pred_strided_storevnx1si */
    case 990:  /* pred_strided_loadvnx1sf */
    case 981:  /* pred_strided_loadvnx1si */
    case 955:  /* *pred_broadcastvnx1sf */
    case 946:  /* *pred_broadcastvnx1si */
    case 920:  /* pred_mergevnx1si_scalar */
    case 898:  /* pred_mergevnx1sf */
    case 889:  /* pred_mergevnx1si */
    case 853:  /* pred_storevnx1sf */
    case 844:  /* pred_storevnx1si */
    case 822:  /* pred_movvnx1sf */
    case 813:  /* pred_movvnx1si */
    case 757:  /* *movvnx1sf_fract */
    case 756:  /* *movvnx1si_fract */
    case 742:  /* *movvnx1sf_whole */
    case 733:  /* *movvnx1si_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 126 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx1SImode));

    case 6049:  /* pred_fault_loadvnx32hi */
    case 6016:  /* pred_compressvnx32hi */
    case 5985:  /* pred_gatherei16vnx32hi */
    case 5955:  /* pred_gathervnx32hi_scalar */
    case 5924:  /* pred_gathervnx32hi */
    case 5867:  /* pred_slide1downvnx32hi */
    case 5866:  /* pred_slide1upvnx32hi */
    case 5805:  /* pred_slidedownvnx32hi */
    case 5804:  /* pred_slideupvnx32hi */
    case 5757:  /* *pred_extract_firstvnx32hi */
    case 5650:  /* pred_widen_reduc_plusuvnx32hivnx2si */
    case 5649:  /* pred_widen_reduc_plusvnx32hivnx2si */
    case 5432:  /* pred_reduc_xorvnx32hivnx4hi */
    case 5431:  /* pred_reduc_orvnx32hivnx4hi */
    case 5430:  /* pred_reduc_andvnx32hivnx4hi */
    case 5429:  /* pred_reduc_minvnx32hivnx4hi */
    case 5428:  /* pred_reduc_minuvnx32hivnx4hi */
    case 5427:  /* pred_reduc_maxvnx32hivnx4hi */
    case 5426:  /* pred_reduc_maxuvnx32hivnx4hi */
    case 5425:  /* pred_reduc_sumvnx32hivnx4hi */
    case 4590:  /* pred_seriesvnx32hi */
    case 4568:  /* pred_iotavnx32hi */
    case 4317:  /* *pred_minus_mulvnx32hi_scalar */
    case 4295:  /* *pred_nmsacvnx32hi_scalar */
    case 4273:  /* *pred_nmsubvnx32hi_scalar */
    case 4251:  /* *pred_minus_mulvnx32hi */
    case 4229:  /* *pred_nmsacvnx32hi */
    case 4207:  /* *pred_nmsubvnx32hi */
    case 4173:  /* *pred_mul_plusvnx32hi_scalar */
    case 4151:  /* *pred_maccvnx32hi_scalar */
    case 4129:  /* *pred_maddvnx32hi_scalar */
    case 4107:  /* *pred_mul_plusvnx32hi */
    case 4085:  /* *pred_maccvnx32hi */
    case 4063:  /* *pred_maddvnx32hi */
    case 4013:  /* *pred_eqnevnx32hi_scalar_narrow */
    case 3995:  /* *pred_eqnevnx32hi_scalar */
    case 3977:  /* *pred_cmpvnx32hi_scalar_narrow */
    case 3959:  /* *pred_cmpvnx32hi_scalar */
    case 3937:  /* *pred_ltgevnx32hi_narrow */
    case 3915:  /* *pred_ltgevnx32hi */
    case 3893:  /* *pred_cmpvnx32hi_narrow */
    case 3871:  /* *pred_cmpvnx32hi */
    case 3740:  /* pred_ssravnx32hi_scalar */
    case 3739:  /* pred_ssrlvnx32hi_scalar */
    case 3689:  /* pred_smulvnx32hi_scalar */
    case 3688:  /* pred_asubvnx32hi_scalar */
    case 3687:  /* pred_asubuvnx32hi_scalar */
    case 3686:  /* pred_aaddvnx32hi_scalar */
    case 3685:  /* pred_aadduvnx32hi_scalar */
    case 3561:  /* pred_ssravnx32hi */
    case 3560:  /* pred_ssrlvnx32hi */
    case 3559:  /* pred_smulvnx32hi */
    case 3558:  /* pred_asubvnx32hi */
    case 3557:  /* pred_asubuvnx32hi */
    case 3556:  /* pred_aaddvnx32hi */
    case 3555:  /* pred_aadduvnx32hi */
    case 3428:  /* pred_ussubvnx32hi_scalar */
    case 3427:  /* pred_sssubvnx32hi_scalar */
    case 3392:  /* pred_usaddvnx32hi_scalar */
    case 3391:  /* pred_ssaddvnx32hi_scalar */
    case 3330:  /* pred_ussubvnx32hi */
    case 3329:  /* pred_usaddvnx32hi */
    case 3328:  /* pred_sssubvnx32hi */
    case 3327:  /* pred_ssaddvnx32hi */
    case 2799:  /* pred_zero_extendvnx32hi_vf2 */
    case 2798:  /* pred_extendvnx32hi_vf2 */
    case 2769:  /* pred_one_cmplvnx32hi */
    case 2768:  /* pred_negvnx32hi */
    case 2722:  /* pred_msbcvnx32hi_overflow_scalar */
    case 2704:  /* pred_madcvnx32hi_overflow_scalar */
    case 2682:  /* pred_msbcvnx32hi_overflow */
    case 2660:  /* pred_madcvnx32hi_overflow */
    case 2626:  /* pred_msbcvnx32hi_scalar */
    case 2608:  /* pred_madcvnx32hi_scalar */
    case 2586:  /* pred_msbcvnx32hi */
    case 2564:  /* pred_madcvnx32hi */
    case 2530:  /* pred_sbcvnx32hi_scalar */
    case 2512:  /* pred_adcvnx32hi_scalar */
    case 2490:  /* pred_sbcvnx32hi */
    case 2468:  /* pred_adcvnx32hi */
    case 2416:  /* pred_mulhsuvnx32hi_scalar */
    case 2415:  /* pred_mulhuvnx32hi_scalar */
    case 2414:  /* pred_mulhvnx32hi_scalar */
    case 2350:  /* pred_mulhsuvnx32hi */
    case 2349:  /* pred_mulhuvnx32hi */
    case 2348:  /* pred_mulhvnx32hi */
    case 2186:  /* pred_subvnx32hi_reverse_scalar */
    case 2148:  /* pred_umodvnx32hi_scalar */
    case 2147:  /* pred_modvnx32hi_scalar */
    case 2146:  /* pred_udivvnx32hi_scalar */
    case 2145:  /* pred_divvnx32hi_scalar */
    case 2144:  /* pred_subvnx32hi_scalar */
    case 2038:  /* pred_mulvnx32hi_scalar */
    case 2037:  /* pred_uminvnx32hi_scalar */
    case 2036:  /* pred_sminvnx32hi_scalar */
    case 2035:  /* pred_umaxvnx32hi_scalar */
    case 2034:  /* pred_smaxvnx32hi_scalar */
    case 2033:  /* pred_xorvnx32hi_scalar */
    case 2032:  /* pred_iorvnx32hi_scalar */
    case 2031:  /* pred_andvnx32hi_scalar */
    case 2030:  /* pred_addvnx32hi_scalar */
    case 1894:  /* pred_lshrvnx32hi_scalar */
    case 1893:  /* pred_ashrvnx32hi_scalar */
    case 1892:  /* pred_ashlvnx32hi_scalar */
    case 1702:  /* pred_umodvnx32hi */
    case 1701:  /* pred_modvnx32hi */
    case 1700:  /* pred_udivvnx32hi */
    case 1699:  /* pred_divvnx32hi */
    case 1698:  /* pred_mulvnx32hi */
    case 1697:  /* pred_uminvnx32hi */
    case 1696:  /* pred_sminvnx32hi */
    case 1695:  /* pred_umaxvnx32hi */
    case 1694:  /* pred_smaxvnx32hi */
    case 1693:  /* pred_lshrvnx32hi */
    case 1692:  /* pred_ashrvnx32hi */
    case 1691:  /* pred_ashlvnx32hi */
    case 1690:  /* pred_xorvnx32hi */
    case 1689:  /* pred_iorvnx32hi */
    case 1688:  /* pred_andvnx32hi */
    case 1687:  /* pred_subvnx32hi */
    case 1686:  /* pred_addvnx32hi */
    case 1479:  /* pred_indexed_ustorevnx32hivnx32hi */
    case 1478:  /* pred_indexed_ostorevnx32hivnx32hi */
    case 1477:  /* pred_indexed_ustorevnx32hivnx32qi */
    case 1476:  /* pred_indexed_ostorevnx32hivnx32qi */
    case 1103:  /* pred_indexed_uloadvnx32hi_x2_greater_eew */
    case 1102:  /* pred_indexed_oloadvnx32hi_x2_greater_eew */
    case 1055:  /* pred_indexed_uloadvnx32hi_same_eew */
    case 1054:  /* pred_indexed_oloadvnx32hi_same_eew */
    case 1011:  /* pred_strided_storevnx32hi */
    case 980:  /* pred_strided_loadvnx32hi */
    case 945:  /* *pred_broadcastvnx32hi */
    case 919:  /* pred_mergevnx32hi_scalar */
    case 888:  /* pred_mergevnx32hi */
    case 843:  /* pred_storevnx32hi */
    case 812:  /* pred_movvnx32hi */
    case 732:  /* *movvnx32hi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 124 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx32HImode));

    case 6048:  /* pred_fault_loadvnx16hi */
    case 6015:  /* pred_compressvnx16hi */
    case 5984:  /* pred_gatherei16vnx16hi */
    case 5954:  /* pred_gathervnx16hi_scalar */
    case 5923:  /* pred_gathervnx16hi */
    case 5865:  /* pred_slide1downvnx16hi */
    case 5864:  /* pred_slide1upvnx16hi */
    case 5803:  /* pred_slidedownvnx16hi */
    case 5802:  /* pred_slideupvnx16hi */
    case 5756:  /* *pred_extract_firstvnx16hi */
    case 5682:  /* pred_widen_reduc_plusuvnx16hivnx1si */
    case 5681:  /* pred_widen_reduc_plusvnx16hivnx1si */
    case 5648:  /* pred_widen_reduc_plusuvnx16hivnx2si */
    case 5647:  /* pred_widen_reduc_plusvnx16hivnx2si */
    case 5592:  /* pred_reduc_xorvnx16hivnx2hi */
    case 5591:  /* pred_reduc_orvnx16hivnx2hi */
    case 5590:  /* pred_reduc_andvnx16hivnx2hi */
    case 5589:  /* pred_reduc_minvnx16hivnx2hi */
    case 5588:  /* pred_reduc_minuvnx16hivnx2hi */
    case 5587:  /* pred_reduc_maxvnx16hivnx2hi */
    case 5586:  /* pred_reduc_maxuvnx16hivnx2hi */
    case 5585:  /* pred_reduc_sumvnx16hivnx2hi */
    case 5424:  /* pred_reduc_xorvnx16hivnx4hi */
    case 5423:  /* pred_reduc_orvnx16hivnx4hi */
    case 5422:  /* pred_reduc_andvnx16hivnx4hi */
    case 5421:  /* pred_reduc_minvnx16hivnx4hi */
    case 5420:  /* pred_reduc_minuvnx16hivnx4hi */
    case 5419:  /* pred_reduc_maxvnx16hivnx4hi */
    case 5418:  /* pred_reduc_maxuvnx16hivnx4hi */
    case 5417:  /* pred_reduc_sumvnx16hivnx4hi */
    case 5304:  /* pred_narrow_fixuns_truncvnx16sf */
    case 5303:  /* pred_narrow_fix_truncvnx16sf */
    case 5286:  /* pred_narrow_fcvt_xu_fvnx16sf */
    case 5285:  /* pred_narrow_fcvt_x_fvnx16sf */
    case 5264:  /* pred_widen_floatunsvnx16sf */
    case 5263:  /* pred_widen_floatvnx16sf */
    case 4589:  /* pred_seriesvnx16hi */
    case 4567:  /* pred_iotavnx16hi */
    case 4439:  /* pred_widen_mul_plususvnx16si_scalar */
    case 4424:  /* pred_widen_mul_plussuvnx16si_scalar */
    case 4409:  /* pred_widen_mul_plussuvnx16si */
    case 4390:  /* pred_widen_mul_plusuvnx16si_scalar */
    case 4389:  /* pred_widen_mul_plussvnx16si_scalar */
    case 4360:  /* pred_widen_mul_plusuvnx16si */
    case 4359:  /* pred_widen_mul_plussvnx16si */
    case 4316:  /* *pred_minus_mulvnx16hi_scalar */
    case 4294:  /* *pred_nmsacvnx16hi_scalar */
    case 4272:  /* *pred_nmsubvnx16hi_scalar */
    case 4250:  /* *pred_minus_mulvnx16hi */
    case 4228:  /* *pred_nmsacvnx16hi */
    case 4206:  /* *pred_nmsubvnx16hi */
    case 4172:  /* *pred_mul_plusvnx16hi_scalar */
    case 4150:  /* *pred_maccvnx16hi_scalar */
    case 4128:  /* *pred_maddvnx16hi_scalar */
    case 4106:  /* *pred_mul_plusvnx16hi */
    case 4084:  /* *pred_maccvnx16hi */
    case 4062:  /* *pred_maddvnx16hi */
    case 4012:  /* *pred_eqnevnx16hi_scalar_narrow */
    case 3994:  /* *pred_eqnevnx16hi_scalar */
    case 3976:  /* *pred_cmpvnx16hi_scalar_narrow */
    case 3958:  /* *pred_cmpvnx16hi_scalar */
    case 3936:  /* *pred_ltgevnx16hi_narrow */
    case 3914:  /* *pred_ltgevnx16hi */
    case 3892:  /* *pred_cmpvnx16hi_narrow */
    case 3870:  /* *pred_cmpvnx16hi */
    case 3850:  /* pred_narrow_clipuvnx16si_scalar */
    case 3849:  /* pred_narrow_clipvnx16si_scalar */
    case 3820:  /* pred_narrow_clipuvnx16si */
    case 3819:  /* pred_narrow_clipvnx16si */
    case 3738:  /* pred_ssravnx16hi_scalar */
    case 3737:  /* pred_ssrlvnx16hi_scalar */
    case 3684:  /* pred_smulvnx16hi_scalar */
    case 3683:  /* pred_asubvnx16hi_scalar */
    case 3682:  /* pred_asubuvnx16hi_scalar */
    case 3681:  /* pred_aaddvnx16hi_scalar */
    case 3680:  /* pred_aadduvnx16hi_scalar */
    case 3554:  /* pred_ssravnx16hi */
    case 3553:  /* pred_ssrlvnx16hi */
    case 3552:  /* pred_smulvnx16hi */
    case 3551:  /* pred_asubvnx16hi */
    case 3550:  /* pred_asubuvnx16hi */
    case 3549:  /* pred_aaddvnx16hi */
    case 3548:  /* pred_aadduvnx16hi */
    case 3426:  /* pred_ussubvnx16hi_scalar */
    case 3425:  /* pred_sssubvnx16hi_scalar */
    case 3390:  /* pred_usaddvnx16hi_scalar */
    case 3389:  /* pred_ssaddvnx16hi_scalar */
    case 3326:  /* pred_ussubvnx16hi */
    case 3325:  /* pred_usaddvnx16hi */
    case 3324:  /* pred_sssubvnx16hi */
    case 3323:  /* pred_ssaddvnx16hi */
    case 3274:  /* pred_truncvnx16si */
    case 3255:  /* pred_narrow_lshrvnx16si_scalar */
    case 3254:  /* pred_narrow_ashrvnx16si_scalar */
    case 3225:  /* pred_narrow_lshrvnx16si */
    case 3224:  /* pred_narrow_ashrvnx16si */
    case 3195:  /* pred_zero_extendvnx16si */
    case 3194:  /* pred_extendvnx16si */
    case 3169:  /* pred_widen_mulsuvnx16si_scalar */
    case 3154:  /* pred_widen_mulsuvnx16si */
    case 3127:  /* pred_single_widen_subuvnx16si_scalar */
    case 3126:  /* pred_single_widen_adduvnx16si_scalar */
    case 3125:  /* pred_single_widen_subsvnx16si_scalar */
    case 3124:  /* pred_single_widen_addsvnx16si_scalar */
    case 3067:  /* pred_single_widen_subuvnx16si */
    case 3066:  /* pred_single_widen_adduvnx16si */
    case 3065:  /* pred_single_widen_subsvnx16si */
    case 3064:  /* pred_single_widen_addsvnx16si */
    case 2999:  /* pred_dual_widen_muluvnx16si_scalar */
    case 2998:  /* pred_dual_widen_subuvnx16si_scalar */
    case 2997:  /* pred_dual_widen_adduvnx16si_scalar */
    case 2996:  /* pred_dual_widen_mulsvnx16si_scalar */
    case 2995:  /* pred_dual_widen_subsvnx16si_scalar */
    case 2994:  /* pred_dual_widen_addsvnx16si_scalar */
    case 2909:  /* pred_dual_widen_muluvnx16si */
    case 2908:  /* pred_dual_widen_subuvnx16si */
    case 2907:  /* pred_dual_widen_adduvnx16si */
    case 2906:  /* pred_dual_widen_mulsvnx16si */
    case 2905:  /* pred_dual_widen_subsvnx16si */
    case 2904:  /* pred_dual_widen_addsvnx16si */
    case 2797:  /* pred_zero_extendvnx16hi_vf2 */
    case 2796:  /* pred_extendvnx16hi_vf2 */
    case 2767:  /* pred_one_cmplvnx16hi */
    case 2766:  /* pred_negvnx16hi */
    case 2721:  /* pred_msbcvnx16hi_overflow_scalar */
    case 2703:  /* pred_madcvnx16hi_overflow_scalar */
    case 2681:  /* pred_msbcvnx16hi_overflow */
    case 2659:  /* pred_madcvnx16hi_overflow */
    case 2625:  /* pred_msbcvnx16hi_scalar */
    case 2607:  /* pred_madcvnx16hi_scalar */
    case 2585:  /* pred_msbcvnx16hi */
    case 2563:  /* pred_madcvnx16hi */
    case 2529:  /* pred_sbcvnx16hi_scalar */
    case 2511:  /* pred_adcvnx16hi_scalar */
    case 2489:  /* pred_sbcvnx16hi */
    case 2467:  /* pred_adcvnx16hi */
    case 2413:  /* pred_mulhsuvnx16hi_scalar */
    case 2412:  /* pred_mulhuvnx16hi_scalar */
    case 2411:  /* pred_mulhvnx16hi_scalar */
    case 2347:  /* pred_mulhsuvnx16hi */
    case 2346:  /* pred_mulhuvnx16hi */
    case 2345:  /* pred_mulhvnx16hi */
    case 2185:  /* pred_subvnx16hi_reverse_scalar */
    case 2143:  /* pred_umodvnx16hi_scalar */
    case 2142:  /* pred_modvnx16hi_scalar */
    case 2141:  /* pred_udivvnx16hi_scalar */
    case 2140:  /* pred_divvnx16hi_scalar */
    case 2139:  /* pred_subvnx16hi_scalar */
    case 2029:  /* pred_mulvnx16hi_scalar */
    case 2028:  /* pred_uminvnx16hi_scalar */
    case 2027:  /* pred_sminvnx16hi_scalar */
    case 2026:  /* pred_umaxvnx16hi_scalar */
    case 2025:  /* pred_smaxvnx16hi_scalar */
    case 2024:  /* pred_xorvnx16hi_scalar */
    case 2023:  /* pred_iorvnx16hi_scalar */
    case 2022:  /* pred_andvnx16hi_scalar */
    case 2021:  /* pred_addvnx16hi_scalar */
    case 1891:  /* pred_lshrvnx16hi_scalar */
    case 1890:  /* pred_ashrvnx16hi_scalar */
    case 1889:  /* pred_ashlvnx16hi_scalar */
    case 1685:  /* pred_umodvnx16hi */
    case 1684:  /* pred_modvnx16hi */
    case 1683:  /* pred_udivvnx16hi */
    case 1682:  /* pred_divvnx16hi */
    case 1681:  /* pred_mulvnx16hi */
    case 1680:  /* pred_uminvnx16hi */
    case 1679:  /* pred_sminvnx16hi */
    case 1678:  /* pred_umaxvnx16hi */
    case 1677:  /* pred_smaxvnx16hi */
    case 1676:  /* pred_lshrvnx16hi */
    case 1675:  /* pred_ashrvnx16hi */
    case 1674:  /* pred_ashlvnx16hi */
    case 1673:  /* pred_xorvnx16hi */
    case 1672:  /* pred_iorvnx16hi */
    case 1671:  /* pred_andvnx16hi */
    case 1670:  /* pred_subvnx16hi */
    case 1669:  /* pred_addvnx16hi */
    case 1467:  /* pred_indexed_ustorevnx16hivnx16si */
    case 1466:  /* pred_indexed_ostorevnx16hivnx16si */
    case 1459:  /* pred_indexed_ustorevnx16hivnx16hi */
    case 1458:  /* pred_indexed_ostorevnx16hivnx16hi */
    case 1451:  /* pred_indexed_ustorevnx16hivnx16qi */
    case 1450:  /* pred_indexed_ostorevnx16hivnx16qi */
    case 1213:  /* pred_indexed_uloadvnx16hi_x2_smaller_eew */
    case 1212:  /* pred_indexed_oloadvnx16hi_x2_smaller_eew */
    case 1101:  /* pred_indexed_uloadvnx16hi_x2_greater_eew */
    case 1100:  /* pred_indexed_oloadvnx16hi_x2_greater_eew */
    case 1053:  /* pred_indexed_uloadvnx16hi_same_eew */
    case 1052:  /* pred_indexed_oloadvnx16hi_same_eew */
    case 1010:  /* pred_strided_storevnx16hi */
    case 979:  /* pred_strided_loadvnx16hi */
    case 944:  /* *pred_broadcastvnx16hi */
    case 918:  /* pred_mergevnx16hi_scalar */
    case 887:  /* pred_mergevnx16hi */
    case 842:  /* pred_storevnx16hi */
    case 811:  /* pred_movvnx16hi */
    case 731:  /* *movvnx16hi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 122 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx16HImode));

    case 6047:  /* pred_fault_loadvnx8hi */
    case 6014:  /* pred_compressvnx8hi */
    case 5983:  /* pred_gatherei16vnx8hi */
    case 5953:  /* pred_gathervnx8hi_scalar */
    case 5922:  /* pred_gathervnx8hi */
    case 5863:  /* pred_slide1downvnx8hi */
    case 5862:  /* pred_slide1upvnx8hi */
    case 5801:  /* pred_slidedownvnx8hi */
    case 5800:  /* pred_slideupvnx8hi */
    case 5755:  /* *pred_extract_firstvnx8hi */
    case 5680:  /* pred_widen_reduc_plusuvnx8hivnx1si */
    case 5679:  /* pred_widen_reduc_plusvnx8hivnx1si */
    case 5646:  /* pred_widen_reduc_plusuvnx8hivnx2si */
    case 5645:  /* pred_widen_reduc_plusvnx8hivnx2si */
    case 5584:  /* pred_reduc_xorvnx8hivnx2hi */
    case 5583:  /* pred_reduc_orvnx8hivnx2hi */
    case 5582:  /* pred_reduc_andvnx8hivnx2hi */
    case 5581:  /* pred_reduc_minvnx8hivnx2hi */
    case 5580:  /* pred_reduc_minuvnx8hivnx2hi */
    case 5579:  /* pred_reduc_maxvnx8hivnx2hi */
    case 5578:  /* pred_reduc_maxuvnx8hivnx2hi */
    case 5577:  /* pred_reduc_sumvnx8hivnx2hi */
    case 5416:  /* pred_reduc_xorvnx8hivnx4hi */
    case 5415:  /* pred_reduc_orvnx8hivnx4hi */
    case 5414:  /* pred_reduc_andvnx8hivnx4hi */
    case 5413:  /* pred_reduc_minvnx8hivnx4hi */
    case 5412:  /* pred_reduc_minuvnx8hivnx4hi */
    case 5411:  /* pred_reduc_maxvnx8hivnx4hi */
    case 5410:  /* pred_reduc_maxuvnx8hivnx4hi */
    case 5409:  /* pred_reduc_sumvnx8hivnx4hi */
    case 5302:  /* pred_narrow_fixuns_truncvnx8sf */
    case 5301:  /* pred_narrow_fix_truncvnx8sf */
    case 5284:  /* pred_narrow_fcvt_xu_fvnx8sf */
    case 5283:  /* pred_narrow_fcvt_x_fvnx8sf */
    case 5262:  /* pred_widen_floatunsvnx8sf */
    case 5261:  /* pred_widen_floatvnx8sf */
    case 4588:  /* pred_seriesvnx8hi */
    case 4566:  /* pred_iotavnx8hi */
    case 4438:  /* pred_widen_mul_plususvnx8si_scalar */
    case 4423:  /* pred_widen_mul_plussuvnx8si_scalar */
    case 4408:  /* pred_widen_mul_plussuvnx8si */
    case 4388:  /* pred_widen_mul_plusuvnx8si_scalar */
    case 4387:  /* pred_widen_mul_plussvnx8si_scalar */
    case 4358:  /* pred_widen_mul_plusuvnx8si */
    case 4357:  /* pred_widen_mul_plussvnx8si */
    case 4315:  /* *pred_minus_mulvnx8hi_scalar */
    case 4293:  /* *pred_nmsacvnx8hi_scalar */
    case 4271:  /* *pred_nmsubvnx8hi_scalar */
    case 4249:  /* *pred_minus_mulvnx8hi */
    case 4227:  /* *pred_nmsacvnx8hi */
    case 4205:  /* *pred_nmsubvnx8hi */
    case 4171:  /* *pred_mul_plusvnx8hi_scalar */
    case 4149:  /* *pred_maccvnx8hi_scalar */
    case 4127:  /* *pred_maddvnx8hi_scalar */
    case 4105:  /* *pred_mul_plusvnx8hi */
    case 4083:  /* *pred_maccvnx8hi */
    case 4061:  /* *pred_maddvnx8hi */
    case 4011:  /* *pred_eqnevnx8hi_scalar_narrow */
    case 3993:  /* *pred_eqnevnx8hi_scalar */
    case 3975:  /* *pred_cmpvnx8hi_scalar_narrow */
    case 3957:  /* *pred_cmpvnx8hi_scalar */
    case 3935:  /* *pred_ltgevnx8hi_narrow */
    case 3913:  /* *pred_ltgevnx8hi */
    case 3891:  /* *pred_cmpvnx8hi_narrow */
    case 3869:  /* *pred_cmpvnx8hi */
    case 3848:  /* pred_narrow_clipuvnx8si_scalar */
    case 3847:  /* pred_narrow_clipvnx8si_scalar */
    case 3818:  /* pred_narrow_clipuvnx8si */
    case 3817:  /* pred_narrow_clipvnx8si */
    case 3736:  /* pred_ssravnx8hi_scalar */
    case 3735:  /* pred_ssrlvnx8hi_scalar */
    case 3679:  /* pred_smulvnx8hi_scalar */
    case 3678:  /* pred_asubvnx8hi_scalar */
    case 3677:  /* pred_asubuvnx8hi_scalar */
    case 3676:  /* pred_aaddvnx8hi_scalar */
    case 3675:  /* pred_aadduvnx8hi_scalar */
    case 3547:  /* pred_ssravnx8hi */
    case 3546:  /* pred_ssrlvnx8hi */
    case 3545:  /* pred_smulvnx8hi */
    case 3544:  /* pred_asubvnx8hi */
    case 3543:  /* pred_asubuvnx8hi */
    case 3542:  /* pred_aaddvnx8hi */
    case 3541:  /* pred_aadduvnx8hi */
    case 3424:  /* pred_ussubvnx8hi_scalar */
    case 3423:  /* pred_sssubvnx8hi_scalar */
    case 3388:  /* pred_usaddvnx8hi_scalar */
    case 3387:  /* pred_ssaddvnx8hi_scalar */
    case 3322:  /* pred_ussubvnx8hi */
    case 3321:  /* pred_usaddvnx8hi */
    case 3320:  /* pred_sssubvnx8hi */
    case 3319:  /* pred_ssaddvnx8hi */
    case 3273:  /* pred_truncvnx8si */
    case 3253:  /* pred_narrow_lshrvnx8si_scalar */
    case 3252:  /* pred_narrow_ashrvnx8si_scalar */
    case 3223:  /* pred_narrow_lshrvnx8si */
    case 3222:  /* pred_narrow_ashrvnx8si */
    case 3193:  /* pred_zero_extendvnx8si */
    case 3192:  /* pred_extendvnx8si */
    case 3168:  /* pred_widen_mulsuvnx8si_scalar */
    case 3153:  /* pred_widen_mulsuvnx8si */
    case 3123:  /* pred_single_widen_subuvnx8si_scalar */
    case 3122:  /* pred_single_widen_adduvnx8si_scalar */
    case 3121:  /* pred_single_widen_subsvnx8si_scalar */
    case 3120:  /* pred_single_widen_addsvnx8si_scalar */
    case 3063:  /* pred_single_widen_subuvnx8si */
    case 3062:  /* pred_single_widen_adduvnx8si */
    case 3061:  /* pred_single_widen_subsvnx8si */
    case 3060:  /* pred_single_widen_addsvnx8si */
    case 2993:  /* pred_dual_widen_muluvnx8si_scalar */
    case 2992:  /* pred_dual_widen_subuvnx8si_scalar */
    case 2991:  /* pred_dual_widen_adduvnx8si_scalar */
    case 2990:  /* pred_dual_widen_mulsvnx8si_scalar */
    case 2989:  /* pred_dual_widen_subsvnx8si_scalar */
    case 2988:  /* pred_dual_widen_addsvnx8si_scalar */
    case 2903:  /* pred_dual_widen_muluvnx8si */
    case 2902:  /* pred_dual_widen_subuvnx8si */
    case 2901:  /* pred_dual_widen_adduvnx8si */
    case 2900:  /* pred_dual_widen_mulsvnx8si */
    case 2899:  /* pred_dual_widen_subsvnx8si */
    case 2898:  /* pred_dual_widen_addsvnx8si */
    case 2795:  /* pred_zero_extendvnx8hi_vf2 */
    case 2794:  /* pred_extendvnx8hi_vf2 */
    case 2765:  /* pred_one_cmplvnx8hi */
    case 2764:  /* pred_negvnx8hi */
    case 2720:  /* pred_msbcvnx8hi_overflow_scalar */
    case 2702:  /* pred_madcvnx8hi_overflow_scalar */
    case 2680:  /* pred_msbcvnx8hi_overflow */
    case 2658:  /* pred_madcvnx8hi_overflow */
    case 2624:  /* pred_msbcvnx8hi_scalar */
    case 2606:  /* pred_madcvnx8hi_scalar */
    case 2584:  /* pred_msbcvnx8hi */
    case 2562:  /* pred_madcvnx8hi */
    case 2528:  /* pred_sbcvnx8hi_scalar */
    case 2510:  /* pred_adcvnx8hi_scalar */
    case 2488:  /* pred_sbcvnx8hi */
    case 2466:  /* pred_adcvnx8hi */
    case 2410:  /* pred_mulhsuvnx8hi_scalar */
    case 2409:  /* pred_mulhuvnx8hi_scalar */
    case 2408:  /* pred_mulhvnx8hi_scalar */
    case 2344:  /* pred_mulhsuvnx8hi */
    case 2343:  /* pred_mulhuvnx8hi */
    case 2342:  /* pred_mulhvnx8hi */
    case 2184:  /* pred_subvnx8hi_reverse_scalar */
    case 2138:  /* pred_umodvnx8hi_scalar */
    case 2137:  /* pred_modvnx8hi_scalar */
    case 2136:  /* pred_udivvnx8hi_scalar */
    case 2135:  /* pred_divvnx8hi_scalar */
    case 2134:  /* pred_subvnx8hi_scalar */
    case 2020:  /* pred_mulvnx8hi_scalar */
    case 2019:  /* pred_uminvnx8hi_scalar */
    case 2018:  /* pred_sminvnx8hi_scalar */
    case 2017:  /* pred_umaxvnx8hi_scalar */
    case 2016:  /* pred_smaxvnx8hi_scalar */
    case 2015:  /* pred_xorvnx8hi_scalar */
    case 2014:  /* pred_iorvnx8hi_scalar */
    case 2013:  /* pred_andvnx8hi_scalar */
    case 2012:  /* pred_addvnx8hi_scalar */
    case 1888:  /* pred_lshrvnx8hi_scalar */
    case 1887:  /* pred_ashrvnx8hi_scalar */
    case 1886:  /* pred_ashlvnx8hi_scalar */
    case 1668:  /* pred_umodvnx8hi */
    case 1667:  /* pred_modvnx8hi */
    case 1666:  /* pred_udivvnx8hi */
    case 1665:  /* pred_divvnx8hi */
    case 1664:  /* pred_mulvnx8hi */
    case 1663:  /* pred_uminvnx8hi */
    case 1662:  /* pred_sminvnx8hi */
    case 1661:  /* pred_umaxvnx8hi */
    case 1660:  /* pred_smaxvnx8hi */
    case 1659:  /* pred_lshrvnx8hi */
    case 1658:  /* pred_ashrvnx8hi */
    case 1657:  /* pred_ashlvnx8hi */
    case 1656:  /* pred_xorvnx8hi */
    case 1655:  /* pred_iorvnx8hi */
    case 1654:  /* pred_andvnx8hi */
    case 1653:  /* pred_subvnx8hi */
    case 1652:  /* pred_addvnx8hi */
    case 1439:  /* pred_indexed_ustorevnx8hivnx8di */
    case 1438:  /* pred_indexed_ostorevnx8hivnx8di */
    case 1427:  /* pred_indexed_ustorevnx8hivnx8si */
    case 1426:  /* pred_indexed_ostorevnx8hivnx8si */
    case 1415:  /* pred_indexed_ustorevnx8hivnx8hi */
    case 1414:  /* pred_indexed_ostorevnx8hivnx8hi */
    case 1403:  /* pred_indexed_ustorevnx8hivnx8qi */
    case 1402:  /* pred_indexed_ostorevnx8hivnx8qi */
    case 1247:  /* pred_indexed_uloadvnx8hi_x4_smaller_eew */
    case 1246:  /* pred_indexed_oloadvnx8hi_x4_smaller_eew */
    case 1211:  /* pred_indexed_uloadvnx8hi_x2_smaller_eew */
    case 1210:  /* pred_indexed_oloadvnx8hi_x2_smaller_eew */
    case 1099:  /* pred_indexed_uloadvnx8hi_x2_greater_eew */
    case 1098:  /* pred_indexed_oloadvnx8hi_x2_greater_eew */
    case 1051:  /* pred_indexed_uloadvnx8hi_same_eew */
    case 1050:  /* pred_indexed_oloadvnx8hi_same_eew */
    case 1009:  /* pred_strided_storevnx8hi */
    case 978:  /* pred_strided_loadvnx8hi */
    case 943:  /* *pred_broadcastvnx8hi */
    case 917:  /* pred_mergevnx8hi_scalar */
    case 886:  /* pred_mergevnx8hi */
    case 841:  /* pred_storevnx8hi */
    case 810:  /* pred_movvnx8hi */
    case 730:  /* *movvnx8hi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx8HImode));

    case 6046:  /* pred_fault_loadvnx4hi */
    case 6013:  /* pred_compressvnx4hi */
    case 5982:  /* pred_gatherei16vnx4hi */
    case 5952:  /* pred_gathervnx4hi_scalar */
    case 5921:  /* pred_gathervnx4hi */
    case 5861:  /* pred_slide1downvnx4hi */
    case 5860:  /* pred_slide1upvnx4hi */
    case 5799:  /* pred_slidedownvnx4hi */
    case 5798:  /* pred_slideupvnx4hi */
    case 5754:  /* *pred_extract_firstvnx4hi */
    case 5678:  /* pred_widen_reduc_plusuvnx4hivnx1si */
    case 5677:  /* pred_widen_reduc_plusvnx4hivnx1si */
    case 5644:  /* pred_widen_reduc_plusuvnx4hivnx2si */
    case 5643:  /* pred_widen_reduc_plusvnx4hivnx2si */
    case 5576:  /* pred_reduc_xorvnx4hivnx2hi */
    case 5575:  /* pred_reduc_orvnx4hivnx2hi */
    case 5574:  /* pred_reduc_andvnx4hivnx2hi */
    case 5573:  /* pred_reduc_minvnx4hivnx2hi */
    case 5572:  /* pred_reduc_minuvnx4hivnx2hi */
    case 5571:  /* pred_reduc_maxvnx4hivnx2hi */
    case 5570:  /* pred_reduc_maxuvnx4hivnx2hi */
    case 5569:  /* pred_reduc_sumvnx4hivnx2hi */
    case 5408:  /* pred_reduc_xorvnx4hivnx4hi */
    case 5407:  /* pred_reduc_orvnx4hivnx4hi */
    case 5406:  /* pred_reduc_andvnx4hivnx4hi */
    case 5405:  /* pred_reduc_minvnx4hivnx4hi */
    case 5404:  /* pred_reduc_minuvnx4hivnx4hi */
    case 5403:  /* pred_reduc_maxvnx4hivnx4hi */
    case 5402:  /* pred_reduc_maxuvnx4hivnx4hi */
    case 5401:  /* pred_reduc_sumvnx4hivnx4hi */
    case 5300:  /* pred_narrow_fixuns_truncvnx4sf */
    case 5299:  /* pred_narrow_fix_truncvnx4sf */
    case 5282:  /* pred_narrow_fcvt_xu_fvnx4sf */
    case 5281:  /* pred_narrow_fcvt_x_fvnx4sf */
    case 5260:  /* pred_widen_floatunsvnx4sf */
    case 5259:  /* pred_widen_floatvnx4sf */
    case 4587:  /* pred_seriesvnx4hi */
    case 4565:  /* pred_iotavnx4hi */
    case 4437:  /* pred_widen_mul_plususvnx4si_scalar */
    case 4422:  /* pred_widen_mul_plussuvnx4si_scalar */
    case 4407:  /* pred_widen_mul_plussuvnx4si */
    case 4386:  /* pred_widen_mul_plusuvnx4si_scalar */
    case 4385:  /* pred_widen_mul_plussvnx4si_scalar */
    case 4356:  /* pred_widen_mul_plusuvnx4si */
    case 4355:  /* pred_widen_mul_plussvnx4si */
    case 4314:  /* *pred_minus_mulvnx4hi_scalar */
    case 4292:  /* *pred_nmsacvnx4hi_scalar */
    case 4270:  /* *pred_nmsubvnx4hi_scalar */
    case 4248:  /* *pred_minus_mulvnx4hi */
    case 4226:  /* *pred_nmsacvnx4hi */
    case 4204:  /* *pred_nmsubvnx4hi */
    case 4170:  /* *pred_mul_plusvnx4hi_scalar */
    case 4148:  /* *pred_maccvnx4hi_scalar */
    case 4126:  /* *pred_maddvnx4hi_scalar */
    case 4104:  /* *pred_mul_plusvnx4hi */
    case 4082:  /* *pred_maccvnx4hi */
    case 4060:  /* *pred_maddvnx4hi */
    case 4010:  /* *pred_eqnevnx4hi_scalar_narrow */
    case 3992:  /* *pred_eqnevnx4hi_scalar */
    case 3974:  /* *pred_cmpvnx4hi_scalar_narrow */
    case 3956:  /* *pred_cmpvnx4hi_scalar */
    case 3934:  /* *pred_ltgevnx4hi_narrow */
    case 3912:  /* *pred_ltgevnx4hi */
    case 3890:  /* *pred_cmpvnx4hi_narrow */
    case 3868:  /* *pred_cmpvnx4hi */
    case 3846:  /* pred_narrow_clipuvnx4si_scalar */
    case 3845:  /* pred_narrow_clipvnx4si_scalar */
    case 3816:  /* pred_narrow_clipuvnx4si */
    case 3815:  /* pred_narrow_clipvnx4si */
    case 3734:  /* pred_ssravnx4hi_scalar */
    case 3733:  /* pred_ssrlvnx4hi_scalar */
    case 3674:  /* pred_smulvnx4hi_scalar */
    case 3673:  /* pred_asubvnx4hi_scalar */
    case 3672:  /* pred_asubuvnx4hi_scalar */
    case 3671:  /* pred_aaddvnx4hi_scalar */
    case 3670:  /* pred_aadduvnx4hi_scalar */
    case 3540:  /* pred_ssravnx4hi */
    case 3539:  /* pred_ssrlvnx4hi */
    case 3538:  /* pred_smulvnx4hi */
    case 3537:  /* pred_asubvnx4hi */
    case 3536:  /* pred_asubuvnx4hi */
    case 3535:  /* pred_aaddvnx4hi */
    case 3534:  /* pred_aadduvnx4hi */
    case 3422:  /* pred_ussubvnx4hi_scalar */
    case 3421:  /* pred_sssubvnx4hi_scalar */
    case 3386:  /* pred_usaddvnx4hi_scalar */
    case 3385:  /* pred_ssaddvnx4hi_scalar */
    case 3318:  /* pred_ussubvnx4hi */
    case 3317:  /* pred_usaddvnx4hi */
    case 3316:  /* pred_sssubvnx4hi */
    case 3315:  /* pred_ssaddvnx4hi */
    case 3272:  /* pred_truncvnx4si */
    case 3251:  /* pred_narrow_lshrvnx4si_scalar */
    case 3250:  /* pred_narrow_ashrvnx4si_scalar */
    case 3221:  /* pred_narrow_lshrvnx4si */
    case 3220:  /* pred_narrow_ashrvnx4si */
    case 3191:  /* pred_zero_extendvnx4si */
    case 3190:  /* pred_extendvnx4si */
    case 3167:  /* pred_widen_mulsuvnx4si_scalar */
    case 3152:  /* pred_widen_mulsuvnx4si */
    case 3119:  /* pred_single_widen_subuvnx4si_scalar */
    case 3118:  /* pred_single_widen_adduvnx4si_scalar */
    case 3117:  /* pred_single_widen_subsvnx4si_scalar */
    case 3116:  /* pred_single_widen_addsvnx4si_scalar */
    case 3059:  /* pred_single_widen_subuvnx4si */
    case 3058:  /* pred_single_widen_adduvnx4si */
    case 3057:  /* pred_single_widen_subsvnx4si */
    case 3056:  /* pred_single_widen_addsvnx4si */
    case 2987:  /* pred_dual_widen_muluvnx4si_scalar */
    case 2986:  /* pred_dual_widen_subuvnx4si_scalar */
    case 2985:  /* pred_dual_widen_adduvnx4si_scalar */
    case 2984:  /* pred_dual_widen_mulsvnx4si_scalar */
    case 2983:  /* pred_dual_widen_subsvnx4si_scalar */
    case 2982:  /* pred_dual_widen_addsvnx4si_scalar */
    case 2897:  /* pred_dual_widen_muluvnx4si */
    case 2896:  /* pred_dual_widen_subuvnx4si */
    case 2895:  /* pred_dual_widen_adduvnx4si */
    case 2894:  /* pred_dual_widen_mulsvnx4si */
    case 2893:  /* pred_dual_widen_subsvnx4si */
    case 2892:  /* pred_dual_widen_addsvnx4si */
    case 2793:  /* pred_zero_extendvnx4hi_vf2 */
    case 2792:  /* pred_extendvnx4hi_vf2 */
    case 2763:  /* pred_one_cmplvnx4hi */
    case 2762:  /* pred_negvnx4hi */
    case 2719:  /* pred_msbcvnx4hi_overflow_scalar */
    case 2701:  /* pred_madcvnx4hi_overflow_scalar */
    case 2679:  /* pred_msbcvnx4hi_overflow */
    case 2657:  /* pred_madcvnx4hi_overflow */
    case 2623:  /* pred_msbcvnx4hi_scalar */
    case 2605:  /* pred_madcvnx4hi_scalar */
    case 2583:  /* pred_msbcvnx4hi */
    case 2561:  /* pred_madcvnx4hi */
    case 2527:  /* pred_sbcvnx4hi_scalar */
    case 2509:  /* pred_adcvnx4hi_scalar */
    case 2487:  /* pred_sbcvnx4hi */
    case 2465:  /* pred_adcvnx4hi */
    case 2407:  /* pred_mulhsuvnx4hi_scalar */
    case 2406:  /* pred_mulhuvnx4hi_scalar */
    case 2405:  /* pred_mulhvnx4hi_scalar */
    case 2341:  /* pred_mulhsuvnx4hi */
    case 2340:  /* pred_mulhuvnx4hi */
    case 2339:  /* pred_mulhvnx4hi */
    case 2183:  /* pred_subvnx4hi_reverse_scalar */
    case 2133:  /* pred_umodvnx4hi_scalar */
    case 2132:  /* pred_modvnx4hi_scalar */
    case 2131:  /* pred_udivvnx4hi_scalar */
    case 2130:  /* pred_divvnx4hi_scalar */
    case 2129:  /* pred_subvnx4hi_scalar */
    case 2011:  /* pred_mulvnx4hi_scalar */
    case 2010:  /* pred_uminvnx4hi_scalar */
    case 2009:  /* pred_sminvnx4hi_scalar */
    case 2008:  /* pred_umaxvnx4hi_scalar */
    case 2007:  /* pred_smaxvnx4hi_scalar */
    case 2006:  /* pred_xorvnx4hi_scalar */
    case 2005:  /* pred_iorvnx4hi_scalar */
    case 2004:  /* pred_andvnx4hi_scalar */
    case 2003:  /* pred_addvnx4hi_scalar */
    case 1885:  /* pred_lshrvnx4hi_scalar */
    case 1884:  /* pred_ashrvnx4hi_scalar */
    case 1883:  /* pred_ashlvnx4hi_scalar */
    case 1651:  /* pred_umodvnx4hi */
    case 1650:  /* pred_modvnx4hi */
    case 1649:  /* pred_udivvnx4hi */
    case 1648:  /* pred_divvnx4hi */
    case 1647:  /* pred_mulvnx4hi */
    case 1646:  /* pred_uminvnx4hi */
    case 1645:  /* pred_sminvnx4hi */
    case 1644:  /* pred_umaxvnx4hi */
    case 1643:  /* pred_smaxvnx4hi */
    case 1642:  /* pred_lshrvnx4hi */
    case 1641:  /* pred_ashrvnx4hi */
    case 1640:  /* pred_ashlvnx4hi */
    case 1639:  /* pred_xorvnx4hi */
    case 1638:  /* pred_iorvnx4hi */
    case 1637:  /* pred_andvnx4hi */
    case 1636:  /* pred_subvnx4hi */
    case 1635:  /* pred_addvnx4hi */
    case 1391:  /* pred_indexed_ustorevnx4hivnx4di */
    case 1390:  /* pred_indexed_ostorevnx4hivnx4di */
    case 1379:  /* pred_indexed_ustorevnx4hivnx4si */
    case 1378:  /* pred_indexed_ostorevnx4hivnx4si */
    case 1367:  /* pred_indexed_ustorevnx4hivnx4hi */
    case 1366:  /* pred_indexed_ostorevnx4hivnx4hi */
    case 1355:  /* pred_indexed_ustorevnx4hivnx4qi */
    case 1354:  /* pred_indexed_ostorevnx4hivnx4qi */
    case 1245:  /* pred_indexed_uloadvnx4hi_x4_smaller_eew */
    case 1244:  /* pred_indexed_oloadvnx4hi_x4_smaller_eew */
    case 1209:  /* pred_indexed_uloadvnx4hi_x2_smaller_eew */
    case 1208:  /* pred_indexed_oloadvnx4hi_x2_smaller_eew */
    case 1097:  /* pred_indexed_uloadvnx4hi_x2_greater_eew */
    case 1096:  /* pred_indexed_oloadvnx4hi_x2_greater_eew */
    case 1049:  /* pred_indexed_uloadvnx4hi_same_eew */
    case 1048:  /* pred_indexed_oloadvnx4hi_same_eew */
    case 1008:  /* pred_strided_storevnx4hi */
    case 977:  /* pred_strided_loadvnx4hi */
    case 942:  /* *pred_broadcastvnx4hi */
    case 916:  /* pred_mergevnx4hi_scalar */
    case 885:  /* pred_mergevnx4hi */
    case 840:  /* pred_storevnx4hi */
    case 809:  /* pred_movvnx4hi */
    case 729:  /* *movvnx4hi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 118 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx4HImode));

    case 6045:  /* pred_fault_loadvnx2hi */
    case 6012:  /* pred_compressvnx2hi */
    case 5981:  /* pred_gatherei16vnx2hi */
    case 5951:  /* pred_gathervnx2hi_scalar */
    case 5920:  /* pred_gathervnx2hi */
    case 5859:  /* pred_slide1downvnx2hi */
    case 5858:  /* pred_slide1upvnx2hi */
    case 5797:  /* pred_slidedownvnx2hi */
    case 5796:  /* pred_slideupvnx2hi */
    case 5753:  /* *pred_extract_firstvnx2hi */
    case 5676:  /* pred_widen_reduc_plusuvnx2hivnx1si */
    case 5675:  /* pred_widen_reduc_plusvnx2hivnx1si */
    case 5642:  /* pred_widen_reduc_plusuvnx2hivnx2si */
    case 5641:  /* pred_widen_reduc_plusvnx2hivnx2si */
    case 5568:  /* pred_reduc_xorvnx2hivnx2hi */
    case 5567:  /* pred_reduc_orvnx2hivnx2hi */
    case 5566:  /* pred_reduc_andvnx2hivnx2hi */
    case 5565:  /* pred_reduc_minvnx2hivnx2hi */
    case 5564:  /* pred_reduc_minuvnx2hivnx2hi */
    case 5563:  /* pred_reduc_maxvnx2hivnx2hi */
    case 5562:  /* pred_reduc_maxuvnx2hivnx2hi */
    case 5561:  /* pred_reduc_sumvnx2hivnx2hi */
    case 5400:  /* pred_reduc_xorvnx2hivnx4hi */
    case 5399:  /* pred_reduc_orvnx2hivnx4hi */
    case 5398:  /* pred_reduc_andvnx2hivnx4hi */
    case 5397:  /* pred_reduc_minvnx2hivnx4hi */
    case 5396:  /* pred_reduc_minuvnx2hivnx4hi */
    case 5395:  /* pred_reduc_maxvnx2hivnx4hi */
    case 5394:  /* pred_reduc_maxuvnx2hivnx4hi */
    case 5393:  /* pred_reduc_sumvnx2hivnx4hi */
    case 5298:  /* pred_narrow_fixuns_truncvnx2sf */
    case 5297:  /* pred_narrow_fix_truncvnx2sf */
    case 5280:  /* pred_narrow_fcvt_xu_fvnx2sf */
    case 5279:  /* pred_narrow_fcvt_x_fvnx2sf */
    case 5258:  /* pred_widen_floatunsvnx2sf */
    case 5257:  /* pred_widen_floatvnx2sf */
    case 4586:  /* pred_seriesvnx2hi */
    case 4564:  /* pred_iotavnx2hi */
    case 4436:  /* pred_widen_mul_plususvnx2si_scalar */
    case 4421:  /* pred_widen_mul_plussuvnx2si_scalar */
    case 4406:  /* pred_widen_mul_plussuvnx2si */
    case 4384:  /* pred_widen_mul_plusuvnx2si_scalar */
    case 4383:  /* pred_widen_mul_plussvnx2si_scalar */
    case 4354:  /* pred_widen_mul_plusuvnx2si */
    case 4353:  /* pred_widen_mul_plussvnx2si */
    case 4313:  /* *pred_minus_mulvnx2hi_scalar */
    case 4291:  /* *pred_nmsacvnx2hi_scalar */
    case 4269:  /* *pred_nmsubvnx2hi_scalar */
    case 4247:  /* *pred_minus_mulvnx2hi */
    case 4225:  /* *pred_nmsacvnx2hi */
    case 4203:  /* *pred_nmsubvnx2hi */
    case 4169:  /* *pred_mul_plusvnx2hi_scalar */
    case 4147:  /* *pred_maccvnx2hi_scalar */
    case 4125:  /* *pred_maddvnx2hi_scalar */
    case 4103:  /* *pred_mul_plusvnx2hi */
    case 4081:  /* *pred_maccvnx2hi */
    case 4059:  /* *pred_maddvnx2hi */
    case 4009:  /* *pred_eqnevnx2hi_scalar_narrow */
    case 3991:  /* *pred_eqnevnx2hi_scalar */
    case 3973:  /* *pred_cmpvnx2hi_scalar_narrow */
    case 3955:  /* *pred_cmpvnx2hi_scalar */
    case 3933:  /* *pred_ltgevnx2hi_narrow */
    case 3911:  /* *pred_ltgevnx2hi */
    case 3889:  /* *pred_cmpvnx2hi_narrow */
    case 3867:  /* *pred_cmpvnx2hi */
    case 3844:  /* pred_narrow_clipuvnx2si_scalar */
    case 3843:  /* pred_narrow_clipvnx2si_scalar */
    case 3814:  /* pred_narrow_clipuvnx2si */
    case 3813:  /* pred_narrow_clipvnx2si */
    case 3732:  /* pred_ssravnx2hi_scalar */
    case 3731:  /* pred_ssrlvnx2hi_scalar */
    case 3669:  /* pred_smulvnx2hi_scalar */
    case 3668:  /* pred_asubvnx2hi_scalar */
    case 3667:  /* pred_asubuvnx2hi_scalar */
    case 3666:  /* pred_aaddvnx2hi_scalar */
    case 3665:  /* pred_aadduvnx2hi_scalar */
    case 3533:  /* pred_ssravnx2hi */
    case 3532:  /* pred_ssrlvnx2hi */
    case 3531:  /* pred_smulvnx2hi */
    case 3530:  /* pred_asubvnx2hi */
    case 3529:  /* pred_asubuvnx2hi */
    case 3528:  /* pred_aaddvnx2hi */
    case 3527:  /* pred_aadduvnx2hi */
    case 3420:  /* pred_ussubvnx2hi_scalar */
    case 3419:  /* pred_sssubvnx2hi_scalar */
    case 3384:  /* pred_usaddvnx2hi_scalar */
    case 3383:  /* pred_ssaddvnx2hi_scalar */
    case 3314:  /* pred_ussubvnx2hi */
    case 3313:  /* pred_usaddvnx2hi */
    case 3312:  /* pred_sssubvnx2hi */
    case 3311:  /* pred_ssaddvnx2hi */
    case 3271:  /* pred_truncvnx2si */
    case 3249:  /* pred_narrow_lshrvnx2si_scalar */
    case 3248:  /* pred_narrow_ashrvnx2si_scalar */
    case 3219:  /* pred_narrow_lshrvnx2si */
    case 3218:  /* pred_narrow_ashrvnx2si */
    case 3189:  /* pred_zero_extendvnx2si */
    case 3188:  /* pred_extendvnx2si */
    case 3166:  /* pred_widen_mulsuvnx2si_scalar */
    case 3151:  /* pred_widen_mulsuvnx2si */
    case 3115:  /* pred_single_widen_subuvnx2si_scalar */
    case 3114:  /* pred_single_widen_adduvnx2si_scalar */
    case 3113:  /* pred_single_widen_subsvnx2si_scalar */
    case 3112:  /* pred_single_widen_addsvnx2si_scalar */
    case 3055:  /* pred_single_widen_subuvnx2si */
    case 3054:  /* pred_single_widen_adduvnx2si */
    case 3053:  /* pred_single_widen_subsvnx2si */
    case 3052:  /* pred_single_widen_addsvnx2si */
    case 2981:  /* pred_dual_widen_muluvnx2si_scalar */
    case 2980:  /* pred_dual_widen_subuvnx2si_scalar */
    case 2979:  /* pred_dual_widen_adduvnx2si_scalar */
    case 2978:  /* pred_dual_widen_mulsvnx2si_scalar */
    case 2977:  /* pred_dual_widen_subsvnx2si_scalar */
    case 2976:  /* pred_dual_widen_addsvnx2si_scalar */
    case 2891:  /* pred_dual_widen_muluvnx2si */
    case 2890:  /* pred_dual_widen_subuvnx2si */
    case 2889:  /* pred_dual_widen_adduvnx2si */
    case 2888:  /* pred_dual_widen_mulsvnx2si */
    case 2887:  /* pred_dual_widen_subsvnx2si */
    case 2886:  /* pred_dual_widen_addsvnx2si */
    case 2791:  /* pred_zero_extendvnx2hi_vf2 */
    case 2790:  /* pred_extendvnx2hi_vf2 */
    case 2761:  /* pred_one_cmplvnx2hi */
    case 2760:  /* pred_negvnx2hi */
    case 2718:  /* pred_msbcvnx2hi_overflow_scalar */
    case 2700:  /* pred_madcvnx2hi_overflow_scalar */
    case 2678:  /* pred_msbcvnx2hi_overflow */
    case 2656:  /* pred_madcvnx2hi_overflow */
    case 2622:  /* pred_msbcvnx2hi_scalar */
    case 2604:  /* pred_madcvnx2hi_scalar */
    case 2582:  /* pred_msbcvnx2hi */
    case 2560:  /* pred_madcvnx2hi */
    case 2526:  /* pred_sbcvnx2hi_scalar */
    case 2508:  /* pred_adcvnx2hi_scalar */
    case 2486:  /* pred_sbcvnx2hi */
    case 2464:  /* pred_adcvnx2hi */
    case 2404:  /* pred_mulhsuvnx2hi_scalar */
    case 2403:  /* pred_mulhuvnx2hi_scalar */
    case 2402:  /* pred_mulhvnx2hi_scalar */
    case 2338:  /* pred_mulhsuvnx2hi */
    case 2337:  /* pred_mulhuvnx2hi */
    case 2336:  /* pred_mulhvnx2hi */
    case 2182:  /* pred_subvnx2hi_reverse_scalar */
    case 2128:  /* pred_umodvnx2hi_scalar */
    case 2127:  /* pred_modvnx2hi_scalar */
    case 2126:  /* pred_udivvnx2hi_scalar */
    case 2125:  /* pred_divvnx2hi_scalar */
    case 2124:  /* pred_subvnx2hi_scalar */
    case 2002:  /* pred_mulvnx2hi_scalar */
    case 2001:  /* pred_uminvnx2hi_scalar */
    case 2000:  /* pred_sminvnx2hi_scalar */
    case 1999:  /* pred_umaxvnx2hi_scalar */
    case 1998:  /* pred_smaxvnx2hi_scalar */
    case 1997:  /* pred_xorvnx2hi_scalar */
    case 1996:  /* pred_iorvnx2hi_scalar */
    case 1995:  /* pred_andvnx2hi_scalar */
    case 1994:  /* pred_addvnx2hi_scalar */
    case 1882:  /* pred_lshrvnx2hi_scalar */
    case 1881:  /* pred_ashrvnx2hi_scalar */
    case 1880:  /* pred_ashlvnx2hi_scalar */
    case 1634:  /* pred_umodvnx2hi */
    case 1633:  /* pred_modvnx2hi */
    case 1632:  /* pred_udivvnx2hi */
    case 1631:  /* pred_divvnx2hi */
    case 1630:  /* pred_mulvnx2hi */
    case 1629:  /* pred_uminvnx2hi */
    case 1628:  /* pred_sminvnx2hi */
    case 1627:  /* pred_umaxvnx2hi */
    case 1626:  /* pred_smaxvnx2hi */
    case 1625:  /* pred_lshrvnx2hi */
    case 1624:  /* pred_ashrvnx2hi */
    case 1623:  /* pred_ashlvnx2hi */
    case 1622:  /* pred_xorvnx2hi */
    case 1621:  /* pred_iorvnx2hi */
    case 1620:  /* pred_andvnx2hi */
    case 1619:  /* pred_subvnx2hi */
    case 1618:  /* pred_addvnx2hi */
    case 1343:  /* pred_indexed_ustorevnx2hivnx2di */
    case 1342:  /* pred_indexed_ostorevnx2hivnx2di */
    case 1331:  /* pred_indexed_ustorevnx2hivnx2si */
    case 1330:  /* pred_indexed_ostorevnx2hivnx2si */
    case 1319:  /* pred_indexed_ustorevnx2hivnx2hi */
    case 1318:  /* pred_indexed_ostorevnx2hivnx2hi */
    case 1307:  /* pred_indexed_ustorevnx2hivnx2qi */
    case 1306:  /* pred_indexed_ostorevnx2hivnx2qi */
    case 1243:  /* pred_indexed_uloadvnx2hi_x4_smaller_eew */
    case 1242:  /* pred_indexed_oloadvnx2hi_x4_smaller_eew */
    case 1207:  /* pred_indexed_uloadvnx2hi_x2_smaller_eew */
    case 1206:  /* pred_indexed_oloadvnx2hi_x2_smaller_eew */
    case 1095:  /* pred_indexed_uloadvnx2hi_x2_greater_eew */
    case 1094:  /* pred_indexed_oloadvnx2hi_x2_greater_eew */
    case 1047:  /* pred_indexed_uloadvnx2hi_same_eew */
    case 1046:  /* pred_indexed_oloadvnx2hi_same_eew */
    case 1007:  /* pred_strided_storevnx2hi */
    case 976:  /* pred_strided_loadvnx2hi */
    case 941:  /* *pred_broadcastvnx2hi */
    case 915:  /* pred_mergevnx2hi_scalar */
    case 884:  /* pred_mergevnx2hi */
    case 839:  /* pred_storevnx2hi */
    case 808:  /* pred_movvnx2hi */
    case 755:  /* *movvnx2hi_fract */
    case 728:  /* *movvnx2hi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 116 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx2HImode));

    case 6043:  /* pred_fault_loadvnx64qi */
    case 6010:  /* pred_compressvnx64qi */
    case 5949:  /* pred_gathervnx64qi_scalar */
    case 5918:  /* pred_gathervnx64qi */
    case 5855:  /* pred_slide1downvnx64qi */
    case 5854:  /* pred_slide1upvnx64qi */
    case 5793:  /* pred_slidedownvnx64qi */
    case 5792:  /* pred_slideupvnx64qi */
    case 5751:  /* *pred_extract_firstvnx64qi */
    case 5638:  /* pred_widen_reduc_plusuvnx64qivnx4hi */
    case 5637:  /* pred_widen_reduc_plusvnx64qivnx4hi */
    case 5384:  /* pred_reduc_xorvnx64qivnx8qi */
    case 5383:  /* pred_reduc_orvnx64qivnx8qi */
    case 5382:  /* pred_reduc_andvnx64qivnx8qi */
    case 5381:  /* pred_reduc_minvnx64qivnx8qi */
    case 5380:  /* pred_reduc_minuvnx64qivnx8qi */
    case 5379:  /* pred_reduc_maxvnx64qivnx8qi */
    case 5378:  /* pred_reduc_maxuvnx64qivnx8qi */
    case 5377:  /* pred_reduc_sumvnx64qivnx8qi */
    case 4584:  /* pred_seriesvnx64qi */
    case 4562:  /* pred_iotavnx64qi */
    case 4555:  /* pred_sofvnx64bi */
    case 4554:  /* pred_sifvnx64bi */
    case 4553:  /* pred_sbfvnx64bi */
    case 4534:  /* pred_ffsvnx64bidi */
    case 4527:  /* pred_ffsvnx64bisi */
    case 4520:  /* pred_popcountvnx64bidi */
    case 4513:  /* pred_popcountvnx64bisi */
    case 4506:  /* pred_notvnx64bi */
    case 4499:  /* pred_iornotvnx64bi */
    case 4498:  /* pred_andnotvnx64bi */
    case 4485:  /* pred_nxorvnx64bi */
    case 4484:  /* pred_niorvnx64bi */
    case 4483:  /* pred_nandvnx64bi */
    case 4464:  /* pred_xorvnx64bi */
    case 4463:  /* pred_iorvnx64bi */
    case 4462:  /* pred_andvnx64bi */
    case 4311:  /* *pred_minus_mulvnx64qi_scalar */
    case 4289:  /* *pred_nmsacvnx64qi_scalar */
    case 4267:  /* *pred_nmsubvnx64qi_scalar */
    case 4245:  /* *pred_minus_mulvnx64qi */
    case 4223:  /* *pred_nmsacvnx64qi */
    case 4201:  /* *pred_nmsubvnx64qi */
    case 4167:  /* *pred_mul_plusvnx64qi_scalar */
    case 4145:  /* *pred_maccvnx64qi_scalar */
    case 4123:  /* *pred_maddvnx64qi_scalar */
    case 4101:  /* *pred_mul_plusvnx64qi */
    case 4079:  /* *pred_maccvnx64qi */
    case 4057:  /* *pred_maddvnx64qi */
    case 4007:  /* *pred_eqnevnx64qi_scalar_narrow */
    case 3989:  /* *pred_eqnevnx64qi_scalar */
    case 3971:  /* *pred_cmpvnx64qi_scalar_narrow */
    case 3953:  /* *pred_cmpvnx64qi_scalar */
    case 3931:  /* *pred_ltgevnx64qi_narrow */
    case 3909:  /* *pred_ltgevnx64qi */
    case 3887:  /* *pred_cmpvnx64qi_narrow */
    case 3865:  /* *pred_cmpvnx64qi */
    case 3728:  /* pred_ssravnx64qi_scalar */
    case 3727:  /* pred_ssrlvnx64qi_scalar */
    case 3659:  /* pred_smulvnx64qi_scalar */
    case 3658:  /* pred_asubvnx64qi_scalar */
    case 3657:  /* pred_asubuvnx64qi_scalar */
    case 3656:  /* pred_aaddvnx64qi_scalar */
    case 3655:  /* pred_aadduvnx64qi_scalar */
    case 3519:  /* pred_ssravnx64qi */
    case 3518:  /* pred_ssrlvnx64qi */
    case 3517:  /* pred_smulvnx64qi */
    case 3516:  /* pred_asubvnx64qi */
    case 3515:  /* pred_asubuvnx64qi */
    case 3514:  /* pred_aaddvnx64qi */
    case 3513:  /* pred_aadduvnx64qi */
    case 3416:  /* pred_ussubvnx64qi_scalar */
    case 3415:  /* pred_sssubvnx64qi_scalar */
    case 3380:  /* pred_usaddvnx64qi_scalar */
    case 3379:  /* pred_ssaddvnx64qi_scalar */
    case 3306:  /* pred_ussubvnx64qi */
    case 3305:  /* pred_usaddvnx64qi */
    case 3304:  /* pred_sssubvnx64qi */
    case 3303:  /* pred_ssaddvnx64qi */
    case 2757:  /* pred_one_cmplvnx64qi */
    case 2756:  /* pred_negvnx64qi */
    case 2716:  /* pred_msbcvnx64qi_overflow_scalar */
    case 2698:  /* pred_madcvnx64qi_overflow_scalar */
    case 2676:  /* pred_msbcvnx64qi_overflow */
    case 2654:  /* pred_madcvnx64qi_overflow */
    case 2620:  /* pred_msbcvnx64qi_scalar */
    case 2602:  /* pred_madcvnx64qi_scalar */
    case 2580:  /* pred_msbcvnx64qi */
    case 2558:  /* pred_madcvnx64qi */
    case 2524:  /* pred_sbcvnx64qi_scalar */
    case 2506:  /* pred_adcvnx64qi_scalar */
    case 2484:  /* pred_sbcvnx64qi */
    case 2462:  /* pred_adcvnx64qi */
    case 2398:  /* pred_mulhsuvnx64qi_scalar */
    case 2397:  /* pred_mulhuvnx64qi_scalar */
    case 2396:  /* pred_mulhvnx64qi_scalar */
    case 2332:  /* pred_mulhsuvnx64qi */
    case 2331:  /* pred_mulhuvnx64qi */
    case 2330:  /* pred_mulhvnx64qi */
    case 2180:  /* pred_subvnx64qi_reverse_scalar */
    case 2118:  /* pred_umodvnx64qi_scalar */
    case 2117:  /* pred_modvnx64qi_scalar */
    case 2116:  /* pred_udivvnx64qi_scalar */
    case 2115:  /* pred_divvnx64qi_scalar */
    case 2114:  /* pred_subvnx64qi_scalar */
    case 1984:  /* pred_mulvnx64qi_scalar */
    case 1983:  /* pred_uminvnx64qi_scalar */
    case 1982:  /* pred_sminvnx64qi_scalar */
    case 1981:  /* pred_umaxvnx64qi_scalar */
    case 1980:  /* pred_smaxvnx64qi_scalar */
    case 1979:  /* pred_xorvnx64qi_scalar */
    case 1978:  /* pred_iorvnx64qi_scalar */
    case 1977:  /* pred_andvnx64qi_scalar */
    case 1976:  /* pred_addvnx64qi_scalar */
    case 1876:  /* pred_lshrvnx64qi_scalar */
    case 1875:  /* pred_ashrvnx64qi_scalar */
    case 1874:  /* pred_ashlvnx64qi_scalar */
    case 1600:  /* pred_umodvnx64qi */
    case 1599:  /* pred_modvnx64qi */
    case 1598:  /* pred_udivvnx64qi */
    case 1597:  /* pred_divvnx64qi */
    case 1596:  /* pred_mulvnx64qi */
    case 1595:  /* pred_uminvnx64qi */
    case 1594:  /* pred_sminvnx64qi */
    case 1593:  /* pred_umaxvnx64qi */
    case 1592:  /* pred_smaxvnx64qi */
    case 1591:  /* pred_lshrvnx64qi */
    case 1590:  /* pred_ashrvnx64qi */
    case 1589:  /* pred_ashlvnx64qi */
    case 1588:  /* pred_xorvnx64qi */
    case 1587:  /* pred_iorvnx64qi */
    case 1586:  /* pred_andvnx64qi */
    case 1585:  /* pred_subvnx64qi */
    case 1584:  /* pred_addvnx64qi */
    case 1481:  /* pred_indexed_ustorevnx64qivnx64qi */
    case 1480:  /* pred_indexed_ostorevnx64qivnx64qi */
    case 1043:  /* pred_indexed_uloadvnx64qi_same_eew */
    case 1042:  /* pred_indexed_oloadvnx64qi_same_eew */
    case 1005:  /* pred_strided_storevnx64qi */
    case 974:  /* pred_strided_loadvnx64qi */
    case 939:  /* *pred_broadcastvnx64qi */
    case 913:  /* pred_mergevnx64qi_scalar */
    case 882:  /* pred_mergevnx64qi */
    case 875:  /* pred_storevnx64bi */
    case 868:  /* pred_movvnx64bi */
    case 837:  /* pred_storevnx64qi */
    case 806:  /* pred_movvnx64qi */
    case 764:  /* *movvnx64bi */
    case 727:  /* *movvnx64qi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 112 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx64QImode));

    case 6042:  /* pred_fault_loadvnx32qi */
    case 6009:  /* pred_compressvnx32qi */
    case 5979:  /* pred_gatherei16vnx32qi */
    case 5948:  /* pred_gathervnx32qi_scalar */
    case 5917:  /* pred_gathervnx32qi */
    case 5853:  /* pred_slide1downvnx32qi */
    case 5852:  /* pred_slide1upvnx32qi */
    case 5791:  /* pred_slidedownvnx32qi */
    case 5790:  /* pred_slideupvnx32qi */
    case 5750:  /* *pred_extract_firstvnx32qi */
    case 5672:  /* pred_widen_reduc_plusuvnx32qivnx2hi */
    case 5671:  /* pred_widen_reduc_plusvnx32qivnx2hi */
    case 5636:  /* pred_widen_reduc_plusuvnx32qivnx4hi */
    case 5635:  /* pred_widen_reduc_plusvnx32qivnx4hi */
    case 5552:  /* pred_reduc_xorvnx32qivnx4qi */
    case 5551:  /* pred_reduc_orvnx32qivnx4qi */
    case 5550:  /* pred_reduc_andvnx32qivnx4qi */
    case 5549:  /* pred_reduc_minvnx32qivnx4qi */
    case 5548:  /* pred_reduc_minuvnx32qivnx4qi */
    case 5547:  /* pred_reduc_maxvnx32qivnx4qi */
    case 5546:  /* pred_reduc_maxuvnx32qivnx4qi */
    case 5545:  /* pred_reduc_sumvnx32qivnx4qi */
    case 5376:  /* pred_reduc_xorvnx32qivnx8qi */
    case 5375:  /* pred_reduc_orvnx32qivnx8qi */
    case 5374:  /* pred_reduc_andvnx32qivnx8qi */
    case 5373:  /* pred_reduc_minvnx32qivnx8qi */
    case 5372:  /* pred_reduc_minuvnx32qivnx8qi */
    case 5371:  /* pred_reduc_maxvnx32qivnx8qi */
    case 5370:  /* pred_reduc_maxuvnx32qivnx8qi */
    case 5369:  /* pred_reduc_sumvnx32qivnx8qi */
    case 4583:  /* pred_seriesvnx32qi */
    case 4561:  /* pred_iotavnx32qi */
    case 4552:  /* pred_sofvnx32bi */
    case 4551:  /* pred_sifvnx32bi */
    case 4550:  /* pred_sbfvnx32bi */
    case 4533:  /* pred_ffsvnx32bidi */
    case 4526:  /* pred_ffsvnx32bisi */
    case 4519:  /* pred_popcountvnx32bidi */
    case 4512:  /* pred_popcountvnx32bisi */
    case 4505:  /* pred_notvnx32bi */
    case 4497:  /* pred_iornotvnx32bi */
    case 4496:  /* pred_andnotvnx32bi */
    case 4482:  /* pred_nxorvnx32bi */
    case 4481:  /* pred_niorvnx32bi */
    case 4480:  /* pred_nandvnx32bi */
    case 4461:  /* pred_xorvnx32bi */
    case 4460:  /* pred_iorvnx32bi */
    case 4459:  /* pred_andvnx32bi */
    case 4434:  /* pred_widen_mul_plususvnx32hi_scalar */
    case 4419:  /* pred_widen_mul_plussuvnx32hi_scalar */
    case 4404:  /* pred_widen_mul_plussuvnx32hi */
    case 4380:  /* pred_widen_mul_plusuvnx32hi_scalar */
    case 4379:  /* pred_widen_mul_plussvnx32hi_scalar */
    case 4350:  /* pred_widen_mul_plusuvnx32hi */
    case 4349:  /* pred_widen_mul_plussvnx32hi */
    case 4310:  /* *pred_minus_mulvnx32qi_scalar */
    case 4288:  /* *pred_nmsacvnx32qi_scalar */
    case 4266:  /* *pred_nmsubvnx32qi_scalar */
    case 4244:  /* *pred_minus_mulvnx32qi */
    case 4222:  /* *pred_nmsacvnx32qi */
    case 4200:  /* *pred_nmsubvnx32qi */
    case 4166:  /* *pred_mul_plusvnx32qi_scalar */
    case 4144:  /* *pred_maccvnx32qi_scalar */
    case 4122:  /* *pred_maddvnx32qi_scalar */
    case 4100:  /* *pred_mul_plusvnx32qi */
    case 4078:  /* *pred_maccvnx32qi */
    case 4056:  /* *pred_maddvnx32qi */
    case 4006:  /* *pred_eqnevnx32qi_scalar_narrow */
    case 3988:  /* *pred_eqnevnx32qi_scalar */
    case 3970:  /* *pred_cmpvnx32qi_scalar_narrow */
    case 3952:  /* *pred_cmpvnx32qi_scalar */
    case 3930:  /* *pred_ltgevnx32qi_narrow */
    case 3908:  /* *pred_ltgevnx32qi */
    case 3886:  /* *pred_cmpvnx32qi_narrow */
    case 3864:  /* *pred_cmpvnx32qi */
    case 3840:  /* pred_narrow_clipuvnx32hi_scalar */
    case 3839:  /* pred_narrow_clipvnx32hi_scalar */
    case 3810:  /* pred_narrow_clipuvnx32hi */
    case 3809:  /* pred_narrow_clipvnx32hi */
    case 3726:  /* pred_ssravnx32qi_scalar */
    case 3725:  /* pred_ssrlvnx32qi_scalar */
    case 3654:  /* pred_smulvnx32qi_scalar */
    case 3653:  /* pred_asubvnx32qi_scalar */
    case 3652:  /* pred_asubuvnx32qi_scalar */
    case 3651:  /* pred_aaddvnx32qi_scalar */
    case 3650:  /* pred_aadduvnx32qi_scalar */
    case 3512:  /* pred_ssravnx32qi */
    case 3511:  /* pred_ssrlvnx32qi */
    case 3510:  /* pred_smulvnx32qi */
    case 3509:  /* pred_asubvnx32qi */
    case 3508:  /* pred_asubuvnx32qi */
    case 3507:  /* pred_aaddvnx32qi */
    case 3506:  /* pred_aadduvnx32qi */
    case 3414:  /* pred_ussubvnx32qi_scalar */
    case 3413:  /* pred_sssubvnx32qi_scalar */
    case 3378:  /* pred_usaddvnx32qi_scalar */
    case 3377:  /* pred_ssaddvnx32qi_scalar */
    case 3302:  /* pred_ussubvnx32qi */
    case 3301:  /* pred_usaddvnx32qi */
    case 3300:  /* pred_sssubvnx32qi */
    case 3299:  /* pred_ssaddvnx32qi */
    case 3269:  /* pred_truncvnx32hi */
    case 3245:  /* pred_narrow_lshrvnx32hi_scalar */
    case 3244:  /* pred_narrow_ashrvnx32hi_scalar */
    case 3215:  /* pred_narrow_lshrvnx32hi */
    case 3214:  /* pred_narrow_ashrvnx32hi */
    case 3185:  /* pred_zero_extendvnx32hi */
    case 3184:  /* pred_extendvnx32hi */
    case 3164:  /* pred_widen_mulsuvnx32hi_scalar */
    case 3149:  /* pred_widen_mulsuvnx32hi */
    case 3107:  /* pred_single_widen_subuvnx32hi_scalar */
    case 3106:  /* pred_single_widen_adduvnx32hi_scalar */
    case 3105:  /* pred_single_widen_subsvnx32hi_scalar */
    case 3104:  /* pred_single_widen_addsvnx32hi_scalar */
    case 3047:  /* pred_single_widen_subuvnx32hi */
    case 3046:  /* pred_single_widen_adduvnx32hi */
    case 3045:  /* pred_single_widen_subsvnx32hi */
    case 3044:  /* pred_single_widen_addsvnx32hi */
    case 2969:  /* pred_dual_widen_muluvnx32hi_scalar */
    case 2968:  /* pred_dual_widen_subuvnx32hi_scalar */
    case 2967:  /* pred_dual_widen_adduvnx32hi_scalar */
    case 2966:  /* pred_dual_widen_mulsvnx32hi_scalar */
    case 2965:  /* pred_dual_widen_subsvnx32hi_scalar */
    case 2964:  /* pred_dual_widen_addsvnx32hi_scalar */
    case 2879:  /* pred_dual_widen_muluvnx32hi */
    case 2878:  /* pred_dual_widen_subuvnx32hi */
    case 2877:  /* pred_dual_widen_adduvnx32hi */
    case 2876:  /* pred_dual_widen_mulsvnx32hi */
    case 2875:  /* pred_dual_widen_subsvnx32hi */
    case 2874:  /* pred_dual_widen_addsvnx32hi */
    case 2755:  /* pred_one_cmplvnx32qi */
    case 2754:  /* pred_negvnx32qi */
    case 2715:  /* pred_msbcvnx32qi_overflow_scalar */
    case 2697:  /* pred_madcvnx32qi_overflow_scalar */
    case 2675:  /* pred_msbcvnx32qi_overflow */
    case 2653:  /* pred_madcvnx32qi_overflow */
    case 2619:  /* pred_msbcvnx32qi_scalar */
    case 2601:  /* pred_madcvnx32qi_scalar */
    case 2579:  /* pred_msbcvnx32qi */
    case 2557:  /* pred_madcvnx32qi */
    case 2523:  /* pred_sbcvnx32qi_scalar */
    case 2505:  /* pred_adcvnx32qi_scalar */
    case 2483:  /* pred_sbcvnx32qi */
    case 2461:  /* pred_adcvnx32qi */
    case 2395:  /* pred_mulhsuvnx32qi_scalar */
    case 2394:  /* pred_mulhuvnx32qi_scalar */
    case 2393:  /* pred_mulhvnx32qi_scalar */
    case 2329:  /* pred_mulhsuvnx32qi */
    case 2328:  /* pred_mulhuvnx32qi */
    case 2327:  /* pred_mulhvnx32qi */
    case 2179:  /* pred_subvnx32qi_reverse_scalar */
    case 2113:  /* pred_umodvnx32qi_scalar */
    case 2112:  /* pred_modvnx32qi_scalar */
    case 2111:  /* pred_udivvnx32qi_scalar */
    case 2110:  /* pred_divvnx32qi_scalar */
    case 2109:  /* pred_subvnx32qi_scalar */
    case 1975:  /* pred_mulvnx32qi_scalar */
    case 1974:  /* pred_uminvnx32qi_scalar */
    case 1973:  /* pred_sminvnx32qi_scalar */
    case 1972:  /* pred_umaxvnx32qi_scalar */
    case 1971:  /* pred_smaxvnx32qi_scalar */
    case 1970:  /* pred_xorvnx32qi_scalar */
    case 1969:  /* pred_iorvnx32qi_scalar */
    case 1968:  /* pred_andvnx32qi_scalar */
    case 1967:  /* pred_addvnx32qi_scalar */
    case 1873:  /* pred_lshrvnx32qi_scalar */
    case 1872:  /* pred_ashrvnx32qi_scalar */
    case 1871:  /* pred_ashlvnx32qi_scalar */
    case 1583:  /* pred_umodvnx32qi */
    case 1582:  /* pred_modvnx32qi */
    case 1581:  /* pred_udivvnx32qi */
    case 1580:  /* pred_divvnx32qi */
    case 1579:  /* pred_mulvnx32qi */
    case 1578:  /* pred_uminvnx32qi */
    case 1577:  /* pred_sminvnx32qi */
    case 1576:  /* pred_umaxvnx32qi */
    case 1575:  /* pred_smaxvnx32qi */
    case 1574:  /* pred_lshrvnx32qi */
    case 1573:  /* pred_ashrvnx32qi */
    case 1572:  /* pred_ashlvnx32qi */
    case 1571:  /* pred_xorvnx32qi */
    case 1570:  /* pred_iorvnx32qi */
    case 1569:  /* pred_andvnx32qi */
    case 1568:  /* pred_subvnx32qi */
    case 1567:  /* pred_addvnx32qi */
    case 1475:  /* pred_indexed_ustorevnx32qivnx32hi */
    case 1474:  /* pred_indexed_ostorevnx32qivnx32hi */
    case 1473:  /* pred_indexed_ustorevnx32qivnx32qi */
    case 1472:  /* pred_indexed_ostorevnx32qivnx32qi */
    case 1203:  /* pred_indexed_uloadvnx32qi_x2_smaller_eew */
    case 1202:  /* pred_indexed_oloadvnx32qi_x2_smaller_eew */
    case 1041:  /* pred_indexed_uloadvnx32qi_same_eew */
    case 1040:  /* pred_indexed_oloadvnx32qi_same_eew */
    case 1004:  /* pred_strided_storevnx32qi */
    case 973:  /* pred_strided_loadvnx32qi */
    case 938:  /* *pred_broadcastvnx32qi */
    case 912:  /* pred_mergevnx32qi_scalar */
    case 881:  /* pred_mergevnx32qi */
    case 874:  /* pred_storevnx32bi */
    case 867:  /* pred_movvnx32bi */
    case 836:  /* pred_storevnx32qi */
    case 805:  /* pred_movvnx32qi */
    case 763:  /* *movvnx32bi */
    case 726:  /* *movvnx32qi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 110 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx32QImode));

    case 6041:  /* pred_fault_loadvnx16qi */
    case 6008:  /* pred_compressvnx16qi */
    case 5978:  /* pred_gatherei16vnx16qi */
    case 5947:  /* pred_gathervnx16qi_scalar */
    case 5916:  /* pred_gathervnx16qi */
    case 5851:  /* pred_slide1downvnx16qi */
    case 5850:  /* pred_slide1upvnx16qi */
    case 5789:  /* pred_slidedownvnx16qi */
    case 5788:  /* pred_slideupvnx16qi */
    case 5749:  /* *pred_extract_firstvnx16qi */
    case 5670:  /* pred_widen_reduc_plusuvnx16qivnx2hi */
    case 5669:  /* pred_widen_reduc_plusvnx16qivnx2hi */
    case 5634:  /* pred_widen_reduc_plusuvnx16qivnx4hi */
    case 5633:  /* pred_widen_reduc_plusvnx16qivnx4hi */
    case 5544:  /* pred_reduc_xorvnx16qivnx4qi */
    case 5543:  /* pred_reduc_orvnx16qivnx4qi */
    case 5542:  /* pred_reduc_andvnx16qivnx4qi */
    case 5541:  /* pred_reduc_minvnx16qivnx4qi */
    case 5540:  /* pred_reduc_minuvnx16qivnx4qi */
    case 5539:  /* pred_reduc_maxvnx16qivnx4qi */
    case 5538:  /* pred_reduc_maxuvnx16qivnx4qi */
    case 5537:  /* pred_reduc_sumvnx16qivnx4qi */
    case 5368:  /* pred_reduc_xorvnx16qivnx8qi */
    case 5367:  /* pred_reduc_orvnx16qivnx8qi */
    case 5366:  /* pred_reduc_andvnx16qivnx8qi */
    case 5365:  /* pred_reduc_minvnx16qivnx8qi */
    case 5364:  /* pred_reduc_minuvnx16qivnx8qi */
    case 5363:  /* pred_reduc_maxvnx16qivnx8qi */
    case 5362:  /* pred_reduc_maxuvnx16qivnx8qi */
    case 5361:  /* pred_reduc_sumvnx16qivnx8qi */
    case 4582:  /* pred_seriesvnx16qi */
    case 4560:  /* pred_iotavnx16qi */
    case 4549:  /* pred_sofvnx16bi */
    case 4548:  /* pred_sifvnx16bi */
    case 4547:  /* pred_sbfvnx16bi */
    case 4532:  /* pred_ffsvnx16bidi */
    case 4525:  /* pred_ffsvnx16bisi */
    case 4518:  /* pred_popcountvnx16bidi */
    case 4511:  /* pred_popcountvnx16bisi */
    case 4504:  /* pred_notvnx16bi */
    case 4495:  /* pred_iornotvnx16bi */
    case 4494:  /* pred_andnotvnx16bi */
    case 4479:  /* pred_nxorvnx16bi */
    case 4478:  /* pred_niorvnx16bi */
    case 4477:  /* pred_nandvnx16bi */
    case 4458:  /* pred_xorvnx16bi */
    case 4457:  /* pred_iorvnx16bi */
    case 4456:  /* pred_andvnx16bi */
    case 4433:  /* pred_widen_mul_plususvnx16hi_scalar */
    case 4418:  /* pred_widen_mul_plussuvnx16hi_scalar */
    case 4403:  /* pred_widen_mul_plussuvnx16hi */
    case 4378:  /* pred_widen_mul_plusuvnx16hi_scalar */
    case 4377:  /* pred_widen_mul_plussvnx16hi_scalar */
    case 4348:  /* pred_widen_mul_plusuvnx16hi */
    case 4347:  /* pred_widen_mul_plussvnx16hi */
    case 4309:  /* *pred_minus_mulvnx16qi_scalar */
    case 4287:  /* *pred_nmsacvnx16qi_scalar */
    case 4265:  /* *pred_nmsubvnx16qi_scalar */
    case 4243:  /* *pred_minus_mulvnx16qi */
    case 4221:  /* *pred_nmsacvnx16qi */
    case 4199:  /* *pred_nmsubvnx16qi */
    case 4165:  /* *pred_mul_plusvnx16qi_scalar */
    case 4143:  /* *pred_maccvnx16qi_scalar */
    case 4121:  /* *pred_maddvnx16qi_scalar */
    case 4099:  /* *pred_mul_plusvnx16qi */
    case 4077:  /* *pred_maccvnx16qi */
    case 4055:  /* *pred_maddvnx16qi */
    case 4005:  /* *pred_eqnevnx16qi_scalar_narrow */
    case 3987:  /* *pred_eqnevnx16qi_scalar */
    case 3969:  /* *pred_cmpvnx16qi_scalar_narrow */
    case 3951:  /* *pred_cmpvnx16qi_scalar */
    case 3929:  /* *pred_ltgevnx16qi_narrow */
    case 3907:  /* *pred_ltgevnx16qi */
    case 3885:  /* *pred_cmpvnx16qi_narrow */
    case 3863:  /* *pred_cmpvnx16qi */
    case 3838:  /* pred_narrow_clipuvnx16hi_scalar */
    case 3837:  /* pred_narrow_clipvnx16hi_scalar */
    case 3808:  /* pred_narrow_clipuvnx16hi */
    case 3807:  /* pred_narrow_clipvnx16hi */
    case 3724:  /* pred_ssravnx16qi_scalar */
    case 3723:  /* pred_ssrlvnx16qi_scalar */
    case 3649:  /* pred_smulvnx16qi_scalar */
    case 3648:  /* pred_asubvnx16qi_scalar */
    case 3647:  /* pred_asubuvnx16qi_scalar */
    case 3646:  /* pred_aaddvnx16qi_scalar */
    case 3645:  /* pred_aadduvnx16qi_scalar */
    case 3505:  /* pred_ssravnx16qi */
    case 3504:  /* pred_ssrlvnx16qi */
    case 3503:  /* pred_smulvnx16qi */
    case 3502:  /* pred_asubvnx16qi */
    case 3501:  /* pred_asubuvnx16qi */
    case 3500:  /* pred_aaddvnx16qi */
    case 3499:  /* pred_aadduvnx16qi */
    case 3412:  /* pred_ussubvnx16qi_scalar */
    case 3411:  /* pred_sssubvnx16qi_scalar */
    case 3376:  /* pred_usaddvnx16qi_scalar */
    case 3375:  /* pred_ssaddvnx16qi_scalar */
    case 3298:  /* pred_ussubvnx16qi */
    case 3297:  /* pred_usaddvnx16qi */
    case 3296:  /* pred_sssubvnx16qi */
    case 3295:  /* pred_ssaddvnx16qi */
    case 3268:  /* pred_truncvnx16hi */
    case 3243:  /* pred_narrow_lshrvnx16hi_scalar */
    case 3242:  /* pred_narrow_ashrvnx16hi_scalar */
    case 3213:  /* pred_narrow_lshrvnx16hi */
    case 3212:  /* pred_narrow_ashrvnx16hi */
    case 3183:  /* pred_zero_extendvnx16hi */
    case 3182:  /* pred_extendvnx16hi */
    case 3163:  /* pred_widen_mulsuvnx16hi_scalar */
    case 3148:  /* pred_widen_mulsuvnx16hi */
    case 3103:  /* pred_single_widen_subuvnx16hi_scalar */
    case 3102:  /* pred_single_widen_adduvnx16hi_scalar */
    case 3101:  /* pred_single_widen_subsvnx16hi_scalar */
    case 3100:  /* pred_single_widen_addsvnx16hi_scalar */
    case 3043:  /* pred_single_widen_subuvnx16hi */
    case 3042:  /* pred_single_widen_adduvnx16hi */
    case 3041:  /* pred_single_widen_subsvnx16hi */
    case 3040:  /* pred_single_widen_addsvnx16hi */
    case 2963:  /* pred_dual_widen_muluvnx16hi_scalar */
    case 2962:  /* pred_dual_widen_subuvnx16hi_scalar */
    case 2961:  /* pred_dual_widen_adduvnx16hi_scalar */
    case 2960:  /* pred_dual_widen_mulsvnx16hi_scalar */
    case 2959:  /* pred_dual_widen_subsvnx16hi_scalar */
    case 2958:  /* pred_dual_widen_addsvnx16hi_scalar */
    case 2873:  /* pred_dual_widen_muluvnx16hi */
    case 2872:  /* pred_dual_widen_subuvnx16hi */
    case 2871:  /* pred_dual_widen_adduvnx16hi */
    case 2870:  /* pred_dual_widen_mulsvnx16hi */
    case 2869:  /* pred_dual_widen_subsvnx16hi */
    case 2868:  /* pred_dual_widen_addsvnx16hi */
    case 2753:  /* pred_one_cmplvnx16qi */
    case 2752:  /* pred_negvnx16qi */
    case 2714:  /* pred_msbcvnx16qi_overflow_scalar */
    case 2696:  /* pred_madcvnx16qi_overflow_scalar */
    case 2674:  /* pred_msbcvnx16qi_overflow */
    case 2652:  /* pred_madcvnx16qi_overflow */
    case 2618:  /* pred_msbcvnx16qi_scalar */
    case 2600:  /* pred_madcvnx16qi_scalar */
    case 2578:  /* pred_msbcvnx16qi */
    case 2556:  /* pred_madcvnx16qi */
    case 2522:  /* pred_sbcvnx16qi_scalar */
    case 2504:  /* pred_adcvnx16qi_scalar */
    case 2482:  /* pred_sbcvnx16qi */
    case 2460:  /* pred_adcvnx16qi */
    case 2392:  /* pred_mulhsuvnx16qi_scalar */
    case 2391:  /* pred_mulhuvnx16qi_scalar */
    case 2390:  /* pred_mulhvnx16qi_scalar */
    case 2326:  /* pred_mulhsuvnx16qi */
    case 2325:  /* pred_mulhuvnx16qi */
    case 2324:  /* pred_mulhvnx16qi */
    case 2178:  /* pred_subvnx16qi_reverse_scalar */
    case 2108:  /* pred_umodvnx16qi_scalar */
    case 2107:  /* pred_modvnx16qi_scalar */
    case 2106:  /* pred_udivvnx16qi_scalar */
    case 2105:  /* pred_divvnx16qi_scalar */
    case 2104:  /* pred_subvnx16qi_scalar */
    case 1966:  /* pred_mulvnx16qi_scalar */
    case 1965:  /* pred_uminvnx16qi_scalar */
    case 1964:  /* pred_sminvnx16qi_scalar */
    case 1963:  /* pred_umaxvnx16qi_scalar */
    case 1962:  /* pred_smaxvnx16qi_scalar */
    case 1961:  /* pred_xorvnx16qi_scalar */
    case 1960:  /* pred_iorvnx16qi_scalar */
    case 1959:  /* pred_andvnx16qi_scalar */
    case 1958:  /* pred_addvnx16qi_scalar */
    case 1870:  /* pred_lshrvnx16qi_scalar */
    case 1869:  /* pred_ashrvnx16qi_scalar */
    case 1868:  /* pred_ashlvnx16qi_scalar */
    case 1566:  /* pred_umodvnx16qi */
    case 1565:  /* pred_modvnx16qi */
    case 1564:  /* pred_udivvnx16qi */
    case 1563:  /* pred_divvnx16qi */
    case 1562:  /* pred_mulvnx16qi */
    case 1561:  /* pred_uminvnx16qi */
    case 1560:  /* pred_sminvnx16qi */
    case 1559:  /* pred_umaxvnx16qi */
    case 1558:  /* pred_smaxvnx16qi */
    case 1557:  /* pred_lshrvnx16qi */
    case 1556:  /* pred_ashrvnx16qi */
    case 1555:  /* pred_ashlvnx16qi */
    case 1554:  /* pred_xorvnx16qi */
    case 1553:  /* pred_iorvnx16qi */
    case 1552:  /* pred_andvnx16qi */
    case 1551:  /* pred_subvnx16qi */
    case 1550:  /* pred_addvnx16qi */
    case 1465:  /* pred_indexed_ustorevnx16qivnx16si */
    case 1464:  /* pred_indexed_ostorevnx16qivnx16si */
    case 1457:  /* pred_indexed_ustorevnx16qivnx16hi */
    case 1456:  /* pred_indexed_ostorevnx16qivnx16hi */
    case 1449:  /* pred_indexed_ustorevnx16qivnx16qi */
    case 1448:  /* pred_indexed_ostorevnx16qivnx16qi */
    case 1239:  /* pred_indexed_uloadvnx16qi_x4_smaller_eew */
    case 1238:  /* pred_indexed_oloadvnx16qi_x4_smaller_eew */
    case 1201:  /* pred_indexed_uloadvnx16qi_x2_smaller_eew */
    case 1200:  /* pred_indexed_oloadvnx16qi_x2_smaller_eew */
    case 1039:  /* pred_indexed_uloadvnx16qi_same_eew */
    case 1038:  /* pred_indexed_oloadvnx16qi_same_eew */
    case 1003:  /* pred_strided_storevnx16qi */
    case 972:  /* pred_strided_loadvnx16qi */
    case 937:  /* *pred_broadcastvnx16qi */
    case 911:  /* pred_mergevnx16qi_scalar */
    case 880:  /* pred_mergevnx16qi */
    case 873:  /* pred_storevnx16bi */
    case 866:  /* pred_movvnx16bi */
    case 835:  /* pred_storevnx16qi */
    case 804:  /* pred_movvnx16qi */
    case 762:  /* *movvnx16bi */
    case 725:  /* *movvnx16qi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 108 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx16QImode));

    case 6040:  /* pred_fault_loadvnx8qi */
    case 6007:  /* pred_compressvnx8qi */
    case 5977:  /* pred_gatherei16vnx8qi */
    case 5946:  /* pred_gathervnx8qi_scalar */
    case 5915:  /* pred_gathervnx8qi */
    case 5849:  /* pred_slide1downvnx8qi */
    case 5848:  /* pred_slide1upvnx8qi */
    case 5787:  /* pred_slidedownvnx8qi */
    case 5786:  /* pred_slideupvnx8qi */
    case 5748:  /* *pred_extract_firstvnx8qi */
    case 5668:  /* pred_widen_reduc_plusuvnx8qivnx2hi */
    case 5667:  /* pred_widen_reduc_plusvnx8qivnx2hi */
    case 5632:  /* pred_widen_reduc_plusuvnx8qivnx4hi */
    case 5631:  /* pred_widen_reduc_plusvnx8qivnx4hi */
    case 5536:  /* pred_reduc_xorvnx8qivnx4qi */
    case 5535:  /* pred_reduc_orvnx8qivnx4qi */
    case 5534:  /* pred_reduc_andvnx8qivnx4qi */
    case 5533:  /* pred_reduc_minvnx8qivnx4qi */
    case 5532:  /* pred_reduc_minuvnx8qivnx4qi */
    case 5531:  /* pred_reduc_maxvnx8qivnx4qi */
    case 5530:  /* pred_reduc_maxuvnx8qivnx4qi */
    case 5529:  /* pred_reduc_sumvnx8qivnx4qi */
    case 5360:  /* pred_reduc_xorvnx8qivnx8qi */
    case 5359:  /* pred_reduc_orvnx8qivnx8qi */
    case 5358:  /* pred_reduc_andvnx8qivnx8qi */
    case 5357:  /* pred_reduc_minvnx8qivnx8qi */
    case 5356:  /* pred_reduc_minuvnx8qivnx8qi */
    case 5355:  /* pred_reduc_maxvnx8qivnx8qi */
    case 5354:  /* pred_reduc_maxuvnx8qivnx8qi */
    case 5353:  /* pred_reduc_sumvnx8qivnx8qi */
    case 4581:  /* pred_seriesvnx8qi */
    case 4559:  /* pred_iotavnx8qi */
    case 4546:  /* pred_sofvnx8bi */
    case 4545:  /* pred_sifvnx8bi */
    case 4544:  /* pred_sbfvnx8bi */
    case 4531:  /* pred_ffsvnx8bidi */
    case 4524:  /* pred_ffsvnx8bisi */
    case 4517:  /* pred_popcountvnx8bidi */
    case 4510:  /* pred_popcountvnx8bisi */
    case 4503:  /* pred_notvnx8bi */
    case 4493:  /* pred_iornotvnx8bi */
    case 4492:  /* pred_andnotvnx8bi */
    case 4476:  /* pred_nxorvnx8bi */
    case 4475:  /* pred_niorvnx8bi */
    case 4474:  /* pred_nandvnx8bi */
    case 4455:  /* pred_xorvnx8bi */
    case 4454:  /* pred_iorvnx8bi */
    case 4453:  /* pred_andvnx8bi */
    case 4432:  /* pred_widen_mul_plususvnx8hi_scalar */
    case 4417:  /* pred_widen_mul_plussuvnx8hi_scalar */
    case 4402:  /* pred_widen_mul_plussuvnx8hi */
    case 4376:  /* pred_widen_mul_plusuvnx8hi_scalar */
    case 4375:  /* pred_widen_mul_plussvnx8hi_scalar */
    case 4346:  /* pred_widen_mul_plusuvnx8hi */
    case 4345:  /* pred_widen_mul_plussvnx8hi */
    case 4308:  /* *pred_minus_mulvnx8qi_scalar */
    case 4286:  /* *pred_nmsacvnx8qi_scalar */
    case 4264:  /* *pred_nmsubvnx8qi_scalar */
    case 4242:  /* *pred_minus_mulvnx8qi */
    case 4220:  /* *pred_nmsacvnx8qi */
    case 4198:  /* *pred_nmsubvnx8qi */
    case 4164:  /* *pred_mul_plusvnx8qi_scalar */
    case 4142:  /* *pred_maccvnx8qi_scalar */
    case 4120:  /* *pred_maddvnx8qi_scalar */
    case 4098:  /* *pred_mul_plusvnx8qi */
    case 4076:  /* *pred_maccvnx8qi */
    case 4054:  /* *pred_maddvnx8qi */
    case 4004:  /* *pred_eqnevnx8qi_scalar_narrow */
    case 3986:  /* *pred_eqnevnx8qi_scalar */
    case 3968:  /* *pred_cmpvnx8qi_scalar_narrow */
    case 3950:  /* *pred_cmpvnx8qi_scalar */
    case 3928:  /* *pred_ltgevnx8qi_narrow */
    case 3906:  /* *pred_ltgevnx8qi */
    case 3884:  /* *pred_cmpvnx8qi_narrow */
    case 3862:  /* *pred_cmpvnx8qi */
    case 3836:  /* pred_narrow_clipuvnx8hi_scalar */
    case 3835:  /* pred_narrow_clipvnx8hi_scalar */
    case 3806:  /* pred_narrow_clipuvnx8hi */
    case 3805:  /* pred_narrow_clipvnx8hi */
    case 3722:  /* pred_ssravnx8qi_scalar */
    case 3721:  /* pred_ssrlvnx8qi_scalar */
    case 3644:  /* pred_smulvnx8qi_scalar */
    case 3643:  /* pred_asubvnx8qi_scalar */
    case 3642:  /* pred_asubuvnx8qi_scalar */
    case 3641:  /* pred_aaddvnx8qi_scalar */
    case 3640:  /* pred_aadduvnx8qi_scalar */
    case 3498:  /* pred_ssravnx8qi */
    case 3497:  /* pred_ssrlvnx8qi */
    case 3496:  /* pred_smulvnx8qi */
    case 3495:  /* pred_asubvnx8qi */
    case 3494:  /* pred_asubuvnx8qi */
    case 3493:  /* pred_aaddvnx8qi */
    case 3492:  /* pred_aadduvnx8qi */
    case 3410:  /* pred_ussubvnx8qi_scalar */
    case 3409:  /* pred_sssubvnx8qi_scalar */
    case 3374:  /* pred_usaddvnx8qi_scalar */
    case 3373:  /* pred_ssaddvnx8qi_scalar */
    case 3294:  /* pred_ussubvnx8qi */
    case 3293:  /* pred_usaddvnx8qi */
    case 3292:  /* pred_sssubvnx8qi */
    case 3291:  /* pred_ssaddvnx8qi */
    case 3267:  /* pred_truncvnx8hi */
    case 3241:  /* pred_narrow_lshrvnx8hi_scalar */
    case 3240:  /* pred_narrow_ashrvnx8hi_scalar */
    case 3211:  /* pred_narrow_lshrvnx8hi */
    case 3210:  /* pred_narrow_ashrvnx8hi */
    case 3181:  /* pred_zero_extendvnx8hi */
    case 3180:  /* pred_extendvnx8hi */
    case 3162:  /* pred_widen_mulsuvnx8hi_scalar */
    case 3147:  /* pred_widen_mulsuvnx8hi */
    case 3099:  /* pred_single_widen_subuvnx8hi_scalar */
    case 3098:  /* pred_single_widen_adduvnx8hi_scalar */
    case 3097:  /* pred_single_widen_subsvnx8hi_scalar */
    case 3096:  /* pred_single_widen_addsvnx8hi_scalar */
    case 3039:  /* pred_single_widen_subuvnx8hi */
    case 3038:  /* pred_single_widen_adduvnx8hi */
    case 3037:  /* pred_single_widen_subsvnx8hi */
    case 3036:  /* pred_single_widen_addsvnx8hi */
    case 2957:  /* pred_dual_widen_muluvnx8hi_scalar */
    case 2956:  /* pred_dual_widen_subuvnx8hi_scalar */
    case 2955:  /* pred_dual_widen_adduvnx8hi_scalar */
    case 2954:  /* pred_dual_widen_mulsvnx8hi_scalar */
    case 2953:  /* pred_dual_widen_subsvnx8hi_scalar */
    case 2952:  /* pred_dual_widen_addsvnx8hi_scalar */
    case 2867:  /* pred_dual_widen_muluvnx8hi */
    case 2866:  /* pred_dual_widen_subuvnx8hi */
    case 2865:  /* pred_dual_widen_adduvnx8hi */
    case 2864:  /* pred_dual_widen_mulsvnx8hi */
    case 2863:  /* pred_dual_widen_subsvnx8hi */
    case 2862:  /* pred_dual_widen_addsvnx8hi */
    case 2751:  /* pred_one_cmplvnx8qi */
    case 2750:  /* pred_negvnx8qi */
    case 2713:  /* pred_msbcvnx8qi_overflow_scalar */
    case 2695:  /* pred_madcvnx8qi_overflow_scalar */
    case 2673:  /* pred_msbcvnx8qi_overflow */
    case 2651:  /* pred_madcvnx8qi_overflow */
    case 2617:  /* pred_msbcvnx8qi_scalar */
    case 2599:  /* pred_madcvnx8qi_scalar */
    case 2577:  /* pred_msbcvnx8qi */
    case 2555:  /* pred_madcvnx8qi */
    case 2521:  /* pred_sbcvnx8qi_scalar */
    case 2503:  /* pred_adcvnx8qi_scalar */
    case 2481:  /* pred_sbcvnx8qi */
    case 2459:  /* pred_adcvnx8qi */
    case 2389:  /* pred_mulhsuvnx8qi_scalar */
    case 2388:  /* pred_mulhuvnx8qi_scalar */
    case 2387:  /* pred_mulhvnx8qi_scalar */
    case 2323:  /* pred_mulhsuvnx8qi */
    case 2322:  /* pred_mulhuvnx8qi */
    case 2321:  /* pred_mulhvnx8qi */
    case 2177:  /* pred_subvnx8qi_reverse_scalar */
    case 2103:  /* pred_umodvnx8qi_scalar */
    case 2102:  /* pred_modvnx8qi_scalar */
    case 2101:  /* pred_udivvnx8qi_scalar */
    case 2100:  /* pred_divvnx8qi_scalar */
    case 2099:  /* pred_subvnx8qi_scalar */
    case 1957:  /* pred_mulvnx8qi_scalar */
    case 1956:  /* pred_uminvnx8qi_scalar */
    case 1955:  /* pred_sminvnx8qi_scalar */
    case 1954:  /* pred_umaxvnx8qi_scalar */
    case 1953:  /* pred_smaxvnx8qi_scalar */
    case 1952:  /* pred_xorvnx8qi_scalar */
    case 1951:  /* pred_iorvnx8qi_scalar */
    case 1950:  /* pred_andvnx8qi_scalar */
    case 1949:  /* pred_addvnx8qi_scalar */
    case 1867:  /* pred_lshrvnx8qi_scalar */
    case 1866:  /* pred_ashrvnx8qi_scalar */
    case 1865:  /* pred_ashlvnx8qi_scalar */
    case 1549:  /* pred_umodvnx8qi */
    case 1548:  /* pred_modvnx8qi */
    case 1547:  /* pred_udivvnx8qi */
    case 1546:  /* pred_divvnx8qi */
    case 1545:  /* pred_mulvnx8qi */
    case 1544:  /* pred_uminvnx8qi */
    case 1543:  /* pred_sminvnx8qi */
    case 1542:  /* pred_umaxvnx8qi */
    case 1541:  /* pred_smaxvnx8qi */
    case 1540:  /* pred_lshrvnx8qi */
    case 1539:  /* pred_ashrvnx8qi */
    case 1538:  /* pred_ashlvnx8qi */
    case 1537:  /* pred_xorvnx8qi */
    case 1536:  /* pred_iorvnx8qi */
    case 1535:  /* pred_andvnx8qi */
    case 1534:  /* pred_subvnx8qi */
    case 1533:  /* pred_addvnx8qi */
    case 1437:  /* pred_indexed_ustorevnx8qivnx8di */
    case 1436:  /* pred_indexed_ostorevnx8qivnx8di */
    case 1425:  /* pred_indexed_ustorevnx8qivnx8si */
    case 1424:  /* pred_indexed_ostorevnx8qivnx8si */
    case 1413:  /* pred_indexed_ustorevnx8qivnx8hi */
    case 1412:  /* pred_indexed_ostorevnx8qivnx8hi */
    case 1401:  /* pred_indexed_ustorevnx8qivnx8qi */
    case 1400:  /* pred_indexed_ostorevnx8qivnx8qi */
    case 1255:  /* pred_indexed_uloadvnx8qi_x8_smaller_eew */
    case 1254:  /* pred_indexed_oloadvnx8qi_x8_smaller_eew */
    case 1237:  /* pred_indexed_uloadvnx8qi_x4_smaller_eew */
    case 1236:  /* pred_indexed_oloadvnx8qi_x4_smaller_eew */
    case 1199:  /* pred_indexed_uloadvnx8qi_x2_smaller_eew */
    case 1198:  /* pred_indexed_oloadvnx8qi_x2_smaller_eew */
    case 1037:  /* pred_indexed_uloadvnx8qi_same_eew */
    case 1036:  /* pred_indexed_oloadvnx8qi_same_eew */
    case 1002:  /* pred_strided_storevnx8qi */
    case 971:  /* pred_strided_loadvnx8qi */
    case 936:  /* *pred_broadcastvnx8qi */
    case 910:  /* pred_mergevnx8qi_scalar */
    case 879:  /* pred_mergevnx8qi */
    case 872:  /* pred_storevnx8bi */
    case 865:  /* pred_movvnx8bi */
    case 834:  /* pred_storevnx8qi */
    case 803:  /* pred_movvnx8qi */
    case 761:  /* *movvnx8bi */
    case 724:  /* *movvnx8qi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 106 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx8QImode));

    case 6039:  /* pred_fault_loadvnx4qi */
    case 6006:  /* pred_compressvnx4qi */
    case 5976:  /* pred_gatherei16vnx4qi */
    case 5945:  /* pred_gathervnx4qi_scalar */
    case 5914:  /* pred_gathervnx4qi */
    case 5847:  /* pred_slide1downvnx4qi */
    case 5846:  /* pred_slide1upvnx4qi */
    case 5785:  /* pred_slidedownvnx4qi */
    case 5784:  /* pred_slideupvnx4qi */
    case 5747:  /* *pred_extract_firstvnx4qi */
    case 5666:  /* pred_widen_reduc_plusuvnx4qivnx2hi */
    case 5665:  /* pred_widen_reduc_plusvnx4qivnx2hi */
    case 5630:  /* pred_widen_reduc_plusuvnx4qivnx4hi */
    case 5629:  /* pred_widen_reduc_plusvnx4qivnx4hi */
    case 5528:  /* pred_reduc_xorvnx4qivnx4qi */
    case 5527:  /* pred_reduc_orvnx4qivnx4qi */
    case 5526:  /* pred_reduc_andvnx4qivnx4qi */
    case 5525:  /* pred_reduc_minvnx4qivnx4qi */
    case 5524:  /* pred_reduc_minuvnx4qivnx4qi */
    case 5523:  /* pred_reduc_maxvnx4qivnx4qi */
    case 5522:  /* pred_reduc_maxuvnx4qivnx4qi */
    case 5521:  /* pred_reduc_sumvnx4qivnx4qi */
    case 5352:  /* pred_reduc_xorvnx4qivnx8qi */
    case 5351:  /* pred_reduc_orvnx4qivnx8qi */
    case 5350:  /* pred_reduc_andvnx4qivnx8qi */
    case 5349:  /* pred_reduc_minvnx4qivnx8qi */
    case 5348:  /* pred_reduc_minuvnx4qivnx8qi */
    case 5347:  /* pred_reduc_maxvnx4qivnx8qi */
    case 5346:  /* pred_reduc_maxuvnx4qivnx8qi */
    case 5345:  /* pred_reduc_sumvnx4qivnx8qi */
    case 4580:  /* pred_seriesvnx4qi */
    case 4558:  /* pred_iotavnx4qi */
    case 4543:  /* pred_sofvnx4bi */
    case 4542:  /* pred_sifvnx4bi */
    case 4541:  /* pred_sbfvnx4bi */
    case 4530:  /* pred_ffsvnx4bidi */
    case 4523:  /* pred_ffsvnx4bisi */
    case 4516:  /* pred_popcountvnx4bidi */
    case 4509:  /* pred_popcountvnx4bisi */
    case 4502:  /* pred_notvnx4bi */
    case 4491:  /* pred_iornotvnx4bi */
    case 4490:  /* pred_andnotvnx4bi */
    case 4473:  /* pred_nxorvnx4bi */
    case 4472:  /* pred_niorvnx4bi */
    case 4471:  /* pred_nandvnx4bi */
    case 4452:  /* pred_xorvnx4bi */
    case 4451:  /* pred_iorvnx4bi */
    case 4450:  /* pred_andvnx4bi */
    case 4431:  /* pred_widen_mul_plususvnx4hi_scalar */
    case 4416:  /* pred_widen_mul_plussuvnx4hi_scalar */
    case 4401:  /* pred_widen_mul_plussuvnx4hi */
    case 4374:  /* pred_widen_mul_plusuvnx4hi_scalar */
    case 4373:  /* pred_widen_mul_plussvnx4hi_scalar */
    case 4344:  /* pred_widen_mul_plusuvnx4hi */
    case 4343:  /* pred_widen_mul_plussvnx4hi */
    case 4307:  /* *pred_minus_mulvnx4qi_scalar */
    case 4285:  /* *pred_nmsacvnx4qi_scalar */
    case 4263:  /* *pred_nmsubvnx4qi_scalar */
    case 4241:  /* *pred_minus_mulvnx4qi */
    case 4219:  /* *pred_nmsacvnx4qi */
    case 4197:  /* *pred_nmsubvnx4qi */
    case 4163:  /* *pred_mul_plusvnx4qi_scalar */
    case 4141:  /* *pred_maccvnx4qi_scalar */
    case 4119:  /* *pred_maddvnx4qi_scalar */
    case 4097:  /* *pred_mul_plusvnx4qi */
    case 4075:  /* *pred_maccvnx4qi */
    case 4053:  /* *pred_maddvnx4qi */
    case 4003:  /* *pred_eqnevnx4qi_scalar_narrow */
    case 3985:  /* *pred_eqnevnx4qi_scalar */
    case 3967:  /* *pred_cmpvnx4qi_scalar_narrow */
    case 3949:  /* *pred_cmpvnx4qi_scalar */
    case 3927:  /* *pred_ltgevnx4qi_narrow */
    case 3905:  /* *pred_ltgevnx4qi */
    case 3883:  /* *pred_cmpvnx4qi_narrow */
    case 3861:  /* *pred_cmpvnx4qi */
    case 3834:  /* pred_narrow_clipuvnx4hi_scalar */
    case 3833:  /* pred_narrow_clipvnx4hi_scalar */
    case 3804:  /* pred_narrow_clipuvnx4hi */
    case 3803:  /* pred_narrow_clipvnx4hi */
    case 3720:  /* pred_ssravnx4qi_scalar */
    case 3719:  /* pred_ssrlvnx4qi_scalar */
    case 3639:  /* pred_smulvnx4qi_scalar */
    case 3638:  /* pred_asubvnx4qi_scalar */
    case 3637:  /* pred_asubuvnx4qi_scalar */
    case 3636:  /* pred_aaddvnx4qi_scalar */
    case 3635:  /* pred_aadduvnx4qi_scalar */
    case 3491:  /* pred_ssravnx4qi */
    case 3490:  /* pred_ssrlvnx4qi */
    case 3489:  /* pred_smulvnx4qi */
    case 3488:  /* pred_asubvnx4qi */
    case 3487:  /* pred_asubuvnx4qi */
    case 3486:  /* pred_aaddvnx4qi */
    case 3485:  /* pred_aadduvnx4qi */
    case 3408:  /* pred_ussubvnx4qi_scalar */
    case 3407:  /* pred_sssubvnx4qi_scalar */
    case 3372:  /* pred_usaddvnx4qi_scalar */
    case 3371:  /* pred_ssaddvnx4qi_scalar */
    case 3290:  /* pred_ussubvnx4qi */
    case 3289:  /* pred_usaddvnx4qi */
    case 3288:  /* pred_sssubvnx4qi */
    case 3287:  /* pred_ssaddvnx4qi */
    case 3266:  /* pred_truncvnx4hi */
    case 3239:  /* pred_narrow_lshrvnx4hi_scalar */
    case 3238:  /* pred_narrow_ashrvnx4hi_scalar */
    case 3209:  /* pred_narrow_lshrvnx4hi */
    case 3208:  /* pred_narrow_ashrvnx4hi */
    case 3179:  /* pred_zero_extendvnx4hi */
    case 3178:  /* pred_extendvnx4hi */
    case 3161:  /* pred_widen_mulsuvnx4hi_scalar */
    case 3146:  /* pred_widen_mulsuvnx4hi */
    case 3095:  /* pred_single_widen_subuvnx4hi_scalar */
    case 3094:  /* pred_single_widen_adduvnx4hi_scalar */
    case 3093:  /* pred_single_widen_subsvnx4hi_scalar */
    case 3092:  /* pred_single_widen_addsvnx4hi_scalar */
    case 3035:  /* pred_single_widen_subuvnx4hi */
    case 3034:  /* pred_single_widen_adduvnx4hi */
    case 3033:  /* pred_single_widen_subsvnx4hi */
    case 3032:  /* pred_single_widen_addsvnx4hi */
    case 2951:  /* pred_dual_widen_muluvnx4hi_scalar */
    case 2950:  /* pred_dual_widen_subuvnx4hi_scalar */
    case 2949:  /* pred_dual_widen_adduvnx4hi_scalar */
    case 2948:  /* pred_dual_widen_mulsvnx4hi_scalar */
    case 2947:  /* pred_dual_widen_subsvnx4hi_scalar */
    case 2946:  /* pred_dual_widen_addsvnx4hi_scalar */
    case 2861:  /* pred_dual_widen_muluvnx4hi */
    case 2860:  /* pred_dual_widen_subuvnx4hi */
    case 2859:  /* pred_dual_widen_adduvnx4hi */
    case 2858:  /* pred_dual_widen_mulsvnx4hi */
    case 2857:  /* pred_dual_widen_subsvnx4hi */
    case 2856:  /* pred_dual_widen_addsvnx4hi */
    case 2749:  /* pred_one_cmplvnx4qi */
    case 2748:  /* pred_negvnx4qi */
    case 2712:  /* pred_msbcvnx4qi_overflow_scalar */
    case 2694:  /* pred_madcvnx4qi_overflow_scalar */
    case 2672:  /* pred_msbcvnx4qi_overflow */
    case 2650:  /* pred_madcvnx4qi_overflow */
    case 2616:  /* pred_msbcvnx4qi_scalar */
    case 2598:  /* pred_madcvnx4qi_scalar */
    case 2576:  /* pred_msbcvnx4qi */
    case 2554:  /* pred_madcvnx4qi */
    case 2520:  /* pred_sbcvnx4qi_scalar */
    case 2502:  /* pred_adcvnx4qi_scalar */
    case 2480:  /* pred_sbcvnx4qi */
    case 2458:  /* pred_adcvnx4qi */
    case 2386:  /* pred_mulhsuvnx4qi_scalar */
    case 2385:  /* pred_mulhuvnx4qi_scalar */
    case 2384:  /* pred_mulhvnx4qi_scalar */
    case 2320:  /* pred_mulhsuvnx4qi */
    case 2319:  /* pred_mulhuvnx4qi */
    case 2318:  /* pred_mulhvnx4qi */
    case 2176:  /* pred_subvnx4qi_reverse_scalar */
    case 2098:  /* pred_umodvnx4qi_scalar */
    case 2097:  /* pred_modvnx4qi_scalar */
    case 2096:  /* pred_udivvnx4qi_scalar */
    case 2095:  /* pred_divvnx4qi_scalar */
    case 2094:  /* pred_subvnx4qi_scalar */
    case 1948:  /* pred_mulvnx4qi_scalar */
    case 1947:  /* pred_uminvnx4qi_scalar */
    case 1946:  /* pred_sminvnx4qi_scalar */
    case 1945:  /* pred_umaxvnx4qi_scalar */
    case 1944:  /* pred_smaxvnx4qi_scalar */
    case 1943:  /* pred_xorvnx4qi_scalar */
    case 1942:  /* pred_iorvnx4qi_scalar */
    case 1941:  /* pred_andvnx4qi_scalar */
    case 1940:  /* pred_addvnx4qi_scalar */
    case 1864:  /* pred_lshrvnx4qi_scalar */
    case 1863:  /* pred_ashrvnx4qi_scalar */
    case 1862:  /* pred_ashlvnx4qi_scalar */
    case 1532:  /* pred_umodvnx4qi */
    case 1531:  /* pred_modvnx4qi */
    case 1530:  /* pred_udivvnx4qi */
    case 1529:  /* pred_divvnx4qi */
    case 1528:  /* pred_mulvnx4qi */
    case 1527:  /* pred_uminvnx4qi */
    case 1526:  /* pred_sminvnx4qi */
    case 1525:  /* pred_umaxvnx4qi */
    case 1524:  /* pred_smaxvnx4qi */
    case 1523:  /* pred_lshrvnx4qi */
    case 1522:  /* pred_ashrvnx4qi */
    case 1521:  /* pred_ashlvnx4qi */
    case 1520:  /* pred_xorvnx4qi */
    case 1519:  /* pred_iorvnx4qi */
    case 1518:  /* pred_andvnx4qi */
    case 1517:  /* pred_subvnx4qi */
    case 1516:  /* pred_addvnx4qi */
    case 1389:  /* pred_indexed_ustorevnx4qivnx4di */
    case 1388:  /* pred_indexed_ostorevnx4qivnx4di */
    case 1377:  /* pred_indexed_ustorevnx4qivnx4si */
    case 1376:  /* pred_indexed_ostorevnx4qivnx4si */
    case 1365:  /* pred_indexed_ustorevnx4qivnx4hi */
    case 1364:  /* pred_indexed_ostorevnx4qivnx4hi */
    case 1353:  /* pred_indexed_ustorevnx4qivnx4qi */
    case 1352:  /* pred_indexed_ostorevnx4qivnx4qi */
    case 1253:  /* pred_indexed_uloadvnx4qi_x8_smaller_eew */
    case 1252:  /* pred_indexed_oloadvnx4qi_x8_smaller_eew */
    case 1235:  /* pred_indexed_uloadvnx4qi_x4_smaller_eew */
    case 1234:  /* pred_indexed_oloadvnx4qi_x4_smaller_eew */
    case 1197:  /* pred_indexed_uloadvnx4qi_x2_smaller_eew */
    case 1196:  /* pred_indexed_oloadvnx4qi_x2_smaller_eew */
    case 1035:  /* pred_indexed_uloadvnx4qi_same_eew */
    case 1034:  /* pred_indexed_oloadvnx4qi_same_eew */
    case 1001:  /* pred_strided_storevnx4qi */
    case 970:  /* pred_strided_loadvnx4qi */
    case 935:  /* *pred_broadcastvnx4qi */
    case 909:  /* pred_mergevnx4qi_scalar */
    case 878:  /* pred_mergevnx4qi */
    case 871:  /* pred_storevnx4bi */
    case 864:  /* pred_movvnx4bi */
    case 833:  /* pred_storevnx4qi */
    case 802:  /* pred_movvnx4qi */
    case 760:  /* *movvnx4bi */
    case 753:  /* *movvnx4qi_fract */
    case 723:  /* *movvnx4qi_whole */
      extract_constrain_insn_cached (insn);
      return 
#line 104 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx4QImode));

    case 793:  /* vsetvlsi */
    case 794:  /* vsetvldi */
      extract_constrain_insn_cached (insn);
      return 
#line 877 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[3]));

    case 796:  /* vsetvl_discard_resultsi */
    case 797:  /* vsetvl_discard_resultdi */
      extract_constrain_insn_cached (insn);
      return 
#line 876 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(INTVAL (operands[2]));

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      extract_constrain_insn_cached (insn);
      if (((cached_mode = get_attr_mode (insn)) == MODE_VNX1QI) || (cached_mode == MODE_VNX1BI))
        {
	  return 
#line 100 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx1QImode));
        }
      else if ((cached_mode == MODE_VNX2QI) || (cached_mode == MODE_VNX2BI))
        {
	  return 
#line 102 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx2QImode));
        }
      else if ((cached_mode == MODE_VNX4QI) || (cached_mode == MODE_VNX4BI))
        {
	  return 
#line 104 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx4QImode));
        }
      else if ((cached_mode == MODE_VNX8QI) || (cached_mode == MODE_VNX8BI))
        {
	  return 
#line 106 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx8QImode));
        }
      else if ((cached_mode == MODE_VNX16QI) || (cached_mode == MODE_VNX16BI))
        {
	  return 
#line 108 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx16QImode));
        }
      else if ((cached_mode == MODE_VNX32QI) || (cached_mode == MODE_VNX32BI))
        {
	  return 
#line 110 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx32QImode));
        }
      else if ((cached_mode == MODE_VNX64QI) || (cached_mode == MODE_VNX64BI))
        {
	  return 
#line 112 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx64QImode));
        }
      else if (cached_mode == MODE_VNX1HI)
        {
	  return 
#line 114 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx1HImode));
        }
      else if (cached_mode == MODE_VNX2HI)
        {
	  return 
#line 116 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx2HImode));
        }
      else if (cached_mode == MODE_VNX4HI)
        {
	  return 
#line 118 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx4HImode));
        }
      else if (cached_mode == MODE_VNX8HI)
        {
	  return 
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx8HImode));
        }
      else if (cached_mode == MODE_VNX16HI)
        {
	  return 
#line 122 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx16HImode));
        }
      else if (cached_mode == MODE_VNX32HI)
        {
	  return 
#line 124 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx32HImode));
        }
      else if ((cached_mode == MODE_VNX1SI) || (cached_mode == MODE_VNX1SF))
        {
	  return 
#line 126 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx1SImode));
        }
      else if ((cached_mode == MODE_VNX2SI) || (cached_mode == MODE_VNX2SF))
        {
	  return 
#line 128 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx2SImode));
        }
      else if ((cached_mode == MODE_VNX4SI) || (cached_mode == MODE_VNX4SF))
        {
	  return 
#line 130 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx4SImode));
        }
      else if ((cached_mode == MODE_VNX8SI) || (cached_mode == MODE_VNX8SF))
        {
	  return 
#line 132 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx8SImode));
        }
      else if ((cached_mode == MODE_VNX16SI) || (cached_mode == MODE_VNX16SF))
        {
	  return 
#line 134 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx16SImode));
        }
      else if ((cached_mode == MODE_VNX1DI) || (cached_mode == MODE_VNX1DF))
        {
	  return 
#line 136 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx1DImode));
        }
      else if ((cached_mode == MODE_VNX2DI) || (cached_mode == MODE_VNX2DF))
        {
	  return 
#line 138 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx2DImode));
        }
      else if ((cached_mode == MODE_VNX4DI) || (cached_mode == MODE_VNX4DF))
        {
	  return 
#line 140 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx4DImode));
        }
      else if ((cached_mode == MODE_VNX8DI) || (cached_mode == MODE_VNX8DF))
        {
	  return 
#line 142 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/riscv/vector.md"
(riscv_vector::get_vlmul(E_VNx8DImode));
        }
      else
        {
	  return 255 /* 0xff */;
        }

    default:
      return 255 /* 0xff */;

    }
}

int
eligible_for_delay (rtx_insn *delay_insn ATTRIBUTE_UNUSED, int slot, 
		   rtx_insn *candidate_insn, int flags ATTRIBUTE_UNUSED)
{
  rtx_insn *insn ATTRIBUTE_UNUSED;

  if (num_delay_slots (delay_insn) == 0)
    return 0;
  gcc_assert (slot < 0);

  if (!INSN_P (candidate_insn))
    return 0;

  insn = candidate_insn;
  switch (slot)
    {
    default:
      gcc_unreachable ();
    }
}

int
eligible_for_annul_true (rtx_insn *delay_insn ATTRIBUTE_UNUSED,
    int slot ATTRIBUTE_UNUSED,
    rtx_insn *candidate_insn ATTRIBUTE_UNUSED,
    int flags ATTRIBUTE_UNUSED)
{
  return 0;
}

int
eligible_for_annul_false (rtx_insn *delay_insn ATTRIBUTE_UNUSED,
    int slot ATTRIBUTE_UNUSED,
    rtx_insn *candidate_insn ATTRIBUTE_UNUSED,
    int flags ATTRIBUTE_UNUSED)
{
  return 0;
}

int
const_num_delay_slots (rtx_insn *insn)
{
  switch (recog_memoized (insn))
    {
    default:
      return 1;
    }
}

EXPORTED_CONST int length_unit_log = 0;
